package com.temboo.Library.AdMob;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CampaignSearch

Search for ad campaigns using IDs.
*/
public class CampaignSearch extends Choreography {

	/**
	Create a new instance of the CampaignSearch Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CampaignSearch(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/AdMob/CampaignSearch"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CampaignSearchInputSet
	*/
	public CampaignSearchInputSet newInputSet() {
		return new CampaignSearchInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CampaignSearchResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CampaignSearchResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CampaignSearch
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CampaignSearchInputSet extends InputSet {
		/** 
		Set the value of the CampaignID input for this Choreo. 

		@param String - (optional, string) Search for ad campaigns using this ID.
		*/
		public void set_CampaignID(String value) {
			this.setInput("CampaignID", value);
		}



		/** 
		Set the value of the ClientKey input for this Choreo. 

		@param String - (required, string) The Client Key provided by AdMob.
		*/
		public void set_ClientKey(String value) {
			this.setInput("ClientKey", value);
		}



		/** 
		Set the value of the Email input for this Choreo. 

		@param String - (conditional, string) Your AdMob username. Required unless providing a valid Token input.
		*/
		public void set_Email(String value) {
			this.setInput("Email", value);
		}



		/** 
		Set the value of the IncludeDeleted input for this Choreo. 

		@param Boolean - (optional, boolean) If set to 1, ad groups that have been deleted will be included in the search result.
		*/
		public void set_IncludeDeleted(Boolean value) {
			this.setInput("IncludeDeleted", value);
		}

		/** 
		Set the value of the IncludeDeleted input for this Choreo as a String. 

		@param String - (optional, boolean) If set to 1, ad groups that have been deleted will be included in the search result.
		*/
		public void set_IncludeDeleted(String value) {
			this.setInput("IncludeDeleted", value);	
		}

		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (conditional, password) Your Admob password. Required unless providing a valid Token input.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that your want the response to be in. Accepted values are: xml (the default) and json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the Token input for this Choreo. 

		@param String - (conditional, string) If provided, the Choreo will use the token to authenticate. If the token is expired or not provided, the Choreo will relogin and retrieve a new token when Email and Password are supplied.
		*/
		public void set_Token(String value) {
			this.setInput("Token", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CampaignSearch Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CampaignSearchResultSet extends ResultSet {
		public CampaignSearchResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from AdMob. Corresponds to the ResponseFormat input. Defaults to xml.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** 
		Retrieve the value for the "Token" output from this Choreo execution

		@return String - (conditional, string) If provided, the Choreo will use the token to authenticate. If the token is expired or not provided, the Choreo will relogin and retrieve a new token when Email and Password are supplied.
		*/
		public String get_Token() {
			return this.getResult("Token");
		}
	}
	
}
