package com.temboo.Library.AdMob;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CampaignStats

Retrieve campaign stats by ID.
*/
public class CampaignStats extends Choreography {

	/**
	Create a new instance of the CampaignStats Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CampaignStats(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/AdMob/CampaignStats"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CampaignStatsInputSet
	*/
	public CampaignStatsInputSet newInputSet() {
		return new CampaignStatsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CampaignStatsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CampaignStatsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CampaignStats
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CampaignStatsInputSet extends InputSet {
		/** 
		Set the value of the CampaignID input for this Choreo. 

		@param String - (required, string) Search for ad campaigns using this ID.
		*/
		public void set_CampaignID(String value) {
			this.setInput("CampaignID", value);
		}



		/** 
		Set the value of the ClientKey input for this Choreo. 

		@param String - (required, string) The Client Key provided by AdMob.
		*/
		public void set_ClientKey(String value) {
			this.setInput("ClientKey", value);
		}



		/** 
		Set the value of the Email input for this Choreo. 

		@param String - (conditional, string) Your AdMob username. Required unless providing a valid Token input.
		*/
		public void set_Email(String value) {
			this.setInput("Email", value);
		}



		/** 
		Set the value of the EndDate input for this Choreo. 

		@param String - (required, date) Enter search end date in following format: 2011-09-12
		*/
		public void set_EndDate(String value) {
			this.setInput("EndDate", value);
		}



		/** 
		Set the value of the ObjectDimension input for this Choreo. 

		@param String - (optional, string) Specify a campaign to group and narrow your search.
		*/
		public void set_ObjectDimension(String value) {
			this.setInput("ObjectDimension", value);
		}



		/** 
		Set the value of the OrderBy input for this Choreo. 

		@param String - (optional, string) Order by the number of impressions. Example: [impressions]=asc
		*/
		public void set_OrderBy(String value) {
			this.setInput("OrderBy", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (conditional, password) Your Admob password. Required unless providing a valid Token input.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that your want the response to be in. Accepted values are: xml (the default) and json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the StartDate input for this Choreo. 

		@param String - (required, date) Enter search start date in following format: 2011-09-12
		*/
		public void set_StartDate(String value) {
			this.setInput("StartDate", value);
		}



		/** 
		Set the value of the TimeDimension input for this Choreo. 

		@param String - (optional, string) Specify whether stats should be grouped by day, week, or month.
		*/
		public void set_TimeDimension(String value) {
			this.setInput("TimeDimension", value);
		}



		/** 
		Set the value of the Token input for this Choreo. 

		@param String - (conditional, string) If provided, the Choreo will use the token to authenticate. If the token is expired or not provided, the Choreo will relogin and retrieve a new token when Email and Password are supplied.
		*/
		public void set_Token(String value) {
			this.setInput("Token", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CampaignStats Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CampaignStatsResultSet extends ResultSet {
		public CampaignStatsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from AdMob. Corresponds to the ResponseFormat input. Defaults to xml.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** 
		Retrieve the value for the "Token" output from this Choreo execution

		@return String - (conditional, string) If provided, the Choreo will use the token to authenticate. If the token is expired or not provided, the Choreo will relogin and retrieve a new token when Email and Password are supplied.
		*/
		public String get_Token() {
			return this.getResult("Token");
		}
	}
	
}
