package com.temboo.Library.AdMob;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Login

Log into AdMob service and obtain an authorization token.
*/
public class Login extends Choreography {

	/**
	Create a new instance of the Login Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Login(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/AdMob/Login"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return LoginInputSet
	*/
	public LoginInputSet newInputSet() {
		return new LoginInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public LoginResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new LoginResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Login
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class LoginInputSet extends InputSet {
		/** 
		Set the value of the ClientKey input for this Choreo. 

		@param String - (required, string) The Client Key provided by AdMob.
		*/
		public void set_ClientKey(String value) {
			this.setInput("ClientKey", value);
		}



		/** 
		Set the value of the Email input for this Choreo. 

		@param String - (required, string) Your AdMob username.
		*/
		public void set_Email(String value) {
			this.setInput("Email", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Admob password.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Login Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class LoginResultSet extends ResultSet {
		public LoginResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from AdMob in XML format
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** 
		Retrieve the value for the "Token" output from this Choreo execution

		@return String - (string) The token obtained by running this choreo.
		*/
		public String get_Token() {
			return this.getResult("Token");
		}
	}
	
}
