package com.temboo.Library.AdMob;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Logout

Logout from AdMob service.
*/
public class Logout extends Choreography {

	/**
	Create a new instance of the Logout Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Logout(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/AdMob/Logout"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return LogoutInputSet
	*/
	public LogoutInputSet newInputSet() {
		return new LogoutInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public LogoutResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new LogoutResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Logout
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class LogoutInputSet extends InputSet {
		/** 
		Set the value of the ClientKey input for this Choreo. 

		@param String - (required, string) The Client Key provided by AdMob.
		*/
		public void set_ClientKey(String value) {
			this.setInput("ClientKey", value);
		}



		/** 
		Set the value of the Token input for this Choreo. 

		@param String - (required, string) The security token returned by the Login Choreo.
		*/
		public void set_Token(String value) {
			this.setInput("Token", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Logout Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class LogoutResultSet extends ResultSet {
		public LogoutResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from AdMob in XML format
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
