package com.temboo.Library.Amazon.EC2;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
AttachVolume

Attaches an Amazon EBS volume to a running instance and exposes it as the specified device.
*/
public class AttachVolume extends Choreography {

	/**
	Create a new instance of the AttachVolume Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public AttachVolume(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/EC2/AttachVolume"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return AttachVolumeInputSet
	*/
	public AttachVolumeInputSet newInputSet() {
		return new AttachVolumeInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public AttachVolumeResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new AttachVolumeResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the AttachVolume
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class AttachVolumeInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the Device input for this Choreo. 

		@param String - (required, string) How the device is exposed to the instance (i.e. " /dev/sdh" or "xvdh").
		*/
		public void set_Device(String value) {
			this.setInput("Device", value);
		}



		/** 
		Set the value of the InstanceId input for this Choreo. 

		@param String - (required, string) The ID of the instance to which the volume attaches. The volume and instance must be within the same Availability Zone and the instance must be running.
		*/
		public void set_InstanceId(String value) {
			this.setInput("InstanceId", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the VolumeId input for this Choreo. 

		@param String - (required, string) The ID of the Amazon EBS volume. The volume and instance must be within the same Availability Zone and the instance must be running.
		*/
		public void set_VolumeId(String value) {
			this.setInput("VolumeId", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the AttachVolume Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class AttachVolumeResultSet extends ResultSet {
		public AttachVolumeResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Amazon.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
