package com.temboo.Library.Amazon.EC2;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CreateSecurityGroup

Creates a new EC2 security group.
*/
public class CreateSecurityGroup extends Choreography {

	/**
	Create a new instance of the CreateSecurityGroup Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CreateSecurityGroup(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/EC2/CreateSecurityGroup"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CreateSecurityGroupInputSet
	*/
	public CreateSecurityGroupInputSet newInputSet() {
		return new CreateSecurityGroupInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CreateSecurityGroupResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CreateSecurityGroupResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CreateSecurityGroup
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CreateSecurityGroupInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the GroupDescription input for this Choreo. 

		@param String - (required, string) A description for the security group that that you want to create.
		*/
		public void set_GroupDescription(String value) {
			this.setInput("GroupDescription", value);
		}



		/** 
		Set the value of the GroupName input for this Choreo. 

		@param String - (required, string) A name for the security group to create.
		*/
		public void set_GroupName(String value) {
			this.setInput("GroupName", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the VpcId input for this Choreo. 

		@param String - (optional, string) The ID of the VPC. Required for EC2-VPC.
		*/
		public void set_VpcId(String value) {
			this.setInput("VpcId", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CreateSecurityGroup Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CreateSecurityGroupResultSet extends ResultSet {
		public CreateSecurityGroupResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Amazon.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
