package com.temboo.Library.Amazon.EC2;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
DescribeKeyPairs

Describes one or more of your key pairs.
*/
public class DescribeKeyPairs extends Choreography {

	/**
	Create a new instance of the DescribeKeyPairs Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DescribeKeyPairs(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/EC2/DescribeKeyPairs"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DescribeKeyPairsInputSet
	*/
	public DescribeKeyPairsInputSet newInputSet() {
		return new DescribeKeyPairsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DescribeKeyPairsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DescribeKeyPairsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DescribeKeyPairs
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DescribeKeyPairsInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the FilterName input for this Choreo. 

		@param String - (optional, string) The name of a supported filter to narrow the results with.
		*/
		public void set_FilterName(String value) {
			this.setInput("FilterName", value);
		}



		/** 
		Set the value of the FilterValue input for this Choreo. 

		@param String - (optional, string) A value for the specified filter.
		*/
		public void set_FilterValue(String value) {
			this.setInput("FilterValue", value);
		}



		/** 
		Set the value of the KeyName input for this Choreo. 

		@param String - (optional, string) One or more key pair names to return. This can be a comma-separated list of up to 10 key pair namess.
		*/
		public void set_KeyName(String value) {
			this.setInput("KeyName", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DescribeKeyPairs Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DescribeKeyPairsResultSet extends ResultSet {
		public DescribeKeyPairsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Amazon.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
