package com.temboo.Library.Amazon.EC2;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
DescribeSecurityGroups

Returns security group information associated with your AWS Account.
*/
public class DescribeSecurityGroups extends Choreography {

	/**
	Create a new instance of the DescribeSecurityGroups Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DescribeSecurityGroups(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/EC2/DescribeSecurityGroups"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DescribeSecurityGroupsInputSet
	*/
	public DescribeSecurityGroupsInputSet newInputSet() {
		return new DescribeSecurityGroupsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DescribeSecurityGroupsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DescribeSecurityGroupsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DescribeSecurityGroups
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DescribeSecurityGroupsInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the FilterName input for this Choreo. 

		@param String - (optional, string) The name of a supported filter to narrow results with.
		*/
		public void set_FilterName(String value) {
			this.setInput("FilterName", value);
		}



		/** 
		Set the value of the FilterValue input for this Choreo. 

		@param String - (optional, string) A value for the specified filter.
		*/
		public void set_FilterValue(String value) {
			this.setInput("FilterValue", value);
		}



		/** 
		Set the value of the GroupId input for this Choreo. 

		@param String - (optional, string) One or more security group IDs.  This can be a comma-separated list of up to 10 GroupIDs.  If no group names nor group IDs supplied, returns all groups.
		*/
		public void set_GroupId(String value) {
			this.setInput("GroupId", value);
		}



		/** 
		Set the value of the GroupName input for this Choreo. 

		@param String - (optional, string) One or more security group names. This can be a comma-separated list of up to 10 group names.  If no group names nor group IDs supplied, returns all groups.
		*/
		public void set_GroupName(String value) {
			this.setInput("GroupName", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DescribeSecurityGroups Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DescribeSecurityGroupsResultSet extends ResultSet {
		public DescribeSecurityGroupsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Amazon.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
