package com.temboo.Library.Amazon.EC2;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
DetachVolume

Detaches an Amazon EBS volume from an instance.
*/
public class DetachVolume extends Choreography {

	/**
	Create a new instance of the DetachVolume Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DetachVolume(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/EC2/DetachVolume"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DetachVolumeInputSet
	*/
	public DetachVolumeInputSet newInputSet() {
		return new DetachVolumeInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DetachVolumeResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DetachVolumeResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DetachVolume
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DetachVolumeInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the Device input for this Choreo. 

		@param String - (optional, string) The device name.
		*/
		public void set_Device(String value) {
			this.setInput("Device", value);
		}



		/** 
		Set the value of the Force input for this Choreo. 

		@param Boolean - (required, boolean) Forces detachment if the previous detachment attempt did not occur cleanly. Use this option only as a last resort to detach a volume from a failed instance. Defaults to false.
		*/
		public void set_Force(Boolean value) {
			this.setInput("Force", value);
		}

		/** 
		Set the value of the Force input for this Choreo as a String. 

		@param String - (required, boolean) Forces detachment if the previous detachment attempt did not occur cleanly. Use this option only as a last resort to detach a volume from a failed instance. Defaults to false.
		*/
		public void set_Force(String value) {
			this.setInput("Force", value);	
		}

		/** 
		Set the value of the InstanceId input for this Choreo. 

		@param String - (optional, string) The ID of the instance.
		*/
		public void set_InstanceId(String value) {
			this.setInput("InstanceId", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the VolumeId input for this Choreo. 

		@param String - (required, string) The ID of the volume.
		*/
		public void set_VolumeId(String value) {
			this.setInput("VolumeId", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DetachVolume Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DetachVolumeResultSet extends ResultSet {
		public DetachVolumeResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Amazon.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
