package com.temboo.Library.Amazon.EC2;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ModifyImageAttribute

Modifies an attribute of an AMI.
*/
public class ModifyImageAttribute extends Choreography {

	/**
	Create a new instance of the ModifyImageAttribute Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ModifyImageAttribute(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/EC2/ModifyImageAttribute"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ModifyImageAttributeInputSet
	*/
	public ModifyImageAttributeInputSet newInputSet() {
		return new ModifyImageAttributeInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ModifyImageAttributeResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ModifyImageAttributeResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ModifyImageAttribute
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ModifyImageAttributeInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the AddGroup input for this Choreo. 

		@param String - (optional, string) Adds the specified group to the image's list of launch permissions. The only valid value is "all".
		*/
		public void set_AddGroup(String value) {
			this.setInput("AddGroup", value);
		}



		/** 
		Set the value of the AddUserId input for this Choreo. 

		@param String - (optional, string) Adds the specified AWS account ID to the AMI's list of launch permissions.
		*/
		public void set_AddUserId(String value) {
			this.setInput("AddUserId", value);
		}



		/** 
		Set the value of the Description input for this Choreo. 

		@param String - (optional, string) Changes the AMI's description to the specified value.
		*/
		public void set_Description(String value) {
			this.setInput("Description", value);
		}



		/** 
		Set the value of the ImageId input for this Choreo. 

		@param String - (required, string) The AMI ID.
		*/
		public void set_ImageId(String value) {
			this.setInput("ImageId", value);
		}



		/** 
		Set the value of the ProductCode input for this Choreo. 

		@param String - (optional, string) Adds the specified product code to the specified Amazon S3-backed AMI. Once you add a product code to an AMI, it can't be removed.
		*/
		public void set_ProductCode(String value) {
			this.setInput("ProductCode", value);
		}



		/** 
		Set the value of the RemoveGroup input for this Choreo. 

		@param String - (optional, string) Removes the specified group from the image's list of launch permissions. The only valid value is "all".
		*/
		public void set_RemoveGroup(String value) {
			this.setInput("RemoveGroup", value);
		}



		/** 
		Set the value of the RemoveUserId input for this Choreo. 

		@param String - (optional, string) Removes the specified AWS account ID from the AMI's list of launch permissions.
		*/
		public void set_RemoveUserId(String value) {
			this.setInput("RemoveUserId", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ModifyImageAttribute Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ModifyImageAttributeResultSet extends ResultSet {
		public ModifyImageAttributeResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Amazon.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
