package com.temboo.Library.Amazon.IAM;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CreateInstanceProfile

Creates a new instance profile.
*/
public class CreateInstanceProfile extends Choreography {

	/**
	Create a new instance of the CreateInstanceProfile Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CreateInstanceProfile(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/IAM/CreateInstanceProfile"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CreateInstanceProfileInputSet
	*/
	public CreateInstanceProfileInputSet newInputSet() {
		return new CreateInstanceProfileInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CreateInstanceProfileResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CreateInstanceProfileResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CreateInstanceProfile
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CreateInstanceProfileInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the InstanceProfileName input for this Choreo. 

		@param String - (required, string) Name of the instance profile to create.
		*/
		public void set_InstanceProfileName(String value) {
			this.setInput("InstanceProfileName", value);
		}



		/** 
		Set the value of the Path input for this Choreo. 

		@param String - (optional, string) The path for the user name. If it is not included, it defaults to a slash (/).
		*/
		public void set_Path(String value) {
			this.setInput("Path", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CreateInstanceProfile Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CreateInstanceProfileResultSet extends ResultSet {
		public CreateInstanceProfileResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Amazon.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
