package com.temboo.Library.Amazon.IAM;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
DeleteUserPolicy

Deletes the specified policy associated with the specified user.
*/
public class DeleteUserPolicy extends Choreography {

	/**
	Create a new instance of the DeleteUserPolicy Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DeleteUserPolicy(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/IAM/DeleteUserPolicy"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DeleteUserPolicyInputSet
	*/
	public DeleteUserPolicyInputSet newInputSet() {
		return new DeleteUserPolicyInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DeleteUserPolicyResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DeleteUserPolicyResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DeleteUserPolicy
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DeleteUserPolicyInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the PolicyName input for this Choreo. 

		@param String - (required, string) Name of the user policy document you would like to delete.
		*/
		public void set_PolicyName(String value) {
			this.setInput("PolicyName", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the UserName input for this Choreo. 

		@param String - (required, string) Name of the user to delete the specified policy for.
		*/
		public void set_UserName(String value) {
			this.setInput("UserName", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DeleteUserPolicy Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DeleteUserPolicyResultSet extends ResultSet {
		public DeleteUserPolicyResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Amazon.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
