package com.temboo.Library.Amazon.IAM;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ListMFADevices

Lists the MFA devices. If the request includes the user name, then this action lists all the MFA devices associated with the specified user name. If you do not specify a user name, IAM determines the user name implicitly based on the AWS Access Key ID signing the request.
*/
public class ListMFADevices extends Choreography {

	/**
	Create a new instance of the ListMFADevices Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListMFADevices(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/IAM/ListMFADevices"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListMFADevicesInputSet
	*/
	public ListMFADevicesInputSet newInputSet() {
		return new ListMFADevicesInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListMFADevicesResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListMFADevicesResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListMFADevices
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListMFADevicesInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the Marker input for this Choreo. 

		@param String - (optional, string) Used for pagination to indicate the starting point of the results to return.
		*/
		public void set_Marker(String value) {
			this.setInput("Marker", value);
		}



		/** 
		Set the value of the MaxItems input for this Choreo. 

		@param Integer - (optional, integer) Used for pagination to limit the number of results returned. Defaults to 100.
		*/
		public void set_MaxItems(Integer value) {
			this.setInput("MaxItems", value);
		}

		/** 
		Set the value of the MaxItems input for this Choreo as a String. 

		@param String - (optional, integer) Used for pagination to limit the number of results returned. Defaults to 100.
		*/
		public void set_MaxItems(String value) {
			this.setInput("MaxItems", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the UserName input for this Choreo. 

		@param String - (optional, string) Name of the user whose MFA devices you want to list.
		*/
		public void set_UserName(String value) {
			this.setInput("UserName", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListMFADevices Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListMFADevicesResultSet extends ResultSet {
		public ListMFADevicesResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Amazon.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
