package com.temboo.Library.Amazon.IAM;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ListVirtualMFADevices

Lists the virtual MFA devices under the AWS account.
*/
public class ListVirtualMFADevices extends Choreography {

	/**
	Create a new instance of the ListVirtualMFADevices Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListVirtualMFADevices(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/IAM/ListVirtualMFADevices"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListVirtualMFADevicesInputSet
	*/
	public ListVirtualMFADevicesInputSet newInputSet() {
		return new ListVirtualMFADevicesInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListVirtualMFADevicesResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListVirtualMFADevicesResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListVirtualMFADevices
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListVirtualMFADevicesInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the AssignmentStatus input for this Choreo. 

		@param String - (optional, string) Filters by the whether the device is assigned or unassigned to a specific user. Valid values: "Unassigned", "Assigned" or "Any" (default - both assigned and unassigned devices).
		*/
		public void set_AssignmentStatus(String value) {
			this.setInput("AssignmentStatus", value);
		}



		/** 
		Set the value of the Marker input for this Choreo. 

		@param String - (optional, string) Used for pagination to indicate the starting point of the results to return.
		*/
		public void set_Marker(String value) {
			this.setInput("Marker", value);
		}



		/** 
		Set the value of the MaxItems input for this Choreo. 

		@param Integer - (optional, integer) Used for pagination to limit the number of results returned. Defaults to 100.
		*/
		public void set_MaxItems(Integer value) {
			this.setInput("MaxItems", value);
		}

		/** 
		Set the value of the MaxItems input for this Choreo as a String. 

		@param String - (optional, integer) Used for pagination to limit the number of results returned. Defaults to 100.
		*/
		public void set_MaxItems(String value) {
			this.setInput("MaxItems", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListVirtualMFADevices Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListVirtualMFADevicesResultSet extends ResultSet {
		public ListVirtualMFADevicesResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Amazon.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
