package com.temboo.Library.Amazon.IAM;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
UpdateLoginProfile

Changes the password for the specified user.
*/
public class UpdateLoginProfile extends Choreography {

	/**
	Create a new instance of the UpdateLoginProfile Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public UpdateLoginProfile(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/IAM/UpdateLoginProfile"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return UpdateLoginProfileInputSet
	*/
	public UpdateLoginProfileInputSet newInputSet() {
		return new UpdateLoginProfileInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public UpdateLoginProfileResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new UpdateLoginProfileResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the UpdateLoginProfile
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class UpdateLoginProfileInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the MustChangePassword input for this Choreo. 

		@param Boolean - (optional, boolean) Specifies whether or not the user should be required to change their password immediately.  Valid values are true/false or 1/0.
		*/
		public void set_MustChangePassword(Boolean value) {
			this.setInput("MustChangePassword", value);
		}

		/** 
		Set the value of the MustChangePassword input for this Choreo as a String. 

		@param String - (optional, boolean) Specifies whether or not the user should be required to change their password immediately.  Valid values are true/false or 1/0.
		*/
		public void set_MustChangePassword(String value) {
			this.setInput("MustChangePassword", value);	
		}

		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, string) The new password for the user name.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the UserName input for this Choreo. 

		@param String - (required, string) The name of the user to update.
		*/
		public void set_UserName(String value) {
			this.setInput("UserName", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the UpdateLoginProfile Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class UpdateLoginProfileResultSet extends ResultSet {
		public UpdateLoginProfileResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Amazon.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
