package com.temboo.Library.Amazon.Marketplace.Feeds;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
AddOrUpdateInventoryItem

Add or update an individual inventory listing.
*/
public class AddOrUpdateInventoryItem extends Choreography {

	/**
	Create a new instance of the AddOrUpdateInventoryItem Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public AddOrUpdateInventoryItem(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/Marketplace/Feeds/AddOrUpdateInventoryItem"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return AddOrUpdateInventoryItemInputSet
	*/
	public AddOrUpdateInventoryItemInputSet newInputSet() {
		return new AddOrUpdateInventoryItemInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public AddOrUpdateInventoryItemResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new AddOrUpdateInventoryItemResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the AddOrUpdateInventoryItem
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class AddOrUpdateInventoryItemInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSMarketplaceId input for this Choreo. 

		@param String - (required, string) The Marketplace ID provided by Amazon Web Services.
		*/
		public void set_AWSMarketplaceId(String value) {
			this.setInput("AWSMarketplaceId", value);
		}



		/** 
		Set the value of the AWSMerchantId input for this Choreo. 

		@param String - (required, string) The Merchant ID provided by Amazon Web Services.
		*/
		public void set_AWSMerchantId(String value) {
			this.setInput("AWSMerchantId", value);
		}



		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the Endpoint input for this Choreo. 

		@param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
		*/
		public void set_Endpoint(String value) {
			this.setInput("Endpoint", value);
		}



		/** 
		Set the value of the ExpeditedShipping input for this Choreo. 

		@param String - (optional, string) The expedited shipping options that you offer for this item. Valid values: 3 = UK Only; N = None, no express delivery offered.
		*/
		public void set_ExpeditedShipping(String value) {
			this.setInput("ExpeditedShipping", value);
		}



		/** 
		Set the value of the FulfillmentCenterId input for this Choreo. 

		@param String - (conditional, string) For those merchants using Amazon fulfillment services, this designates which fulfillment network will be used. Required when using Amazon fulfillment services. Valid values are: AMAZON_EU, DEFAULT.
		*/
		public void set_FulfillmentCenterId(String value) {
			this.setInput("FulfillmentCenterId", value);
		}



		/** 
		Set the value of the ItemCondition input for this Choreo. 

		@param Integer - (conditional, integer) A numerical entry that indicates the condition of the item. Required for new listings. Valid values are: 1-11. See documentation for description of item condition numeric values.
		*/
		public void set_ItemCondition(Integer value) {
			this.setInput("ItemCondition", value);
		}

		/** 
		Set the value of the ItemCondition input for this Choreo as a String. 

		@param String - (conditional, integer) A numerical entry that indicates the condition of the item. Required for new listings. Valid values are: 1-11. See documentation for description of item condition numeric values.
		*/
		public void set_ItemCondition(String value) {
			this.setInput("ItemCondition", value);	
		}

		/** 
		Set the value of the ItemNote input for this Choreo. 

		@param String - (optional, string) A description or note for the item you're adding or updating.
		*/
		public void set_ItemNote(String value) {
			this.setInput("ItemNote", value);
		}



		/** 
		Set the value of the Price input for this Choreo. 

		@param BigDecimal - (conditional, decimal) The price at which the merchant offers the product for sale. Required if ProductId is provided.
		*/
		public void set_Price(BigDecimal value) {
			this.setInput("Price", value);
		}

		/** 
		Set the value of the Price input for this Choreo as a String. 

		@param String - (conditional, decimal) The price at which the merchant offers the product for sale. Required if ProductId is provided.
		*/
		public void set_Price(String value) {
			this.setInput("Price", value);	
		}

		/** 
		Set the value of the ProductIdType input for this Choreo. 

		@param Integer - (conditional, integer) The type of standard, unique identifier entered in the product-id field. This is a required field if product-id is provided. Valid values are: 1 (ASIN), 2 (ISBN), 3 (UPC), 4  (EAN).
		*/
		public void set_ProductIdType(Integer value) {
			this.setInput("ProductIdType", value);
		}

		/** 
		Set the value of the ProductIdType input for this Choreo as a String. 

		@param String - (conditional, integer) The type of standard, unique identifier entered in the product-id field. This is a required field if product-id is provided. Valid values are: 1 (ASIN), 2 (ISBN), 3 (UPC), 4  (EAN).
		*/
		public void set_ProductIdType(String value) {
			this.setInput("ProductIdType", value);	
		}

		/** 
		Set the value of the ProductId input for this Choreo. 

		@param String - (conditional, string) A standard, alphanumeric string that uniquely identifies the product. This could be a UPC, EAN or ISBN.  This is a required field if product-id-type is provided.
		*/
		public void set_ProductId(String value) {
			this.setInput("ProductId", value);
		}



		/** 
		Set the value of the Quantity input for this Choreo. 

		@param Integer - (conditional, integer) Enter the quantity of the item you are making available for sale. Required for merchant-fulfilled items. Leave blank for amazon-fullfilled items.
		*/
		public void set_Quantity(Integer value) {
			this.setInput("Quantity", value);
		}

		/** 
		Set the value of the Quantity input for this Choreo as a String. 

		@param String - (conditional, integer) Enter the quantity of the item you are making available for sale. Required for merchant-fulfilled items. Leave blank for amazon-fullfilled items.
		*/
		public void set_Quantity(String value) {
			this.setInput("Quantity", value);	
		}

		/** 
		Set the value of the SKU input for this Choreo. 

		@param String - (required, string) A unique identifier for the product, assigned by the merchant. The SKU must be unique for each product listed.
		*/
		public void set_SKU(String value) {
			this.setInput("SKU", value);
		}



		/** 
		Set the value of the TimeToWait input for this Choreo. 

		@param Integer - (optional, integer) By default, the Choreo will wait for 10 minutes to see if the report is ready for retrieval. Max is 120 minutes.
		*/
		public void set_TimeToWait(Integer value) {
			this.setInput("TimeToWait", value);
		}

		/** 
		Set the value of the TimeToWait input for this Choreo as a String. 

		@param String - (optional, integer) By default, the Choreo will wait for 10 minutes to see if the report is ready for retrieval. Max is 120 minutes.
		*/
		public void set_TimeToWait(String value) {
			this.setInput("TimeToWait", value);	
		}

		/** 
		Set the value of the WillShipInternationally input for this Choreo. 

		@param Integer - (optional, integer) Specify your international shipping options. Valid values are: 3 = UK Only; 4 = UK and Europe; 5 = UK, Europe, and North America; 6 = Worldwide
		*/
		public void set_WillShipInternationally(Integer value) {
			this.setInput("WillShipInternationally", value);
		}

		/** 
		Set the value of the WillShipInternationally input for this Choreo as a String. 

		@param String - (optional, integer) Specify your international shipping options. Valid values are: 3 = UK Only; 4 = UK and Europe; 5 = UK, Europe, and North America; 6 = Worldwide
		*/
		public void set_WillShipInternationally(String value) {
			this.setInput("WillShipInternationally", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the AddOrUpdateInventoryItem Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class AddOrUpdateInventoryItemResultSet extends ResultSet {
		public AddOrUpdateInventoryItemResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "ProcessingStatus" output from this Choreo execution

		@return String - (string) The processing status of the product submission which is parsed from the Amazon response.
		*/
		public String get_ProcessingStatus() {
			return this.getResult("ProcessingStatus");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Amazon after submitting the feed.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** 
		Retrieve the value for the "SubmissionId" output from this Choreo execution

		@return String - (integer) The submission id parsed from the Amazon response.
		*/
		public String get_SubmissionId() {
			return this.getResult("SubmissionId");
		}
		/** 
		Retrieve the value for the "SubmissionResult" output from this Choreo execution

		@return String - (string) The submission result returned from Amazon.
		*/
		public String get_SubmissionResult() {
			return this.getResult("SubmissionResult");
		}
	}
	
}
