package com.temboo.Library.Amazon.Marketplace.Feeds;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
AddOrUpdateProductImage

Adds or updates a product image with a given image location and SKU.
*/
public class AddOrUpdateProductImage extends Choreography {

	/**
	Create a new instance of the AddOrUpdateProductImage Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public AddOrUpdateProductImage(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/Marketplace/Feeds/AddOrUpdateProductImage"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return AddOrUpdateProductImageInputSet
	*/
	public AddOrUpdateProductImageInputSet newInputSet() {
		return new AddOrUpdateProductImageInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public AddOrUpdateProductImageResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new AddOrUpdateProductImageResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the AddOrUpdateProductImage
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class AddOrUpdateProductImageInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSMarketplaceId input for this Choreo. 

		@param String - (required, string) The Marketplace ID provided by Amazon Web Services.
		*/
		public void set_AWSMarketplaceId(String value) {
			this.setInput("AWSMarketplaceId", value);
		}



		/** 
		Set the value of the AWSMerchantId input for this Choreo. 

		@param String - (required, string) The Merchant ID provided by Amazon Web Services.
		*/
		public void set_AWSMerchantId(String value) {
			this.setInput("AWSMerchantId", value);
		}



		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the Endpoint input for this Choreo. 

		@param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
		*/
		public void set_Endpoint(String value) {
			this.setInput("Endpoint", value);
		}



		/** 
		Set the value of the ImageLocation input for this Choreo. 

		@param String - (required, string) The URL for the image location.
		*/
		public void set_ImageLocation(String value) {
			this.setInput("ImageLocation", value);
		}



		/** 
		Set the value of the ImageType input for this Choreo. 

		@param String - (optional, string) The type of image (Main, Alternate, or Swatch). Defaults to "Main".
		*/
		public void set_ImageType(String value) {
			this.setInput("ImageType", value);
		}



		/** 
		Set the value of the SKU input for this Choreo. 

		@param String - (required, string) A SKU is a "Stock Keeping Unit" which you can assign to your products to track your inventory. Provide the SKU for the product that is associated with the image you are uploading.
		*/
		public void set_SKU(String value) {
			this.setInput("SKU", value);
		}



		/** 
		Set the value of the TimeToWait input for this Choreo. 

		@param Integer - (optional, integer) By default, the Choreo will wait for 10 minutes to see if the report is ready for retrieval. Max is 120 minutes.
		*/
		public void set_TimeToWait(Integer value) {
			this.setInput("TimeToWait", value);
		}

		/** 
		Set the value of the TimeToWait input for this Choreo as a String. 

		@param String - (optional, integer) By default, the Choreo will wait for 10 minutes to see if the report is ready for retrieval. Max is 120 minutes.
		*/
		public void set_TimeToWait(String value) {
			this.setInput("TimeToWait", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the AddOrUpdateProductImage Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class AddOrUpdateProductImageResultSet extends ResultSet {
		public AddOrUpdateProductImageResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "ProcessingStatus" output from this Choreo execution

		@return String - (string) The processing status of the feed submission which is parsed from the Amazon response.
		*/
		public String get_ProcessingStatus() {
			return this.getResult("ProcessingStatus");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Amazon after submitting the feed.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** 
		Retrieve the value for the "SubmissionId" output from this Choreo execution

		@return String - (integer) The submission id parsed from the Amazon response.
		*/
		public String get_SubmissionId() {
			return this.getResult("SubmissionId");
		}
		/** 
		Retrieve the value for the "SubmissionResult" output from this Choreo execution

		@return String - (string) The submission result returned from Amazon.
		*/
		public String get_SubmissionResult() {
			return this.getResult("SubmissionResult");
		}
	}
	
}
