package com.temboo.Library.Amazon.Marketplace.Orders;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ListOrders

Returns orders created during a time frame that you specify.
*/
public class ListOrders extends Choreography {

	/**
	Create a new instance of the ListOrders Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListOrders(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/Marketplace/Orders/ListOrders"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListOrdersInputSet
	*/
	public ListOrdersInputSet newInputSet() {
		return new ListOrdersInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListOrdersResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListOrdersResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListOrders
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListOrdersInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSMarketplaceId input for this Choreo. 

		@param String - (required, string) The Marketplace ID provided by Amazon Web Services.
		*/
		public void set_AWSMarketplaceId(String value) {
			this.setInput("AWSMarketplaceId", value);
		}



		/** 
		Set the value of the AWSMerchantId input for this Choreo. 

		@param String - (required, string) The Merchant ID provided by Amazon Web Services.
		*/
		public void set_AWSMerchantId(String value) {
			this.setInput("AWSMerchantId", value);
		}



		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the CreatedAfter input for this Choreo. 

		@param String - (optional, date) A date used for selecting orders created after (or at) a specified time, in ISO 8601 date format (i.e. 2012-01-01). Defaults to today's date if not provided.
		*/
		public void set_CreatedAfter(String value) {
			this.setInput("CreatedAfter", value);
		}



		/** 
		Set the value of the CreatedBefore input for this Choreo. 

		@param String - (optional, date) A date used for selecting orders created before (or at) a specified time, in ISO 8601 date format (i.e. 2012-01-01).
		*/
		public void set_CreatedBefore(String value) {
			this.setInput("CreatedBefore", value);
		}



		/** 
		Set the value of the Endpoint input for this Choreo. 

		@param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
		*/
		public void set_Endpoint(String value) {
			this.setInput("Endpoint", value);
		}



		/** 
		Set the value of the FullfillmentChannel input for this Choreo. 

		@param String - (optional, string) A string indicating how an order was fulfilled. Use "AFN" for Amazon fulfilled orders, and "MFN" for seller fulfilled orders.
		*/
		public void set_FullfillmentChannel(String value) {
			this.setInput("FullfillmentChannel", value);
		}



		/** 
		Set the value of the MaxResultsPerPage input for this Choreo. 

		@param Integer - (optional, integer) A number that indicates the maximum number of orders that can be returned per page. Valid values are: 1-100.
		*/
		public void set_MaxResultsPerPage(Integer value) {
			this.setInput("MaxResultsPerPage", value);
		}

		/** 
		Set the value of the MaxResultsPerPage input for this Choreo as a String. 

		@param String - (optional, integer) A number that indicates the maximum number of orders that can be returned per page. Valid values are: 1-100.
		*/
		public void set_MaxResultsPerPage(String value) {
			this.setInput("MaxResultsPerPage", value);	
		}

		/** 
		Set the value of the OrderStatus input for this Choreo. 

		@param String - (optional, string) An OrderStatus value to select only orders with a certain status. Valid values are: Pending, Unshipped, PartiallyShipped, Shipped, Canceled, Unfulfillable.
		*/
		public void set_OrderStatus(String value) {
			this.setInput("OrderStatus", value);
		}



		/** 
		Set the value of the PaymentMethod input for this Choreo. 

		@param String - (optional, string) Used to select only orders of a certain payment type. Valid values are: COD (cash on delivery), CSV (convenience store payment), or Other (Any payment method other than COD or CVS).
		*/
		public void set_PaymentMethod(String value) {
			this.setInput("PaymentMethod", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListOrders Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListOrdersResultSet extends ResultSet {
		public ListOrdersResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) Stores the response from Amazon.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
