package com.temboo.Library.Amazon.Marketplace.Reports;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CancelReportRequest

Cancels one or more report requests.
*/
public class CancelReportRequest extends Choreography {

	/**
	Create a new instance of the CancelReportRequest Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CancelReportRequest(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/Marketplace/Reports/CancelReportRequest"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CancelReportRequestInputSet
	*/
	public CancelReportRequestInputSet newInputSet() {
		return new CancelReportRequestInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CancelReportRequestResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CancelReportRequestResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CancelReportRequest
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CancelReportRequestInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSMarketplaceId input for this Choreo. 

		@param String - (required, string) The Marketplace ID provided by Amazon Web Services.
		*/
		public void set_AWSMarketplaceId(String value) {
			this.setInput("AWSMarketplaceId", value);
		}



		/** 
		Set the value of the AWSMerchantId input for this Choreo. 

		@param String - (required, string) The Merchant ID provided by Amazon Web Services.
		*/
		public void set_AWSMerchantId(String value) {
			this.setInput("AWSMerchantId", value);
		}



		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the Endpoint input for this Choreo. 

		@param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
		*/
		public void set_Endpoint(String value) {
			this.setInput("Endpoint", value);
		}



		/** 
		Set the value of the ReportProcessingStatus input for this Choreo. 

		@param String - (optional, string) A report processing status by which to filter report requests. Valid values are: _SUBMITTED_, _IN_PROGRESS_, _CANCELLED_, _DONE_, _DONE_NO_DATA_.
		*/
		public void set_ReportProcessingStatus(String value) {
			this.setInput("ReportProcessingStatus", value);
		}



		/** 
		Set the value of the ReportRequestId input for this Choreo. 

		@param String - (optional, string) A ReportRequestId value. If you pass in a ReportRequestId value, other query conditions are ignored.
		*/
		public void set_ReportRequestId(String value) {
			this.setInput("ReportRequestId", value);
		}



		/** 
		Set the value of the ReportType input for this Choreo. 

		@param String - (optional, string) A ReportType enumeration value (i.e. GET_ORDERS_DATA_).
		*/
		public void set_ReportType(String value) {
			this.setInput("ReportType", value);
		}



		/** 
		Set the value of the RequestedFromDate input for this Choreo. 

		@param String - (optional, date) The start of the date range used for selecting the data to report, in ISO8601 date format (i.e. 2012-01-01).
		*/
		public void set_RequestedFromDate(String value) {
			this.setInput("RequestedFromDate", value);
		}



		/** 
		Set the value of the RequestedToDate input for this Choreo. 

		@param String - (optional, date) The end of the date range used for selecting the data to report, in ISO8601 date format (i.e. 2012-01-01).
		*/
		public void set_RequestedToDate(String value) {
			this.setInput("RequestedToDate", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CancelReportRequest Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CancelReportRequestResultSet extends ResultSet {
		public CancelReportRequestResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Count" output from this Choreo execution

		@return String - (integer) A non-negative integer that represents the total number of report requests that were cancelled.
		*/
		public String get_Count() {
			return this.getResult("Count");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - Stores the response from Amazon.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
