package com.temboo.Library.Amazon.Marketplace.Reports;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
MerchantListingsLiteReport

Returns a tab-delimited flat file active listings report that contains only the SKU, ASIN, Price, and Quantity fields for items that have a quantity greater than zero.
*/
public class MerchantListingsLiteReport extends Choreography {

	/**
	Create a new instance of the MerchantListingsLiteReport Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public MerchantListingsLiteReport(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/Marketplace/Reports/MerchantListingsLiteReport"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return MerchantListingsLiteReportInputSet
	*/
	public MerchantListingsLiteReportInputSet newInputSet() {
		return new MerchantListingsLiteReportInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public MerchantListingsLiteReportResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new MerchantListingsLiteReportResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the MerchantListingsLiteReport
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class MerchantListingsLiteReportInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSMarketplaceId input for this Choreo. 

		@param String - (required, string) The Marketplace ID provided by Amazon Web Services.
		*/
		public void set_AWSMarketplaceId(String value) {
			this.setInput("AWSMarketplaceId", value);
		}



		/** 
		Set the value of the AWSMerchantId input for this Choreo. 

		@param String - (required, string) The Merchant ID provided by Amazon Web Services.
		*/
		public void set_AWSMerchantId(String value) {
			this.setInput("AWSMerchantId", value);
		}



		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the Endpoint input for this Choreo. 

		@param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
		*/
		public void set_Endpoint(String value) {
			this.setInput("Endpoint", value);
		}



		/** 
		Set the value of the TimeToWait input for this Choreo. 

		@param Integer - (optional, integer) By default, the Choreo will wait for 5 minutes to see if the report is ready for retrieval. Max is 120 minutes.
		*/
		public void set_TimeToWait(Integer value) {
			this.setInput("TimeToWait", value);
		}

		/** 
		Set the value of the TimeToWait input for this Choreo as a String. 

		@param String - (optional, integer) By default, the Choreo will wait for 5 minutes to see if the report is ready for retrieval. Max is 120 minutes.
		*/
		public void set_TimeToWait(String value) {
			this.setInput("TimeToWait", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the MerchantListingsLiteReport Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class MerchantListingsLiteReportResultSet extends ResultSet {
		public MerchantListingsLiteReportResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "GeneratedReportId" output from this Choreo execution

		@return String - (integer) The GeneratedReportId parsed from the Amazon response.
		*/
		public String get_GeneratedReportId() {
			return this.getResult("GeneratedReportId");
		}
		/** 
		Retrieve the value for the "ReportProcessingStatus" output from this Choreo execution

		@return String - (string) The status of the report request parsed from the Amazon response.
		*/
		public String get_ReportProcessingStatus() {
			return this.getResult("ReportProcessingStatus");
		}
		/** 
		Retrieve the value for the "ReportRequestId" output from this Choreo execution

		@return String - (integer) The ReportRequestId parsed from the Amazon response. This id is used in GetReportRequestList.
		*/
		public String get_ReportRequestId() {
			return this.getResult("ReportRequestId");
		}
		/** 
		Retrieve the value for the "Report" output from this Choreo execution

		@return String - (multiline) The report contents.
		*/
		public String get_Report() {
			return this.getResult("Report");
		}
	}
	
}
