package com.temboo.Library.Amazon.RDS;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
AuthorizeDBSecurityGroupIngress

Allows restricted access to your database instance by adding EC2 Security Groups to the DBSecurityGroup or by specifying an allowed IP range.
*/
public class AuthorizeDBSecurityGroupIngress extends Choreography {

	/**
	Create a new instance of the AuthorizeDBSecurityGroupIngress Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public AuthorizeDBSecurityGroupIngress(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/RDS/AuthorizeDBSecurityGroupIngress"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return AuthorizeDBSecurityGroupIngressInputSet
	*/
	public AuthorizeDBSecurityGroupIngressInputSet newInputSet() {
		return new AuthorizeDBSecurityGroupIngressInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public AuthorizeDBSecurityGroupIngressResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new AuthorizeDBSecurityGroupIngressResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the AuthorizeDBSecurityGroupIngress
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class AuthorizeDBSecurityGroupIngressInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the CIDRIP input for this Choreo. 

		@param String - (conditional, string) IP range that should have access. Required unless EC2SecurityGroupName and EC2SecurityGroupOwnerId are used.
		*/
		public void set_CIDRIP(String value) {
			this.setInput("CIDRIP", value);
		}



		/** 
		Set the value of the DBSecurityGroupName input for this Choreo. 

		@param String - (required, string) A unique name for the security group you want to authorize.
		*/
		public void set_DBSecurityGroupName(String value) {
			this.setInput("DBSecurityGroupName", value);
		}



		/** 
		Set the value of the EC2SecurityGroupName input for this Choreo. 

		@param String - (conditional, string) The EC2 security group to authorize. This and EC2SecurityGroupOwnerId are required if CIDRIP is not used.
		*/
		public void set_EC2SecurityGroupName(String value) {
			this.setInput("EC2SecurityGroupName", value);
		}



		/** 
		Set the value of the EC2SecurityGroupOwnerId input for this Choreo. 

		@param String - (conditional, string) The AWS account number for the security group owner. This and EC2SecurityGroupName are required if CIDRIP is not used.
		*/
		public void set_EC2SecurityGroupOwnerId(String value) {
			this.setInput("EC2SecurityGroupOwnerId", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the AuthorizeDBSecurityGroupIngress Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class AuthorizeDBSecurityGroupIngressResultSet extends ResultSet {
		public AuthorizeDBSecurityGroupIngressResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Amazon.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
