package com.temboo.Library.Amazon.RDS;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
DescribeDBSnapshot

Returns information about DB Snapshots.
*/
public class DescribeDBSnapshot extends Choreography {

	/**
	Create a new instance of the DescribeDBSnapshot Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DescribeDBSnapshot(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/RDS/DescribeDBSnapshot"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DescribeDBSnapshotInputSet
	*/
	public DescribeDBSnapshotInputSet newInputSet() {
		return new DescribeDBSnapshotInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DescribeDBSnapshotResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DescribeDBSnapshotResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DescribeDBSnapshot
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DescribeDBSnapshotInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the DBInstanceIdentifier input for this Choreo. 

		@param String - (optional, string) The DB Instance identifier. Should be in all lowercase.
		*/
		public void set_DBInstanceIdentifier(String value) {
			this.setInput("DBInstanceIdentifier", value);
		}



		/** 
		Set the value of the DBSnapshotIdentifier input for this Choreo. 

		@param String - (optional, string) The unique identifier for the db snapshot you're retrieving information for.
		*/
		public void set_DBSnapshotIdentifier(String value) {
			this.setInput("DBSnapshotIdentifier", value);
		}



		/** 
		Set the value of the MaxRecords input for this Choreo. 

		@param Integer - (optional, integer) The max number of results to return in the response. Defaults to 100. Minimum is 20.
		*/
		public void set_MaxRecords(Integer value) {
			this.setInput("MaxRecords", value);
		}

		/** 
		Set the value of the MaxRecords input for this Choreo as a String. 

		@param String - (optional, integer) The max number of results to return in the response. Defaults to 100. Minimum is 20.
		*/
		public void set_MaxRecords(String value) {
			this.setInput("MaxRecords", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DescribeDBSnapshot Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DescribeDBSnapshotResultSet extends ResultSet {
		public DescribeDBSnapshotResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Amazon.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
