package com.temboo.Library.Amazon.RDS;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ModifyDBInstance

Modify settings for a DB Instance. You can change one or more database configuration parameters by specifying values for the Choreo inputs.
*/
public class ModifyDBInstance extends Choreography {

	/**
	Create a new instance of the ModifyDBInstance Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ModifyDBInstance(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/RDS/ModifyDBInstance"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ModifyDBInstanceInputSet
	*/
	public ModifyDBInstanceInputSet newInputSet() {
		return new ModifyDBInstanceInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ModifyDBInstanceResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ModifyDBInstanceResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ModifyDBInstance
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ModifyDBInstanceInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the AllocatedStorage input for this Choreo. 

		@param Integer - (required, integer) Storage amount (in gigabytes) to be configured for the DB. Use 5 to 1024 for MySQL or 10 to 1024 for Oracle. Value supplied must be at least 10% greater than the current value
		*/
		public void set_AllocatedStorage(Integer value) {
			this.setInput("AllocatedStorage", value);
		}

		/** 
		Set the value of the AllocatedStorage input for this Choreo as a String. 

		@param String - (required, integer) Storage amount (in gigabytes) to be configured for the DB. Use 5 to 1024 for MySQL or 10 to 1024 for Oracle. Value supplied must be at least 10% greater than the current value
		*/
		public void set_AllocatedStorage(String value) {
			this.setInput("AllocatedStorage", value);	
		}

		/** 
		Set the value of the AllowMajorVersionUpgrade input for this Choreo. 

		@param Boolean - (optional, boolean) Indicates that major version upgrades are allowed. Defaults to 0 (false).
		*/
		public void set_AllowMajorVersionUpgrade(Boolean value) {
			this.setInput("AllowMajorVersionUpgrade", value);
		}

		/** 
		Set the value of the AllowMajorVersionUpgrade input for this Choreo as a String. 

		@param String - (optional, boolean) Indicates that major version upgrades are allowed. Defaults to 0 (false).
		*/
		public void set_AllowMajorVersionUpgrade(String value) {
			this.setInput("AllowMajorVersionUpgrade", value);	
		}

		/** 
		Set the value of the ApplyImmediately input for this Choreo. 

		@param Boolean - (optional, boolean) Specifies whether or not the modifications applied as soon as possible, regardless of the PreferredMaintenanceWindow setting for the DB Instance. Defaults to 0 (false).
		*/
		public void set_ApplyImmediately(Boolean value) {
			this.setInput("ApplyImmediately", value);
		}

		/** 
		Set the value of the ApplyImmediately input for this Choreo as a String. 

		@param String - (optional, boolean) Specifies whether or not the modifications applied as soon as possible, regardless of the PreferredMaintenanceWindow setting for the DB Instance. Defaults to 0 (false).
		*/
		public void set_ApplyImmediately(String value) {
			this.setInput("ApplyImmediately", value);	
		}

		/** 
		Set the value of the AutoMinorVersionUpgrade input for this Choreo. 

		@param Boolean - (optional, boolean) Indicates that minor version upgrades will be applied automatically to the DB Instance during the maintenance window. Defaults to 0 (false).
		*/
		public void set_AutoMinorVersionUpgrade(Boolean value) {
			this.setInput("AutoMinorVersionUpgrade", value);
		}

		/** 
		Set the value of the AutoMinorVersionUpgrade input for this Choreo as a String. 

		@param String - (optional, boolean) Indicates that minor version upgrades will be applied automatically to the DB Instance during the maintenance window. Defaults to 0 (false).
		*/
		public void set_AutoMinorVersionUpgrade(String value) {
			this.setInput("AutoMinorVersionUpgrade", value);	
		}

		/** 
		Set the value of the BackupRetentionPeriod input for this Choreo. 

		@param Integer - (optional, integer) Number of days to retain automated backups. Setting to a positive number enables backups. Setting to 0 disables automated backups. Must be a value from 0 to 8. Defaults to 0 (disabled).
		*/
		public void set_BackupRetentionPeriod(Integer value) {
			this.setInput("BackupRetentionPeriod", value);
		}

		/** 
		Set the value of the BackupRetentionPeriod input for this Choreo as a String. 

		@param String - (optional, integer) Number of days to retain automated backups. Setting to a positive number enables backups. Setting to 0 disables automated backups. Must be a value from 0 to 8. Defaults to 0 (disabled).
		*/
		public void set_BackupRetentionPeriod(String value) {
			this.setInput("BackupRetentionPeriod", value);	
		}

		/** 
		Set the value of the DBInstanceClass input for this Choreo. 

		@param String - (required, string) Capacity for the DB instance.  (db.m1.small, db.m1.large, db.m1.xlarge, db.m2.xlarge, db.m2.2xlarge, or db.m2.4xlarge).
		*/
		public void set_DBInstanceClass(String value) {
			this.setInput("DBInstanceClass", value);
		}



		/** 
		Set the value of the DBInstanceIdentifier input for this Choreo. 

		@param String - (required, string) The DB Instance identifier. Should be in all lowercase.
		*/
		public void set_DBInstanceIdentifier(String value) {
			this.setInput("DBInstanceIdentifier", value);
		}



		/** 
		Set the value of the DBParameterGroupName input for this Choreo. 

		@param String - (optional, string) The name of the DB Parameter Group to apply to this DB Instance.
		*/
		public void set_DBParameterGroupName(String value) {
			this.setInput("DBParameterGroupName", value);
		}



		/** 
		Set the value of the DBSecurityGroup input for this Choreo. 

		@param String - (optional, string) A DB Security Groups to authorize on this DB Instance.
		*/
		public void set_DBSecurityGroup(String value) {
			this.setInput("DBSecurityGroup", value);
		}



		/** 
		Set the value of the EngineVersion input for this Choreo. 

		@param String - (optional, string) The version number of the database engine to upgrade to.
		*/
		public void set_EngineVersion(String value) {
			this.setInput("EngineVersion", value);
		}



		/** 
		Set the value of the MasterUserPassword input for this Choreo. 

		@param String - (required, string) The new password for the DB Instance master user.
		*/
		public void set_MasterUserPassword(String value) {
			this.setInput("MasterUserPassword", value);
		}



		/** 
		Set the value of the MultiAZ input for this Choreo. 

		@param Boolean - (optional, boolean) Specifies if the DB Instance is a Multi-AZ deployment.
		*/
		public void set_MultiAZ(Boolean value) {
			this.setInput("MultiAZ", value);
		}

		/** 
		Set the value of the MultiAZ input for this Choreo as a String. 

		@param String - (optional, boolean) Specifies if the DB Instance is a Multi-AZ deployment.
		*/
		public void set_MultiAZ(String value) {
			this.setInput("MultiAZ", value);	
		}

		/** 
		Set the value of the PreferredBackupWindow input for this Choreo. 

		@param String - (optional, string) The daily time range during which automated backups are created. Format: hh24:mi-hh24:mi (in UTC). Must be at least 30 minutes. Can not conflict with PreferredMaintenanceWindow setting.
		*/
		public void set_PreferredBackupWindow(String value) {
			this.setInput("PreferredBackupWindow", value);
		}



		/** 
		Set the value of the PreferredMaintenanceWindow input for this Choreo. 

		@param String - (optional, string) The weekly time range (in UTC) during which system maintenance can occur, which may result in an outage. Format: ddd:hh24:mi-ddd:hh24:mi. Valid Days: Mon | Tue | Wed | Thu | Fri | Sat | Sun.
		*/
		public void set_PreferredMaintenanceWindow(String value) {
			this.setInput("PreferredMaintenanceWindow", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ModifyDBInstance Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ModifyDBInstanceResultSet extends ResultSet {
		public ModifyDBInstanceResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Amazon.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
