package com.temboo.Library.Amazon.RDS;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
RebootDBInstance

Reboots a specified database instance.
*/
public class RebootDBInstance extends Choreography {

	/**
	Create a new instance of the RebootDBInstance Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public RebootDBInstance(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/RDS/RebootDBInstance"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return RebootDBInstanceInputSet
	*/
	public RebootDBInstanceInputSet newInputSet() {
		return new RebootDBInstanceInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public RebootDBInstanceResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new RebootDBInstanceResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the RebootDBInstance
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class RebootDBInstanceInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the DBInstanceIdentifier input for this Choreo. 

		@param String - (required, string) The ID for the DB instance to reboot.
		*/
		public void set_DBInstanceIdentifier(String value) {
			this.setInput("DBInstanceIdentifier", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the RebootDBInstance Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class RebootDBInstanceResultSet extends ResultSet {
		public RebootDBInstanceResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Amazon.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
