package com.temboo.Library.Amazon.S3;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
DeleteMultipleObjects

Deletes multiple objects from an S3 Bucket.
*/
public class DeleteMultipleObjects extends Choreography {

	/**
	Create a new instance of the DeleteMultipleObjects Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DeleteMultipleObjects(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/S3/DeleteMultipleObjects"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DeleteMultipleObjectsInputSet
	*/
	public DeleteMultipleObjectsInputSet newInputSet() {
		return new DeleteMultipleObjectsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DeleteMultipleObjectsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DeleteMultipleObjectsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DeleteMultipleObjects
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DeleteMultipleObjectsInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the BucketName input for this Choreo. 

		@param String - (required, string) The the name of the bucket that contains the objects that you want to delete.
		*/
		public void set_BucketName(String value) {
			this.setInput("BucketName", value);
		}



		/** 
		Set the value of the FileNames input for this Choreo. 

		@param String - (required, string) A list of file names to delete (separated by commas).
		*/
		public void set_FileNames(String value) {
			this.setInput("FileNames", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DeleteMultipleObjects Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DeleteMultipleObjectsResultSet extends ResultSet {
		public DeleteMultipleObjectsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Amazon. Note that no content is returned for a successful delete operation.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
