package com.temboo.Library.Amazon.S3;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
PutBucketWebsiteRedirectAll

Configures the specified bucket as a website and redirects all web requests to the designated hostname.
*/
public class PutBucketWebsiteRedirectAll extends Choreography {

	/**
	Create a new instance of the PutBucketWebsiteRedirectAll Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public PutBucketWebsiteRedirectAll(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/S3/PutBucketWebsiteRedirectAll"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return PutBucketWebsiteRedirectAllInputSet
	*/
	public PutBucketWebsiteRedirectAllInputSet newInputSet() {
		return new PutBucketWebsiteRedirectAllInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public PutBucketWebsiteRedirectAllResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new PutBucketWebsiteRedirectAllResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the PutBucketWebsiteRedirectAll
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class PutBucketWebsiteRedirectAllInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the BucketName input for this Choreo. 

		@param String - (required, string) The name of the bucket that you wish to configure.
		*/
		public void set_BucketName(String value) {
			this.setInput("BucketName", value);
		}



		/** 
		Set the value of the HostName input for this Choreo. 

		@param String - (required, string) Name of the host where requests will be redirected. Ex.: example.com
		*/
		public void set_HostName(String value) {
			this.setInput("HostName", value);
		}



		/** 
		Set the value of the Protocol input for this Choreo. 

		@param String - (optional, string) Protocol to use (http, https) when redirecting requests. The default is http.
		*/
		public void set_Protocol(String value) {
			this.setInput("Protocol", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the PutBucketWebsiteRedirectAll Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class PutBucketWebsiteRedirectAllResultSet extends ResultSet {
		public PutBucketWebsiteRedirectAllResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - Stores the response from Amazon. Note that for a successful website configuration request, no content is returned and this output variable will be empty.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
