package com.temboo.Library.Amazon.S3;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
PutObject

Uploads a file to your Amazon S3 storage bucket.
*/
public class PutObject extends Choreography {

	/**
	Create a new instance of the PutObject Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public PutObject(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/S3/PutObject"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return PutObjectInputSet
	*/
	public PutObjectInputSet newInputSet() {
		return new PutObjectInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public PutObjectResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new PutObjectResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the PutObject
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class PutObjectInputSet extends InputSet {
		/** 
		Set the value of the FileContents input for this Choreo. 

		@param String - (required, string) The Base64-encoded file contents that you want to upload to an AmazonS3 bucket.
		*/
		public void set_FileContents(String value) {
			this.setInput("FileContents", value);
		}



		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the BucketName input for this Choreo. 

		@param String - (required, string) The name of the bucket that will be the file destination.
		*/
		public void set_BucketName(String value) {
			this.setInput("BucketName", value);
		}



		/** 
		Set the value of the CannedACL input for this Choreo. 

		@param String - (optional, string) By default all objects are private (only owner has full access control). Valid values: private, public-read, public-read-write, authenticated-read, bucket-owner-read, bucket-owner-full-control.
		*/
		public void set_CannedACL(String value) {
			this.setInput("CannedACL", value);
		}



		/** 
		Set the value of the ContentType input for this Choreo. 

		@param String - (optional, string) Sets the content-type (text/html, image/jpeg, etc.). Default is application/octet-stream.
		*/
		public void set_ContentType(String value) {
			this.setInput("ContentType", value);
		}



		/** 
		Set the value of the FileName input for this Choreo. 

		@param String - (required, string) The name of the file to put in S3 Storage. Ex.: file.txt or folder/file.txt
		*/
		public void set_FileName(String value) {
			this.setInput("FileName", value);
		}



		/** 
		Set the value of the ServerSideEncryption input for this Choreo. 

		@param String - (optional, string) Specifies the server-side encryption algorithm to use when Amazon S3 creates the target object. Valid value: AES256.
		*/
		public void set_ServerSideEncryption(String value) {
			this.setInput("ServerSideEncryption", value);
		}



		/** 
		Set the value of the StorageClass input for this Choreo. 

		@param String - (optional, string) Enables RRS customers to store their noncritical, reproducible data at lower levels of redundancy than Amazon S3's standard storage. Valid Values: STANDARD (default), REDUCED_REDUNDANCY.
		*/
		public void set_StorageClass(String value) {
			this.setInput("StorageClass", value);
		}



		/** 
		Set the value of the WebsiteRedirectLocation input for this Choreo. 

		@param String - (optional, string) If the bucket is configured as a website, redirects requests for this object to another object in the same bucket or to an external URL. Ex: /anotherPage.html, http://www.page.com. Max length: 2 K.
		*/
		public void set_WebsiteRedirectLocation(String value) {
			this.setInput("WebsiteRedirectLocation", value);
		}



		/** 
		Set the value of the VaultFile input for this Choreo. 

		@param TembooPath - (optional, vault file) The path to a vault file that you want to upload to an Amazon S3 bucket. Required unless using the FileContents input variable.
		*/
		public void set_VaultFile(TembooPath value) {
			this.setAlias("VaultFile", value);
		}
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the PutObject Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class PutObjectResultSet extends ResultSet {
		public PutObjectResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Amazon. Note that no content is returned for successful uploads.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
