package com.temboo.Library.Amazon.S3;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ZipObject

Creates a zipped version of the specified S3 file and returns a download link for the new compressed file.
*/
public class ZipObject extends Choreography {

	/**
	Create a new instance of the ZipObject Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ZipObject(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/S3/ZipObject"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ZipObjectInputSet
	*/
	public ZipObjectInputSet newInputSet() {
		return new ZipObjectInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ZipObjectResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ZipObjectResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ZipObject
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ZipObjectInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the BucketName input for this Choreo. 

		@param String - (required, string) The name of the bucket that contains the object to retrieve and zip.
		*/
		public void set_BucketName(String value) {
			this.setInput("BucketName", value);
		}



		/** 
		Set the value of the CannedACL input for this Choreo. 

		@param String - (conditional, string) This sets the permissions for the newly created zip file. Valid values are: private, public-read, public-read-write, authenticated-read, bucket-owner-read, or bucket-owner-full-control.
		*/
		public void set_CannedACL(String value) {
			this.setInput("CannedACL", value);
		}



		/** 
		Set the value of the FileName input for this Choreo. 

		@param String - (required, string) The name of the file to retrieve and zip.
		*/
		public void set_FileName(String value) {
			this.setInput("FileName", value);
		}



		/** 
		Set the value of the ZipFileLocation input for this Choreo. 

		@param String - (optional, string) The name of the bucket to put the new zip file in. When not specified, the zip file will be put in the bucket where the original uncompressed file is located.
		*/
		public void set_ZipFileLocation(String value) {
			this.setInput("ZipFileLocation", value);
		}



		/** 
		Set the value of the ZipFileName input for this Choreo. 

		@param String - (optional, string) The name of the zip file that will be created. If not specified, the original file name will be used with .zip extension.
		*/
		public void set_ZipFileName(String value) {
			this.setInput("ZipFileName", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ZipObject Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ZipObjectResultSet extends ResultSet {
		public ZipObjectResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "URL" output from this Choreo execution

		@return String - (string) The URL location of the new zip file.
		*/
		public String get_URL() {
			return this.getResult("URL");
		}
	}
	
}
