package com.temboo.Library.Amazon.SNS;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ListSubscriptionsByTopic

Returns a list of the subscriptions for a specified topic.
*/
public class ListSubscriptionsByTopic extends Choreography {

	/**
	Create a new instance of the ListSubscriptionsByTopic Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListSubscriptionsByTopic(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/SNS/ListSubscriptionsByTopic"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListSubscriptionsByTopicInputSet
	*/
	public ListSubscriptionsByTopicInputSet newInputSet() {
		return new ListSubscriptionsByTopicInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListSubscriptionsByTopicResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListSubscriptionsByTopicResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListSubscriptionsByTopic
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListSubscriptionsByTopicInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the NextToken input for this Choreo. 

		@param String - (optional, string) The token returned from a previous LIstSubscriptionsByTopic request.
		*/
		public void set_NextToken(String value) {
			this.setInput("NextToken", value);
		}



		/** 
		Set the value of the TopicArn input for this Choreo. 

		@param String - (required, string) The ARN of the topic that you want to find subscriptions for.
		*/
		public void set_TopicArn(String value) {
			this.setInput("TopicArn", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListSubscriptionsByTopic Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListSubscriptionsByTopicResultSet extends ResultSet {
		public ListSubscriptionsByTopicResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Amazon.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
