package com.temboo.Library.Amazon.SNS;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ListTopics

Returns a list of the user's topics.
*/
public class ListTopics extends Choreography {

	/**
	Create a new instance of the ListTopics Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListTopics(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/SNS/ListTopics"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListTopicsInputSet
	*/
	public ListTopicsInputSet newInputSet() {
		return new ListTopicsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListTopicsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListTopicsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListTopics
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListTopicsInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the NextToken input for this Choreo. 

		@param String - (optional, string) The token returned from a previous LIstTopics request.
		*/
		public void set_NextToken(String value) {
			this.setInput("NextToken", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListTopics Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListTopicsResultSet extends ResultSet {
		public ListTopicsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Amazon.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
