package com.temboo.Library.Amazon.SNS;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Publish

Sends a message to a topic's subscribed endpoints.
*/
public class Publish extends Choreography {

	/**
	Create a new instance of the Publish Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Publish(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/SNS/Publish"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return PublishInputSet
	*/
	public PublishInputSet newInputSet() {
		return new PublishInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public PublishResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new PublishResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Publish
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class PublishInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the MessageStructure input for this Choreo. 

		@param String - (optional, string) Can be set to 'json' if you are providing a valid JSON object for the Message input variable.
		*/
		public void set_MessageStructure(String value) {
			this.setInput("MessageStructure", value);
		}



		/** 
		Set the value of the Message input for this Choreo. 

		@param String - (required, string) The text for the message you want to send to the topic.
		*/
		public void set_Message(String value) {
			this.setInput("Message", value);
		}



		/** 
		Set the value of the Subject input for this Choreo. 

		@param String - (optional, string) The "Subject" line of the message when the message is delivered to e-mail endpoints or as a JSON message.
		*/
		public void set_Subject(String value) {
			this.setInput("Subject", value);
		}



		/** 
		Set the value of the TopicArn input for this Choreo. 

		@param String - (required, string) The ARN of the topic you want to publish to.
		*/
		public void set_TopicArn(String value) {
			this.setInput("TopicArn", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Publish Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class PublishResultSet extends ResultSet {
		public PublishResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Amazon.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
