package com.temboo.Library.Amazon.SNS;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
SetTopicAttributes

Allows a topic owner to update the attribute of a topic to a new value.
*/
public class SetTopicAttributes extends Choreography {

	/**
	Create a new instance of the SetTopicAttributes Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public SetTopicAttributes(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/SNS/SetTopicAttributes"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return SetTopicAttributesInputSet
	*/
	public SetTopicAttributesInputSet newInputSet() {
		return new SetTopicAttributesInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public SetTopicAttributesResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new SetTopicAttributesResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the SetTopicAttributes
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class SetTopicAttributesInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the AttributeName input for this Choreo. 

		@param String - (required, string) The name of the attribute you want to modify. Valid values are: Policy and DisplayName.
		*/
		public void set_AttributeName(String value) {
			this.setInput("AttributeName", value);
		}



		/** 
		Set the value of the AttributeValue input for this Choreo. 

		@param String - (required, string) The new value for the attribute that you want to update.
		*/
		public void set_AttributeValue(String value) {
			this.setInput("AttributeValue", value);
		}



		/** 
		Set the value of the TopicArn input for this Choreo. 

		@param String - (required, string) The ARN of the topic that has an attribute that you want to set.
		*/
		public void set_TopicArn(String value) {
			this.setInput("TopicArn", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the SetTopicAttributes Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class SetTopicAttributesResultSet extends ResultSet {
		public SetTopicAttributesResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Amazon.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
