package com.temboo.Library.Amazon.SNS;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Subscribe

Sends the endpoint a confirmation message in preparation for subscribing an endpoint.
*/
public class Subscribe extends Choreography {

	/**
	Create a new instance of the Subscribe Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Subscribe(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/SNS/Subscribe"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return SubscribeInputSet
	*/
	public SubscribeInputSet newInputSet() {
		return new SubscribeInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public SubscribeResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new SubscribeResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Subscribe
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class SubscribeInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the Endpoint input for this Choreo. 

		@param String - (required, string) The endpoint that will receive the notifications. Can be an email address, URL, or the ARN of an Amazon SQS queue depending on the protocol specified.
		*/
		public void set_Endpoint(String value) {
			this.setInput("Endpoint", value);
		}



		/** 
		Set the value of the Protocol input for this Choreo. 

		@param String - (required, string) The protocol you want to use. Accepted values are: http, https, email, email-json, or sqs.
		*/
		public void set_Protocol(String value) {
			this.setInput("Protocol", value);
		}



		/** 
		Set the value of the TopicArn input for this Choreo. 

		@param String - (required, string) The ARN of the topic you want to subscribe to.
		*/
		public void set_TopicArn(String value) {
			this.setInput("TopicArn", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Subscribe Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class SubscribeResultSet extends ResultSet {
		public SubscribeResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Amazon.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
