package com.temboo.Library.Amazon.SQS;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
AddPermission

Adds a permission to a queue for a specific principal user.
*/
public class AddPermission extends Choreography {

	/**
	Create a new instance of the AddPermission Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public AddPermission(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/SQS/AddPermission"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return AddPermissionInputSet
	*/
	public AddPermissionInputSet newInputSet() {
		return new AddPermissionInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public AddPermissionResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new AddPermissionResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the AddPermission
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class AddPermissionInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSAccountId1 input for this Choreo. 

		@param Integer - (required, integer) The AWS account number of the user that will be granted access to a specified action. Enter account number omitting any dashes.
		*/
		public void set_AWSAccountId1(Integer value) {
			this.setInput("AWSAccountId1", value);
		}

		/** 
		Set the value of the AWSAccountId1 input for this Choreo as a String. 

		@param String - (required, integer) The AWS account number of the user that will be granted access to a specified action. Enter account number omitting any dashes.
		*/
		public void set_AWSAccountId1(String value) {
			this.setInput("AWSAccountId1", value);	
		}

		/** 
		Set the value of the AWSAccountId input for this Choreo. 

		@param Integer - (required, integer) The AWS account number of the queue owner. Enter account number omitting any dashes.
		*/
		public void set_AWSAccountId(Integer value) {
			this.setInput("AWSAccountId", value);
		}

		/** 
		Set the value of the AWSAccountId input for this Choreo as a String. 

		@param String - (required, integer) The AWS account number of the queue owner. Enter account number omitting any dashes.
		*/
		public void set_AWSAccountId(String value) {
			this.setInput("AWSAccountId", value);	
		}

		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the ActionName input for this Choreo. 

		@param String - (required, string) The action to allow for a specified user. Valid values: SendMessage, ReceiveMessage, DeleteMessage,ChangeMessageVisibility, GetQueueAttributes.
		*/
		public void set_ActionName(String value) {
			this.setInput("ActionName", value);
		}



		/** 
		Set the value of the Label input for this Choreo. 

		@param String - (required, string) The unique identifier for the new permission that is being set.
		*/
		public void set_Label(String value) {
			this.setInput("Label", value);
		}



		/** 
		Set the value of the QueueName input for this Choreo. 

		@param String - (required, string) The name of the queue that you're granting access to.
		*/
		public void set_QueueName(String value) {
			this.setInput("QueueName", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the AddPermission Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class AddPermissionResultSet extends ResultSet {
		public AddPermissionResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Amazon.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
