package com.temboo.Library.Amazon.SQS;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CreateQueue

Creates a new queue with a specified queue name.
*/
public class CreateQueue extends Choreography {

	/**
	Create a new instance of the CreateQueue Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CreateQueue(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/SQS/CreateQueue"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CreateQueueInputSet
	*/
	public CreateQueueInputSet newInputSet() {
		return new CreateQueueInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CreateQueueResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CreateQueueResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CreateQueue
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CreateQueueInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the DefaultVisibilityTimeout input for this Choreo. 

		@param Integer - (optional, integer) The visibility timeout (in seconds) to use for the newly created queue.
		*/
		public void set_DefaultVisibilityTimeout(Integer value) {
			this.setInput("DefaultVisibilityTimeout", value);
		}

		/** 
		Set the value of the DefaultVisibilityTimeout input for this Choreo as a String. 

		@param String - (optional, integer) The visibility timeout (in seconds) to use for the newly created queue.
		*/
		public void set_DefaultVisibilityTimeout(String value) {
			this.setInput("DefaultVisibilityTimeout", value);	
		}

		/** 
		Set the value of the QueueName input for this Choreo. 

		@param String - (required, string) The name of the queue you want to create.
		*/
		public void set_QueueName(String value) {
			this.setInput("QueueName", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CreateQueue Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CreateQueueResultSet extends ResultSet {
		public CreateQueueResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Amazon.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
