package com.temboo.Library.Amazon.SQS;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
DeleteMessage

Deletes a particular message from a specified queue.
*/
public class DeleteMessage extends Choreography {

	/**
	Create a new instance of the DeleteMessage Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DeleteMessage(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/SQS/DeleteMessage"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DeleteMessageInputSet
	*/
	public DeleteMessageInputSet newInputSet() {
		return new DeleteMessageInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DeleteMessageResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DeleteMessageResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DeleteMessage
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DeleteMessageInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSAccountId input for this Choreo. 

		@param Integer - (required, integer) The AWS account id associated with the queue. Enter account number omitting any dashes.
		*/
		public void set_AWSAccountId(Integer value) {
			this.setInput("AWSAccountId", value);
		}

		/** 
		Set the value of the AWSAccountId input for this Choreo as a String. 

		@param String - (required, integer) The AWS account id associated with the queue. Enter account number omitting any dashes.
		*/
		public void set_AWSAccountId(String value) {
			this.setInput("AWSAccountId", value);	
		}

		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the QueueName input for this Choreo. 

		@param String - (required, string) The name of the queue that contains the message you want to delete.
		*/
		public void set_QueueName(String value) {
			this.setInput("QueueName", value);
		}



		/** 
		Set the value of the ReceiptHandle input for this Choreo. 

		@param String - (required, string) The receipt handle associated with the message you want to delete. This is returned in the RecieveMessage request.
		*/
		public void set_ReceiptHandle(String value) {
			this.setInput("ReceiptHandle", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DeleteMessage Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DeleteMessageResultSet extends ResultSet {
		public DeleteMessageResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Amazon.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
