package com.temboo.Library.Amazon.SQS;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ReceiveMessage

Returns one or more messages from the specified queue.
*/
public class ReceiveMessage extends Choreography {

	/**
	Create a new instance of the ReceiveMessage Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ReceiveMessage(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/SQS/ReceiveMessage"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ReceiveMessageInputSet
	*/
	public ReceiveMessageInputSet newInputSet() {
		return new ReceiveMessageInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ReceiveMessageResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ReceiveMessageResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ReceiveMessage
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ReceiveMessageInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSAccountId input for this Choreo. 

		@param Integer - (required, integer) The id for the AWS account associated with the queue you're retrieving a message from (remove all dashes in the account number).
		*/
		public void set_AWSAccountId(Integer value) {
			this.setInput("AWSAccountId", value);
		}

		/** 
		Set the value of the AWSAccountId input for this Choreo as a String. 

		@param String - (required, integer) The id for the AWS account associated with the queue you're retrieving a message from (remove all dashes in the account number).
		*/
		public void set_AWSAccountId(String value) {
			this.setInput("AWSAccountId", value);	
		}

		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the AttributeName input for this Choreo. 

		@param String - (optional, string) The attribute you to return. Values are: All (default), SenderId, SentTimestamp, ApproximateReceiveCount, or ApproximateFirstReceiveTimestamp.
		*/
		public void set_AttributeName(String value) {
			this.setInput("AttributeName", value);
		}



		/** 
		Set the value of the MaxNumberOfMessages input for this Choreo. 

		@param Integer - (optional, integer) The maximum number of messages to return. Defaults to 1.
		*/
		public void set_MaxNumberOfMessages(Integer value) {
			this.setInput("MaxNumberOfMessages", value);
		}

		/** 
		Set the value of the MaxNumberOfMessages input for this Choreo as a String. 

		@param String - (optional, integer) The maximum number of messages to return. Defaults to 1.
		*/
		public void set_MaxNumberOfMessages(String value) {
			this.setInput("MaxNumberOfMessages", value);	
		}

		/** 
		Set the value of the QueueName input for this Choreo. 

		@param String - (required, string) The name of the queue you want to retrieve a message from.
		*/
		public void set_QueueName(String value) {
			this.setInput("QueueName", value);
		}



		/** 
		Set the value of the VisibilityTimeout input for this Choreo. 

		@param Integer - (optional, integer) The duration (in seconds) that the received messages are hidden from future retrieve requests after a ReceiveMessage request (max is 43200).
		*/
		public void set_VisibilityTimeout(Integer value) {
			this.setInput("VisibilityTimeout", value);
		}

		/** 
		Set the value of the VisibilityTimeout input for this Choreo as a String. 

		@param String - (optional, integer) The duration (in seconds) that the received messages are hidden from future retrieve requests after a ReceiveMessage request (max is 43200).
		*/
		public void set_VisibilityTimeout(String value) {
			this.setInput("VisibilityTimeout", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ReceiveMessage Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ReceiveMessageResultSet extends ResultSet {
		public ReceiveMessageResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Amazon.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
