package com.temboo.Library.Amazon.SQS;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
RemovePermission

Removes any permission in the queue policy by specifying the permission label.
*/
public class RemovePermission extends Choreography {

	/**
	Create a new instance of the RemovePermission Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public RemovePermission(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/SQS/RemovePermission"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return RemovePermissionInputSet
	*/
	public RemovePermissionInputSet newInputSet() {
		return new RemovePermissionInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public RemovePermissionResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new RemovePermissionResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the RemovePermission
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class RemovePermissionInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSAccountId input for this Choreo. 

		@param Integer - (required, integer) The AWS account number of the queue owner. Enter account number omitting any dashes.
		*/
		public void set_AWSAccountId(Integer value) {
			this.setInput("AWSAccountId", value);
		}

		/** 
		Set the value of the AWSAccountId input for this Choreo as a String. 

		@param String - (required, integer) The AWS account number of the queue owner. Enter account number omitting any dashes.
		*/
		public void set_AWSAccountId(String value) {
			this.setInput("AWSAccountId", value);	
		}

		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the Label input for this Choreo. 

		@param String - (required, string) The unique identifier for the permission that is being removed.
		*/
		public void set_Label(String value) {
			this.setInput("Label", value);
		}



		/** 
		Set the value of the QueueName input for this Choreo. 

		@param String - (required, string) The name of the queue that that has the policy you want to adjust.
		*/
		public void set_QueueName(String value) {
			this.setInput("QueueName", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the RemovePermission Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class RemovePermissionResultSet extends ResultSet {
		public RemovePermissionResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Amazon.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
