package com.temboo.Library.Amazon.SQS;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
SendMessage

Sends a message to a specified queue.
*/
public class SendMessage extends Choreography {

	/**
	Create a new instance of the SendMessage Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public SendMessage(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/SQS/SendMessage"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return SendMessageInputSet
	*/
	public SendMessageInputSet newInputSet() {
		return new SendMessageInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public SendMessageResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new SendMessageResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the SendMessage
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class SendMessageInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}



		/** 
		Set the value of the AWSAccountId input for this Choreo. 

		@param Integer - (required, integer) The id for the AWS account associated with the queue you're sending a message to (remove all dashes in the account number).
		*/
		public void set_AWSAccountId(Integer value) {
			this.setInput("AWSAccountId", value);
		}

		/** 
		Set the value of the AWSAccountId input for this Choreo as a String. 

		@param String - (required, integer) The id for the AWS account associated with the queue you're sending a message to (remove all dashes in the account number).
		*/
		public void set_AWSAccountId(String value) {
			this.setInput("AWSAccountId", value);	
		}

		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}



		/** 
		Set the value of the MessageBody input for this Choreo. 

		@param String - (required, string) The message to send. Maximum size is 64 KB.
		*/
		public void set_MessageBody(String value) {
			this.setInput("MessageBody", value);
		}



		/** 
		Set the value of the QueueName input for this Choreo. 

		@param String - (required, string) The name of the queue you want to send a message to.
		*/
		public void set_QueueName(String value) {
			this.setInput("QueueName", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the SendMessage Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class SendMessageResultSet extends ResultSet {
		public SendMessageResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Amazon.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
