package com.temboo.Library.AuthorizeNet.AutomatedRecurringBilling;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CancelSubscription

Cancels an existing subscription.
*/
public class CancelSubscription extends Choreography {

	/**
	Create a new instance of the CancelSubscription Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CancelSubscription(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/AuthorizeNet/AutomatedRecurringBilling/CancelSubscription"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CancelSubscriptionInputSet
	*/
	public CancelSubscriptionInputSet newInputSet() {
		return new CancelSubscriptionInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CancelSubscriptionResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CancelSubscriptionResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CancelSubscription
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CancelSubscriptionInputSet extends InputSet {
		/** 
		Set the value of the APILoginId input for this Choreo. 

		@param String - (required, string) The API Login Id provided by Authorize.net when signing up for a developer account.
		*/
		public void set_APILoginId(String value) {
			this.setInput("APILoginId", value);
		}



		/** 
		Set the value of the Endpoint input for this Choreo. 

		@param String - (optional, string) Set to api.authorize.net when running in production. Defaults to apitest.authorize.net for sandbox testing.
		*/
		public void set_Endpoint(String value) {
			this.setInput("Endpoint", value);
		}



		/** 
		Set the value of the RefId input for this Choreo. 

		@param String - (optional, string) The merchant assigned reference id for the subscription.
		*/
		public void set_RefId(String value) {
			this.setInput("RefId", value);
		}



		/** 
		Set the value of the SubscriptionId input for this Choreo. 

		@param Integer - (required, integer) The id of the subscription that you want to cancel.
		*/
		public void set_SubscriptionId(Integer value) {
			this.setInput("SubscriptionId", value);
		}

		/** 
		Set the value of the SubscriptionId input for this Choreo as a String. 

		@param String - (required, integer) The id of the subscription that you want to cancel.
		*/
		public void set_SubscriptionId(String value) {
			this.setInput("SubscriptionId", value);	
		}

		/** 
		Set the value of the TransactionKey input for this Choreo. 

		@param String - (required, string) The TransactionKey provided by Authorize.net when signing up for a developer account.
		*/
		public void set_TransactionKey(String value) {
			this.setInput("TransactionKey", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CancelSubscription Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CancelSubscriptionResultSet extends ResultSet {
		public CancelSubscriptionResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Authorize.net.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
