package com.temboo.Library.AuthorizeNet.CustomerInformationManager;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetCustomerProfile

Retrieves an existing customer profile by id with relevant payment profiles and shipping addresses.
*/
public class GetCustomerProfile extends Choreography {

	/**
	Create a new instance of the GetCustomerProfile Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetCustomerProfile(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/AuthorizeNet/CustomerInformationManager/GetCustomerProfile"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetCustomerProfileInputSet
	*/
	public GetCustomerProfileInputSet newInputSet() {
		return new GetCustomerProfileInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetCustomerProfileResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetCustomerProfileResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetCustomerProfile
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetCustomerProfileInputSet extends InputSet {
		/** 
		Set the value of the APILoginId input for this Choreo. 

		@param String - (required, string) The API Login Id provided by Authorize.net when signing up for a developer account.
		*/
		public void set_APILoginId(String value) {
			this.setInput("APILoginId", value);
		}



		/** 
		Set the value of the CustomerProfileId input for this Choreo. 

		@param Integer - (required, integer) The id of the customer who's profile you want to return.
		*/
		public void set_CustomerProfileId(Integer value) {
			this.setInput("CustomerProfileId", value);
		}

		/** 
		Set the value of the CustomerProfileId input for this Choreo as a String. 

		@param String - (required, integer) The id of the customer who's profile you want to return.
		*/
		public void set_CustomerProfileId(String value) {
			this.setInput("CustomerProfileId", value);	
		}

		/** 
		Set the value of the Endpoint input for this Choreo. 

		@param String - (optional, string) Set to api.authorize.net when running in production. Defaults to apitest.authorize.net for sandbox testing.
		*/
		public void set_Endpoint(String value) {
			this.setInput("Endpoint", value);
		}



		/** 
		Set the value of the TransactionKey input for this Choreo. 

		@param String - (required, string) The TransactionKey provided by Authorize.net when signing up for a developer account.
		*/
		public void set_TransactionKey(String value) {
			this.setInput("TransactionKey", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetCustomerProfile Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetCustomerProfileResultSet extends ResultSet {
		public GetCustomerProfileResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Authorize.net.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
