package com.temboo.Library.AuthorizeNet.TransactionDetailsAPI;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetTransactionList

Returns a list of transactions and their details for a specified batch ID.
*/
public class GetTransactionList extends Choreography {

	/**
	Create a new instance of the GetTransactionList Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetTransactionList(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/AuthorizeNet/TransactionDetailsAPI/GetTransactionList"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetTransactionListInputSet
	*/
	public GetTransactionListInputSet newInputSet() {
		return new GetTransactionListInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetTransactionListResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetTransactionListResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetTransactionList
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetTransactionListInputSet extends InputSet {
		/** 
		Set the value of the APILoginId input for this Choreo. 

		@param String - (required, string) The API Login Id provided by Authorize.net when signing up for a developer account.
		*/
		public void set_APILoginId(String value) {
			this.setInput("APILoginId", value);
		}



		/** 
		Set the value of the BatchId input for this Choreo. 

		@param Integer - (required, integer) The id of the batch that you want to retrieve a list of transactions for.
		*/
		public void set_BatchId(Integer value) {
			this.setInput("BatchId", value);
		}

		/** 
		Set the value of the BatchId input for this Choreo as a String. 

		@param String - (required, integer) The id of the batch that you want to retrieve a list of transactions for.
		*/
		public void set_BatchId(String value) {
			this.setInput("BatchId", value);	
		}

		/** 
		Set the value of the Endpoint input for this Choreo. 

		@param String - (optional, string) Set to api.authorize.net when running in production. Defaults to apitest.authorize.net for sandbox testing.
		*/
		public void set_Endpoint(String value) {
			this.setInput("Endpoint", value);
		}



		/** 
		Set the value of the TransactionKey input for this Choreo. 

		@param String - (required, string) The TransactionKey provided by Authorize.net when signing up for a developer account.
		*/
		public void set_TransactionKey(String value) {
			this.setInput("TransactionKey", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetTransactionList Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetTransactionListResultSet extends ResultSet {
		public GetTransactionListResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Authorize.net.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
