package com.temboo.Library.Bitly.Links;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetLinkInfo

Returns the page title for a given bitly link.
*/
public class GetLinkInfo extends Choreography {

	/**
	Create a new instance of the GetLinkInfo Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetLinkInfo(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Bitly/Links/GetLinkInfo"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetLinkInfoInputSet
	*/
	public GetLinkInfoInputSet newInputSet() {
		return new GetLinkInfoInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetLinkInfoResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetLinkInfoResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetLinkInfo
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetLinkInfoInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The oAuth access token provided by Bitly.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that you want the response to be in. Accepted values are "json" or "xml". Defaults to "json".
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the ShortURL input for this Choreo. 

		@param String - (required, string) One or more bitly links.
		*/
		public void set_ShortURL(String value) {
			this.setInput("ShortURL", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetLinkInfo Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetLinkInfoResultSet extends ResultSet {
		public GetLinkInfoResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Bitly.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
