package com.temboo.Library.Bitly.Links;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
LinkLookup

Used to lookup a bitly link with a given long URL.
*/
public class LinkLookup extends Choreography {

	/**
	Create a new instance of the LinkLookup Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public LinkLookup(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Bitly/Links/LinkLookup"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return LinkLookupInputSet
	*/
	public LinkLookupInputSet newInputSet() {
		return new LinkLookupInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public LinkLookupResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new LinkLookupResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the LinkLookup
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class LinkLookupInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The oAuth access token provided by Bitly.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that you want the response to be in. Accepted values are "json" or "xml". Defaults to "json".
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the URL input for this Choreo. 

		@param String - (required, string) One or more long URLs to lookup.
		*/
		public void set_URL(String value) {
			this.setInput("URL", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the LinkLookup Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class LinkLookupResultSet extends ResultSet {
		public LinkLookupResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Bitly.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
