package com.temboo.Library.Bitly.Links;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ShortenURL

Returns a shortened URL for a long URL that you provide.
*/
public class ShortenURL extends Choreography {

	/**
	Create a new instance of the ShortenURL Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ShortenURL(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Bitly/Links/ShortenURL"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ShortenURLInputSet
	*/
	public ShortenURLInputSet newInputSet() {
		return new ShortenURLInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ShortenURLResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ShortenURLResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ShortenURL
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ShortenURLInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The oAuth access token provided by Bitly.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the LongURL input for this Choreo. 

		@param String - (required, string) The long url that you want to shorten.
		*/
		public void set_LongURL(String value) {
			this.setInput("LongURL", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that you want the response to be in. Defaults to simple "txt" format which will just return the shortened URL. "json" and "xml" are also supported.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ShortenURL Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ShortenURLResultSet extends ResultSet {
		public ShortenURLResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Bitly.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
