package com.temboo.Library.Box.Collaborations;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
AddCollaboration

Adds a collaboration for a single user to a specific folder.
*/
public class AddCollaboration extends Choreography {

	/**
	Create a new instance of the AddCollaboration Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public AddCollaboration(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Box/Collaborations/AddCollaboration"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return AddCollaborationInputSet
	*/
	public AddCollaborationInputSet newInputSet() {
		return new AddCollaborationInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public AddCollaborationResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new AddCollaborationResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the AddCollaboration
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class AddCollaborationInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The access token retrieved during the OAuth2 process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the Fields input for this Choreo. 

		@param String - (optional, string) A comma-separated list of fields to include in the response.
		*/
		public void set_Fields(String value) {
			this.setInput("Fields", value);
		}



		/** 
		Set the value of the FolderID input for this Choreo. 

		@param String - (required, string) The id of the folder that you want to create a collaboration for.
		*/
		public void set_FolderID(String value) {
			this.setInput("FolderID", value);
		}



		/** 
		Set the value of the Login input for this Choreo. 

		@param String - (conditional, string) The email address of someone who this collaboration applies to. Required unless providing the UserID. Note, this does not need to be a Box user.
		*/
		public void set_Login(String value) {
			this.setInput("Login", value);
		}



		/** 
		Set the value of the Role input for this Choreo. 

		@param String - (optional, string) The access level of the collaboration. Valid values are "viewer" or "editor". Defaults to "viewer".
		*/
		public void set_Role(String value) {
			this.setInput("Role", value);
		}



		/** 
		Set the value of the UserID input for this Choreo. 

		@param String - (conditional, string) The id of a Box user who this collaboration applies to. Required unless providing the EmailAddress.
		*/
		public void set_UserID(String value) {
			this.setInput("UserID", value);
		}



		/** 
		Set the value of the VaultFile input for this Choreo. 

		@param TembooPath - (optional, vault file) The path to a vault file that you want to upload. Required unless using the FileContents input.
		*/
		public void set_VaultFile(TembooPath value) {
			this.setAlias("VaultFile", value);
		}
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the AddCollaboration Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class AddCollaborationResultSet extends ResultSet {
		public AddCollaborationResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Box.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
