package com.temboo.Library.Box.Comments;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
AddComment

Adds a comment to a specific file.
*/
public class AddComment extends Choreography {

	/**
	Create a new instance of the AddComment Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public AddComment(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Box/Comments/AddComment"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return AddCommentInputSet
	*/
	public AddCommentInputSet newInputSet() {
		return new AddCommentInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public AddCommentResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new AddCommentResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the AddComment
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class AddCommentInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The access token retrieved during the OAuth2 process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the Fields input for this Choreo. 

		@param String - (optional, string) A comma-separated list of fields to include in the response.
		*/
		public void set_Fields(String value) {
			this.setInput("Fields", value);
		}



		/** 
		Set the value of the FileID input for this Choreo. 

		@param String - (required, string) The id of the file that you want to view comments for.
		*/
		public void set_FileID(String value) {
			this.setInput("FileID", value);
		}



		/** 
		Set the value of the Message input for this Choreo. 

		@param String - (required, string) The text of the comment to be posted.
		*/
		public void set_Message(String value) {
			this.setInput("Message", value);
		}



		/** 
		Set the value of the VaultFile input for this Choreo. 

		@param TembooPath - (optional, vault file) The path to a vault file that you want to upload. Required unless using the FileContents input.
		*/
		public void set_VaultFile(TembooPath value) {
			this.setAlias("VaultFile", value);
		}
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the AddComment Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class AddCommentResultSet extends ResultSet {
		public AddCommentResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Box.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
