package com.temboo.Library.Box.Files;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
UpdateFile

Updates individual or multiple fields in the file object.
*/
public class UpdateFile extends Choreography {

	/**
	Create a new instance of the UpdateFile Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public UpdateFile(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Box/Files/UpdateFile"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return UpdateFileInputSet
	*/
	public UpdateFileInputSet newInputSet() {
		return new UpdateFileInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public UpdateFileResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new UpdateFileResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the UpdateFile
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class UpdateFileInputSet extends InputSet {
		/** 
		Set the value of the FileObject input for this Choreo. 

		@param String - (required, json) A JSON object representing the new file information. See documentation for formatting examples.
		*/
		public void set_FileObject(String value) {
			this.setInput("FileObject", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The access token retrieved during the OAuth2 process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the Fields input for this Choreo. 

		@param String - (optional, string) A comma-separated list of fields to include in the response.
		*/
		public void set_Fields(String value) {
			this.setInput("Fields", value);
		}



		/** 
		Set the value of the FileID input for this Choreo. 

		@param String - (required, string) The id of the file to update.
		*/
		public void set_FileID(String value) {
			this.setInput("FileID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the UpdateFile Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class UpdateFileResultSet extends ResultSet {
		public UpdateFileResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Box.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
