package com.temboo.Library.Box.Folders;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CreateFolder

Creates a new folder in the parent folder you specify.
*/
public class CreateFolder extends Choreography {

	/**
	Create a new instance of the CreateFolder Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CreateFolder(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Box/Folders/CreateFolder"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CreateFolderInputSet
	*/
	public CreateFolderInputSet newInputSet() {
		return new CreateFolderInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CreateFolderResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CreateFolderResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CreateFolder
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CreateFolderInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The access token retrieved during the OAuth2 process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the Fields input for this Choreo. 

		@param String - (optional, string) A comma-separated list of fields to include in the response.
		*/
		public void set_Fields(String value) {
			this.setInput("Fields", value);
		}



		/** 
		Set the value of the Name input for this Choreo. 

		@param String - (required, string) The name of the folder to create.
		*/
		public void set_Name(String value) {
			this.setInput("Name", value);
		}



		/** 
		Set the value of the ParentID input for this Choreo. 

		@param String - (optional, string) The ID of the parent folder in which to create the new folder. Defaults to 0 indicating the "root" folder.
		*/
		public void set_ParentID(String value) {
			this.setInput("ParentID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CreateFolder Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CreateFolderResultSet extends ResultSet {
		public CreateFolderResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Box.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
