package com.temboo.Library.Box.Folders;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CreateSharedLink

Creates a shared link for a particular folder.
*/
public class CreateSharedLink extends Choreography {

	/**
	Create a new instance of the CreateSharedLink Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CreateSharedLink(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Box/Folders/CreateSharedLink"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CreateSharedLinkInputSet
	*/
	public CreateSharedLinkInputSet newInputSet() {
		return new CreateSharedLinkInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CreateSharedLinkResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CreateSharedLinkResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CreateSharedLink
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CreateSharedLinkInputSet extends InputSet {
		/** 
		Set the value of the SharedLink input for this Choreo. 

		@param String - (required, json) A JSON object  representing the item’s shared link and associated permissions. See documentation for formatting examples.
		*/
		public void set_SharedLink(String value) {
			this.setInput("SharedLink", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The access token retrieved during the OAuth2 process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the Fields input for this Choreo. 

		@param String - (optional, string) A comma-separated list of fields to include in the response.
		*/
		public void set_Fields(String value) {
			this.setInput("Fields", value);
		}



		/** 
		Set the value of the FolderID input for this Choreo. 

		@param String - (required, string) The id of the folder to get a shared link for.
		*/
		public void set_FolderID(String value) {
			this.setInput("FolderID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CreateSharedLink Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CreateSharedLinkResultSet extends ResultSet {
		public CreateSharedLinkResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Box.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
