package com.temboo.Library.Box.Folders;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ZipFolder

Creates a zip file containing all files within the specified folder and returns a link to the new compressed file.
*/
public class ZipFolder extends Choreography {

	/**
	Create a new instance of the ZipFolder Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ZipFolder(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Box/Folders/ZipFolder"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ZipFolderInputSet
	*/
	public ZipFolderInputSet newInputSet() {
		return new ZipFolderInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ZipFolderResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ZipFolderResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ZipFolder
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ZipFolderInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The access token retrieved during the OAuth2 process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the FolderID input for this Choreo. 

		@param String - (conditional, string) The id of the folder that you want to retrieve items for to zip. To indicate the root folder, specify 0.
		*/
		public void set_FolderID(String value) {
			this.setInput("FolderID", value);
		}



		/** 
		Set the value of the SharedLink input for this Choreo. 

		@param String - (conditional, json) A JSON object  representing the item’s shared link and associated permissions. See documentation for formatting examples.
		*/
		public void set_SharedLink(String value) {
			this.setInput("SharedLink", value);
		}



		/** 
		Set the value of the ZipFileLocation input for this Choreo. 

		@param String - (optional, string) The id of the folder to put the new zip file in. When not specified, the zip file will be put in the root folder.
		*/
		public void set_ZipFileLocation(String value) {
			this.setInput("ZipFileLocation", value);
		}



		/** 
		Set the value of the ZipFileName input for this Choreo. 

		@param String - (required, string) The name of the zip file that will be created.
		*/
		public void set_ZipFileName(String value) {
			this.setInput("ZipFileName", value);
		}



		/** 
		Set the value of the VaultFile input for this Choreo. 

		@param TembooPath - (optional, vault file) The path to a vault file that you want to upload. Required unless using the FileContents input.
		*/
		public void set_VaultFile(TembooPath value) {
			this.setAlias("VaultFile", value);
		}
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ZipFolder Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ZipFolderResultSet extends ResultSet {
		public ZipFolderResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Box. This contains the newly created zip file metadata.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** 
		Retrieve the value for the "URL" output from this Choreo execution

		@return String - (string) The url for the newly created zip file.
		*/
		public String get_URL() {
			return this.getResult("URL");
		}
	}
	
}
