package com.temboo.Library.Box.Users;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
DeleteUser

Deletes a specified user.
*/
public class DeleteUser extends Choreography {

	/**
	Create a new instance of the DeleteUser Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DeleteUser(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Box/Users/DeleteUser"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DeleteUserInputSet
	*/
	public DeleteUserInputSet newInputSet() {
		return new DeleteUserInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DeleteUserResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DeleteUserResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DeleteUser
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DeleteUserInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The access token retrieved during the OAuth2 process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the Force input for this Choreo. 

		@param Boolean - (optional, boolean) Whether or not the user should be deleted even when they still own files.
		*/
		public void set_Force(Boolean value) {
			this.setInput("Force", value);
		}

		/** 
		Set the value of the Force input for this Choreo as a String. 

		@param String - (optional, boolean) Whether or not the user should be deleted even when they still own files.
		*/
		public void set_Force(String value) {
			this.setInput("Force", value);	
		}

		/** 
		Set the value of the Notify input for this Choreo. 

		@param Boolean - (optional, boolean) Indicates that the user should receive an email notification of the transfer.
		*/
		public void set_Notify(Boolean value) {
			this.setInput("Notify", value);
		}

		/** 
		Set the value of the Notify input for this Choreo as a String. 

		@param String - (optional, boolean) Indicates that the user should receive an email notification of the transfer.
		*/
		public void set_Notify(String value) {
			this.setInput("Notify", value);	
		}

		/** 
		Set the value of the UserID input for this Choreo. 

		@param String - (required, string) The id of the user whose information should be updated.
		*/
		public void set_UserID(String value) {
			this.setInput("UserID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DeleteUser Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DeleteUserResultSet extends ResultSet {
		public DeleteUserResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Box.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
