package com.temboo.Library.BrighterPlanet;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Automobile

Returns greenhouse gas modeling for passenger vehicles operated over periods of time.
*/
public class Automobile extends Choreography {

	/**
	Create a new instance of the Automobile Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Automobile(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/BrighterPlanet/Automobile"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return AutomobileInputSet
	*/
	public AutomobileInputSet newInputSet() {
		return new AutomobileInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public AutomobileResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new AutomobileResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Automobile
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class AutomobileInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Brighter Planet.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Acquisition input for this Choreo. 

		@param String - (optional, string) Date automobile was acquired in YYYY-MM-DD format.
		*/
		public void set_Acquisition(String value) {
			this.setInput("Acquisition", value);
		}



		/** 
		Set the value of the AnnualDistance input for this Choreo. 

		@param BigDecimal - (optional, decimal) Annual distance traveled in kilometres.
		*/
		public void set_AnnualDistance(BigDecimal value) {
			this.setInput("AnnualDistance", value);
		}

		/** 
		Set the value of the AnnualDistance input for this Choreo as a String. 

		@param String - (optional, decimal) Annual distance traveled in kilometres.
		*/
		public void set_AnnualDistance(String value) {
			this.setInput("AnnualDistance", value);	
		}

		/** 
		Set the value of the AnnualFuelUse input for this Choreo. 

		@param BigDecimal - (optional, decimal) Total fuel used in one year in litres.
		*/
		public void set_AnnualFuelUse(BigDecimal value) {
			this.setInput("AnnualFuelUse", value);
		}

		/** 
		Set the value of the AnnualFuelUse input for this Choreo as a String. 

		@param String - (optional, decimal) Total fuel used in one year in litres.
		*/
		public void set_AnnualFuelUse(String value) {
			this.setInput("AnnualFuelUse", value);	
		}

		/** 
		Set the value of the AutomobileFuel input for this Choreo. 

		@param String - (optional, string) Fuel used by automobile (e.g. regular gasoline).
		*/
		public void set_AutomobileFuel(String value) {
			this.setInput("AutomobileFuel", value);
		}



		/** 
		Set the value of the Country input for this Choreo. 

		@param String - (optional, string) ISO code of the country. Defaults to 3166.
		*/
		public void set_Country(String value) {
			this.setInput("Country", value);
		}



		/** 
		Set the value of the DailyDistance input for this Choreo. 

		@param BigDecimal - (optional, decimal) Daily distance traveled on average in kilometres.
		*/
		public void set_DailyDistance(BigDecimal value) {
			this.setInput("DailyDistance", value);
		}

		/** 
		Set the value of the DailyDistance input for this Choreo as a String. 

		@param String - (optional, decimal) Daily distance traveled on average in kilometres.
		*/
		public void set_DailyDistance(String value) {
			this.setInput("DailyDistance", value);	
		}

		/** 
		Set the value of the DailyDuration input for this Choreo. 

		@param Integer - (optional, integer) Average amount of time used daily in seconds.
		*/
		public void set_DailyDuration(Integer value) {
			this.setInput("DailyDuration", value);
		}

		/** 
		Set the value of the DailyDuration input for this Choreo as a String. 

		@param String - (optional, integer) Average amount of time used daily in seconds.
		*/
		public void set_DailyDuration(String value) {
			this.setInput("DailyDuration", value);	
		}

		/** 
		Set the value of the FuelEfficiency input for this Choreo. 

		@param BigDecimal - (optional, decimal) The automobile's fuel efficiency in kilometres per litre.
		*/
		public void set_FuelEfficiency(BigDecimal value) {
			this.setInput("FuelEfficiency", value);
		}

		/** 
		Set the value of the FuelEfficiency input for this Choreo as a String. 

		@param String - (optional, decimal) The automobile's fuel efficiency in kilometres per litre.
		*/
		public void set_FuelEfficiency(String value) {
			this.setInput("FuelEfficiency", value);	
		}

		/** 
		Set the value of the FuelUse input for this Choreo. 

		@param BigDecimal - (optional, decimal) Amount of fuel used in litres.
		*/
		public void set_FuelUse(BigDecimal value) {
			this.setInput("FuelUse", value);
		}

		/** 
		Set the value of the FuelUse input for this Choreo as a String. 

		@param String - (optional, decimal) Amount of fuel used in litres.
		*/
		public void set_FuelUse(String value) {
			this.setInput("FuelUse", value);	
		}

		/** 
		Set the value of the Hybridity input for this Choreo. 

		@param Boolean - (optional, boolean) Enter whether the automobile is a hybrid.
		*/
		public void set_Hybridity(Boolean value) {
			this.setInput("Hybridity", value);
		}

		/** 
		Set the value of the Hybridity input for this Choreo as a String. 

		@param String - (optional, boolean) Enter whether the automobile is a hybrid.
		*/
		public void set_Hybridity(String value) {
			this.setInput("Hybridity", value);	
		}

		/** 
		Set the value of the Make input for this Choreo. 

		@param String - (optional, string) Automobile make (e.g. Honda).
		*/
		public void set_Make(String value) {
			this.setInput("Make", value);
		}



		/** 
		Set the value of the Model input for this Choreo. 

		@param String - (optional, string) Model of automobile (e.g. Civic, Accord).
		*/
		public void set_Model(String value) {
			this.setInput("Model", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) Specify your desired response format. Accepted values are xml and json (the default).
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the Retirement input for this Choreo. 

		@param String - (optional, string) Date automobile is retired from use in YYYY-MM-DD format.
		*/
		public void set_Retirement(String value) {
			this.setInput("Retirement", value);
		}



		/** 
		Set the value of the SizeClass input for this Choreo. 

		@param String - (optional, string) Automobile size class (e.g. midsize car, large van).
		*/
		public void set_SizeClass(String value) {
			this.setInput("SizeClass", value);
		}



		/** 
		Set the value of the Speed input for this Choreo. 

		@param BigDecimal - (optional, decimal) Enter average speed when in use in kilometres per hour.
		*/
		public void set_Speed(BigDecimal value) {
			this.setInput("Speed", value);
		}

		/** 
		Set the value of the Speed input for this Choreo as a String. 

		@param String - (optional, decimal) Enter average speed when in use in kilometres per hour.
		*/
		public void set_Speed(String value) {
			this.setInput("Speed", value);	
		}

		/** 
		Set the value of the Urbanity input for this Choreo. 

		@param Boolean - (optional, boolean) Enter whether the trip is in an urban area.
		*/
		public void set_Urbanity(Boolean value) {
			this.setInput("Urbanity", value);
		}

		/** 
		Set the value of the Urbanity input for this Choreo as a String. 

		@param String - (optional, boolean) Enter whether the trip is in an urban area.
		*/
		public void set_Urbanity(String value) {
			this.setInput("Urbanity", value);	
		}

		/** 
		Set the value of the WeeklyDistance input for this Choreo. 

		@param Integer - (optional, integer) Enter average weekly distance automobile travels in kilometres.
		*/
		public void set_WeeklyDistance(Integer value) {
			this.setInput("WeeklyDistance", value);
		}

		/** 
		Set the value of the WeeklyDistance input for this Choreo as a String. 

		@param String - (optional, integer) Enter average weekly distance automobile travels in kilometres.
		*/
		public void set_WeeklyDistance(String value) {
			this.setInput("WeeklyDistance", value);	
		}

		/** 
		Set the value of the Year input for this Choreo. 

		@param Integer - (optional, integer) Year that automobile was manufactured.
		*/
		public void set_Year(Integer value) {
			this.setInput("Year", value);
		}

		/** 
		Set the value of the Year input for this Choreo as a String. 

		@param String - (optional, integer) Year that automobile was manufactured.
		*/
		public void set_Year(String value) {
			this.setInput("Year", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Automobile Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class AutomobileResultSet extends ResultSet {
		public AutomobileResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Brighter Planet.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
