package com.temboo.Library.BrighterPlanet;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
BusTrip

Returns information about the carbon footprint of passenger bus travel.
*/
public class BusTrip extends Choreography {

	/**
	Create a new instance of the BusTrip Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public BusTrip(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/BrighterPlanet/BusTrip"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return BusTripInputSet
	*/
	public BusTripInputSet newInputSet() {
		return new BusTripInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public BusTripResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new BusTripResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the BusTrip
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class BusTripInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Brighter Planet.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the BusClass input for this Choreo. 

		@param String - (optional, string) The bus class for the trip (i.e. city transit, regional coach).
		*/
		public void set_BusClass(String value) {
			this.setInput("BusClass", value);
		}



		/** 
		Set the value of the Compliance input for this Choreo. 

		@param String - (optional, string) Comply with one or more protocols: Greenhouse Gas Protocol Scope 3 (ghg_protocol_scope_3), and ISO 14064-1 (iso), and The Climate Registry (tcr).
		*/
		public void set_Compliance(String value) {
			this.setInput("Compliance", value);
		}



		/** 
		Set the value of the Date input for this Choreo. 

		@param String - (optional, date) The date of the bus trip in YYYY-MM-DD format.
		*/
		public void set_Date(String value) {
			this.setInput("Date", value);
		}



		/** 
		Set the value of the Distance input for this Choreo. 

		@param BigDecimal - (optional, decimal) The distance of the bus trip in kilometres.
		*/
		public void set_Distance(BigDecimal value) {
			this.setInput("Distance", value);
		}

		/** 
		Set the value of the Distance input for this Choreo as a String. 

		@param String - (optional, decimal) The distance of the bus trip in kilometres.
		*/
		public void set_Distance(String value) {
			this.setInput("Distance", value);	
		}

		/** 
		Set the value of the Duration input for this Choreo. 

		@param BigDecimal - (optional, decimal) The duration of the bus trip in seconds.
		*/
		public void set_Duration(BigDecimal value) {
			this.setInput("Duration", value);
		}

		/** 
		Set the value of the Duration input for this Choreo as a String. 

		@param String - (optional, decimal) The duration of the bus trip in seconds.
		*/
		public void set_Duration(String value) {
			this.setInput("Duration", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) Specify your desired response format. Accepted values are xml and json (the default).
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the Timeframe input for this Choreo. 

		@param String - (optional, string) A date range specified in the following format: 2008-01-01/2008-07-09
		*/
		public void set_Timeframe(String value) {
			this.setInput("Timeframe", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the BusTrip Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class BusTripResultSet extends ResultSet {
		public BusTripResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Brighter Planet.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
