package com.temboo.Library.BrighterPlanet;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Diet

Returns information about the carbon footprint of an individual's yearly food consumption.
*/
public class Diet extends Choreography {

	/**
	Create a new instance of the Diet Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Diet(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/BrighterPlanet/Diet"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DietInputSet
	*/
	public DietInputSet newInputSet() {
		return new DietInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DietResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DietResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Diet
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DietInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Brighter Planet.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the DietClass input for this Choreo. 

		@param String - (optional, string) Enter the type of diet. Acceptable inputs: standard, vegetarian, vegan.
		*/
		public void set_DietClass(String value) {
			this.setInput("DietClass", value);
		}



		/** 
		Set the value of the EndDate input for this Choreo. 

		@param String - (optional, string) End date od diet in YYYY-MM-DD format. Defaults to 2013-01-01 when none specified.
		*/
		public void set_EndDate(String value) {
			this.setInput("EndDate", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) Specify your desired response format. Accepted values are xml and json (the default).
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the Size input for this Choreo. 

		@param Integer - (required, integer) Enter the number of calories consumed per day. See documentation below for a set of national averages for reference.
		*/
		public void set_Size(Integer value) {
			this.setInput("Size", value);
		}

		/** 
		Set the value of the Size input for this Choreo as a String. 

		@param String - (required, integer) Enter the number of calories consumed per day. See documentation below for a set of national averages for reference.
		*/
		public void set_Size(String value) {
			this.setInput("Size", value);	
		}

		/** 
		Set the value of the StartDate input for this Choreo. 

		@param String - (optional, string) Start date of diet in YYYY-MM-DD format. Defaults to 2012-01-01 when none specified.
		*/
		public void set_StartDate(String value) {
			this.setInput("StartDate", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Diet Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DietResultSet extends ResultSet {
		public DietResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Brighter Planet.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
