package com.temboo.Library.BrighterPlanet;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ElectricityUse

Returns information about the carbon footprint of using electricity from the US public grid.
*/
public class ElectricityUse extends Choreography {

	/**
	Create a new instance of the ElectricityUse Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ElectricityUse(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/BrighterPlanet/ElectricityUse"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ElectricityUseInputSet
	*/
	public ElectricityUseInputSet newInputSet() {
		return new ElectricityUseInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ElectricityUseResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ElectricityUseResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ElectricityUse
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ElectricityUseInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Brighter Planet.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Country input for this Choreo. 

		@param String - (optional, string) An iso_3166 country code.
		*/
		public void set_Country(String value) {
			this.setInput("Country", value);
		}



		/** 
		Set the value of the Date input for this Choreo. 

		@param String - (optional, date) The date of the electricity use in YYYY-MM-DD format.
		*/
		public void set_Date(String value) {
			this.setInput("Date", value);
		}



		/** 
		Set the value of the Energy input for this Choreo. 

		@param BigDecimal - (optional, decimal) The amount of engery in kilowatt hours.
		*/
		public void set_Energy(BigDecimal value) {
			this.setInput("Energy", value);
		}

		/** 
		Set the value of the Energy input for this Choreo as a String. 

		@param String - (optional, decimal) The amount of engery in kilowatt hours.
		*/
		public void set_Energy(String value) {
			this.setInput("Energy", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) Specify your desired response format. Accepted values are xml and json (the default).
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the State input for this Choreo. 

		@param String - (optional, string) A postal abbreviation for the state to return electricity information for.
		*/
		public void set_State(String value) {
			this.setInput("State", value);
		}



		/** 
		Set the value of the Timeframe input for this Choreo. 

		@param String - (optional, string) A date range specified in the following format: 2008-01-01/2008-07-09
		*/
		public void set_Timeframe(String value) {
			this.setInput("Timeframe", value);
		}



		/** 
		Set the value of the ZipCode input for this Choreo. 

		@param String - (optional, string) The postal code for the area to retrieve electricity information for.
		*/
		public void set_ZipCode(String value) {
			this.setInput("ZipCode", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ElectricityUse Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ElectricityUseResultSet extends ResultSet {
		public ElectricityUseResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Brighter Planet.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
