package com.temboo.Library.BrighterPlanet;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
FuelPurchase

Returns information about the carbon emissions from using a wide variety of fuel types.
*/
public class FuelPurchase extends Choreography {

	/**
	Create a new instance of the FuelPurchase Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public FuelPurchase(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/BrighterPlanet/FuelPurchase"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return FuelPurchaseInputSet
	*/
	public FuelPurchaseInputSet newInputSet() {
		return new FuelPurchaseInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public FuelPurchaseResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new FuelPurchaseResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the FuelPurchase
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class FuelPurchaseInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Brighter Planet.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Cost input for this Choreo. 

		@param BigDecimal - (optional, decimal) The cost of the fuel purchase.
		*/
		public void set_Cost(BigDecimal value) {
			this.setInput("Cost", value);
		}

		/** 
		Set the value of the Cost input for this Choreo as a String. 

		@param String - (optional, decimal) The cost of the fuel purchase.
		*/
		public void set_Cost(String value) {
			this.setInput("Cost", value);	
		}

		/** 
		Set the value of the Date input for this Choreo. 

		@param String - (optional, date) The date of the fuel purchase in YYYY-MM-DD format.
		*/
		public void set_Date(String value) {
			this.setInput("Date", value);
		}



		/** 
		Set the value of the FuelType input for this Choreo. 

		@param String - (optional, string) The fuel type purchases (i.e. Asphalt and Road Oil, Aviation Gasoline, Commercial Coal, Commercial Natural Gas, or Motor Gasoline)
		*/
		public void set_FuelType(String value) {
			this.setInput("FuelType", value);
		}



		/** 
		Set the value of the PADD input for this Choreo. 

		@param String - (optional, string) A code for the Petroleum administration for defense districts (1A, 1B, 1C, 2, or 3).
		*/
		public void set_PADD(String value) {
			this.setInput("PADD", value);
		}



		/** 
		Set the value of the Price input for this Choreo. 

		@param String - (optional, string) The price of the fuel.
		*/
		public void set_Price(String value) {
			this.setInput("Price", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) Specify your desired response format. Accepted values are xml and json (the default).
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the State input for this Choreo. 

		@param String - (optional, string) A postal abbreviation for the state where the fuel was purchased.
		*/
		public void set_State(String value) {
			this.setInput("State", value);
		}



		/** 
		Set the value of the Timeframe input for this Choreo. 

		@param String - (optional, string) A date range specified in the following format: 2008-01-01/2008-07-09
		*/
		public void set_Timeframe(String value) {
			this.setInput("Timeframe", value);
		}



		/** 
		Set the value of the Volume input for this Choreo. 

		@param BigDecimal - (optional, decimal) The amount of fuel purchased.
		*/
		public void set_Volume(BigDecimal value) {
			this.setInput("Volume", value);
		}

		/** 
		Set the value of the Volume input for this Choreo as a String. 

		@param String - (optional, decimal) The amount of fuel purchased.
		*/
		public void set_Volume(String value) {
			this.setInput("Volume", value);	
		}

		/** 
		Set the value of the ZipCode input for this Choreo. 

		@param String - (optional, string) The postal code for the area where the fuel was purchased.
		*/
		public void set_ZipCode(String value) {
			this.setInput("ZipCode", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the FuelPurchase Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class FuelPurchaseResultSet extends ResultSet {
		public FuelPurchaseResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Brighter Planet.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
