package com.temboo.Library.BrighterPlanet;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetReferenceData

Retrieves a wide variety of reference data sets provided by Brighter Planet.
*/
public class GetReferenceData extends Choreography {

	/**
	Create a new instance of the GetReferenceData Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetReferenceData(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/BrighterPlanet/GetReferenceData"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetReferenceDataInputSet
	*/
	public GetReferenceDataInputSet newInputSet() {
		return new GetReferenceDataInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetReferenceDataResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetReferenceDataResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetReferenceData
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetReferenceDataInputSet extends InputSet {
		/** 
		Set the value of the Resource input for this Choreo. 

		@param String - (required, string) The name of the reference data resource you want to retrieve (i.e. airports, airlines, etc). Resource names are formatted using plural, lowercase, and underscores (i.e. automobile_makes).
		*/
		public void set_Resource(String value) {
			this.setInput("Resource", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The desired response format. Accepted formats are: csv, xml, and json (the default).
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetReferenceData Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetReferenceDataResultSet extends ResultSet {
		public GetReferenceDataResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Brighter Planet.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
