package com.temboo.Library.BrighterPlanet;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Lodging

Returns the the footprint of a guest's hotel stay.
*/
public class Lodging extends Choreography {

	/**
	Create a new instance of the Lodging Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Lodging(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/BrighterPlanet/Lodging"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return LodgingInputSet
	*/
	public LodgingInputSet newInputSet() {
		return new LodgingInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public LodgingResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new LodgingResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Lodging
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class LodgingInputSet extends InputSet {
		/** 
		Set the value of the ACCoverage input for this Choreo. 

		@param BigDecimal - (optional, decimal) A numeric value representing the AC coverage of the lodging establishment.
		*/
		public void set_ACCoverage(BigDecimal value) {
			this.setInput("ACCoverage", value);
		}

		/** 
		Set the value of the ACCoverage input for this Choreo as a String. 

		@param String - (optional, decimal) A numeric value representing the AC coverage of the lodging establishment.
		*/
		public void set_ACCoverage(String value) {
			this.setInput("ACCoverage", value);	
		}

		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Brighter Planet.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the City input for this Choreo. 

		@param String - (optional, string) The city of the establishment.
		*/
		public void set_City(String value) {
			this.setInput("City", value);
		}



		/** 
		Set the value of the Compliance input for this Choreo. 

		@param String - (optional, string) Comply with one or more protocols:  Greenhouse Gas Protocol Scope 3 (ghg_protocol_scope_3), ISO 14064-1 (iso), and The Climate Registry (tcr).
		*/
		public void set_Compliance(String value) {
			this.setInput("Compliance", value);
		}



		/** 
		Set the value of the ConstructionYear input for this Choreo. 

		@param Integer - (optional, integer) The year that the establishment was constructed.
		*/
		public void set_ConstructionYear(Integer value) {
			this.setInput("ConstructionYear", value);
		}

		/** 
		Set the value of the ConstructionYear input for this Choreo as a String. 

		@param String - (optional, integer) The year that the establishment was constructed.
		*/
		public void set_ConstructionYear(String value) {
			this.setInput("ConstructionYear", value);	
		}

		/** 
		Set the value of the Country input for this Choreo. 

		@param String - (optional, string) The ISO 3166 country code associated with the establishment.
		*/
		public void set_Country(String value) {
			this.setInput("Country", value);
		}



		/** 
		Set the value of the Date input for this Choreo. 

		@param String - (optional, date) The date of the stay at the establishment in YYYY-MM-DD format.
		*/
		public void set_Date(String value) {
			this.setInput("Date", value);
		}



		/** 
		Set the value of the Duration input for this Choreo. 

		@param Integer - (optional, integer) The amount of time spent at the establishment in seconds.
		*/
		public void set_Duration(Integer value) {
			this.setInput("Duration", value);
		}

		/** 
		Set the value of the Duration input for this Choreo as a String. 

		@param String - (optional, integer) The amount of time spent at the establishment in seconds.
		*/
		public void set_Duration(String value) {
			this.setInput("Duration", value);	
		}

		/** 
		Set the value of the Floors input for this Choreo. 

		@param Integer - (optional, integer) The number of floors at the establishment.
		*/
		public void set_Floors(Integer value) {
			this.setInput("Floors", value);
		}

		/** 
		Set the value of the Floors input for this Choreo as a String. 

		@param String - (optional, integer) The number of floors at the establishment.
		*/
		public void set_Floors(String value) {
			this.setInput("Floors", value);	
		}

		/** 
		Set the value of the HotTubs input for this Choreo. 

		@param Integer - (optional, integer) The number of hot tubs that the establishment has.
		*/
		public void set_HotTubs(Integer value) {
			this.setInput("HotTubs", value);
		}

		/** 
		Set the value of the HotTubs input for this Choreo as a String. 

		@param String - (optional, integer) The number of hot tubs that the establishment has.
		*/
		public void set_HotTubs(String value) {
			this.setInput("HotTubs", value);	
		}

		/** 
		Set the value of the IndoorPools input for this Choreo. 

		@param Integer - (optional, integer) The number of indoor pools that the establishment has.
		*/
		public void set_IndoorPools(Integer value) {
			this.setInput("IndoorPools", value);
		}

		/** 
		Set the value of the IndoorPools input for this Choreo as a String. 

		@param String - (optional, integer) The number of indoor pools that the establishment has.
		*/
		public void set_IndoorPools(String value) {
			this.setInput("IndoorPools", value);	
		}

		/** 
		Set the value of the LodgingClass input for this Choreo. 

		@param String - (optional, string) The lodging class (i.e. Hotel, Inn, or Motel).
		*/
		public void set_LodgingClass(String value) {
			this.setInput("LodgingClass", value);
		}



		/** 
		Set the value of the OutdoorPools input for this Choreo. 

		@param Integer - (optional, integer) The number of outdoor pools that the establishment has.
		*/
		public void set_OutdoorPools(Integer value) {
			this.setInput("OutdoorPools", value);
		}

		/** 
		Set the value of the OutdoorPools input for this Choreo as a String. 

		@param String - (optional, integer) The number of outdoor pools that the establishment has.
		*/
		public void set_OutdoorPools(String value) {
			this.setInput("OutdoorPools", value);	
		}

		/** 
		Set the value of the PropertyRooms input for this Choreo. 

		@param Integer - (optional, integer) The number of rooms on the property.
		*/
		public void set_PropertyRooms(Integer value) {
			this.setInput("PropertyRooms", value);
		}

		/** 
		Set the value of the PropertyRooms input for this Choreo as a String. 

		@param String - (optional, integer) The number of rooms on the property.
		*/
		public void set_PropertyRooms(String value) {
			this.setInput("PropertyRooms", value);	
		}

		/** 
		Set the value of the Property input for this Choreo. 

		@param Integer - (optional, integer) A property id (or northstart_id) associated with the establishment.
		*/
		public void set_Property(Integer value) {
			this.setInput("Property", value);
		}

		/** 
		Set the value of the Property input for this Choreo as a String. 

		@param String - (optional, integer) A property id (or northstart_id) associated with the establishment.
		*/
		public void set_Property(String value) {
			this.setInput("Property", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) Specify your desired response format. Accepted values are xml and json (the default).
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the Rooms input for this Choreo. 

		@param Integer - (optional, integer) The number of rooms.
		*/
		public void set_Rooms(Integer value) {
			this.setInput("Rooms", value);
		}

		/** 
		Set the value of the Rooms input for this Choreo as a String. 

		@param String - (optional, integer) The number of rooms.
		*/
		public void set_Rooms(String value) {
			this.setInput("Rooms", value);	
		}

		/** 
		Set the value of the State input for this Choreo. 

		@param String - (optional, string) The postal abbreviation for the state that the establishment is in.
		*/
		public void set_State(String value) {
			this.setInput("State", value);
		}



		/** 
		Set the value of the Timeframe input for this Choreo. 

		@param String - (optional, string) A date range specified in the following format: 2008-01-01/2008-07-09
		*/
		public void set_Timeframe(String value) {
			this.setInput("Timeframe", value);
		}



		/** 
		Set the value of the ZipCode input for this Choreo. 

		@param String - (optional, string) The postal code associated with the establishment.
		*/
		public void set_ZipCode(String value) {
			this.setInput("ZipCode", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Lodging Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class LodgingResultSet extends ResultSet {
		public LodgingResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Brighter Planet.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
