package com.temboo.Library.BrighterPlanet;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Meeting

Returns facility operations emissions analysis for corporate and cultural events.
*/
public class Meeting extends Choreography {

	/**
	Create a new instance of the Meeting Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Meeting(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/BrighterPlanet/Meeting"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return MeetingInputSet
	*/
	public MeetingInputSet newInputSet() {
		return new MeetingInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public MeetingResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new MeetingResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Meeting
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class MeetingInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Brighter Planet.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Area input for this Choreo. 

		@param Integer - (optional, integer) Area of event venue in square meters.
		*/
		public void set_Area(Integer value) {
			this.setInput("Area", value);
		}

		/** 
		Set the value of the Area input for this Choreo as a String. 

		@param String - (optional, integer) Area of event venue in square meters.
		*/
		public void set_Area(String value) {
			this.setInput("Area", value);	
		}

		/** 
		Set the value of the Date input for this Choreo. 

		@param String - (optional, string) Date of event in YYYY-MM-DD format.
		*/
		public void set_Date(String value) {
			this.setInput("Date", value);
		}



		/** 
		Set the value of the Duration input for this Choreo. 

		@param Integer - (optional, integer) Event duration in total seconds.
		*/
		public void set_Duration(Integer value) {
			this.setInput("Duration", value);
		}

		/** 
		Set the value of the Duration input for this Choreo as a String. 

		@param String - (optional, integer) Event duration in total seconds.
		*/
		public void set_Duration(String value) {
			this.setInput("Duration", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) Specify your desired response format. Accepted values are xml and json (the default).
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the State input for this Choreo. 

		@param String - (optional, string) Two-letter postal abbreviation for the state in which the meeting takes place (e.g. NY).
		*/
		public void set_State(String value) {
			this.setInput("State", value);
		}



		/** 
		Set the value of the Zip input for this Choreo. 

		@param Integer - (optional, integer) Five digit zip code in which the meeting takes place.
		*/
		public void set_Zip(Integer value) {
			this.setInput("Zip", value);
		}

		/** 
		Set the value of the Zip input for this Choreo as a String. 

		@param String - (optional, integer) Five digit zip code in which the meeting takes place.
		*/
		public void set_Zip(String value) {
			this.setInput("Zip", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Meeting Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class MeetingResultSet extends ResultSet {
		public MeetingResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Brighter Planet.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
