package com.temboo.Library.BrighterPlanet;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Pet

Returns lifecycle food production and veterinary care emissions modeling for domestic animals.
*/
public class Pet extends Choreography {

	/**
	Create a new instance of the Pet Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Pet(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/BrighterPlanet/Pet"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return PetInputSet
	*/
	public PetInputSet newInputSet() {
		return new PetInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public PetResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new PetResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Pet
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class PetInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Brighter Planet.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Acquisition input for this Choreo. 

		@param String - (optional, string) Enter date the pet was acquired.
		*/
		public void set_Acquisition(String value) {
			this.setInput("Acquisition", value);
		}



		/** 
		Set the value of the Breed input for this Choreo. 

		@param String - (optional, string) Enter a cat, dog, or horse breed.
		*/
		public void set_Breed(String value) {
			this.setInput("Breed", value);
		}



		/** 
		Set the value of the Gender input for this Choreo. 

		@param String - (optional, string) Enter cat, dog, or horse gender.
		*/
		public void set_Gender(String value) {
			this.setInput("Gender", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) Specify your desired response format. Accepted values are xml and json (the default).
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the Retirement input for this Choreo. 

		@param String - (optional, string) Enter date you no longer have the pet.
		*/
		public void set_Retirement(String value) {
			this.setInput("Retirement", value);
		}



		/** 
		Set the value of the Species input for this Choreo. 

		@param String - (optional, string) Enter the species type (e.g. bird, cat, dog, ferret, fish).
		*/
		public void set_Species(String value) {
			this.setInput("Species", value);
		}



		/** 
		Set the value of the Weight input for this Choreo. 

		@param BigDecimal - (optional, decimal) Enter pet weight in kilograms.
		*/
		public void set_Weight(BigDecimal value) {
			this.setInput("Weight", value);
		}

		/** 
		Set the value of the Weight input for this Choreo as a String. 

		@param String - (optional, decimal) Enter pet weight in kilograms.
		*/
		public void set_Weight(String value) {
			this.setInput("Weight", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Pet Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class PetResultSet extends ResultSet {
		public PetResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Brighter Planet.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
