package com.temboo.Library.BrighterPlanet;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Purchase

Returns lifecycle emissions for any good or service. 
*/
public class Purchase extends Choreography {

	/**
	Create a new instance of the Purchase Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Purchase(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/BrighterPlanet/Purchase"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return PurchaseInputSet
	*/
	public PurchaseInputSet newInputSet() {
		return new PurchaseInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public PurchaseResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new PurchaseResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Purchase
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class PurchaseInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Brighter Planet.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Cost input for this Choreo. 

		@param BigDecimal - (optional, decimal) The cost associated with the purchase.
		*/
		public void set_Cost(BigDecimal value) {
			this.setInput("Cost", value);
		}

		/** 
		Set the value of the Cost input for this Choreo as a String. 

		@param String - (optional, decimal) The cost associated with the purchase.
		*/
		public void set_Cost(String value) {
			this.setInput("Cost", value);	
		}

		/** 
		Set the value of the Date input for this Choreo. 

		@param String - (optional, date) The date of the purchase in YYYY-MM-DD format.
		*/
		public void set_Date(String value) {
			this.setInput("Date", value);
		}



		/** 
		Set the value of the Industry input for this Choreo. 

		@param Integer - (optional, integer) An industry code (NAICS CODE) corresponding to the industry to return results for. For example, the id for Audio and Video Equipment Manufacturing is 334310.
		*/
		public void set_Industry(Integer value) {
			this.setInput("Industry", value);
		}

		/** 
		Set the value of the Industry input for this Choreo as a String. 

		@param String - (optional, integer) An industry code (NAICS CODE) corresponding to the industry to return results for. For example, the id for Audio and Video Equipment Manufacturing is 334310.
		*/
		public void set_Industry(String value) {
			this.setInput("Industry", value);	
		}

		/** 
		Set the value of the MerchantCategory input for this Choreo. 

		@param String - (optional, string) The id for a merchant category.
		*/
		public void set_MerchantCategory(String value) {
			this.setInput("MerchantCategory", value);
		}



		/** 
		Set the value of the Merchant input for this Choreo. 

		@param Integer - (optional, integer) An id corresponding to a merchant that you want to return data for.
		*/
		public void set_Merchant(Integer value) {
			this.setInput("Merchant", value);
		}

		/** 
		Set the value of the Merchant input for this Choreo as a String. 

		@param String - (optional, integer) An id corresponding to a merchant that you want to return data for.
		*/
		public void set_Merchant(String value) {
			this.setInput("Merchant", value);	
		}

		/** 
		Set the value of the PurchaseAmount input for this Choreo. 

		@param BigDecimal - (optional, decimal) The purchase amount.
		*/
		public void set_PurchaseAmount(BigDecimal value) {
			this.setInput("PurchaseAmount", value);
		}

		/** 
		Set the value of the PurchaseAmount input for this Choreo as a String. 

		@param String - (optional, decimal) The purchase amount.
		*/
		public void set_PurchaseAmount(String value) {
			this.setInput("PurchaseAmount", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) Specify your desired response format. Accepted values are xml and json (the default).
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the SicIndustry input for this Choreo. 

		@param Integer - (optional, integer) A Sic Industry id (i.e. 0111 is the code for Wheat, 0112 is the code for Rice, etc).
		*/
		public void set_SicIndustry(Integer value) {
			this.setInput("SicIndustry", value);
		}

		/** 
		Set the value of the SicIndustry input for this Choreo as a String. 

		@param String - (optional, integer) A Sic Industry id (i.e. 0111 is the code for Wheat, 0112 is the code for Rice, etc).
		*/
		public void set_SicIndustry(String value) {
			this.setInput("SicIndustry", value);	
		}

		/** 
		Set the value of the Tax input for this Choreo. 

		@param BigDecimal - (optional, decimal) The tax amount for the purchase.
		*/
		public void set_Tax(BigDecimal value) {
			this.setInput("Tax", value);
		}

		/** 
		Set the value of the Tax input for this Choreo as a String. 

		@param String - (optional, decimal) The tax amount for the purchase.
		*/
		public void set_Tax(String value) {
			this.setInput("Tax", value);	
		}

		/** 
		Set the value of the Timeframe input for this Choreo. 

		@param String - (optional, string) A date range specified in the following format: 2008-01-01/2008-07-09
		*/
		public void set_Timeframe(String value) {
			this.setInput("Timeframe", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Purchase Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class PurchaseResultSet extends ResultSet {
		public PurchaseResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Brighter Planet.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
