package com.temboo.Library.BrighterPlanet;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
RailTrip

Returns information about the carbon footprint of a passenger's train travel.
*/
public class RailTrip extends Choreography {

	/**
	Create a new instance of the RailTrip Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public RailTrip(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/BrighterPlanet/RailTrip"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return RailTripInputSet
	*/
	public RailTripInputSet newInputSet() {
		return new RailTripInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public RailTripResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new RailTripResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the RailTrip
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class RailTripInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Brighter Planet.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Compliance input for this Choreo. 

		@param String - (optional, string) Comply with one or more protocols:  Greenhouse Gas Protocol Scope 3 (ghg_protocol_scope_3), ISO 14064-1 (iso), and The Climate Registry (tcr).
		*/
		public void set_Compliance(String value) {
			this.setInput("Compliance", value);
		}



		/** 
		Set the value of the Country input for this Choreo. 

		@param String - (optional, string) A country code associated with the rail trip (in ISO 3166 format).
		*/
		public void set_Country(String value) {
			this.setInput("Country", value);
		}



		/** 
		Set the value of the Date input for this Choreo. 

		@param String - (optional, date) The date of the rail trip in YYYY-MM-DD format.
		*/
		public void set_Date(String value) {
			this.setInput("Date", value);
		}



		/** 
		Set the value of the Destination input for this Choreo. 

		@param String - (optional, string) The destination of the rail trip.
		*/
		public void set_Destination(String value) {
			this.setInput("Destination", value);
		}



		/** 
		Set the value of the Distance input for this Choreo. 

		@param BigDecimal - (optional, decimal) The distance of the rail trip in kilometres.
		*/
		public void set_Distance(BigDecimal value) {
			this.setInput("Distance", value);
		}

		/** 
		Set the value of the Distance input for this Choreo as a String. 

		@param String - (optional, decimal) The distance of the rail trip in kilometres.
		*/
		public void set_Distance(String value) {
			this.setInput("Distance", value);	
		}

		/** 
		Set the value of the Duration input for this Choreo. 

		@param BigDecimal - (optional, decimal) The duration of the rail trip in seconds.
		*/
		public void set_Duration(BigDecimal value) {
			this.setInput("Duration", value);
		}

		/** 
		Set the value of the Duration input for this Choreo as a String. 

		@param String - (optional, decimal) The duration of the rail trip in seconds.
		*/
		public void set_Duration(String value) {
			this.setInput("Duration", value);	
		}

		/** 
		Set the value of the Origin input for this Choreo. 

		@param String - (optional, string) The origin of the rail trip.
		*/
		public void set_Origin(String value) {
			this.setInput("Origin", value);
		}



		/** 
		Set the value of the RailClass input for this Choreo. 

		@param String - (optional, string) The rail class associated with the rail trip (i.e. commuter, heavy, highspeed, intercity, light).
		*/
		public void set_RailClass(String value) {
			this.setInput("RailClass", value);
		}



		/** 
		Set the value of the RailCompany input for this Choreo. 

		@param String - (optional, string) The rail company associated with the rail trip (i.e. AMTRAK).
		*/
		public void set_RailCompany(String value) {
			this.setInput("RailCompany", value);
		}



		/** 
		Set the value of the RailTraction input for this Choreo. 

		@param String - (optional, string) The rail traction associated with the rail trip (i.e. diesel, electric).
		*/
		public void set_RailTraction(String value) {
			this.setInput("RailTraction", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) Specify your desired response format. Accepted values are xml and json (the default).
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the Timeframe input for this Choreo. 

		@param String - (optional, string) A date range specified in the following format: 2008-01-01/2008-07-09
		*/
		public void set_Timeframe(String value) {
			this.setInput("Timeframe", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the RailTrip Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class RailTripResultSet extends ResultSet {
		public RailTripResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Brighter Planet.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
