package com.temboo.Library.BrighterPlanet;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Residence

Returns information about the annual carbon footprint of a home.
*/
public class Residence extends Choreography {

	/**
	Create a new instance of the Residence Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Residence(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/BrighterPlanet/Residence"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ResidenceInputSet
	*/
	public ResidenceInputSet newInputSet() {
		return new ResidenceInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ResidenceResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ResidenceResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Residence
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ResidenceInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Brighter Planet.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Acquisition input for this Choreo. 

		@param String - (optional, date) Date of acquisition in YYYY-MM-DD format.
		*/
		public void set_Acquisition(String value) {
			this.setInput("Acquisition", value);
		}



		/** 
		Set the value of the AirConditionerUse input for this Choreo. 

		@param String - (optional, string) The frequency of air conditioner use. Accepted values are: "Not used at all", "Turned on just about all summer", "Turned on only a few days or nights when really needed", or "Turned on quite a bit"
		*/
		public void set_AirConditionerUse(String value) {
			this.setInput("AirConditionerUse", value);
		}



		/** 
		Set the value of the AnnualCoalVolumeEstimate input for this Choreo. 

		@param BigDecimal - (optional, decimal) An estimate for amount of coal used annually.
		*/
		public void set_AnnualCoalVolumeEstimate(BigDecimal value) {
			this.setInput("AnnualCoalVolumeEstimate", value);
		}

		/** 
		Set the value of the AnnualCoalVolumeEstimate input for this Choreo as a String. 

		@param String - (optional, decimal) An estimate for amount of coal used annually.
		*/
		public void set_AnnualCoalVolumeEstimate(String value) {
			this.setInput("AnnualCoalVolumeEstimate", value);	
		}

		/** 
		Set the value of the AnnualFuelOilCost input for this Choreo. 

		@param BigDecimal - (optional, decimal) Annual cost of oil fuel in dollars.
		*/
		public void set_AnnualFuelOilCost(BigDecimal value) {
			this.setInput("AnnualFuelOilCost", value);
		}

		/** 
		Set the value of the AnnualFuelOilCost input for this Choreo as a String. 

		@param String - (optional, decimal) Annual cost of oil fuel in dollars.
		*/
		public void set_AnnualFuelOilCost(String value) {
			this.setInput("AnnualFuelOilCost", value);	
		}

		/** 
		Set the value of the AnnualFuelOilVolumeEstimate input for this Choreo. 

		@param BigDecimal - (optional, decimal) An estimate for the volume oil used annually.
		*/
		public void set_AnnualFuelOilVolumeEstimate(BigDecimal value) {
			this.setInput("AnnualFuelOilVolumeEstimate", value);
		}

		/** 
		Set the value of the AnnualFuelOilVolumeEstimate input for this Choreo as a String. 

		@param String - (optional, decimal) An estimate for the volume oil used annually.
		*/
		public void set_AnnualFuelOilVolumeEstimate(String value) {
			this.setInput("AnnualFuelOilVolumeEstimate", value);	
		}

		/** 
		Set the value of the AnnualPropaneCost input for this Choreo. 

		@param BigDecimal - (optional, decimal) The annual cost of propane annually in dollars.
		*/
		public void set_AnnualPropaneCost(BigDecimal value) {
			this.setInput("AnnualPropaneCost", value);
		}

		/** 
		Set the value of the AnnualPropaneCost input for this Choreo as a String. 

		@param String - (optional, decimal) The annual cost of propane annually in dollars.
		*/
		public void set_AnnualPropaneCost(String value) {
			this.setInput("AnnualPropaneCost", value);	
		}

		/** 
		Set the value of the AnnualPropaneVolumeEstimate input for this Choreo. 

		@param BigDecimal - (optional, decimal) An estimate of the amount of propane used annually in litres.
		*/
		public void set_AnnualPropaneVolumeEstimate(BigDecimal value) {
			this.setInput("AnnualPropaneVolumeEstimate", value);
		}

		/** 
		Set the value of the AnnualPropaneVolumeEstimate input for this Choreo as a String. 

		@param String - (optional, decimal) An estimate of the amount of propane used annually in litres.
		*/
		public void set_AnnualPropaneVolumeEstimate(String value) {
			this.setInput("AnnualPropaneVolumeEstimate", value);	
		}

		/** 
		Set the value of the AnnualWoodVolumeEstimate input for this Choreo. 

		@param BigDecimal - (optional, decimal) An estimate of the amount of wood used for heating annually (in Joulses).
		*/
		public void set_AnnualWoodVolumeEstimate(BigDecimal value) {
			this.setInput("AnnualWoodVolumeEstimate", value);
		}

		/** 
		Set the value of the AnnualWoodVolumeEstimate input for this Choreo as a String. 

		@param String - (optional, decimal) An estimate of the amount of wood used for heating annually (in Joulses).
		*/
		public void set_AnnualWoodVolumeEstimate(String value) {
			this.setInput("AnnualWoodVolumeEstimate", value);	
		}

		/** 
		Set the value of the Bathrooms input for this Choreo. 

		@param BigDecimal - (optional, decimal) The amount of bathrooms in the residence.
		*/
		public void set_Bathrooms(BigDecimal value) {
			this.setInput("Bathrooms", value);
		}

		/** 
		Set the value of the Bathrooms input for this Choreo as a String. 

		@param String - (optional, decimal) The amount of bathrooms in the residence.
		*/
		public void set_Bathrooms(String value) {
			this.setInput("Bathrooms", value);	
		}

		/** 
		Set the value of the Bedrooms input for this Choreo. 

		@param BigDecimal - (optional, decimal) The number of bedrooms in the residence.
		*/
		public void set_Bedrooms(BigDecimal value) {
			this.setInput("Bedrooms", value);
		}

		/** 
		Set the value of the Bedrooms input for this Choreo as a String. 

		@param String - (optional, decimal) The number of bedrooms in the residence.
		*/
		public void set_Bedrooms(String value) {
			this.setInput("Bedrooms", value);	
		}

		/** 
		Set the value of the ClothesMachineUse input for this Choreo. 

		@param String - (optional, string) The number laundry loads per week. Valid values are: "1 load or less each week", "10 to 15 loads", "2 to 4 loads", "5 to 9 loads", "More than 15 loads"
		*/
		public void set_ClothesMachineUse(String value) {
			this.setInput("ClothesMachineUse", value);
		}



		/** 
		Set the value of the ConstructionYear input for this Choreo. 

		@param Integer - (optional, integer) The year the residence was constructed.
		*/
		public void set_ConstructionYear(Integer value) {
			this.setInput("ConstructionYear", value);
		}

		/** 
		Set the value of the ConstructionYear input for this Choreo as a String. 

		@param String - (optional, integer) The year the residence was constructed.
		*/
		public void set_ConstructionYear(String value) {
			this.setInput("ConstructionYear", value);	
		}

		/** 
		Set the value of the DishwasherUse input for this Choreo. 

		@param String - (optional, string) Number of times the dishwasher is used per week. Valid values: "2 or 3 times a week", "4 to 6 times a week", "At least once each day", "Less than once each week", "Once each week".
		*/
		public void set_DishwasherUse(String value) {
			this.setInput("DishwasherUse", value);
		}



		/** 
		Set the value of the Floors input for this Choreo. 

		@param Integer - (optional, integer) The number of floors.
		*/
		public void set_Floors(Integer value) {
			this.setInput("Floors", value);
		}

		/** 
		Set the value of the Floors input for this Choreo as a String. 

		@param String - (optional, integer) The number of floors.
		*/
		public void set_Floors(String value) {
			this.setInput("Floors", value);	
		}

		/** 
		Set the value of the FloorspaceEstimate input for this Choreo. 

		@param BigDecimal - (optional, decimal) An estimate of the amount of floorspace that the residence has.
		*/
		public void set_FloorspaceEstimate(BigDecimal value) {
			this.setInput("FloorspaceEstimate", value);
		}

		/** 
		Set the value of the FloorspaceEstimate input for this Choreo as a String. 

		@param String - (optional, decimal) An estimate of the amount of floorspace that the residence has.
		*/
		public void set_FloorspaceEstimate(String value) {
			this.setInput("FloorspaceEstimate", value);	
		}

		/** 
		Set the value of the FreezerCount input for this Choreo. 

		@param Integer - (optional, integer) The number of freezers in the residence.
		*/
		public void set_FreezerCount(Integer value) {
			this.setInput("FreezerCount", value);
		}

		/** 
		Set the value of the FreezerCount input for this Choreo as a String. 

		@param String - (optional, integer) The number of freezers in the residence.
		*/
		public void set_FreezerCount(String value) {
			this.setInput("FreezerCount", value);	
		}

		/** 
		Set the value of the FullBathrooms input for this Choreo. 

		@param Integer - (optional, integer) The number of full bathrooms in the residence.
		*/
		public void set_FullBathrooms(Integer value) {
			this.setInput("FullBathrooms", value);
		}

		/** 
		Set the value of the FullBathrooms input for this Choreo as a String. 

		@param String - (optional, integer) The number of full bathrooms in the residence.
		*/
		public void set_FullBathrooms(String value) {
			this.setInput("FullBathrooms", value);	
		}

		/** 
		Set the value of the GreenElectricty input for this Choreo. 

		@param BigDecimal - (optional, decimal) The amount green electricity that the residence uses.
		*/
		public void set_GreenElectricty(BigDecimal value) {
			this.setInput("GreenElectricty", value);
		}

		/** 
		Set the value of the GreenElectricty input for this Choreo as a String. 

		@param String - (optional, decimal) The amount green electricity that the residence uses.
		*/
		public void set_GreenElectricty(String value) {
			this.setInput("GreenElectricty", value);	
		}

		/** 
		Set the value of the HalfBathrooms input for this Choreo. 

		@param Integer - (optional, integer) The number of half bathrooms in the residence.
		*/
		public void set_HalfBathrooms(Integer value) {
			this.setInput("HalfBathrooms", value);
		}

		/** 
		Set the value of the HalfBathrooms input for this Choreo as a String. 

		@param String - (optional, integer) The number of half bathrooms in the residence.
		*/
		public void set_HalfBathrooms(String value) {
			this.setInput("HalfBathrooms", value);	
		}

		/** 
		Set the value of the LightingEfficiency input for this Choreo. 

		@param BigDecimal - (optional, decimal) A numeric value representing the lighting efficiency of the residence.
		*/
		public void set_LightingEfficiency(BigDecimal value) {
			this.setInput("LightingEfficiency", value);
		}

		/** 
		Set the value of the LightingEfficiency input for this Choreo as a String. 

		@param String - (optional, decimal) A numeric value representing the lighting efficiency of the residence.
		*/
		public void set_LightingEfficiency(String value) {
			this.setInput("LightingEfficiency", value);	
		}

		/** 
		Set the value of the MonthlyElectricityCost input for this Choreo. 

		@param BigDecimal - (optional, decimal) The montly cost of electricity for the residence.
		*/
		public void set_MonthlyElectricityCost(BigDecimal value) {
			this.setInput("MonthlyElectricityCost", value);
		}

		/** 
		Set the value of the MonthlyElectricityCost input for this Choreo as a String. 

		@param String - (optional, decimal) The montly cost of electricity for the residence.
		*/
		public void set_MonthlyElectricityCost(String value) {
			this.setInput("MonthlyElectricityCost", value);	
		}

		/** 
		Set the value of the MonthlyElectricityUseEstimate input for this Choreo. 

		@param BigDecimal - (optional, decimal) An estimate for the amount of electricity used monthly in kilowatt hours.
		*/
		public void set_MonthlyElectricityUseEstimate(BigDecimal value) {
			this.setInput("MonthlyElectricityUseEstimate", value);
		}

		/** 
		Set the value of the MonthlyElectricityUseEstimate input for this Choreo as a String. 

		@param String - (optional, decimal) An estimate for the amount of electricity used monthly in kilowatt hours.
		*/
		public void set_MonthlyElectricityUseEstimate(String value) {
			this.setInput("MonthlyElectricityUseEstimate", value);	
		}

		/** 
		Set the value of the MonthlyNaturalGasCost input for this Choreo. 

		@param BigDecimal - (optional, decimal) The monthly cost of natural gas for the residence.
		*/
		public void set_MonthlyNaturalGasCost(BigDecimal value) {
			this.setInput("MonthlyNaturalGasCost", value);
		}

		/** 
		Set the value of the MonthlyNaturalGasCost input for this Choreo as a String. 

		@param String - (optional, decimal) The monthly cost of natural gas for the residence.
		*/
		public void set_MonthlyNaturalGasCost(String value) {
			this.setInput("MonthlyNaturalGasCost", value);	
		}

		/** 
		Set the value of the MonthlyNaturalGasVolumeEstimate input for this Choreo. 

		@param BigDecimal - (optional, decimal) An estimate of the amount of natural gas used monthly.
		*/
		public void set_MonthlyNaturalGasVolumeEstimate(BigDecimal value) {
			this.setInput("MonthlyNaturalGasVolumeEstimate", value);
		}

		/** 
		Set the value of the MonthlyNaturalGasVolumeEstimate input for this Choreo as a String. 

		@param String - (optional, decimal) An estimate of the amount of natural gas used monthly.
		*/
		public void set_MonthlyNaturalGasVolumeEstimate(String value) {
			this.setInput("MonthlyNaturalGasVolumeEstimate", value);	
		}

		/** 
		Set the value of the Occupation input for this Choreo. 

		@param BigDecimal - (optional, decimal) Refers to the percentage of time a residence is occupied during a year. Defaults to 0.937.
		*/
		public void set_Occupation(BigDecimal value) {
			this.setInput("Occupation", value);
		}

		/** 
		Set the value of the Occupation input for this Choreo as a String. 

		@param String - (optional, decimal) Refers to the percentage of time a residence is occupied during a year. Defaults to 0.937.
		*/
		public void set_Occupation(String value) {
			this.setInput("Occupation", value);	
		}

		/** 
		Set the value of the Ownership input for this Choreo. 

		@param Boolean - (optional, boolean) Indicates whether the residence is owned or rented. Set to "true" if you own the residence.
		*/
		public void set_Ownership(Boolean value) {
			this.setInput("Ownership", value);
		}

		/** 
		Set the value of the Ownership input for this Choreo as a String. 

		@param String - (optional, boolean) Indicates whether the residence is owned or rented. Set to "true" if you own the residence.
		*/
		public void set_Ownership(String value) {
			this.setInput("Ownership", value);	
		}

		/** 
		Set the value of the RefrigeratorCount input for this Choreo. 

		@param Integer - (optional, integer) The number of refrigerators in the residence.
		*/
		public void set_RefrigeratorCount(Integer value) {
			this.setInput("RefrigeratorCount", value);
		}

		/** 
		Set the value of the RefrigeratorCount input for this Choreo as a String. 

		@param String - (optional, integer) The number of refrigerators in the residence.
		*/
		public void set_RefrigeratorCount(String value) {
			this.setInput("RefrigeratorCount", value);	
		}

		/** 
		Set the value of the ResidentialClass input for this Choreo. 

		@param String - (optional, string) Valid values: "Apartment in a building with 5 or more units", "Apartment in a house or a building with 2-4 units", "Mobile home", "Single-family attached house", or "Single-family detached house".
		*/
		public void set_ResidentialClass(String value) {
			this.setInput("ResidentialClass", value);
		}



		/** 
		Set the value of the Residents input for this Choreo. 

		@param Integer - (optional, integer) The number of people living in the residence.
		*/
		public void set_Residents(Integer value) {
			this.setInput("Residents", value);
		}

		/** 
		Set the value of the Residents input for this Choreo as a String. 

		@param String - (optional, integer) The number of people living in the residence.
		*/
		public void set_Residents(String value) {
			this.setInput("Residents", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) Specify your desired response format. Accepted values are xml and json (the default).
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the Retirement input for this Choreo. 

		@param String - (optional, date) A date of retirement.
		*/
		public void set_Retirement(String value) {
			this.setInput("Retirement", value);
		}



		/** 
		Set the value of the Timeframe input for this Choreo. 

		@param String - (optional, string) A date range specified in the following format: 2008-01-01/2008-07-09
		*/
		public void set_Timeframe(String value) {
			this.setInput("Timeframe", value);
		}



		/** 
		Set the value of the Urbanity input for this Choreo. 

		@param String - (optional, string) Can be set to: City, Rural, Suburbs, or Town.
		*/
		public void set_Urbanity(String value) {
			this.setInput("Urbanity", value);
		}



		/** 
		Set the value of the ZipCode input for this Choreo. 

		@param String - (optional, string) The postal code of the residence.
		*/
		public void set_ZipCode(String value) {
			this.setInput("ZipCode", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Residence Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ResidenceResultSet extends ResultSet {
		public ResidenceResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Brighter Planet.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
