package com.temboo.Library.BrighterPlanet;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Shipment

Returns information about the carbon footprint of shipping packages.
*/
public class Shipment extends Choreography {

	/**
	Create a new instance of the Shipment Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Shipment(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/BrighterPlanet/Shipment"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ShipmentInputSet
	*/
	public ShipmentInputSet newInputSet() {
		return new ShipmentInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ShipmentResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ShipmentResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Shipment
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ShipmentInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Brighter Planet.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Carrier input for this Choreo. 

		@param String - (optional, string) The carrier used for the shipment. Valid values are: FedEx, UPS, or USPS.
		*/
		public void set_Carrier(String value) {
			this.setInput("Carrier", value);
		}



		/** 
		Set the value of the DestinationZipCode input for this Choreo. 

		@param String - (optional, string) The postal code of the destination address.
		*/
		public void set_DestinationZipCode(String value) {
			this.setInput("DestinationZipCode", value);
		}



		/** 
		Set the value of the Destination input for this Choreo. 

		@param String - (optional, string) The destination of the shipment.
		*/
		public void set_Destination(String value) {
			this.setInput("Destination", value);
		}



		/** 
		Set the value of the Distance input for this Choreo. 

		@param BigDecimal - (optional, decimal) The distance from the shipment origin to the shipment destination.
		*/
		public void set_Distance(BigDecimal value) {
			this.setInput("Distance", value);
		}

		/** 
		Set the value of the Distance input for this Choreo as a String. 

		@param String - (optional, decimal) The distance from the shipment origin to the shipment destination.
		*/
		public void set_Distance(String value) {
			this.setInput("Distance", value);	
		}

		/** 
		Set the value of the Mode input for this Choreo. 

		@param String - (optional, string) The mode or method of shipment. Valid values are: air, courier, or ground.
		*/
		public void set_Mode(String value) {
			this.setInput("Mode", value);
		}



		/** 
		Set the value of the OriginZipCode input for this Choreo. 

		@param String - (optional, string) The postal code of the origin address.
		*/
		public void set_OriginZipCode(String value) {
			this.setInput("OriginZipCode", value);
		}



		/** 
		Set the value of the Origin input for this Choreo. 

		@param String - (optional, string) The origin of the shipment.
		*/
		public void set_Origin(String value) {
			this.setInput("Origin", value);
		}



		/** 
		Set the value of the PackageCount input for this Choreo. 

		@param Integer - (optional, integer) The number of packages in the shipment.
		*/
		public void set_PackageCount(Integer value) {
			this.setInput("PackageCount", value);
		}

		/** 
		Set the value of the PackageCount input for this Choreo as a String. 

		@param String - (optional, integer) The number of packages in the shipment.
		*/
		public void set_PackageCount(String value) {
			this.setInput("PackageCount", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) Specify your desired response format. Accepted values are xml and json (the default).
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the Weight input for this Choreo. 

		@param BigDecimal - (optional, decimal) The weight of the shipment in kilograms.
		*/
		public void set_Weight(BigDecimal value) {
			this.setInput("Weight", value);
		}

		/** 
		Set the value of the Weight input for this Choreo as a String. 

		@param String - (optional, decimal) The weight of the shipment in kilograms.
		*/
		public void set_Weight(String value) {
			this.setInput("Weight", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Shipment Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ShipmentResultSet extends ResultSet {
		public ShipmentResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Brighter Planet.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
