package com.temboo.Library.Bugzilla;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
SearchForBugs

Search for bugs listed by Mozilla product name.
*/
public class SearchForBugs extends Choreography {

	/**
	Create a new instance of the SearchForBugs Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public SearchForBugs(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Bugzilla/SearchForBugs"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return SearchForBugsInputSet
	*/
	public SearchForBugsInputSet newInputSet() {
		return new SearchForBugsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public SearchForBugsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new SearchForBugsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the SearchForBugs
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class SearchForBugsInputSet extends InputSet {
		/** 
		Set the value of the BugChangeDate input for this Choreo. 

		@param String - (optional, string) Retrieve bugs that were changed within a certain date range. For example: 25d will return all bugs changed from 25 days ago untill today.  Or: 3h, to return all bugs entered with 3 hours.
		*/
		public void set_BugChangeDate(String value) {
			this.setInput("BugChangeDate", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (optional, password) Your Bugzilla password.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Priority input for this Choreo. 

		@param Integer - (optional, integer) Filter results by priority: For example: enter P1, to get Priority 1 bugs assoicated with a Product.
		*/
		public void set_Priority(Integer value) {
			this.setInput("Priority", value);
		}

		/** 
		Set the value of the Priority input for this Choreo as a String. 

		@param String - (optional, integer) Filter results by priority: For example: enter P1, to get Priority 1 bugs assoicated with a Product.
		*/
		public void set_Priority(String value) {
			this.setInput("Priority", value);	
		}

		/** 
		Set the value of the Product input for this Choreo. 

		@param String - (required, string) Enter the Mozilla product for which bugs will be retrieved. For example: Bugzilla
		*/
		public void set_Product(String value) {
			this.setInput("Product", value);
		}



		/** 
		Set the value of the Server input for this Choreo. 

		@param String - (optional, string) The base URL for the Bugzilla server to access. Defaults to https://api-dev.bugzilla.mozilla.org/latest. To access the test server, set to https://api-dev.bugzilla.mozilla.org/test/latest.
		*/
		public void set_Server(String value) {
			this.setInput("Server", value);
		}



		/** 
		Set the value of the Severity input for this Choreo. 

		@param String - (optional, string) Filter results by severity. For example: blocker
		*/
		public void set_Severity(String value) {
			this.setInput("Severity", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) Your Bugzilla username.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the SearchForBugs Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class SearchForBugsResultSet extends ResultSet {
		public SearchForBugsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Bugzilla.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
