package com.temboo.Library.Clicky;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetAnalyticsByType

Retrieves a specified type of anlaytics for your website.
*/
public class GetAnalyticsByType extends Choreography {

	/**
	Create a new instance of the GetAnalyticsByType Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetAnalyticsByType(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Clicky/GetAnalyticsByType"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetAnalyticsByTypeInputSet
	*/
	public GetAnalyticsByTypeInputSet newInputSet() {
		return new GetAnalyticsByTypeInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetAnalyticsByTypeResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetAnalyticsByTypeResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetAnalyticsByType
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetAnalyticsByTypeInputSet extends InputSet {
		/** 
		Set the value of the Limit input for this Choreo. 

		@param Integer - (optional, integer) The maximum number of results that will be returned. Defaults to 10.
		*/
		public void set_Limit(Integer value) {
			this.setInput("Limit", value);
		}

		/** 
		Set the value of the Limit input for this Choreo as a String. 

		@param String - (optional, integer) The maximum number of results that will be returned. Defaults to 10.
		*/
		public void set_Limit(String value) {
			this.setInput("Limit", value);	
		}

		/** 
		Set the value of the Output input for this Choreo. 

		@param String - (optional, string) What format you want the returned data to be in. Accepted values: xml, php, json, csv. Defaults to 'xml'.
		*/
		public void set_Output(String value) {
			this.setInput("Output", value);
		}



		/** 
		Set the value of the SiteID input for this Choreo. 

		@param Integer - (required, integer) Your request must include the site's ID that you want to access data from. Available from your site preferences page.
		*/
		public void set_SiteID(Integer value) {
			this.setInput("SiteID", value);
		}

		/** 
		Set the value of the SiteID input for this Choreo as a String. 

		@param String - (required, integer) Your request must include the site's ID that you want to access data from. Available from your site preferences page.
		*/
		public void set_SiteID(String value) {
			this.setInput("SiteID", value);	
		}

		/** 
		Set the value of the SiteKey input for this Choreo. 

		@param String - (required, string) The unique key assigned to you when you first register with Clicky. Available from your site preferences page.
		*/
		public void set_SiteKey(String value) {
			this.setInput("SiteKey", value);
		}



		/** 
		Set the value of the Type input for this Choreo. 

		@param String - (required, string) The type of data you want to retrieve. Can be a comma-separated list of types (i.e. visitors,countries,searches).
		*/
		public void set_Type(String value) {
			this.setInput("Type", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetAnalyticsByType Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetAnalyticsByTypeResultSet extends ResultSet {
		public GetAnalyticsByTypeResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Clicky formatted as specified in the Output parameter. Default is XML.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
