package com.temboo.Library.CloudMine.ObjectStorage;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ObjectSet

Allows you to update or create key/value pairs.

*/
public class ObjectSet extends Choreography {

	/**
	Create a new instance of the ObjectSet Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ObjectSet(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/CloudMine/ObjectStorage/ObjectSet"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ObjectSetInputSet
	*/
	public ObjectSetInputSet newInputSet() {
		return new ObjectSetInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ObjectSetResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ObjectSetResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ObjectSet
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ObjectSetInputSet extends InputSet {
		/** 
		Set the value of the Data input for this Choreo. 

		@param String - (required, json) A valid JSON object containing key/value pairs.
		*/
		public void set_Data(String value) {
			this.setInput("Data", value);
		}



		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by CloudMine after registering your app.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the ApplicationIdentifier input for this Choreo. 

		@param String - (required, string) The application identifier provided by CloudMine after registering your app.
		*/
		public void set_ApplicationIdentifier(String value) {
			this.setInput("ApplicationIdentifier", value);
		}



		/** 
		Set the value of the SessionToken input for this Choreo. 

		@param String - (conditional, string) The session token for an existing user (returned by the AccountLogin Choreo). This is only required if your app is performing this operation on behalf of another user.
		*/
		public void set_SessionToken(String value) {
			this.setInput("SessionToken", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ObjectSet Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ObjectSetResultSet extends ResultSet {
		public ObjectSetResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from CloudMine.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
