package com.temboo.Library.ConstantContact;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
AddMultipleContacts

Creates multiple contacts in your Constant Contact list via the Activities bulk API.  The Choreo can use Excel or CSV files for the bulk upload.
*/
public class AddMultipleContacts extends Choreography {

	/**
	Create a new instance of the AddMultipleContacts Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public AddMultipleContacts(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/ConstantContact/AddMultipleContacts"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return AddMultipleContactsInputSet
	*/
	public AddMultipleContactsInputSet newInputSet() {
		return new AddMultipleContactsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public AddMultipleContactsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new AddMultipleContactsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the AddMultipleContacts
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class AddMultipleContactsInputSet extends InputSet {
		/** 
		Set the value of the FileContents input for this Choreo. 

		@param String - (conditional, multiline) The file contents of the list you want to upload. Should be in CSV format.
		*/
		public void set_FileContents(String value) {
			this.setInput("FileContents", value);
		}



		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Constant Contact.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the ListId input for this Choreo. 

		@param Integer - (required, integer) The numberic id for the list that you want to add contacts to.
		*/
		public void set_ListId(Integer value) {
			this.setInput("ListId", value);
		}

		/** 
		Set the value of the ListId input for this Choreo as a String. 

		@param String - (required, integer) The numberic id for the list that you want to add contacts to.
		*/
		public void set_ListId(String value) {
			this.setInput("ListId", value);	
		}

		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Constant Contact password.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the UserName input for this Choreo. 

		@param String - (required, string) Your Constant Contact username.
		*/
		public void set_UserName(String value) {
			this.setInput("UserName", value);
		}



		/** 
		Set the value of the VaultFile input for this Choreo. 

		@param TembooPath - (optional, vault file) A path to the vault CSV file you want to upload. Required unless using the FileContents input.
		*/
		public void set_VaultFile(TembooPath value) {
			this.setAlias("VaultFile", value);
		}
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the AddMultipleContacts Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class AddMultipleContactsResultSet extends ResultSet {
		public AddMultipleContactsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Constant Contact.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
