package com.temboo.Library.ConstantContact;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ObtainContactInformation

Retrieves contact information from Constant Contact by specifying the contact ID.
*/
public class ObtainContactInformation extends Choreography {

	/**
	Create a new instance of the ObtainContactInformation Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ObtainContactInformation(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/ConstantContact/ObtainContactInformation"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ObtainContactInformationInputSet
	*/
	public ObtainContactInformationInputSet newInputSet() {
		return new ObtainContactInformationInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ObtainContactInformationResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ObtainContactInformationResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ObtainContactInformation
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ObtainContactInformationInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Constant Contact.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the ContactId input for this Choreo. 

		@param Integer - (required, integer) The ID for the contact you want to retrieve information for.
		*/
		public void set_ContactId(Integer value) {
			this.setInput("ContactId", value);
		}

		/** 
		Set the value of the ContactId input for this Choreo as a String. 

		@param String - (required, integer) The ID for the contact you want to retrieve information for.
		*/
		public void set_ContactId(String value) {
			this.setInput("ContactId", value);	
		}

		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Constant Contact password.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the UserName input for this Choreo. 

		@param String - (required, string) Your Constant Contact username.
		*/
		public void set_UserName(String value) {
			this.setInput("UserName", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ObtainContactInformation Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ObtainContactInformationResultSet extends ResultSet {
		public ObtainContactInformationResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Constant Contact.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
