package com.temboo.Library.CorpWatch.Company;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetCompanyByCIK

Returns a company record for a given SEC CIK identification number.
*/
public class GetCompanyByCIK extends Choreography {

	/**
	Create a new instance of the GetCompanyByCIK Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetCompanyByCIK(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/CorpWatch/Company/GetCompanyByCIK"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetCompanyByCIKInputSet
	*/
	public GetCompanyByCIKInputSet newInputSet() {
		return new GetCompanyByCIKInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetCompanyByCIKResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetCompanyByCIKResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetCompanyByCIK
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetCompanyByCIKInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (optional, string) The APIKey from CorpWatch if you have one.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the CIK input for this Choreo. 

		@param String - (required, string) The SEC's CIK identification number.
		*/
		public void set_CIK(String value) {
			this.setInput("CIK", value);
		}



		/** 
		Set the value of the Index input for this Choreo. 

		@param Integer - (optional, integer) Set the index number of the first result to be returned. The index of the first result is 0.
		*/
		public void set_Index(Integer value) {
			this.setInput("Index", value);
		}

		/** 
		Set the value of the Index input for this Choreo as a String. 

		@param String - (optional, integer) Set the index number of the first result to be returned. The index of the first result is 0.
		*/
		public void set_Index(String value) {
			this.setInput("Index", value);	
		}

		/** 
		Set the value of the Limit input for this Choreo. 

		@param Integer - (optional, integer) The number of results to be returned. Defaults to 100. Maximum is 5000.
		*/
		public void set_Limit(Integer value) {
			this.setInput("Limit", value);
		}

		/** 
		Set the value of the Limit input for this Choreo as a String. 

		@param String - (optional, integer) The number of results to be returned. Defaults to 100. Maximum is 5000.
		*/
		public void set_Limit(String value) {
			this.setInput("Limit", value);	
		}

		/** 
		Set the value of the ResponseType input for this Choreo. 

		@param String - (optional, string) Specify json or xml for the type of response to be returned. Defaults to xml.
		*/
		public void set_ResponseType(String value) {
			this.setInput("ResponseType", value);
		}



		/** 
		Set the value of the Year input for this Choreo. 

		@param Integer - (optional, integer) If a year is specified, only records for that year will be returned and the data in the company objects returned will be set appropriately for the request year. Defaults to most recent.
		*/
		public void set_Year(Integer value) {
			this.setInput("Year", value);
		}

		/** 
		Set the value of the Year input for this Choreo as a String. 

		@param String - (optional, integer) If a year is specified, only records for that year will be returned and the data in the company objects returned will be set appropriately for the request year. Defaults to most recent.
		*/
		public void set_Year(String value) {
			this.setInput("Year", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetCompanyByCIK Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetCompanyByCIKResultSet extends ResultSet {
		public GetCompanyByCIKResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from CorpWatch.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
