package com.temboo.Library.DailyMed;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetComponents

Returns imprint data associated with a given National Drug Code (NDC) in the DailyMed database.
*/
public class GetComponents extends Choreography {

	/**
	Create a new instance of the GetComponents Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetComponents(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/DailyMed/GetComponents"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetComponentsInputSet
	*/
	public GetComponentsInputSet newInputSet() {
		return new GetComponentsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetComponentsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetComponentsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetComponents
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetComponentsInputSet extends InputSet {
		/** 
		Set the value of the SetID input for this Choreo. 

		@param String - (required, string) The unique ID assigned by DailyMed to each drug. You can find the SetID of a drug by first running the SearchByName or SearchByNDC Choreos.
		*/
		public void set_SetID(String value) {
			this.setInput("SetID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetComponents Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetComponentsResultSet extends ResultSet {
		public GetComponentsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from DailyMed.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
