package com.temboo.Library.DataGov;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetCensusIDByTypeAndName

Retrieve the U.S. census ID for a specified geography type and name.
*/
public class GetCensusIDByTypeAndName extends Choreography {

	/**
	Create a new instance of the GetCensusIDByTypeAndName Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetCensusIDByTypeAndName(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/DataGov/GetCensusIDByTypeAndName"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetCensusIDByTypeAndNameInputSet
	*/
	public GetCensusIDByTypeAndNameInputSet newInputSet() {
		return new GetCensusIDByTypeAndNameInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetCensusIDByTypeAndNameResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetCensusIDByTypeAndNameResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetCensusIDByTypeAndName
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetCensusIDByTypeAndNameInputSet extends InputSet {
		/** 
		Set the value of the GeographyName input for this Choreo. 

		@param String - (required, string) Specify the geography name for the correspnding type, with at least three leading characters. For example, for the geography type "state" you could enter "ore" for Oregon.
		*/
		public void set_GeographyName(String value) {
			this.setInput("GeographyName", value);
		}



		/** 
		Set the value of the GeographyType input for this Choreo. 

		@param String - (required, string) Specify one of the following geography type values: "state", "county", "tract", "block", "congdistrict", "statehouse", "statesenate", "censusplace", or "msa" (metropolitan statistical area).
		*/
		public void set_GeographyType(String value) {
			this.setInput("GeographyType", value);
		}



		/** 
		Set the value of the MaxResults input for this Choreo. 

		@param Integer - (required, integer) Specify the maximum number of results to return. Defaults to 50.
		*/
		public void set_MaxResults(Integer value) {
			this.setInput("MaxResults", value);
		}

		/** 
		Set the value of the MaxResults input for this Choreo as a String. 

		@param String - (required, integer) Specify the maximum number of results to return. Defaults to 50.
		*/
		public void set_MaxResults(String value) {
			this.setInput("MaxResults", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetCensusIDByTypeAndName Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetCensusIDByTypeAndNameResultSet extends ResultSet {
		public GetCensusIDByTypeAndNameResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "CensusID" output from this Choreo execution

		@return String - (integer) The ID retrieved from the API call.
		*/
		public String get_CensusID() {
			return this.getResult("CensusID");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response returned from the API.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
