package com.temboo.Library.DataGov;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetDemographicsByCoordinates

Retrieve demographic information for specified geographical coordinates.
*/
public class GetDemographicsByCoordinates extends Choreography {

	/**
	Create a new instance of the GetDemographicsByCoordinates Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetDemographicsByCoordinates(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/DataGov/GetDemographicsByCoordinates"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetDemographicsByCoordinatesInputSet
	*/
	public GetDemographicsByCoordinatesInputSet newInputSet() {
		return new GetDemographicsByCoordinatesInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetDemographicsByCoordinatesResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetDemographicsByCoordinatesResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetDemographicsByCoordinates
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetDemographicsByCoordinatesInputSet extends InputSet {
		/** 
		Set the value of the DataVersion input for this Choreo. 

		@param String - (optional, string) Specify the data version to search, such as "jun2011" (the default).
		*/
		public void set_DataVersion(String value) {
			this.setInput("DataVersion", value);
		}



		/** 
		Set the value of the Latitude input for this Choreo. 

		@param BigDecimal - (required, decimal) Specify a latitude to search for, such as "41.486857".
		*/
		public void set_Latitude(BigDecimal value) {
			this.setInput("Latitude", value);
		}

		/** 
		Set the value of the Latitude input for this Choreo as a String. 

		@param String - (required, decimal) Specify a latitude to search for, such as "41.486857".
		*/
		public void set_Latitude(String value) {
			this.setInput("Latitude", value);	
		}

		/** 
		Set the value of the Longitude input for this Choreo. 

		@param BigDecimal - (required, decimal) Specify a longitude to search for, such as "-71.294392".
		*/
		public void set_Longitude(BigDecimal value) {
			this.setInput("Longitude", value);
		}

		/** 
		Set the value of the Longitude input for this Choreo as a String. 

		@param String - (required, decimal) Specify a longitude to search for, such as "-71.294392".
		*/
		public void set_Longitude(String value) {
			this.setInput("Longitude", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetDemographicsByCoordinates Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetDemographicsByCoordinatesResultSet extends ResultSet {
		public GetDemographicsByCoordinatesResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response returned from the API.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
