package com.temboo.Library.DataGov;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetDemographicsByTypeAndID

Retrieve demographic data for a specified geography type and geography ID.
*/
public class GetDemographicsByTypeAndID extends Choreography {

	/**
	Create a new instance of the GetDemographicsByTypeAndID Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetDemographicsByTypeAndID(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/DataGov/GetDemographicsByTypeAndID"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetDemographicsByTypeAndIDInputSet
	*/
	public GetDemographicsByTypeAndIDInputSet newInputSet() {
		return new GetDemographicsByTypeAndIDInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetDemographicsByTypeAndIDResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetDemographicsByTypeAndIDResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetDemographicsByTypeAndID
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetDemographicsByTypeAndIDInputSet extends InputSet {
		/** 
		Set the value of the DataVersion input for this Choreo. 

		@param String - (optional, string) Specify the census data version to search, such as "jun2011" (the default).
		*/
		public void set_DataVersion(String value) {
			this.setInput("DataVersion", value);
		}



		/** 
		Set the value of the GeographyIDs input for this Choreo. 

		@param Integer - (conditional, integer) The geography IDs to search for. Separate multiple IDs by commas; a maximum of 10 IDs are allowed.
		*/
		public void set_GeographyIDs(Integer value) {
			this.setInput("GeographyIDs", value);
		}

		/** 
		Set the value of the GeographyIDs input for this Choreo as a String. 

		@param String - (conditional, integer) The geography IDs to search for. Separate multiple IDs by commas; a maximum of 10 IDs are allowed.
		*/
		public void set_GeographyIDs(String value) {
			this.setInput("GeographyIDs", value);	
		}

		/** 
		Set the value of the GeographyType input for this Choreo. 

		@param String - (required, string) Specify one of the following geography type values: "state", "county", "tract", "block", "congdistrict", "statehouse", "statesenate", "censusplace", or "msa" (metropolitan statistical area).
		*/
		public void set_GeographyType(String value) {
			this.setInput("GeographyType", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetDemographicsByTypeAndID Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetDemographicsByTypeAndIDResultSet extends ResultSet {
		public GetDemographicsByTypeAndIDResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response returned from the API.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
