package com.temboo.Library.DataGov;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetDemographicsForNation

Retrieve demographic information for the entire nation.
*/
public class GetDemographicsForNation extends Choreography {

	/**
	Create a new instance of the GetDemographicsForNation Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetDemographicsForNation(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/DataGov/GetDemographicsForNation"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetDemographicsForNationInputSet
	*/
	public GetDemographicsForNationInputSet newInputSet() {
		return new GetDemographicsForNationInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetDemographicsForNationResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetDemographicsForNationResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetDemographicsForNation
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetDemographicsForNationInputSet extends InputSet {
		/** 
		Set the value of the DataVersion input for this Choreo. 

		@param String - (optional, string) Specify the census data version to search, such as "jun2011" (the default).
		*/
		public void set_DataVersion(String value) {
			this.setInput("DataVersion", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetDemographicsForNation Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetDemographicsForNationResultSet extends ResultSet {
		public GetDemographicsForNationResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response returned from the API.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
