package com.temboo.Library.Delicious;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
AddBookmark

Adds a link bookmark to a Delicious account.
*/
public class AddBookmark extends Choreography {

	/**
	Create a new instance of the AddBookmark Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public AddBookmark(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Delicious/AddBookmark"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return AddBookmarkInputSet
	*/
	public AddBookmarkInputSet newInputSet() {
		return new AddBookmarkInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public AddBookmarkResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new AddBookmarkResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the AddBookmark
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class AddBookmarkInputSet extends InputSet {
		/** 
		Set the value of the Description input for this Choreo. 

		@param String - (required, string) A description for the link to post.
		*/
		public void set_Description(String value) {
			this.setInput("Description", value);
		}



		/** 
		Set the value of the Notes input for this Choreo. 

		@param String - (optional, string) Descriptive notes for the posted link.
		*/
		public void set_Notes(String value) {
			this.setInput("Notes", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The password that corresponds to the specified Delicious account username.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Replace input for this Choreo. 

		@param Integer - (optional, integer) Specify "1" to replace the post if the URL has already been posted. Set to "0" (don't replace) by default.
		*/
		public void set_Replace(Integer value) {
			this.setInput("Replace", value);
		}

		/** 
		Set the value of the Replace input for this Choreo as a String. 

		@param String - (optional, integer) Specify "1" to replace the post if the URL has already been posted. Set to "0" (don't replace) by default.
		*/
		public void set_Replace(String value) {
			this.setInput("Replace", value);	
		}

		/** 
		Set the value of the Shared input for this Choreo. 

		@param Integer - (optional, integer) Specify "1" to make the posted link private. Set to "0" (shared) by default.
		*/
		public void set_Shared(Integer value) {
			this.setInput("Shared", value);
		}

		/** 
		Set the value of the Shared input for this Choreo as a String. 

		@param String - (optional, integer) Specify "1" to make the posted link private. Set to "0" (shared) by default.
		*/
		public void set_Shared(String value) {
			this.setInput("Shared", value);	
		}

		/** 
		Set the value of the Tags input for this Choreo. 

		@param String - (optional, string) Add keyword tags to the posted link. Separate multiple tags with commas.
		*/
		public void set_Tags(String value) {
			this.setInput("Tags", value);
		}



		/** 
		Set the value of the URL input for this Choreo. 

		@param String - (required, string) The URL for the link to post.
		*/
		public void set_URL(String value) {
			this.setInput("URL", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) A valid Delicious account username.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the AddBookmark Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class AddBookmarkResultSet extends ResultSet {
		public AddBookmarkResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response returned from Delicious.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
