package com.temboo.Library.Delicious;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
DeleteTag

Deletes a specified tag.
*/
public class DeleteTag extends Choreography {

	/**
	Create a new instance of the DeleteTag Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DeleteTag(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Delicious/DeleteTag"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DeleteTagInputSet
	*/
	public DeleteTagInputSet newInputSet() {
		return new DeleteTagInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DeleteTagResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DeleteTagResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DeleteTag
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DeleteTagInputSet extends InputSet {
		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The password that corresponds to the specified Delicious account username.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Tag input for this Choreo. 

		@param String - (required, string) The tag to delete.
		*/
		public void set_Tag(String value) {
			this.setInput("Tag", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) A valid Delicious account username.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DeleteTag Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DeleteTagResultSet extends ResultSet {
		public DeleteTagResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response returned from Delicious.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
