package com.temboo.Library.Delicious;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetAllBookmarks

Returns all links posted to a Delicious account.
*/
public class GetAllBookmarks extends Choreography {

	/**
	Create a new instance of the GetAllBookmarks Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetAllBookmarks(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Delicious/GetAllBookmarks"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetAllBookmarksInputSet
	*/
	public GetAllBookmarksInputSet newInputSet() {
		return new GetAllBookmarksInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetAllBookmarksResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetAllBookmarksResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetAllBookmarks
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetAllBookmarksInputSet extends InputSet {
		/** 
		Set the value of the Count input for this Choreo. 

		@param Integer - (optional, integer) The number of bookmarks to return. Defaults to 15.
		*/
		public void set_Count(Integer value) {
			this.setInput("Count", value);
		}

		/** 
		Set the value of the Count input for this Choreo as a String. 

		@param String - (optional, integer) The number of bookmarks to return. Defaults to 15.
		*/
		public void set_Count(String value) {
			this.setInput("Count", value);	
		}

		/** 
		Set the value of the FromDate input for this Choreo. 

		@param String - (optional, date) Return only bookmarks posted on this date and later. Enter in YYYY-MM-DDThh:mm:ssZ format.
		*/
		public void set_FromDate(String value) {
			this.setInput("FromDate", value);
		}



		/** 
		Set the value of the Meta input for this Choreo. 

		@param String - (optional, string) Specify "1" to include a change-detection signature for each item returned. Defaults to "0", or no meta attributes retained.
		*/
		public void set_Meta(String value) {
			this.setInput("Meta", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The password that corresponds to the specified Delicious account username.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Tag input for this Choreo. 

		@param String - (optional, string) Return only bookmrks tagged with this keyword.
		*/
		public void set_Tag(String value) {
			this.setInput("Tag", value);
		}



		/** 
		Set the value of the ToDate input for this Choreo. 

		@param String - (optional, date) Return only bookmarks posted on this date and earlier. Enter in YYYY-MM-DDThh:mm:ssZ format.
		*/
		public void set_ToDate(String value) {
			this.setInput("ToDate", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) A valid Delicious account username.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetAllBookmarks Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetAllBookmarksResultSet extends ResultSet {
		public GetAllBookmarksResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response returned from Delicious.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
