package com.temboo.Library.Delicious;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetBookmark

Retrieves one or more bookmarked links posted on a single day.
*/
public class GetBookmark extends Choreography {

	/**
	Create a new instance of the GetBookmark Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetBookmark(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Delicious/GetBookmark"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetBookmarkInputSet
	*/
	public GetBookmarkInputSet newInputSet() {
		return new GetBookmarkInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetBookmarkResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetBookmarkResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetBookmark
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetBookmarkInputSet extends InputSet {
		/** 
		Set the value of the ChangeSignature input for this Choreo. 

		@param String - (optional, string) Return only bookmarks with the URL MD5 signatures you enter, regardless of posting date. Separate multiple signatures with spaces.
		*/
		public void set_ChangeSignature(String value) {
			this.setInput("ChangeSignature", value);
		}



		/** 
		Set the value of the Date input for this Choreo. 

		@param String - (optional, date) Return only bookmarks posted on a date specified here. Enter in YYYY-MM-DDThh:mm:ssZ format. Defaults to the most recent date.
		*/
		public void set_Date(String value) {
			this.setInput("Date", value);
		}



		/** 
		Set the value of the Meta input for this Choreo. 

		@param String - (optional, string) Specify "1" to include a change-detection signature for each item returned. Defaults to "0", or no meta attributes retained.
		*/
		public void set_Meta(String value) {
			this.setInput("Meta", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The password that corresponds to the specified Delicious account username.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Tag input for this Choreo. 

		@param String - (optional, string) Return only items tagged with the specified keyword. Separate multiple tags with spaces.
		*/
		public void set_Tag(String value) {
			this.setInput("Tag", value);
		}



		/** 
		Set the value of the URL input for this Choreo. 

		@param String - (optional, string) Return only items with the specified URL, regardless of posting date.
		*/
		public void set_URL(String value) {
			this.setInput("URL", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) A valid Delicious account username.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetBookmark Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetBookmarkResultSet extends ResultSet {
		public GetBookmarkResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response returned from Delicious.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
