package com.temboo.Library.Delicious;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetBookmarkDates

Retrieve a list of dates, with the number of bookmarks posted for each date.
*/
public class GetBookmarkDates extends Choreography {

	/**
	Create a new instance of the GetBookmarkDates Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetBookmarkDates(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Delicious/GetBookmarkDates"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetBookmarkDatesInputSet
	*/
	public GetBookmarkDatesInputSet newInputSet() {
		return new GetBookmarkDatesInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetBookmarkDatesResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetBookmarkDatesResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetBookmarkDates
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetBookmarkDatesInputSet extends InputSet {
		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The password that corresponds to the specified Delicious account username.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Tags input for this Choreo. 

		@param String - (optional, string) Return only items tagged with the specified keyword.
		*/
		public void set_Tags(String value) {
			this.setInput("Tags", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) A valid Delicious account username.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetBookmarkDates Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetBookmarkDatesResultSet extends ResultSet {
		public GetBookmarkDatesResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response returned from Delicious.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
