package com.temboo.Library.Delicious;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetRecentBookmarks

Retrieve a list of the most recently posted bookmarks.
*/
public class GetRecentBookmarks extends Choreography {

	/**
	Create a new instance of the GetRecentBookmarks Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetRecentBookmarks(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Delicious/GetRecentBookmarks"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetRecentBookmarksInputSet
	*/
	public GetRecentBookmarksInputSet newInputSet() {
		return new GetRecentBookmarksInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetRecentBookmarksResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetRecentBookmarksResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetRecentBookmarks
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetRecentBookmarksInputSet extends InputSet {
		/** 
		Set the value of the Count input for this Choreo. 

		@param Integer - (optional, integer) Specify the number of bookmarks to retrieve, up the maximum of 100. The default is 15.
		*/
		public void set_Count(Integer value) {
			this.setInput("Count", value);
		}

		/** 
		Set the value of the Count input for this Choreo as a String. 

		@param String - (optional, integer) Specify the number of bookmarks to retrieve, up the maximum of 100. The default is 15.
		*/
		public void set_Count(String value) {
			this.setInput("Count", value);	
		}

		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The password that corresponds to the specified Delicious account username.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Tags input for this Choreo. 

		@param String - (optional, string) Return only items tagged with the specified keyword.
		*/
		public void set_Tags(String value) {
			this.setInput("Tags", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) A valid Delicious account username.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetRecentBookmarks Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetRecentBookmarksResultSet extends ResultSet {
		public GetRecentBookmarksResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response returned from Delicious.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
