package com.temboo.Library.Delicious;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
RenameTag

Renames a specified tag.
*/
public class RenameTag extends Choreography {

	/**
	Create a new instance of the RenameTag Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public RenameTag(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Delicious/RenameTag"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return RenameTagInputSet
	*/
	public RenameTagInputSet newInputSet() {
		return new RenameTagInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public RenameTagResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new RenameTagResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the RenameTag
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class RenameTagInputSet extends InputSet {
		/** 
		Set the value of the NewTag input for this Choreo. 

		@param String - (required, string) The new tag name.
		*/
		public void set_NewTag(String value) {
			this.setInput("NewTag", value);
		}



		/** 
		Set the value of the OldTag input for this Choreo. 

		@param String - (required, string) The existing tag to rename.
		*/
		public void set_OldTag(String value) {
			this.setInput("OldTag", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The password that corresponds to the specified Delicious account username.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) A valid Delicious account username.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the RenameTag Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class RenameTagResultSet extends ResultSet {
		public RenameTagResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response returned from Delicious.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
