package com.temboo.Library.DeptOfEducation.CollegesAndUniversities;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
EducationalOfferings

Returns educational offerings and admissions data for any college or university.
*/
public class EducationalOfferings extends Choreography {

	/**
	Create a new instance of the EducationalOfferings Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public EducationalOfferings(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/DeptOfEducation/CollegesAndUniversities/EducationalOfferings"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return EducationalOfferingsInputSet
	*/
	public EducationalOfferingsInputSet newInputSet() {
		return new EducationalOfferingsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public EducationalOfferingsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new EducationalOfferingsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the EducationalOfferings
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class EducationalOfferingsInputSet extends InputSet {
		/** 
		Set the value of the InstitutionID input for this Choreo. 

		@param String - (optional, string) Specify an institutionID to return data on a specific institution. These ids can be retrieved from the LookupSchool Choreo.
		*/
		public void set_InstitutionID(String value) {
			this.setInput("InstitutionID", value);
		}



		/** 
		Set the value of the MaxRows input for this Choreo. 

		@param Integer - (optional, integer) Limits the number of rows returned. Defaults to 20.
		*/
		public void set_MaxRows(Integer value) {
			this.setInput("MaxRows", value);
		}

		/** 
		Set the value of the MaxRows input for this Choreo as a String. 

		@param String - (optional, integer) Limits the number of rows returned. Defaults to 20.
		*/
		public void set_MaxRows(String value) {
			this.setInput("MaxRows", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the EducationalOfferings Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class EducationalOfferingsResultSet extends ResultSet {
		public EducationalOfferingsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Data.ed.gov.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
