package com.temboo.Library.DeptOfEducation.CollegesAndUniversities;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
LookupMajors

Allows you to search for majors by id or keyword.
*/
public class LookupMajors extends Choreography {

	/**
	Create a new instance of the LookupMajors Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public LookupMajors(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/DeptOfEducation/CollegesAndUniversities/LookupMajors"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return LookupMajorsInputSet
	*/
	public LookupMajorsInputSet newInputSet() {
		return new LookupMajorsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public LookupMajorsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new LookupMajorsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the LookupMajors
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class LookupMajorsInputSet extends InputSet {
		/** 
		Set the value of the Keyword input for this Choreo. 

		@param String - (conditional, string) A keyword search term to lookup majors (i.e. Agriculture).
		*/
		public void set_Keyword(String value) {
			this.setInput("Keyword", value);
		}



		/** 
		Set the value of the MajorID input for this Choreo. 

		@param BigDecimal - (conditional, decimal) The unique id associated with a major to return (i.e. 01.0000). Note that these ids are also returned in the output of the DegreesConferred Choreo.
		*/
		public void set_MajorID(BigDecimal value) {
			this.setInput("MajorID", value);
		}

		/** 
		Set the value of the MajorID input for this Choreo as a String. 

		@param String - (conditional, decimal) The unique id associated with a major to return (i.e. 01.0000). Note that these ids are also returned in the output of the DegreesConferred Choreo.
		*/
		public void set_MajorID(String value) {
			this.setInput("MajorID", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the LookupMajors Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class LookupMajorsResultSet extends ResultSet {
		public LookupMajorsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The results from the search in XML or JSON format.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
