package com.temboo.Library.DeptOfEducation.ElementaryAndSecondary;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
LookupSchool

Allows you to search the U.S. Department of Education elementary and secondary school listings which includes general school information, demographic data, and location data.
*/
public class LookupSchool extends Choreography {

	/**
	Create a new instance of the LookupSchool Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public LookupSchool(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/DeptOfEducation/ElementaryAndSecondary/LookupSchool"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return LookupSchoolInputSet
	*/
	public LookupSchoolInputSet newInputSet() {
		return new LookupSchoolInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public LookupSchoolResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new LookupSchoolResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the LookupSchool
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class LookupSchoolInputSet extends InputSet {
		/** 
		Set the value of the Keyword input for this Choreo. 

		@param String - (required, string) Used to perform a full text search on the data set. For example, you can search for a school name or a school's unique ID.
		*/
		public void set_Keyword(String value) {
			this.setInput("Keyword", value);
		}



		/** 
		Set the value of the MaxRows input for this Choreo. 

		@param Integer - (optional, integer) Limits the number of rows returned. Defaults to 20.
		*/
		public void set_MaxRows(Integer value) {
			this.setInput("MaxRows", value);
		}

		/** 
		Set the value of the MaxRows input for this Choreo as a String. 

		@param String - (optional, integer) Limits the number of rows returned. Defaults to 20.
		*/
		public void set_MaxRows(String value) {
			this.setInput("MaxRows", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the LookupSchool Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class LookupSchoolResultSet extends ResultSet {
		public LookupSchoolResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Data.ed.gov.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
