package com.temboo.Library.Disqus.OAuth;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
RefreshToken

Generates a new access token with a given valid refresh token.
*/
public class RefreshToken extends Choreography {

	/**
	Create a new instance of the RefreshToken Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public RefreshToken(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Disqus/OAuth/RefreshToken"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return RefreshTokenInputSet
	*/
	public RefreshTokenInputSet newInputSet() {
		return new RefreshTokenInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public RefreshTokenResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new RefreshTokenResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the RefreshToken
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class RefreshTokenInputSet extends InputSet {
		/** 
		Set the value of the PublicKey input for this Choreo. 

		@param String - (required, string) The Public Key provided by Disqus (AKA the API Key).
		*/
		public void set_PublicKey(String value) {
			this.setInput("PublicKey", value);
		}



		/** 
		Set the value of the RefreshToken input for this Choreo. 

		@param String - (required, string) A valid refresh token used to generate a new access token.
		*/
		public void set_RefreshToken(String value) {
			this.setInput("RefreshToken", value);
		}



		/** 
		Set the value of the SecretKey input for this Choreo. 

		@param String - (required, string) The Secret Key provided by Disqus (AKA the API Secret).
		*/
		public void set_SecretKey(String value) {
			this.setInput("SecretKey", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the RefreshToken Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class RefreshTokenResultSet extends ResultSet {
		public RefreshTokenResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "AccessToken" output from this Choreo execution

		@return String - (string) The Access Token for the user that has granted access to your application.
		*/
		public String get_AccessToken() {
			return this.getResult("AccessToken");
		}
		/** 
		Retrieve the value for the "Expires" output from this Choreo execution

		@return String - (integer) The expiration time in seconds of the Access Token.
		*/
		public String get_Expires() {
			return this.getResult("Expires");
		}
		/** 
		Retrieve the value for the "NewRefreshToken" output from this Choreo execution

		@return String - (string) The new refresh token which can be used the next time your app needs to get a new access token.
		*/
		public String get_NewRefreshToken() {
			return this.getResult("NewRefreshToken");
		}
	}
	
}
