package com.temboo.Library.Disqus.Threads;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CloseThread

Close a thread.
*/
public class CloseThread extends Choreography {

	/**
	Create a new instance of the CloseThread Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CloseThread(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Disqus/Threads/CloseThread"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CloseThreadInputSet
	*/
	public CloseThreadInputSet newInputSet() {
		return new CloseThreadInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CloseThreadResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CloseThreadResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CloseThread
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CloseThreadInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) A valid OAuth 2.0 access token.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the Forum input for this Choreo. 

		@param Integer - (optional, integer) A forum ID. Required if setting either ThreadByIdentification, or ThreadByLink.
		*/
		public void set_Forum(Integer value) {
			this.setInput("Forum", value);
		}

		/** 
		Set the value of the Forum input for this Choreo as a String. 

		@param String - (optional, integer) A forum ID. Required if setting either ThreadByIdentification, or ThreadByLink.
		*/
		public void set_Forum(String value) {
			this.setInput("Forum", value);	
		}

		/** 
		Set the value of the PublicKey input for this Choreo. 

		@param String - (required, string) The Public Key provided by Disqus (AKA the API Key).
		*/
		public void set_PublicKey(String value) {
			this.setInput("PublicKey", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and jsonp.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the ThreadID input for this Choreo. 

		@param Integer - (conditional, integer) The ID of a thread that is to be closed. Required unless specifying ThreadIdentifier or ThreadLink. If using this parameter, ThreadByIdentification cannot be set.
		*/
		public void set_ThreadID(Integer value) {
			this.setInput("ThreadID", value);
		}

		/** 
		Set the value of the ThreadID input for this Choreo as a String. 

		@param String - (conditional, integer) The ID of a thread that is to be closed. Required unless specifying ThreadIdentifier or ThreadLink. If using this parameter, ThreadByIdentification cannot be set.
		*/
		public void set_ThreadID(String value) {
			this.setInput("ThreadID", value);	
		}

		/** 
		Set the value of the ThreadIdentifier input for this Choreo. 

		@param String - (conditional, string) The identifier to retrieve associated thread details.  Note that a Forum must also be provided when using this parameter. If set, ThreadID and ThreadLink cannot be used.
		*/
		public void set_ThreadIdentifier(String value) {
			this.setInput("ThreadIdentifier", value);
		}



		/** 
		Set the value of the ThreadLink input for this Choreo. 

		@param String - (conditional, string) The link pointing to the thread that is to be closed. Note that a Forum must also be provided when using this parameter. If set, ThreadID and ThreadIdentifier cannot be set.
		*/
		public void set_ThreadLink(String value) {
			this.setInput("ThreadLink", value);
		}



		/** 
		Set the value of the VaultFile input for this Choreo. 

		@param TembooPath - 
		*/
		public void set_VaultFile(TembooPath value) {
			this.setAlias("VaultFile", value);
		}
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CloseThread Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CloseThreadResultSet extends ResultSet {
		public CloseThreadResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Disqus.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
