package com.temboo.Library.Disqus.Threads;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ListPosts

Retrieve a list of posts within a thread.
*/
public class ListPosts extends Choreography {

	/**
	Create a new instance of the ListPosts Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListPosts(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Disqus/Threads/ListPosts"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListPostsInputSet
	*/
	public ListPostsInputSet newInputSet() {
		return new ListPostsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListPostsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListPostsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListPosts
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListPostsInputSet extends InputSet {
		/** 
		Set the value of the Cursor input for this Choreo. 

		@param String - (optional, string) Default is set to null.
		*/
		public void set_Cursor(String value) {
			this.setInput("Cursor", value);
		}



		/** 
		Set the value of the Forum input for this Choreo. 

		@param Integer - (optional, integer) A Disqus forum ID (AKA a short name). If null, threads from all forums moderated by the authenticating user will be retrieved.
		*/
		public void set_Forum(Integer value) {
			this.setInput("Forum", value);
		}

		/** 
		Set the value of the Forum input for this Choreo as a String. 

		@param String - (optional, integer) A Disqus forum ID (AKA a short name). If null, threads from all forums moderated by the authenticating user will be retrieved.
		*/
		public void set_Forum(String value) {
			this.setInput("Forum", value);	
		}

		/** 
		Set the value of the Include input for this Choreo. 

		@param String - (optional, string) Specify a post status parameter to filter results by. Valid parameters include: unapproved, approved, spam, deleted, flagged.  Default is set to: approved.
		*/
		public void set_Include(String value) {
			this.setInput("Include", value);
		}



		/** 
		Set the value of the Limit input for this Choreo. 

		@param Integer - (optional, integer) The number of records to return. Maximum value is 100.  Defaults to 25.
		*/
		public void set_Limit(Integer value) {
			this.setInput("Limit", value);
		}

		/** 
		Set the value of the Limit input for this Choreo as a String. 

		@param String - (optional, integer) The number of records to return. Maximum value is 100.  Defaults to 25.
		*/
		public void set_Limit(String value) {
			this.setInput("Limit", value);	
		}

		/** 
		Set the value of the Order input for this Choreo. 

		@param String - (optional, string) The sort order of the results. Valid values are: asc or desc. Default is set to: asc.
		*/
		public void set_Order(String value) {
			this.setInput("Order", value);
		}



		/** 
		Set the value of the PublicKey input for this Choreo. 

		@param String - (required, string) The Public Key provided by Disqus (AKA the API Key).
		*/
		public void set_PublicKey(String value) {
			this.setInput("PublicKey", value);
		}



		/** 
		Set the value of the Query input for this Choreo. 

		@param String - (optional, string) A search string to limit results.
		*/
		public void set_Query(String value) {
			this.setInput("Query", value);
		}



		/** 
		Set the value of the Related input for this Choreo. 

		@param String - (optional, string) Specify a related thread or forum that are to be included in the response.  Valid entries include: forum.
		*/
		public void set_Related(String value) {
			this.setInput("Related", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are: json (the default), jsonp, or rss.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the Since input for this Choreo. 

		@param Integer - (optional, integer) A Unix timestamp (or ISO datetime standard) to obtain results from. Default is set to null.
		*/
		public void set_Since(Integer value) {
			this.setInput("Since", value);
		}

		/** 
		Set the value of the Since input for this Choreo as a String. 

		@param String - (optional, integer) A Unix timestamp (or ISO datetime standard) to obtain results from. Default is set to null.
		*/
		public void set_Since(String value) {
			this.setInput("Since", value);	
		}

		/** 
		Set the value of the ThreadID input for this Choreo. 

		@param String - (conditional, string) A Thread ID to narrow post search results. Required unless specifying ThreadIdentifier or ThreadLink.
		*/
		public void set_ThreadID(String value) {
			this.setInput("ThreadID", value);
		}



		/** 
		Set the value of the ThreadIdentifier input for this Choreo. 

		@param String - (optional, string) An identifier to retrieve associated thread details. Note that a Forum must also be provided when using this parameter. If set, ThreadID and ThreadLink cannot be used.
		*/
		public void set_ThreadIdentifier(String value) {
			this.setInput("ThreadIdentifier", value);
		}



		/** 
		Set the value of the ThreadLink input for this Choreo. 

		@param String - (optional, string) A link pointing to the thread that is to be retrieved. Note that a Forum must also be provided when using this parameter. If set, ThreadID and ThreadIdentifier cannot be set.
		*/
		public void set_ThreadLink(String value) {
			this.setInput("ThreadLink", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListPosts Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListPostsResultSet extends ResultSet {
		public ListPostsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Disqus.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
