package com.temboo.Library.Disqus.Threads;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ListThreadReactions

Retrieve a list of reactions for a given thread.
*/
public class ListThreadReactions extends Choreography {

	/**
	Create a new instance of the ListThreadReactions Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListThreadReactions(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Disqus/Threads/ListThreadReactions"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListThreadReactionsInputSet
	*/
	public ListThreadReactionsInputSet newInputSet() {
		return new ListThreadReactionsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListThreadReactionsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListThreadReactionsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListThreadReactions
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListThreadReactionsInputSet extends InputSet {
		/** 
		Set the value of the Cursor input for this Choreo. 

		@param String - (optional, string) Default is set to null.
		*/
		public void set_Cursor(String value) {
			this.setInput("Cursor", value);
		}



		/** 
		Set the value of the Forum input for this Choreo. 

		@param Integer - (optional, integer) A Disqus forum ID (AKA a short name). If null, threads from all forums moderated by the authenticating user will be retrieved.
		*/
		public void set_Forum(Integer value) {
			this.setInput("Forum", value);
		}

		/** 
		Set the value of the Forum input for this Choreo as a String. 

		@param String - (optional, integer) A Disqus forum ID (AKA a short name). If null, threads from all forums moderated by the authenticating user will be retrieved.
		*/
		public void set_Forum(String value) {
			this.setInput("Forum", value);	
		}

		/** 
		Set the value of the Limit input for this Choreo. 

		@param Integer - (optional, integer) The number of records to return. Maximum value is 100.  Defaults to 25.
		*/
		public void set_Limit(Integer value) {
			this.setInput("Limit", value);
		}

		/** 
		Set the value of the Limit input for this Choreo as a String. 

		@param String - (optional, integer) The number of records to return. Maximum value is 100.  Defaults to 25.
		*/
		public void set_Limit(String value) {
			this.setInput("Limit", value);	
		}

		/** 
		Set the value of the PublicKey input for this Choreo. 

		@param String - (required, string) The Public Key provided by Disqus (AKA the API Key).
		*/
		public void set_PublicKey(String value) {
			this.setInput("PublicKey", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are: json (the default), jsonp, or rss.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the ThreadID input for this Choreo. 

		@param String - (conditional, string) The ID of the Thread to list reactions for. Required unless specifying ThreadIdentifier or ThreadLink.
		*/
		public void set_ThreadID(String value) {
			this.setInput("ThreadID", value);
		}



		/** 
		Set the value of the ThreadIdentifier input for this Choreo. 

		@param String - (conditional, string) An identifier for which thread reactions will be retrieved.  Note that a Forum must also be provided when using this parameter. If set, ThreadID and ThreadLink cannot be used.
		*/
		public void set_ThreadIdentifier(String value) {
			this.setInput("ThreadIdentifier", value);
		}



		/** 
		Set the value of the ThreadLink input for this Choreo. 

		@param String - (conditional, string) A link pointing to the thread that is to be retrieved. Note that a Forum must also be provided when using this parameter. If set, ThreadID and ThreadIdentifier cannot be set.
		*/
		public void set_ThreadLink(String value) {
			this.setInput("ThreadLink", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListThreadReactions Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListThreadReactionsResultSet extends ResultSet {
		public ListThreadReactionsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Disqus.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
