package com.temboo.Library.Disqus.Threads;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
VoteOnThread

Vote on a thread.
*/
public class VoteOnThread extends Choreography {

	/**
	Create a new instance of the VoteOnThread Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public VoteOnThread(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Disqus/Threads/VoteOnThread"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return VoteOnThreadInputSet
	*/
	public VoteOnThreadInputSet newInputSet() {
		return new VoteOnThreadInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public VoteOnThreadResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new VoteOnThreadResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the VoteOnThread
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class VoteOnThreadInputSet extends InputSet {
		/** 
		Set the value of the Forum input for this Choreo. 

		@param Integer - (optional, integer) The forum ID of a thread that is being voted on. Required if setting either ThreadByIdentification, or ThreadByLink.
		*/
		public void set_Forum(Integer value) {
			this.setInput("Forum", value);
		}

		/** 
		Set the value of the Forum input for this Choreo as a String. 

		@param String - (optional, integer) The forum ID of a thread that is being voted on. Required if setting either ThreadByIdentification, or ThreadByLink.
		*/
		public void set_Forum(String value) {
			this.setInput("Forum", value);	
		}

		/** 
		Set the value of the PublicKey input for this Choreo. 

		@param String - (required, string) The Public Key provided by Disqus (AKA the API Key).
		*/
		public void set_PublicKey(String value) {
			this.setInput("PublicKey", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and jsonp.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the ThreadID input for this Choreo. 

		@param Integer - (optional, integer) The ID of a thread that is being voted on. Required unless specifying the ThreadIdentifier or ThreadLink. If using this parameter, ThreadIdentifier cannot be set.
		*/
		public void set_ThreadID(Integer value) {
			this.setInput("ThreadID", value);
		}

		/** 
		Set the value of the ThreadID input for this Choreo as a String. 

		@param String - (optional, integer) The ID of a thread that is being voted on. Required unless specifying the ThreadIdentifier or ThreadLink. If using this parameter, ThreadIdentifier cannot be set.
		*/
		public void set_ThreadID(String value) {
			this.setInput("ThreadID", value);	
		}

		/** 
		Set the value of the ThreadIdentifier input for this Choreo. 

		@param String - (optional, string) The identifier for the thread that is being voted on. Note that a Forum must also be provided when using this parameter. If set, ThreadID and ThreadLink cannot be used.
		*/
		public void set_ThreadIdentifier(String value) {
			this.setInput("ThreadIdentifier", value);
		}



		/** 
		Set the value of the ThreadLink input for this Choreo. 

		@param String - (optional, string) A link pointing to the thread that is being voted on. Note that a Forum must also be provided when using this parameter. If set, ThreadID and ThreadIdentifier cannot be set.
		*/
		public void set_ThreadLink(String value) {
			this.setInput("ThreadLink", value);
		}



		/** 
		Set the value of the Vote input for this Choreo. 

		@param Integer - (required, integer) A numberic value for your vote. Valid choices are: -1, 0, or 1.
		*/
		public void set_Vote(Integer value) {
			this.setInput("Vote", value);
		}

		/** 
		Set the value of the Vote input for this Choreo as a String. 

		@param String - (required, integer) A numberic value for your vote. Valid choices are: -1, 0, or 1.
		*/
		public void set_Vote(String value) {
			this.setInput("Vote", value);	
		}

		/** 
		Set the value of the VaultFile input for this Choreo. 

		@param TembooPath - 
		*/
		public void set_VaultFile(TembooPath value) {
			this.setAlias("VaultFile", value);
		}
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the VoteOnThread Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class VoteOnThreadResultSet extends ResultSet {
		public VoteOnThreadResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Disqus.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
