package com.temboo.Library.Disqus.Users;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ListPosts

List posts made by a user.
*/
public class ListPosts extends Choreography {

	/**
	Create a new instance of the ListPosts Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListPosts(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Disqus/Users/ListPosts"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListPostsInputSet
	*/
	public ListPostsInputSet newInputSet() {
		return new ListPostsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListPostsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListPostsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListPosts
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListPostsInputSet extends InputSet {
		/** 
		Set the value of the Cursor input for this Choreo. 

		@param String - (optional, string) Default is set to null.
		*/
		public void set_Cursor(String value) {
			this.setInput("Cursor", value);
		}



		/** 
		Set the value of the Included input for this Choreo. 

		@param String - (optional, string) Specify the type of posts that are to be retrieved. Valid values are: unapproved, approved, spam, deleted, flagged, highlighted.  Default is: approved.
		*/
		public void set_Included(String value) {
			this.setInput("Included", value);
		}



		/** 
		Set the value of the Limit input for this Choreo. 

		@param Integer - (optional, integer) The number of records to return. Defaults to 25.
		*/
		public void set_Limit(Integer value) {
			this.setInput("Limit", value);
		}

		/** 
		Set the value of the Limit input for this Choreo as a String. 

		@param String - (optional, integer) The number of records to return. Defaults to 25.
		*/
		public void set_Limit(String value) {
			this.setInput("Limit", value);	
		}

		/** 
		Set the value of the Order input for this Choreo. 

		@param String - (optional, string) The sort order for the results. valid values are: asc or desc. Default is set to: asc.
		*/
		public void set_Order(String value) {
			this.setInput("Order", value);
		}



		/** 
		Set the value of the PublicKey input for this Choreo. 

		@param String - (required, string) The Public Key provided by Disqus (AKA the API Key).
		*/
		public void set_PublicKey(String value) {
			this.setInput("PublicKey", value);
		}



		/** 
		Set the value of the Related input for this Choreo. 

		@param String - (optional, string) Indicates the relations to include with your response. Valid values are: forum, author, category.
		*/
		public void set_Related(String value) {
			this.setInput("Related", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are: json (the default), jsonp, or rss.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the SinceID input for this Choreo. 

		@param Integer - (optional, integer) Default is set to null.
		*/
		public void set_SinceID(Integer value) {
			this.setInput("SinceID", value);
		}

		/** 
		Set the value of the SinceID input for this Choreo as a String. 

		@param String - (optional, integer) Default is set to null.
		*/
		public void set_SinceID(String value) {
			this.setInput("SinceID", value);	
		}

		/** 
		Set the value of the UserID input for this Choreo. 

		@param String - (optional, string) The Disqus User ID, for which active forum information will be retrieved.  If UserID is set, then Username must be null.
		*/
		public void set_UserID(String value) {
			this.setInput("UserID", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (optional, string) A Disqus username. If Username is being set, then UserID must be null.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListPosts Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListPostsResultSet extends ResultSet {
		public ListPostsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Disqus.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
