package com.temboo.Library.DonorsChoose;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
SearchProjectsByKeyword

Allows you to projects subjects by keyword.
*/
public class SearchProjectsByKeyword extends Choreography {

	/**
	Create a new instance of the SearchProjectsByKeyword Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public SearchProjectsByKeyword(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/DonorsChoose/SearchProjectsByKeyword"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return SearchProjectsByKeywordInputSet
	*/
	public SearchProjectsByKeywordInputSet newInputSet() {
		return new SearchProjectsByKeywordInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public SearchProjectsByKeywordResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new SearchProjectsByKeywordResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the SearchProjectsByKeyword
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class SearchProjectsByKeywordInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (optional, string) The APIKey provided by DonorsChoose.org. Defaults to the test  APIKey 'DONORSCHOOSE'.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Keyword input for this Choreo. 

		@param String - (required, string) Allows you to search for subjects using keyword search
		*/
		public void set_Keyword(String value) {
			this.setInput("Keyword", value);
		}



		/** 
		Set the value of the Max input for this Choreo. 

		@param Integer - (optional, integer) The max number of projects to return. Can return up to 50 rows at a time. Defaults to 10 when left empty.
		*/
		public void set_Max(Integer value) {
			this.setInput("Max", value);
		}

		/** 
		Set the value of the Max input for this Choreo as a String. 

		@param String - (optional, integer) The max number of projects to return. Can return up to 50 rows at a time. Defaults to 10 when left empty.
		*/
		public void set_Max(String value) {
			this.setInput("Max", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to xml.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the SearchProjectsByKeyword Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class SearchProjectsByKeywordResultSet extends ResultSet {
		public SearchProjectsByKeywordResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from DonorsChoose.org
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
