package com.temboo.Library.Dropbox.FilesAndMetadata;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetFileRevisions

Retrieves metadata for the previous revisions of a file
*/
public class GetFileRevisions extends Choreography {

	/**
	Create a new instance of the GetFileRevisions Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetFileRevisions(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Dropbox/FilesAndMetadata/GetFileRevisions"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetFileRevisionsInputSet
	*/
	public GetFileRevisionsInputSet newInputSet() {
		return new GetFileRevisionsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetFileRevisionsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetFileRevisionsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetFileRevisions
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetFileRevisionsInputSet extends InputSet {
		/** 
		Set the value of the AccessTokenSecret input for this Choreo. 

		@param String - (required, string) The Access Token Secret retrieved during the OAuth process.
		*/
		public void set_AccessTokenSecret(String value) {
			this.setInput("AccessTokenSecret", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token retrieved during the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the AppKey input for this Choreo. 

		@param String - (required, string) The App Key provided by Dropbox (AKA the OAuth Consumer Key).
		*/
		public void set_AppKey(String value) {
			this.setInput("AppKey", value);
		}



		/** 
		Set the value of the AppSecret input for this Choreo. 

		@param String - (required, string) The App Secret provided by Dropbox (AKA the OAuth Consumer Secret).
		*/
		public void set_AppSecret(String value) {
			this.setInput("AppSecret", value);
		}



		/** 
		Set the value of the Path input for this Choreo. 

		@param String - (required, string) The path to the file that you want to return revisions for (i.e. RootFolder/SubFolder/MyFile.txt).
		*/
		public void set_Path(String value) {
			this.setInput("Path", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the RevisionLimit input for this Choreo. 

		@param Integer - (optional, integer) Default is 10. Max is 1,000. When listing a file, the service will not report listings containing more than the amount specified here.
		*/
		public void set_RevisionLimit(Integer value) {
			this.setInput("RevisionLimit", value);
		}

		/** 
		Set the value of the RevisionLimit input for this Choreo as a String. 

		@param String - (optional, integer) Default is 10. Max is 1,000. When listing a file, the service will not report listings containing more than the amount specified here.
		*/
		public void set_RevisionLimit(String value) {
			this.setInput("RevisionLimit", value);	
		}

		/** 
		Set the value of the Root input for this Choreo. 

		@param String - (conditional, string) The root relative to which path is specified. Valid values are "sandbox" and "dropbox" (the default). When your access token has the App folder level of access, this should be set to "sandbox".
		*/
		public void set_Root(String value) {
			this.setInput("Root", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetFileRevisions Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetFileRevisionsResultSet extends ResultSet {
		public GetFileRevisionsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Dropbox. Corresponds to the ResponseFormat input. Defaults to json.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
