package com.temboo.Library.Dropbox.FilesAndMetadata;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;
import com.temboo.outputs.Dropbox.DropboxFolderContentsList;

/** 
ListFolderContents

Lists contents of a given Dropbox folder.
*/
public class ListFolderContents extends Choreography {

	/**
	Create a new instance of the ListFolderContents Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListFolderContents(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Dropbox/FilesAndMetadata/ListFolderContents"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListFolderContentsInputSet
	*/
	public ListFolderContentsInputSet newInputSet() {
		return new ListFolderContentsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListFolderContentsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListFolderContentsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListFolderContents
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListFolderContentsInputSet extends InputSet {
		/** 
		Set the value of the AccessTokenSecret input for this Choreo. 

		@param String - (required, string) The Access Token Secret retrieved during the OAuth process.
		*/
		public void set_AccessTokenSecret(String value) {
			this.setInput("AccessTokenSecret", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token retrieved during the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the AppKey input for this Choreo. 

		@param String - (required, string) The App Key provided by Dropbox (AKA the OAuth Consumer Key).
		*/
		public void set_AppKey(String value) {
			this.setInput("AppKey", value);
		}



		/** 
		Set the value of the AppSecret input for this Choreo. 

		@param String - (required, string) The App Secret provided by Dropbox (AKA the OAuth Consumer Secret).
		*/
		public void set_AppSecret(String value) {
			this.setInput("AppSecret", value);
		}



		/** 
		Set the value of the FileLimit input for this Choreo. 

		@param Integer - (optional, integer) Dropbox will not return a list that exceeds this specified limit. Defaults to 10,000.
		*/
		public void set_FileLimit(Integer value) {
			this.setInput("FileLimit", value);
		}

		/** 
		Set the value of the FileLimit input for this Choreo as a String. 

		@param String - (optional, integer) Dropbox will not return a list that exceeds this specified limit. Defaults to 10,000.
		*/
		public void set_FileLimit(String value) {
			this.setInput("FileLimit", value);	
		}

		/** 
		Set the value of the Folder input for this Choreo. 

		@param String - (optional, string) The name of the folder that contains the listing you want to retrieve. A path to a sub-folder is also valid (i.e. RootFolder/SubFolder).
		*/
		public void set_Folder(String value) {
			this.setInput("Folder", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the Root input for this Choreo. 

		@param String - (conditional, string) The root relative to which path is specified. Valid values are "sandbox" and "dropbox" (the default). When your access token has the App folder level of access, this should be set to "sandbox".
		*/
		public void set_Root(String value) {
			this.setInput("Root", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListFolderContents Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListFolderContentsResultSet extends ResultSet {
		public ListFolderContentsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Dropbox. Corresponds to the ResponseFormat input. Defaults to json.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** A list of metadata for the folder's contents
		*/
		public DropboxFolderContentsList getFolderContentsList() {
		    return new DropboxFolderContentsList(((JSONObject)getJSONFromString(this.getResult("Response"))));
		}
	}
	
}
