package com.temboo.Library.Dropbox.OAuth;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
InitializeOAuth

Generates an authorization URL that an application can use to complete the first step in the OAuth process.
*/
public class InitializeOAuth extends Choreography {

	/**
	Create a new instance of the InitializeOAuth Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public InitializeOAuth(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Dropbox/OAuth/InitializeOAuth"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return InitializeOAuthInputSet
	*/
	public InitializeOAuthInputSet newInputSet() {
		return new InitializeOAuthInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public InitializeOAuthResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new InitializeOAuthResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the InitializeOAuth
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class InitializeOAuthInputSet extends InputSet {
		/** 
		Set the value of the AccountName input for this Choreo. 

		@param String - (required, string) Your Temboo account name.
		*/
		public void set_AccountName(String value) {
			this.setInput("AccountName", value);
		}



		/** 
		Set the value of the AppKeyName input for this Choreo. 

		@param String - (required, string) The name of your Temboo application key.
		*/
		public void set_AppKeyName(String value) {
			this.setInput("AppKeyName", value);
		}



		/** 
		Set the value of the AppKeyValue input for this Choreo. 

		@param String - (required, string) Your Temboo application key.
		*/
		public void set_AppKeyValue(String value) {
			this.setInput("AppKeyValue", value);
		}



		/** 
		Set the value of the DropboxAppKey input for this Choreo. 

		@param String - (required, string) The App Key provided by Dropbox (AKA the OAuth Consumer Key).
		*/
		public void set_DropboxAppKey(String value) {
			this.setInput("DropboxAppKey", value);
		}



		/** 
		Set the value of the DropboxAppSecret input for this Choreo. 

		@param String - (required, string) The AppSecret provided by Dropbox (AKA the OAuth Consumer Secret).
		*/
		public void set_DropboxAppSecret(String value) {
			this.setInput("DropboxAppSecret", value);
		}



		/** 
		Set the value of the ForwardingURL input for this Choreo. 

		@param String - (optional, string) The URL that Temboo will redirect your users to after they grant your application access.
		*/
		public void set_ForwardingURL(String value) {
			this.setInput("ForwardingURL", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the InitializeOAuth Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class InitializeOAuthResultSet extends ResultSet {
		public InitializeOAuthResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "AuthorizationURL" output from this Choreo execution

		@return String - (string) The authorization URL that the application's user needs to go to in order to grant access to your application.
		*/
		public String get_AuthorizationURL() {
			return this.getResult("AuthorizationURL");
		}
		/** 
		Retrieve the value for the "CallbackID" output from this Choreo execution

		@return String - (string) An ID used to retrieve the callback data that Temboo stores once your application's user authorizes.
		*/
		public String get_CallbackID() {
			return this.getResult("CallbackID");
		}
		/** 
		Retrieve the value for the "OAuthTokenSecret" output from this Choreo execution

		@return String - (string) The temporary OAuth Token Secret that can be exchanged for a final token secret using the FinalizeOAuth Choreo.
		*/
		public String get_OAuthTokenSecret() {
			return this.getResult("OAuthTokenSecret");
		}
	}
	
}
