package com.temboo.Library.Dwolla.FundingSources;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
FundingSourcesByID

Retrieves the account information for the user associated with the given authorized access token.
*/
public class FundingSourcesByID extends Choreography {

	/**
	Create a new instance of the FundingSourcesByID Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public FundingSourcesByID(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Dwolla/FundingSources/FundingSourcesByID"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return FundingSourcesByIDInputSet
	*/
	public FundingSourcesByIDInputSet newInputSet() {
		return new FundingSourcesByIDInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public FundingSourcesByIDResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new FundingSourcesByIDResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the FundingSourcesByID
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class FundingSourcesByIDInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) A valid OAuth token.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the FundingID input for this Choreo. 

		@param String - (required, string) Funding source identifier of the funding source being requested.
		*/
		public void set_FundingID(String value) {
			this.setInput("FundingID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the FundingSourcesByID Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class FundingSourcesByIDResultSet extends ResultSet {
		public FundingSourcesByIDResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Dwolla.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
