package com.temboo.Library.Dwolla.Transactions;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Stats

Retrieves the account information for the user associated with the given authorized access token.
*/
public class Stats extends Choreography {

	/**
	Create a new instance of the Stats Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Stats(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Dwolla/Transactions/Stats"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return StatsInputSet
	*/
	public StatsInputSet newInputSet() {
		return new StatsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public StatsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new StatsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Stats
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class StatsInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) A valid OAuth token.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the EndDate input for this Choreo. 

		@param String - (optional, string) Ending date and time to for which to process transactions stats. Defaults to current date and time in UTC.
		*/
		public void set_EndDate(String value) {
			this.setInput("EndDate", value);
		}



		/** 
		Set the value of the StartDate input for this Choreo. 

		@param String - (optional, string) Starting date and time to for which to process transactions stats. Defaults to 0300 of the current day in UTC.
		*/
		public void set_StartDate(String value) {
			this.setInput("StartDate", value);
		}



		/** 
		Set the value of the Types input for this Choreo. 

		@param String - (optional, string) Types of status to retrieve. Must be comma delimited. Options are TransactionsCount and TransactionsTotal. Defaults to include all stats.
		*/
		public void set_Types(String value) {
			this.setInput("Types", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Stats Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class StatsResultSet extends ResultSet {
		public StatsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Dwolla.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
