package com.temboo.Library.Dwolla.Users;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Account

Retrieves the account information for the user associated with the given authorized access token.
*/
public class Account extends Choreography {

	/**
	Create a new instance of the Account Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Account(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Dwolla/Users/Account"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return AccountInputSet
	*/
	public AccountInputSet newInputSet() {
		return new AccountInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public AccountResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new AccountResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Account
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class AccountInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) A valid OAuth token.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Account Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class AccountResultSet extends ResultSet {
		public AccountResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Dwolla.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
