package com.temboo.Library.EnviroFacts.DesignForEnvironment;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
SearchByProduct

Searches for products in the EPA Design for the Environment database.
*/
public class SearchByProduct extends Choreography {

	/**
	Create a new instance of the SearchByProduct Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public SearchByProduct(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/EnviroFacts/DesignForEnvironment/SearchByProduct"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return SearchByProductInputSet
	*/
	public SearchByProductInputSet newInputSet() {
		return new SearchByProductInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public SearchByProductResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new SearchByProductResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the SearchByProduct
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class SearchByProductInputSet extends InputSet {
		/** 
		Set the value of the CompanyKeyword input for this Choreo. 

		@param String - (conditional, string) A keyword in the name of the company to search for. If a specific ProductName or ProductID is specified, this input is ignored.
		*/
		public void set_CompanyKeyword(String value) {
			this.setInput("CompanyKeyword", value);
		}



		/** 
		Set the value of the Operator input for this Choreo. 

		@param String - (optional, string) Default output is "CONTAINING" and does not require an operator, but users can enter "<", " >", "!=", "BEGINNING", "=" for more customized searches.
		*/
		public void set_Operator(String value) {
			this.setInput("Operator", value);
		}



		/** 
		Set the value of the ProductID input for this Choreo. 

		@param Integer - (conditional, integer) A number representing the unique identifier for a product in the EnviroFacts database.
		*/
		public void set_ProductID(Integer value) {
			this.setInput("ProductID", value);
		}

		/** 
		Set the value of the ProductID input for this Choreo as a String. 

		@param String - (conditional, integer) A number representing the unique identifier for a product in the EnviroFacts database.
		*/
		public void set_ProductID(String value) {
			this.setInput("ProductID", value);	
		}

		/** 
		Set the value of the ProductKeyword input for this Choreo. 

		@param String - (conditional, string) A keyword in the name of the product to search for. If a specific ProductID is specified, this input is ignored.
		*/
		public void set_ProductKeyword(String value) {
			this.setInput("ProductKeyword", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (conditional, string) Response can be returned in JSON or XML. Defaults to XML.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the RowEnd input for this Choreo. 

		@param Integer - (optional, integer) Number 1 or greater indicates the ending row number of the results displayed. Default is 4999 when RowStart is 0. Up to 5000 entries are returned in the output.
		*/
		public void set_RowEnd(Integer value) {
			this.setInput("RowEnd", value);
		}

		/** 
		Set the value of the RowEnd input for this Choreo as a String. 

		@param String - (optional, integer) Number 1 or greater indicates the ending row number of the results displayed. Default is 4999 when RowStart is 0. Up to 5000 entries are returned in the output.
		*/
		public void set_RowEnd(String value) {
			this.setInput("RowEnd", value);	
		}

		/** 
		Set the value of the RowStart input for this Choreo. 

		@param Integer - (optional, integer) Indicates the starting row number of the results displayed. Default is 0.
		*/
		public void set_RowStart(Integer value) {
			this.setInput("RowStart", value);
		}

		/** 
		Set the value of the RowStart input for this Choreo as a String. 

		@param String - (optional, integer) Indicates the starting row number of the results displayed. Default is 0.
		*/
		public void set_RowStart(String value) {
			this.setInput("RowStart", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the SearchByProduct Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class SearchByProductResultSet extends ResultSet {
		public SearchByProductResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Count" output from this Choreo execution

		@return String - The total number of records returned for any given search.
		*/
		public String get_Count() {
			return this.getResult("Count");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from EnviroFacts.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
