package com.temboo.Library.EnviroFacts.UVForecast;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
DailyUVByCity

Retrieves EPA daily Ultraviolet (UV) Index readings in a given city.
*/
public class DailyUVByCity extends Choreography {

	/**
	Create a new instance of the DailyUVByCity Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DailyUVByCity(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/EnviroFacts/UVForecast/DailyUVByCity"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DailyUVByCityInputSet
	*/
	public DailyUVByCityInputSet newInputSet() {
		return new DailyUVByCityInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DailyUVByCityResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DailyUVByCityResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DailyUVByCity
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DailyUVByCityInputSet extends InputSet {
		/** 
		Set the value of the City input for this Choreo. 

		@param String - (required, string) A valid City Name in the United States.
		*/
		public void set_City(String value) {
			this.setInput("City", value);
		}



		/** 
		Set the value of the ResponseType input for this Choreo. 

		@param String - (optional, string) Results can be retrieved in either JSON or XML. Defaults to XML.
		*/
		public void set_ResponseType(String value) {
			this.setInput("ResponseType", value);
		}



		/** 
		Set the value of the State input for this Choreo. 

		@param String - (required, string) The abbreviation of the state that the city resides in.
		*/
		public void set_State(String value) {
			this.setInput("State", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DailyUVByCity Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DailyUVByCityResultSet extends ResultSet {
		public DailyUVByCityResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from EnviroFacts.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
