package com.temboo.Library.EnviroFacts.UVForecast;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
HourlyUVByCity

Retrieves EPA hourly Ultraviolet (UV) Index readings in a given city. 
*/
public class HourlyUVByCity extends Choreography {

	/**
	Create a new instance of the HourlyUVByCity Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public HourlyUVByCity(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/EnviroFacts/UVForecast/HourlyUVByCity"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return HourlyUVByCityInputSet
	*/
	public HourlyUVByCityInputSet newInputSet() {
		return new HourlyUVByCityInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public HourlyUVByCityResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new HourlyUVByCityResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the HourlyUVByCity
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class HourlyUVByCityInputSet extends InputSet {
		/** 
		Set the value of the City input for this Choreo. 

		@param String - (required, string) A valid City Name in the United States.
		*/
		public void set_City(String value) {
			this.setInput("City", value);
		}



		/** 
		Set the value of the ResponseType input for this Choreo. 

		@param String - (optional, string) Results can be retrieved in either JSON or XML. Defaults to XML.
		*/
		public void set_ResponseType(String value) {
			this.setInput("ResponseType", value);
		}



		/** 
		Set the value of the State input for this Choreo. 

		@param String - (required, string) The abbreviation of the state that the city resides in.
		*/
		public void set_State(String value) {
			this.setInput("State", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the HourlyUVByCity Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class HourlyUVByCityResultSet extends ResultSet {
		public HourlyUVByCityResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from EnviroFacts.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
