package com.temboo.Library.EnviroFacts.UVForecast;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
HourlyUVByZipCode

Retrieves EPA hourly Ultraviolet (UV) Index readings in a given zip code.
*/
public class HourlyUVByZipCode extends Choreography {

	/**
	Create a new instance of the HourlyUVByZipCode Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public HourlyUVByZipCode(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/EnviroFacts/UVForecast/HourlyUVByZipCode"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return HourlyUVByZipCodeInputSet
	*/
	public HourlyUVByZipCodeInputSet newInputSet() {
		return new HourlyUVByZipCodeInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public HourlyUVByZipCodeResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new HourlyUVByZipCodeResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the HourlyUVByZipCode
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class HourlyUVByZipCodeInputSet extends InputSet {
		/** 
		Set the value of the ResponseType input for this Choreo. 

		@param String - (optional, string) Results can be retrieved in either JSON or XML. Defaults to XML.
		*/
		public void set_ResponseType(String value) {
			this.setInput("ResponseType", value);
		}



		/** 
		Set the value of the Zip input for this Choreo. 

		@param Integer - (required, integer) A valid United States Postal Service (USPS) ZIP Code or Postal Code.
		*/
		public void set_Zip(Integer value) {
			this.setInput("Zip", value);
		}

		/** 
		Set the value of the Zip input for this Choreo as a String. 

		@param String - (required, integer) A valid United States Postal Service (USPS) ZIP Code or Postal Code.
		*/
		public void set_Zip(String value) {
			this.setInput("Zip", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the HourlyUVByZipCode Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class HourlyUVByZipCodeResultSet extends ResultSet {
		public HourlyUVByZipCodeResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from EnviroFacts.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
