package com.temboo.Library.Facebook.Deleting;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
DeleteStatus

Deletes a specified status message from the authenticated user's feed.
*/
public class DeleteStatus extends Choreography {

	/**
	Create a new instance of the DeleteStatus Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DeleteStatus(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Facebook/Deleting/DeleteStatus"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DeleteStatusInputSet
	*/
	public DeleteStatusInputSet newInputSet() {
		return new DeleteStatusInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DeleteStatusResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DeleteStatusResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DeleteStatus
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DeleteStatusInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The access token retrieved from the final step of the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the StatusID input for this Choreo. 

		@param String - (required, string) The ID for the status message you want to delete.
		*/
		public void set_StatusID(String value) {
			this.setInput("StatusID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DeleteStatus Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DeleteStatusResultSet extends ResultSet {
		public DeleteStatusResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (boolean) The response from Facebook. Returns "true" on success.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
