package com.temboo.Library.Facebook.Publishing;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
PublishLink

Publishes a link on a given profile.
*/
public class PublishLink extends Choreography {

	/**
	Create a new instance of the PublishLink Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public PublishLink(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Facebook/Publishing/PublishLink"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return PublishLinkInputSet
	*/
	public PublishLinkInputSet newInputSet() {
		return new PublishLinkInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public PublishLinkResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new PublishLinkResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the PublishLink
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class PublishLinkInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The access token retrieved from the final step of the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the Caption input for this Choreo. 

		@param String - (optional, string) A caption for the link being published.
		*/
		public void set_Caption(String value) {
			this.setInput("Caption", value);
		}



		/** 
		Set the value of the Description input for this Choreo. 

		@param String - (optional, string) A description of the link being published.
		*/
		public void set_Description(String value) {
			this.setInput("Description", value);
		}



		/** 
		Set the value of the Link input for this Choreo. 

		@param String - (required, string) The link to publish.
		*/
		public void set_Link(String value) {
			this.setInput("Link", value);
		}



		/** 
		Set the value of the Message input for this Choreo. 

		@param String - (optional, string) A message about the link.
		*/
		public void set_Message(String value) {
			this.setInput("Message", value);
		}



		/** 
		Set the value of the Name input for this Choreo. 

		@param String - (optional, string) The name of the link.
		*/
		public void set_Name(String value) {
			this.setInput("Name", value);
		}



		/** 
		Set the value of the Picture input for this Choreo. 

		@param String - (optional, string) A URL to the thumbnail image to use for the link post.
		*/
		public void set_Picture(String value) {
			this.setInput("Picture", value);
		}



		/** 
		Set the value of the ProfileID input for this Choreo. 

		@param String - (optional, string) The id of the profile that the link will be published to. Defaults to "me" indicating the authenticated user.
		*/
		public void set_ProfileID(String value) {
			this.setInput("ProfileID", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the PublishLink Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class PublishLinkResultSet extends ResultSet {
		public PublishLinkResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Facebook. Corresponds to the ResponseFormat input. Defaults to JSON.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** Get the ID of the object that has been created
		*/
		public String getFacebookObjectId() {
		    return (String) ((JSONObject)getJSONFromString(this.getResult("Response"))).opt("id");
		}
	}
	
}
