package com.temboo.Library.Facebook.Publishing;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
UploadPhoto

Uploads a photo to a given album.
*/
public class UploadPhoto extends Choreography {

	/**
	Create a new instance of the UploadPhoto Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public UploadPhoto(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Facebook/Publishing/UploadPhoto"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return UploadPhotoInputSet
	*/
	public UploadPhotoInputSet newInputSet() {
		return new UploadPhotoInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public UploadPhotoResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new UploadPhotoResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the UploadPhoto
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class UploadPhotoInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The access token retrieved from the final step of the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the AlbumID input for this Choreo. 

		@param String - (required, string) The id of the album to upload the photo to.
		*/
		public void set_AlbumID(String value) {
			this.setInput("AlbumID", value);
		}



		/** 
		Set the value of the Message input for this Choreo. 

		@param String - (optional, string) A message to attach to the photo.
		*/
		public void set_Message(String value) {
			this.setInput("Message", value);
		}



		/** 
		Set the value of the Photo input for this Choreo. 

		@param String - (conditional, any) The image contents formatted as a Base64 encoded string.
		*/
		public void set_Photo(String value) {
			this.setInput("Photo", value);
		}



		/** 
		Set the value of the Place input for this Choreo. 

		@param String - (optional, string) A location associated with a Photo.
		*/
		public void set_Place(String value) {
			this.setInput("Place", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the Source input for this Choreo. 

		@param String - (optional, string) A link to the source image of the photo.
		*/
		public void set_Source(String value) {
			this.setInput("Source", value);
		}



		/** 
		Set the value of the VaultFile input for this Choreo. 

		@param TembooPath - A path to image in the vault. This can be used as an alternative to the Photo input.
		*/
		public void set_VaultFile(TembooPath value) {
			this.setAlias("VaultFile", value);
		}
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the UploadPhoto Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class UploadPhotoResultSet extends ResultSet {
		public UploadPhotoResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Facebook. Corresponds to the ResponseFormat input. Defaults to JSON.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** Get the ID of the object that has been created
		*/
		public String getFacebookObjectId() {
		    return (String) ((JSONObject)getJSONFromString(this.getResult("Response"))).opt("id");
		}
	}
	
}
