package com.temboo.Library.Facebook.Reading;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;
import com.temboo.outputs.Facebook.FacebookFriendRequest;
import com.temboo.outputs.Facebook.FacebookSummary;

/** 
FriendRequests

Retrieves a list of friend requests for a specified user.
*/
public class FriendRequests extends Choreography {

	/**
	Create a new instance of the FriendRequests Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public FriendRequests(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Facebook/Reading/FriendRequests"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return FriendRequestsInputSet
	*/
	public FriendRequestsInputSet newInputSet() {
		return new FriendRequestsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public FriendRequestsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new FriendRequestsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the FriendRequests
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class FriendRequestsInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The access token retrieved from the final step of the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the Fields input for this Choreo. 

		@param String - (optional, string) A comma separated list of fields to return (i.e. id,name).
		*/
		public void set_Fields(String value) {
			this.setInput("Fields", value);
		}



		/** 
		Set the value of the Limt input for this Choreo. 

		@param Integer - (optional, integer) Used to page through results. Limits the number of records returned in the response.
		*/
		public void set_Limt(Integer value) {
			this.setInput("Limt", value);
		}

		/** 
		Set the value of the Limt input for this Choreo as a String. 

		@param String - (optional, integer) Used to page through results. Limits the number of records returned in the response.
		*/
		public void set_Limt(String value) {
			this.setInput("Limt", value);	
		}

		/** 
		Set the value of the Offset input for this Choreo. 

		@param Integer - (optional, integer) Used to page through results. Returns results starting from the specified number.
		*/
		public void set_Offset(Integer value) {
			this.setInput("Offset", value);
		}

		/** 
		Set the value of the Offset input for this Choreo as a String. 

		@param String - (optional, integer) Used to page through results. Returns results starting from the specified number.
		*/
		public void set_Offset(String value) {
			this.setInput("Offset", value);	
		}

		/** 
		Set the value of the ProfileID input for this Choreo. 

		@param String - (optional, string) The id of the profile to retrieve friend requests for. Defaults to "me" indicating the authenticated user.
		*/
		public void set_ProfileID(String value) {
			this.setInput("ProfileID", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the Since input for this Choreo. 

		@param String - (optional, date) Used for time-based pagination. Values can be a unix timestamp or any date accepted by strtotime.
		*/
		public void set_Since(String value) {
			this.setInput("Since", value);
		}



		/** 
		Set the value of the Until input for this Choreo. 

		@param String - (optional, date) Used for time-based pagination. Values can be a unix timestamp or any date accepted by strtotime.
		*/
		public void set_Until(String value) {
			this.setInput("Until", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the FriendRequests Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class FriendRequestsResultSet extends ResultSet {
		public FriendRequestsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Facebook. Corresponds to the ResponseFormat input. Defaults to JSON.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** Get a friend requests for this user
		*/
		public FacebookFriendRequest[] getFriendRequests() {
		    JSONArray list = (JSONArray) ((JSONObject)getJSONFromString(this.getResult("Response"))).opt("data");
		    FacebookFriendRequest[] resultArray = new FacebookFriendRequest[(list != null) ? list.length() : 0];
		    if(list != null) {
		    	for(int i=0; i<list.length(); i++) {
		    	    try {
		    	        resultArray[i] = new FacebookFriendRequest(list.get(i));
		    	    } catch (JSONException e) {}
		    	}
		    }
		    return resultArray;

		}
		/** Get the summary for friend requests
		*/
		public FacebookSummary getSummary() {
		    return new FacebookSummary(((JSONObject)getJSONFromString(this.getResult("Response"))).opt("summary"));
		}
	}
	
}
