package com.temboo.Library.Facebook.Searching;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
FQL

Allows you to use a SQL-style syntax to query data in the Graph API.
*/
public class FQL extends Choreography {

	/**
	Create a new instance of the FQL Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public FQL(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Facebook/Searching/FQL"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return FQLInputSet
	*/
	public FQLInputSet newInputSet() {
		return new FQLInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public FQLResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new FQLResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the FQL
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class FQLInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The access token retrieved from the final step of the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the Conditions input for this Choreo. 

		@param String - (required, string) The conditions to use in the WHERE clause of the FQL statement.
		*/
		public void set_Conditions(String value) {
			this.setInput("Conditions", value);
		}



		/** 
		Set the value of the Fields input for this Choreo. 

		@param String - (required, string) The fields to return in the response.
		*/
		public void set_Fields(String value) {
			this.setInput("Fields", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the Table input for this Choreo. 

		@param String - (required, string) The table to select records from.
		*/
		public void set_Table(String value) {
			this.setInput("Table", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the FQL Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class FQLResultSet extends ResultSet {
		public FQLResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Facebook. Corresponds to the ResponseFormat input. Defaults to JSON.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
