package com.temboo.Library.Facebook.Searching;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
MultiQuery

Allows you to submit multiple FQL statements and retrieve all the results you need in one request.
*/
public class MultiQuery extends Choreography {

	/**
	Create a new instance of the MultiQuery Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public MultiQuery(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Facebook/Searching/MultiQuery"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return MultiQueryInputSet
	*/
	public MultiQueryInputSet newInputSet() {
		return new MultiQueryInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public MultiQueryResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new MultiQueryResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the MultiQuery
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class MultiQueryInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The access token retrieved from the final step of the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the Queries input for this Choreo. 

		@param String - (required, json) A JSON dictionary containing multiple queries to execute. See documentation for formatting examples.
		*/
		public void set_Queries(String value) {
			this.setInput("Queries", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the MultiQuery Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class MultiQueryResultSet extends ResultSet {
		public MultiQueryResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Facebook. Corresponds to the ResponseFormat input. Defaults to JSON.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
