package com.temboo.Library.Factual;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
FilterPlacesByTopLevelCategory

Find places by top-level category and near specified latitude, longitude coordinates.
*/
public class FilterPlacesByTopLevelCategory extends Choreography {

	/**
	Create a new instance of the FilterPlacesByTopLevelCategory Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public FilterPlacesByTopLevelCategory(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Factual/FilterPlacesByTopLevelCategory"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return FilterPlacesByTopLevelCategoryInputSet
	*/
	public FilterPlacesByTopLevelCategoryInputSet newInputSet() {
		return new FilterPlacesByTopLevelCategoryInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public FilterPlacesByTopLevelCategoryResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new FilterPlacesByTopLevelCategoryResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the FilterPlacesByTopLevelCategory
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class FilterPlacesByTopLevelCategoryInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (optional, string) The API Key provided by Factual (AKA the OAuth Consumer Key).
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the APISecret input for this Choreo. 

		@param String - (optional, string) The API Secret provided by Factual (AKA the OAuth Consumer Secret).
		*/
		public void set_APISecret(String value) {
			this.setInput("APISecret", value);
		}



		/** 
		Set the value of the Category input for this Choreo. 

		@param String - (required, string) Enter a Factual top-level category to narrow the search results. See Choreo doc for a list of Factual top-level categories.
		*/
		public void set_Category(String value) {
			this.setInput("Category", value);
		}



		/** 
		Set the value of the Latitude input for this Choreo. 

		@param BigDecimal - (required, decimal) Enter latitude coordinates of the location defining the center of the search radius.
		*/
		public void set_Latitude(BigDecimal value) {
			this.setInput("Latitude", value);
		}

		/** 
		Set the value of the Latitude input for this Choreo as a String. 

		@param String - (required, decimal) Enter latitude coordinates of the location defining the center of the search radius.
		*/
		public void set_Latitude(String value) {
			this.setInput("Latitude", value);	
		}

		/** 
		Set the value of the Longitude input for this Choreo. 

		@param BigDecimal - (required, decimal) Enter longitude coordinates of the location defining the center of the search radius.
		*/
		public void set_Longitude(BigDecimal value) {
			this.setInput("Longitude", value);
		}

		/** 
		Set the value of the Longitude input for this Choreo as a String. 

		@param String - (required, decimal) Enter longitude coordinates of the location defining the center of the search radius.
		*/
		public void set_Longitude(String value) {
			this.setInput("Longitude", value);	
		}

		/** 
		Set the value of the Query input for this Choreo. 

		@param String - (optional, string) A search string (i.e. Starbucks)
		*/
		public void set_Query(String value) {
			this.setInput("Query", value);
		}



		/** 
		Set the value of the Radius input for this Choreo. 

		@param Integer - (required, integer) Provide the radius (in meters, and centered on the latitude-longitude coordinates specified) for which search results will be returned.
		*/
		public void set_Radius(Integer value) {
			this.setInput("Radius", value);
		}

		/** 
		Set the value of the Radius input for this Choreo as a String. 

		@param String - (required, integer) Provide the radius (in meters, and centered on the latitude-longitude coordinates specified) for which search results will be returned.
		*/
		public void set_Radius(String value) {
			this.setInput("Radius", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the FilterPlacesByTopLevelCategory Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class FilterPlacesByTopLevelCategoryResultSet extends ResultSet {
		public FilterPlacesByTopLevelCategoryResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Factual.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
