package com.temboo.Library.Factual;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
FindRestaurantsByName

Search for restaurants by name. 
*/
public class FindRestaurantsByName extends Choreography {

	/**
	Create a new instance of the FindRestaurantsByName Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public FindRestaurantsByName(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Factual/FindRestaurantsByName"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return FindRestaurantsByNameInputSet
	*/
	public FindRestaurantsByNameInputSet newInputSet() {
		return new FindRestaurantsByNameInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public FindRestaurantsByNameResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new FindRestaurantsByNameResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the FindRestaurantsByName
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class FindRestaurantsByNameInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (optional, string) The API Key provided by Factual (AKA the OAuth Consumer Key).
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the APISecret input for this Choreo. 

		@param String - (optional, string) The API Secret provided by Factual (AKA the OAuth Consumer Secret).
		*/
		public void set_APISecret(String value) {
			this.setInput("APISecret", value);
		}



		/** 
		Set the value of the Query input for this Choreo. 

		@param String - (required, string) A search string (i.e. Starbucks)
		*/
		public void set_Query(String value) {
			this.setInput("Query", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the FindRestaurantsByName Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class FindRestaurantsByNameResultSet extends ResultSet {
		public FindRestaurantsByNameResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Factual.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
