package com.temboo.Library.FedEx;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
AddressValidationRequest

Allows you to submit an address for validation to FedEx Web Services.
*/
public class AddressValidationRequest extends Choreography {

	/**
	Create a new instance of the AddressValidationRequest Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public AddressValidationRequest(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/FedEx/AddressValidationRequest"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return AddressValidationRequestInputSet
	*/
	public AddressValidationRequestInputSet newInputSet() {
		return new AddressValidationRequestInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public AddressValidationRequestResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new AddressValidationRequestResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the AddressValidationRequest
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class AddressValidationRequestInputSet extends InputSet {
		/** 
		Set the value of the AccountNumber input for this Choreo. 

		@param String - (required, string) Your FedEx Account Number
		*/
		public void set_AccountNumber(String value) {
			this.setInput("AccountNumber", value);
		}



		/** 
		Set the value of the AuthenticationKey input for this Choreo. 

		@param String - (required, string) The Production Authentication Key provided by FedEx Web Services
		*/
		public void set_AuthenticationKey(String value) {
			this.setInput("AuthenticationKey", value);
		}



		/** 
		Set the value of the City input for this Choreo. 

		@param String - (required, string) The city to use in the address validation request
		*/
		public void set_City(String value) {
			this.setInput("City", value);
		}



		/** 
		Set the value of the CountryCode input for this Choreo. 

		@param String - (required, string) The country code to use in the address validation request
		*/
		public void set_CountryCode(String value) {
			this.setInput("CountryCode", value);
		}



		/** 
		Set the value of the MeterNumber input for this Choreo. 

		@param String - (required, string) The Production Meter Number provided by FedEx Web Services
		*/
		public void set_MeterNumber(String value) {
			this.setInput("MeterNumber", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The Production Password provided by FedEx Web Services
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the PostalCode input for this Choreo. 

		@param String - (required, string) The postal code to use in the address validation request
		*/
		public void set_PostalCode(String value) {
			this.setInput("PostalCode", value);
		}



		/** 
		Set the value of the State input for this Choreo. 

		@param String - (required, string) The state to use in the address validation request
		*/
		public void set_State(String value) {
			this.setInput("State", value);
		}



		/** 
		Set the value of the Street input for this Choreo. 

		@param String - (required, string) The street to use in the address validation request
		*/
		public void set_Street(String value) {
			this.setInput("Street", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the AddressValidationRequest Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class AddressValidationRequestResultSet extends ResultSet {
		public AddressValidationRequestResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "DeliveryPointValidation" output from this Choreo execution

		@return String - (string) The Delivery Point Validation parsed from the FedEx response
		*/
		public String get_DeliveryPointValidation() {
			return this.getResult("DeliveryPointValidation");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from FedEx
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
