package com.temboo.Library.FedEx;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ServiceAvailabilityRequest

Retrieves available shipping options and delivery dates for a specified origin and destination.
*/
public class ServiceAvailabilityRequest extends Choreography {

	/**
	Create a new instance of the ServiceAvailabilityRequest Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ServiceAvailabilityRequest(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/FedEx/ServiceAvailabilityRequest"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ServiceAvailabilityRequestInputSet
	*/
	public ServiceAvailabilityRequestInputSet newInputSet() {
		return new ServiceAvailabilityRequestInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ServiceAvailabilityRequestResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ServiceAvailabilityRequestResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ServiceAvailabilityRequest
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ServiceAvailabilityRequestInputSet extends InputSet {
		/** 
		Set the value of the AccountNumber input for this Choreo. 

		@param String - (required, string) Your FedEx Account Number
		*/
		public void set_AccountNumber(String value) {
			this.setInput("AccountNumber", value);
		}



		/** 
		Set the value of the AuthenticationKey input for this Choreo. 

		@param String - (required, string) The Production Authentication Key provided by FedEx Web Services
		*/
		public void set_AuthenticationKey(String value) {
			this.setInput("AuthenticationKey", value);
		}



		/** 
		Set the value of the DestinationCountryCode input for this Choreo. 

		@param String - (required, string) The destination country code to use as an input to the service availability request
		*/
		public void set_DestinationCountryCode(String value) {
			this.setInput("DestinationCountryCode", value);
		}



		/** 
		Set the value of the DestinationPostalCode input for this Choreo. 

		@param String - (required, string) The destination postal code to use as an input to the service availability request
		*/
		public void set_DestinationPostalCode(String value) {
			this.setInput("DestinationPostalCode", value);
		}



		/** 
		Set the value of the MeterNumber input for this Choreo. 

		@param String - (required, string) The Production Meter Number provided by FedEx Web Services
		*/
		public void set_MeterNumber(String value) {
			this.setInput("MeterNumber", value);
		}



		/** 
		Set the value of the OriginCountryCode input for this Choreo. 

		@param String - (required, string) The origin country code to use as an input to the service availability request
		*/
		public void set_OriginCountryCode(String value) {
			this.setInput("OriginCountryCode", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The Production Password provided by FedEx Web Services
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the ShipDate input for this Choreo. 

		@param String - (required, date) The date to use for the service availability request (epoch timestamp in milliseconds or formatted like yyyy-MM-dd)
		*/
		public void set_ShipDate(String value) {
			this.setInput("ShipDate", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ServiceAvailabilityRequest Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ServiceAvailabilityRequestResultSet extends ResultSet {
		public ServiceAvailabilityRequestResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from FedEx
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
