package com.temboo.Library.FedEx;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
TrackingRequest

Retrieves package information for a specified tracking number.
*/
public class TrackingRequest extends Choreography {

	/**
	Create a new instance of the TrackingRequest Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public TrackingRequest(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/FedEx/TrackingRequest"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return TrackingRequestInputSet
	*/
	public TrackingRequestInputSet newInputSet() {
		return new TrackingRequestInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public TrackingRequestResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new TrackingRequestResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the TrackingRequest
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class TrackingRequestInputSet extends InputSet {
		/** 
		Set the value of the AccountNumber input for this Choreo. 

		@param String - (required, string) Your FedEx Account Number
		*/
		public void set_AccountNumber(String value) {
			this.setInput("AccountNumber", value);
		}



		/** 
		Set the value of the AuthenticationKey input for this Choreo. 

		@param String - (required, string) The Production Authentication Key provided by FedEx Web Services
		*/
		public void set_AuthenticationKey(String value) {
			this.setInput("AuthenticationKey", value);
		}



		/** 
		Set the value of the MeterNumber input for this Choreo. 

		@param String - (required, string) The Production Meter Number provided by FedEx Web Services
		*/
		public void set_MeterNumber(String value) {
			this.setInput("MeterNumber", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The Production Password provided by FedEx Web Services
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the TrackingNumber input for this Choreo. 

		@param String - (required, string) The package tracking number to use in the request
		*/
		public void set_TrackingNumber(String value) {
			this.setInput("TrackingNumber", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the TrackingRequest Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class TrackingRequestResultSet extends ResultSet {
		public TrackingRequestResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from FedEx
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** 
		Retrieve the value for the "StatusDescription" output from this Choreo execution

		@return String - (string) The status description for the package which is parsed from the FedEx response
		*/
		public String get_StatusDescription() {
			return this.getResult("StatusDescription");
		}
	}
	
}
