package com.temboo.Library.FilesAnywhere;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
AccountLogout

Logout a user.
*/
public class AccountLogout extends Choreography {

	/**
	Create a new instance of the AccountLogout Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public AccountLogout(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/FilesAnywhere/AccountLogout"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return AccountLogoutInputSet
	*/
	public AccountLogoutInputSet newInputSet() {
		return new AccountLogoutInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public AccountLogoutResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new AccountLogoutResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the AccountLogout
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class AccountLogoutInputSet extends InputSet {
		/** 
		Set the value of the Token input for this Choreo. 

		@param String - (required, string) The token retrieved from authentication.  Can be passed from the AccountLogin Choreo.
		*/
		public void set_Token(String value) {
			this.setInput("Token", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the AccountLogout Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class AccountLogoutResultSet extends ResultSet {
		public AccountLogoutResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from FilesAnywhere.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
