package com.temboo.Library.FilesAnywhere;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ListItems

Lists files within a specified directory in your FilesAnywhere account.
*/
public class ListItems extends Choreography {

	/**
	Create a new instance of the ListItems Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListItems(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/FilesAnywhere/ListItems"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListItemsInputSet
	*/
	public ListItemsInputSet newInputSet() {
		return new ListItemsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListItemsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListItemsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListItems
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListItemsInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (conditional, string) The API Key provided by FilesAnywhere. Required unless supplying a valid Token input.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the PageNum input for this Choreo. 

		@param Integer - (optional, integer) The page number to return. Can be used to page through large result sets. Defaults to 1.
		*/
		public void set_PageNum(Integer value) {
			this.setInput("PageNum", value);
		}

		/** 
		Set the value of the PageNum input for this Choreo as a String. 

		@param String - (optional, integer) The page number to return. Can be used to page through large result sets. Defaults to 1.
		*/
		public void set_PageNum(String value) {
			this.setInput("PageNum", value);	
		}

		/** 
		Set the value of the PageSize input for this Choreo. 

		@param Integer - (optional, integer) The number of results to return per page. Defaults to 10.
		*/
		public void set_PageSize(Integer value) {
			this.setInput("PageSize", value);
		}

		/** 
		Set the value of the PageSize input for this Choreo as a String. 

		@param String - (optional, integer) The number of results to return per page. Defaults to 10.
		*/
		public void set_PageSize(String value) {
			this.setInput("PageSize", value);	
		}

		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (conditional, password) Your FilesAnywhere password. Required unless supplying a valid Token input.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Path input for this Choreo. 

		@param String - (required, string) The path to the folder that you want to list items for (i.e. \JOHNSMITH\MyFolder).
		*/
		public void set_Path(String value) {
			this.setInput("Path", value);
		}



		/** 
		Set the value of the Token input for this Choreo. 

		@param String - (conditional, string) If provided, the Choreo will use the token to authenticate. If the token is expired or not provided, the Choreo will relogin and retrieve a new token when APIKey, Username, and Password are supplied.
		*/
		public void set_Token(String value) {
			this.setInput("Token", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (conditional, string) Your FilesAnywhere username. Required unless supplying a valid Token input.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListItems Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListItemsResultSet extends ResultSet {
		public ListItemsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from FilesAnywhere.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** 
		Retrieve the value for the "Token" output from this Choreo execution

		@return String - (conditional, string) If provided, the Choreo will use the token to authenticate. If the token is expired or not provided, the Choreo will relogin and retrieve a new token when APIKey, Username, and Password are supplied.
		*/
		public String get_Token() {
			return this.getResult("Token");
		}
	}
	
}
