package com.temboo.Library.FilesAnywhere;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ListUserVolumes

List user volumes.
*/
public class ListUserVolumes extends Choreography {

	/**
	Create a new instance of the ListUserVolumes Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListUserVolumes(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/FilesAnywhere/ListUserVolumes"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListUserVolumesInputSet
	*/
	public ListUserVolumesInputSet newInputSet() {
		return new ListUserVolumesInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListUserVolumesResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListUserVolumesResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListUserVolumes
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListUserVolumesInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (conditional, string) The API Key provided by FilesAnywhere. Required unless supplying a valid Token input.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (conditional, password) Your FilesAnywhere password. Required unless supplying a valid Token input.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Token input for this Choreo. 

		@param String - (conditional, string) If provided, the Choreo will use the token to authenticate. If the token is expired or not provided, the Choreo will relogin and retrieve a new token when APIKey, Username, and Password are supplied.
		*/
		public void set_Token(String value) {
			this.setInput("Token", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (conditional, string) Your FilesAnywhere username. Required unless supplying a valid Token input.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



		/** 
		Set the value of the VaultFile input for this Choreo. 

		@param TembooPath - (optional, vault file) The path to a vault file that you want to upload. Required unless using the FileContents input.
		*/
		public void set_VaultFile(TembooPath value) {
			this.setAlias("VaultFile", value);
		}
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListUserVolumes Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListUserVolumesResultSet extends ResultSet {
		public ListUserVolumesResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from FilesAnywhere.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** 
		Retrieve the value for the "Token" output from this Choreo execution

		@return String - (conditional, string) If provided, the Choreo will use the token to authenticate. If the token is expired or not provided, the Choreo will relogin and retrieve a new token when APIKey, Username, and Password are supplied.
		*/
		public String get_Token() {
			return this.getResult("Token");
		}
	}
	
}
