package com.temboo.Library.Fitbit.Body;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
LogBodyMeasurements

Creates a new log entry for a user's body measurements.
*/
public class LogBodyMeasurements extends Choreography {

	/**
	Create a new instance of the LogBodyMeasurements Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public LogBodyMeasurements(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Fitbit/Body/LogBodyMeasurements"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return LogBodyMeasurementsInputSet
	*/
	public LogBodyMeasurementsInputSet newInputSet() {
		return new LogBodyMeasurementsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public LogBodyMeasurementsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new LogBodyMeasurementsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the LogBodyMeasurements
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class LogBodyMeasurementsInputSet extends InputSet {
		/** 
		Set the value of the AccessTokenSecret input for this Choreo. 

		@param String - (required, string) The Access Token Secret retrieved during the OAuth process.
		*/
		public void set_AccessTokenSecret(String value) {
			this.setInput("AccessTokenSecret", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token retrieved during the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the Bicep input for this Choreo. 

		@param BigDecimal - (conditional, decimal) The user's bicep measurement.
		*/
		public void set_Bicep(BigDecimal value) {
			this.setInput("Bicep", value);
		}

		/** 
		Set the value of the Bicep input for this Choreo as a String. 

		@param String - (conditional, decimal) The user's bicep measurement.
		*/
		public void set_Bicep(String value) {
			this.setInput("Bicep", value);	
		}

		/** 
		Set the value of the Calf input for this Choreo. 

		@param BigDecimal - (conditional, decimal) The user's calf measurement.
		*/
		public void set_Calf(BigDecimal value) {
			this.setInput("Calf", value);
		}

		/** 
		Set the value of the Calf input for this Choreo as a String. 

		@param String - (conditional, decimal) The user's calf measurement.
		*/
		public void set_Calf(String value) {
			this.setInput("Calf", value);	
		}

		/** 
		Set the value of the ConsumerKey input for this Choreo. 

		@param String - (required, string) The Consumer Key provided by Fitbit.
		*/
		public void set_ConsumerKey(String value) {
			this.setInput("ConsumerKey", value);
		}



		/** 
		Set the value of the ConsumerSecret input for this Choreo. 

		@param String - (required, string) The Consumer Secret provided by Fitbit.
		*/
		public void set_ConsumerSecret(String value) {
			this.setInput("ConsumerSecret", value);
		}



		/** 
		Set the value of the Date input for this Choreo. 

		@param String - (required, date) The date that corresponds with the new log entry (in the format yyyy-MM-dd).
		*/
		public void set_Date(String value) {
			this.setInput("Date", value);
		}



		/** 
		Set the value of the Forearm input for this Choreo. 

		@param BigDecimal - (conditional, decimal) The user's forearm measurement.
		*/
		public void set_Forearm(BigDecimal value) {
			this.setInput("Forearm", value);
		}

		/** 
		Set the value of the Forearm input for this Choreo as a String. 

		@param String - (conditional, decimal) The user's forearm measurement.
		*/
		public void set_Forearm(String value) {
			this.setInput("Forearm", value);	
		}

		/** 
		Set the value of the Hips input for this Choreo. 

		@param BigDecimal - (conditional, decimal) The user's hips measurement.
		*/
		public void set_Hips(BigDecimal value) {
			this.setInput("Hips", value);
		}

		/** 
		Set the value of the Hips input for this Choreo as a String. 

		@param String - (conditional, decimal) The user's hips measurement.
		*/
		public void set_Hips(String value) {
			this.setInput("Hips", value);	
		}

		/** 
		Set the value of the Neck input for this Choreo. 

		@param BigDecimal - (conditional, decimal) The user's neck measurement.
		*/
		public void set_Neck(BigDecimal value) {
			this.setInput("Neck", value);
		}

		/** 
		Set the value of the Neck input for this Choreo as a String. 

		@param String - (conditional, decimal) The user's neck measurement.
		*/
		public void set_Neck(String value) {
			this.setInput("Neck", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that you want the response to be in: xml or json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the Thigh input for this Choreo. 

		@param BigDecimal - (conditional, decimal) The user's thigh measurement.
		*/
		public void set_Thigh(BigDecimal value) {
			this.setInput("Thigh", value);
		}

		/** 
		Set the value of the Thigh input for this Choreo as a String. 

		@param String - (conditional, decimal) The user's thigh measurement.
		*/
		public void set_Thigh(String value) {
			this.setInput("Thigh", value);	
		}

		/** 
		Set the value of the UserID input for this Choreo. 

		@param String - (optional, string) The user's encoded id. Defaults to "-" (dash) which will return data for the user associated with the token credentials provided.
		*/
		public void set_UserID(String value) {
			this.setInput("UserID", value);
		}



		/** 
		Set the value of the Waist input for this Choreo. 

		@param BigDecimal - (conditional, decimal) The user's waist measurement.
		*/
		public void set_Waist(BigDecimal value) {
			this.setInput("Waist", value);
		}

		/** 
		Set the value of the Waist input for this Choreo as a String. 

		@param String - (conditional, decimal) The user's waist measurement.
		*/
		public void set_Waist(String value) {
			this.setInput("Waist", value);	
		}

		/** 
		Set the value of the Weight input for this Choreo. 

		@param BigDecimal - (conditional, decimal) The user's weight.
		*/
		public void set_Weight(BigDecimal value) {
			this.setInput("Weight", value);
		}

		/** 
		Set the value of the Weight input for this Choreo as a String. 

		@param String - (conditional, decimal) The user's weight.
		*/
		public void set_Weight(String value) {
			this.setInput("Weight", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the LogBodyMeasurements Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class LogBodyMeasurementsResultSet extends ResultSet {
		public LogBodyMeasurementsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Fitbit.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
