package com.temboo.Library.Fitbit.Foods;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CreateFood

Create new private food for a user.
*/
public class CreateFood extends Choreography {

	/**
	Create a new instance of the CreateFood Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CreateFood(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Fitbit/Foods/CreateFood"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CreateFoodInputSet
	*/
	public CreateFoodInputSet newInputSet() {
		return new CreateFoodInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CreateFoodResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CreateFoodResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CreateFood
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CreateFoodInputSet extends InputSet {
		/** 
		Set the value of the AccessTokenSecret input for this Choreo. 

		@param String - (required, string) The Access Token Secret retrieved during the OAuth process.
		*/
		public void set_AccessTokenSecret(String value) {
			this.setInput("AccessTokenSecret", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token retrieved during the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the Calories input for this Choreo. 

		@param Integer - (required, integer) The number of calories per serving size.
		*/
		public void set_Calories(Integer value) {
			this.setInput("Calories", value);
		}

		/** 
		Set the value of the Calories input for this Choreo as a String. 

		@param String - (required, integer) The number of calories per serving size.
		*/
		public void set_Calories(String value) {
			this.setInput("Calories", value);	
		}

		/** 
		Set the value of the ConsumerKey input for this Choreo. 

		@param String - (required, string) The Consumer Key provided by Fitbit.
		*/
		public void set_ConsumerKey(String value) {
			this.setInput("ConsumerKey", value);
		}



		/** 
		Set the value of the ConsumerSecret input for this Choreo. 

		@param String - (required, string) The Consumer Secret provided by Fitbit.
		*/
		public void set_ConsumerSecret(String value) {
			this.setInput("ConsumerSecret", value);
		}



		/** 
		Set the value of the Description input for this Choreo. 

		@param String - (optional, string) A description for the food entry.
		*/
		public void set_Description(String value) {
			this.setInput("Description", value);
		}



		/** 
		Set the value of the FormType input for this Choreo. 

		@param String - (optional, string) Form type; (LIQUID or DRY).
		*/
		public void set_FormType(String value) {
			this.setInput("FormType", value);
		}



		/** 
		Set the value of the MeasurementUnitID input for this Choreo. 

		@param Integer - (required, integer) The default measurement unit.
		*/
		public void set_MeasurementUnitID(Integer value) {
			this.setInput("MeasurementUnitID", value);
		}

		/** 
		Set the value of the MeasurementUnitID input for this Choreo as a String. 

		@param String - (required, integer) The default measurement unit.
		*/
		public void set_MeasurementUnitID(String value) {
			this.setInput("MeasurementUnitID", value);	
		}

		/** 
		Set the value of the Name input for this Choreo. 

		@param String - (required, string) The name of the food.
		*/
		public void set_Name(String value) {
			this.setInput("Name", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that you want the response to be in: xml or json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the ServingSize input for this Choreo. 

		@param Integer - (required, integer) The default serving size.
		*/
		public void set_ServingSize(Integer value) {
			this.setInput("ServingSize", value);
		}

		/** 
		Set the value of the ServingSize input for this Choreo as a String. 

		@param String - (required, integer) The default serving size.
		*/
		public void set_ServingSize(String value) {
			this.setInput("ServingSize", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CreateFood Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CreateFoodResultSet extends ResultSet {
		public CreateFoodResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Fitbit.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
