package com.temboo.Library.Fitbit.Foods;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
LogFood

Log a new food entry for a particular date.
*/
public class LogFood extends Choreography {

	/**
	Create a new instance of the LogFood Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public LogFood(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Fitbit/Foods/LogFood"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return LogFoodInputSet
	*/
	public LogFoodInputSet newInputSet() {
		return new LogFoodInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public LogFoodResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new LogFoodResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the LogFood
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class LogFoodInputSet extends InputSet {
		/** 
		Set the value of the AccessTokenSecret input for this Choreo. 

		@param String - (required, string) The Access Token Secret retrieved during the OAuth process.
		*/
		public void set_AccessTokenSecret(String value) {
			this.setInput("AccessTokenSecret", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token retrieved during the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the Amount input for this Choreo. 

		@param Integer - (required, integer) The amount of food consumed formatted like X.XX. Note that this input corresponds with the UnitId input.
		*/
		public void set_Amount(Integer value) {
			this.setInput("Amount", value);
		}

		/** 
		Set the value of the Amount input for this Choreo as a String. 

		@param String - (required, integer) The amount of food consumed formatted like X.XX. Note that this input corresponds with the UnitId input.
		*/
		public void set_Amount(String value) {
			this.setInput("Amount", value);	
		}

		/** 
		Set the value of the ConsumerKey input for this Choreo. 

		@param String - (required, string) The Consumer Key provided by Fitbit.
		*/
		public void set_ConsumerKey(String value) {
			this.setInput("ConsumerKey", value);
		}



		/** 
		Set the value of the ConsumerSecret input for this Choreo. 

		@param String - (required, string) The Consumer Secret provided by Fitbit.
		*/
		public void set_ConsumerSecret(String value) {
			this.setInput("ConsumerSecret", value);
		}



		/** 
		Set the value of the Date input for this Choreo. 

		@param String - (required, date) The date that corresponds with the new log entry (in the format yyyy-MM-dd).
		*/
		public void set_Date(String value) {
			this.setInput("Date", value);
		}



		/** 
		Set the value of the Favorite input for this Choreo. 

		@param Boolean - (optional, boolean) Set to 1 to add food to favorites after creating log entry. Defaults to 0 for false.
		*/
		public void set_Favorite(Boolean value) {
			this.setInput("Favorite", value);
		}

		/** 
		Set the value of the Favorite input for this Choreo as a String. 

		@param String - (optional, boolean) Set to 1 to add food to favorites after creating log entry. Defaults to 0 for false.
		*/
		public void set_Favorite(String value) {
			this.setInput("Favorite", value);	
		}

		/** 
		Set the value of the FoodID input for this Choreo. 

		@param Integer - (required, integer) The id of the food to create a log entry for.
		*/
		public void set_FoodID(Integer value) {
			this.setInput("FoodID", value);
		}

		/** 
		Set the value of the FoodID input for this Choreo as a String. 

		@param String - (required, integer) The id of the food to create a log entry for.
		*/
		public void set_FoodID(String value) {
			this.setInput("FoodID", value);	
		}

		/** 
		Set the value of the MealType input for this Choreo. 

		@param String - (required, string) The type of meal. Valid values: Breakfast, Morning Snack, Lunch, Afternoon Snack, Dinner, Anytime.
		*/
		public void set_MealType(String value) {
			this.setInput("MealType", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that you want the response to be in: xml or json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the UnitID input for this Choreo. 

		@param Integer - (required, integer) This id can be retrieved through other calls such as: Get Foods (Recent, Frequent, Favorite), Search Foods or Get Food Units.
		*/
		public void set_UnitID(Integer value) {
			this.setInput("UnitID", value);
		}

		/** 
		Set the value of the UnitID input for this Choreo as a String. 

		@param String - (required, integer) This id can be retrieved through other calls such as: Get Foods (Recent, Frequent, Favorite), Search Foods or Get Food Units.
		*/
		public void set_UnitID(String value) {
			this.setInput("UnitID", value);	
		}

		/** 
		Set the value of the UserID input for this Choreo. 

		@param String - (optional, string) The user's encoded id. Defaults to "-" (dash) which will return data for the user associated with the token credentials provided.
		*/
		public void set_UserID(String value) {
			this.setInput("UserID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the LogFood Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class LogFoodResultSet extends ResultSet {
		public LogFoodResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Fitbit.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
