package com.temboo.Library.Fitbit.Heart;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
LogHeartRate

Creates log entry for a heart rate measurement.
*/
public class LogHeartRate extends Choreography {

	/**
	Create a new instance of the LogHeartRate Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public LogHeartRate(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Fitbit/Heart/LogHeartRate"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return LogHeartRateInputSet
	*/
	public LogHeartRateInputSet newInputSet() {
		return new LogHeartRateInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public LogHeartRateResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new LogHeartRateResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the LogHeartRate
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class LogHeartRateInputSet extends InputSet {
		/** 
		Set the value of the AccessTokenSecret input for this Choreo. 

		@param String - (required, string) The Access Token Secret retrieved during the OAuth process.
		*/
		public void set_AccessTokenSecret(String value) {
			this.setInput("AccessTokenSecret", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token retrieved during the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ConsumerKey input for this Choreo. 

		@param String - (required, string) The Consumer Key provided by Fitbit.
		*/
		public void set_ConsumerKey(String value) {
			this.setInput("ConsumerKey", value);
		}



		/** 
		Set the value of the ConsumerSecret input for this Choreo. 

		@param String - (required, string) The Consumer Secret provided by Fitbit.
		*/
		public void set_ConsumerSecret(String value) {
			this.setInput("ConsumerSecret", value);
		}



		/** 
		Set the value of the Date input for this Choreo. 

		@param String - (required, date) The date that corresponds with the log entry (in the format yyyy-MM-dd).
		*/
		public void set_Date(String value) {
			this.setInput("Date", value);
		}



		/** 
		Set the value of the HeartRate input for this Choreo. 

		@param Integer - (required, integer) Heart rate measurement.
		*/
		public void set_HeartRate(Integer value) {
			this.setInput("HeartRate", value);
		}

		/** 
		Set the value of the HeartRate input for this Choreo as a String. 

		@param String - (required, integer) Heart rate measurement.
		*/
		public void set_HeartRate(String value) {
			this.setInput("HeartRate", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that you want the response to be in: xml or json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the Time input for this Choreo. 

		@param String - (optional, string) Time of the measurement; hours and minutes in the format HH:mm.
		*/
		public void set_Time(String value) {
			this.setInput("Time", value);
		}



		/** 
		Set the value of the Tracker input for this Choreo. 

		@param String - (required, string) Heart rate tracker name; predefined or custom tracker name (matches tracker name on the website).
		*/
		public void set_Tracker(String value) {
			this.setInput("Tracker", value);
		}



		/** 
		Set the value of the UserID input for this Choreo. 

		@param String - (optional, string) The user's encoded id. Defaults to "-" (dash) which will return data for the user associated with the token credentials provided.
		*/
		public void set_UserID(String value) {
			this.setInput("UserID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the LogHeartRate Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class LogHeartRateResultSet extends ResultSet {
		public LogHeartRateResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Fitbit.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
