package com.temboo.Library.Fitbit.Social;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
AcceptInvite

Accepts or rejects an invite to become friends with inviting user.
*/
public class AcceptInvite extends Choreography {

	/**
	Create a new instance of the AcceptInvite Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public AcceptInvite(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Fitbit/Social/AcceptInvite"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return AcceptInviteInputSet
	*/
	public AcceptInviteInputSet newInputSet() {
		return new AcceptInviteInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public AcceptInviteResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new AcceptInviteResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the AcceptInvite
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class AcceptInviteInputSet extends InputSet {
		/** 
		Set the value of the Accept input for this Choreo. 

		@param Boolean - (required, boolean) Accept or reject an invite; (true or false).
		*/
		public void set_Accept(Boolean value) {
			this.setInput("Accept", value);
		}

		/** 
		Set the value of the Accept input for this Choreo as a String. 

		@param String - (required, boolean) Accept or reject an invite; (true or false).
		*/
		public void set_Accept(String value) {
			this.setInput("Accept", value);	
		}

		/** 
		Set the value of the AccessTokenSecret input for this Choreo. 

		@param String - (required, string) The Access Token Secret retrieved during the OAuth process.
		*/
		public void set_AccessTokenSecret(String value) {
			this.setInput("AccessTokenSecret", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token retrieved during the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ConsumerKey input for this Choreo. 

		@param String - (required, string) The Consumer Key provided by Fitbit.
		*/
		public void set_ConsumerKey(String value) {
			this.setInput("ConsumerKey", value);
		}



		/** 
		Set the value of the ConsumerSecret input for this Choreo. 

		@param String - (required, string) The Consumer Secret provided by Fitbit.
		*/
		public void set_ConsumerSecret(String value) {
			this.setInput("ConsumerSecret", value);
		}



		/** 
		Set the value of the FromUserID input for this Choreo. 

		@param String - (required, string) The user's id to indicate user to accept or reject invite from.
		*/
		public void set_FromUserID(String value) {
			this.setInput("FromUserID", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that you want the response to be in: xml or json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the UserID input for this Choreo. 

		@param String - (optional, string) The user's encoded id. Defaults to "-" (dash) which will return data for the user associated with the token credentials provided.
		*/
		public void set_UserID(String value) {
			this.setInput("UserID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the AcceptInvite Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class AcceptInviteResultSet extends ResultSet {
		public AcceptInviteResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Fitbit.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
