package com.temboo.Library.Flickr.Favorites;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetContextForFavorite

Returns next and previous favorites for a photo in a user's favorites.
*/
public class GetContextForFavorite extends Choreography {

	/**
	Create a new instance of the GetContextForFavorite Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetContextForFavorite(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Flickr/Favorites/GetContextForFavorite"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetContextForFavoriteInputSet
	*/
	public GetContextForFavoriteInputSet newInputSet() {
		return new GetContextForFavoriteInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetContextForFavoriteResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetContextForFavoriteResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetContextForFavorite
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetContextForFavoriteInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Flickr (AKA the OAuth Consumer Key).
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the PhotoID input for this Choreo. 

		@param Integer - (required, integer) The id of the photo to fetch the context for.
		*/
		public void set_PhotoID(Integer value) {
			this.setInput("PhotoID", value);
		}

		/** 
		Set the value of the PhotoID input for this Choreo as a String. 

		@param String - (required, integer) The id of the photo to fetch the context for.
		*/
		public void set_PhotoID(String value) {
			this.setInput("PhotoID", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are: xml and json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the UserID input for this Choreo. 

		@param String - (required, string) The user who counts the photo as a favorite.
		*/
		public void set_UserID(String value) {
			this.setInput("UserID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetContextForFavorite Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetContextForFavoriteResultSet extends ResultSet {
		public GetContextForFavoriteResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Flickr.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
