package com.temboo.Library.Flickr.Galleries;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CreatePhotoGallery

Creates a new photo gallery.
*/
public class CreatePhotoGallery extends Choreography {

	/**
	Create a new instance of the CreatePhotoGallery Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CreatePhotoGallery(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Flickr/Galleries/CreatePhotoGallery"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CreatePhotoGalleryInputSet
	*/
	public CreatePhotoGalleryInputSet newInputSet() {
		return new CreatePhotoGalleryInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CreatePhotoGalleryResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CreatePhotoGalleryResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CreatePhotoGallery
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CreatePhotoGalleryInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Flickr (AKA the OAuth Consumer Key).
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the APISecret input for this Choreo. 

		@param String - (required, string) The API Secret provided by Flickr (AKA the OAuth Consumer Secret).
		*/
		public void set_APISecret(String value) {
			this.setInput("APISecret", value);
		}



		/** 
		Set the value of the AccessTokenSecret input for this Choreo. 

		@param String - (required, string) The Access Token Secret retrieved during the OAuth process.
		*/
		public void set_AccessTokenSecret(String value) {
			this.setInput("AccessTokenSecret", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token retrieved during the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the Description input for this Choreo. 

		@param String - (required, string) A short description for the gallery.
		*/
		public void set_Description(String value) {
			this.setInput("Description", value);
		}



		/** 
		Set the value of the PrimaryPhotoID input for this Choreo. 

		@param Integer - (optional, integer) The first photo to add to your gallery.
		*/
		public void set_PrimaryPhotoID(Integer value) {
			this.setInput("PrimaryPhotoID", value);
		}

		/** 
		Set the value of the PrimaryPhotoID input for this Choreo as a String. 

		@param String - (optional, integer) The first photo to add to your gallery.
		*/
		public void set_PrimaryPhotoID(String value) {
			this.setInput("PrimaryPhotoID", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are: xml and json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the Title input for this Choreo. 

		@param String - (required, string) The name of the gallery.
		*/
		public void set_Title(String value) {
			this.setInput("Title", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CreatePhotoGallery Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CreatePhotoGalleryResultSet extends ResultSet {
		public CreatePhotoGalleryResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Flickr.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
