package com.temboo.Library.Flickr.Galleries;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ListGalleries

Get a gallery list for a specfied user.
*/
public class ListGalleries extends Choreography {

	/**
	Create a new instance of the ListGalleries Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListGalleries(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Flickr/Galleries/ListGalleries"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListGalleriesInputSet
	*/
	public ListGalleriesInputSet newInputSet() {
		return new ListGalleriesInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListGalleriesResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListGalleriesResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListGalleries
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListGalleriesInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Flickr (AKA the OAuth Consumer Key).
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Page input for this Choreo. 

		@param Integer - (optional, integer) Enter the number of results pages to be returned.  Default is: 1.
		*/
		public void set_Page(Integer value) {
			this.setInput("Page", value);
		}

		/** 
		Set the value of the Page input for this Choreo as a String. 

		@param String - (optional, integer) Enter the number of results pages to be returned.  Default is: 1.
		*/
		public void set_Page(String value) {
			this.setInput("Page", value);	
		}

		/** 
		Set the value of the PerPage input for this Choreo. 

		@param Integer - (optional, integer) Specify the number of galleries that are to be returned per page.  If null, defaults to 100 galleries returned.  Maximum is 500.
		*/
		public void set_PerPage(Integer value) {
			this.setInput("PerPage", value);
		}

		/** 
		Set the value of the PerPage input for this Choreo as a String. 

		@param String - (optional, integer) Specify the number of galleries that are to be returned per page.  If null, defaults to 100 galleries returned.  Maximum is 500.
		*/
		public void set_PerPage(String value) {
			this.setInput("PerPage", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are: xml and json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the UserID input for this Choreo. 

		@param String - (required, string) Provide the NSID for the user whose gallery list(s) are to be retreived.
		*/
		public void set_UserID(String value) {
			this.setInput("UserID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListGalleries Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListGalleriesResultSet extends ResultSet {
		public ListGalleriesResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Flickr.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
