package com.temboo.Library.Flickr.Photos;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ListRecentPhotos

Retrieve public photos that have been recently uploaded to Flickr.
*/
public class ListRecentPhotos extends Choreography {

	/**
	Create a new instance of the ListRecentPhotos Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListRecentPhotos(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Flickr/Photos/ListRecentPhotos"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListRecentPhotosInputSet
	*/
	public ListRecentPhotosInputSet newInputSet() {
		return new ListRecentPhotosInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListRecentPhotosResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListRecentPhotosResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListRecentPhotos
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListRecentPhotosInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Flickr (AKA the OAuth Consumer Key).
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Extras input for this Choreo. 

		@param String - (optional, string) A comma-separated list returning additional photo information such as: license, description, date_upload, date_taken.  Additional options are listed on this method's API doc page.
		*/
		public void set_Extras(String value) {
			this.setInput("Extras", value);
		}



		/** 
		Set the value of the Page input for this Choreo. 

		@param Integer - (optional, integer) Specify the page of photos that is to be returned.  If unspecified, the first page is returned.
		*/
		public void set_Page(Integer value) {
			this.setInput("Page", value);
		}

		/** 
		Set the value of the Page input for this Choreo as a String. 

		@param String - (optional, integer) Specify the page of photos that is to be returned.  If unspecified, the first page is returned.
		*/
		public void set_Page(String value) {
			this.setInput("Page", value);	
		}

		/** 
		Set the value of the PerPage input for this Choreo. 

		@param Integer - (optional, integer) Specify how many photos to display per page. Default is set to: 100. The mamimum allowed value is: 500.
		*/
		public void set_PerPage(Integer value) {
			this.setInput("PerPage", value);
		}

		/** 
		Set the value of the PerPage input for this Choreo as a String. 

		@param String - (optional, integer) Specify how many photos to display per page. Default is set to: 100. The mamimum allowed value is: 500.
		*/
		public void set_PerPage(String value) {
			this.setInput("PerPage", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are: xml and json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListRecentPhotos Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListRecentPhotosResultSet extends ResultSet {
		public ListRecentPhotosResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Flickr.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
