package com.temboo.Library.Flickr.Places;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
FindByKeyword

Returns a list of place IDs for a query string.
*/
public class FindByKeyword extends Choreography {

	/**
	Create a new instance of the FindByKeyword Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public FindByKeyword(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Flickr/Places/FindByKeyword"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return FindByKeywordInputSet
	*/
	public FindByKeywordInputSet newInputSet() {
		return new FindByKeywordInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public FindByKeywordResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new FindByKeywordResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the FindByKeyword
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class FindByKeywordInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Flickr (AKA the OAuth Consumer Key).
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Query input for this Choreo. 

		@param String - (required, string) The query string to use for place ID lookups.
		*/
		public void set_Query(String value) {
			this.setInput("Query", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are: xml and json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the FindByKeyword Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class FindByKeywordResultSet extends ResultSet {
		public FindByKeywordResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Flickr.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
