package com.temboo.Library.Foursquare.Checkins;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;
import com.temboo.outputs.Foursquare.FoursquareLikes;
import com.temboo.outputs.Foursquare.FoursquareMeta;

/** 
Likes

Returns friends and a total count of users who have liked a check-in.
*/
public class Likes extends Choreography {

	/**
	Create a new instance of the Likes Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Likes(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Foursquare/Checkins/Likes"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return LikesInputSet
	*/
	public LikesInputSet newInputSet() {
		return new LikesInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public LikesResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new LikesResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Likes
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class LikesInputSet extends InputSet {
		/** 
		Set the value of the CheckinID input for this Choreo. 

		@param String - (required, string) The ID of the check-in to retrieve likes for.
		*/
		public void set_CheckinID(String value) {
			this.setInput("CheckinID", value);
		}



		/** 
		Set the value of the ClientID input for this Choreo. 

		@param String - (conditional, string) Your Foursquare client ID, obtained after registering at Foursquare. Required unless using the OauthToken input.
		*/
		public void set_ClientID(String value) {
			this.setInput("ClientID", value);
		}



		/** 
		Set the value of the ClientSecret input for this Choreo. 

		@param String - (conditional, string) Your Foursquare client secret, obtained after registering at Foursquare. Required unless using the OauthToken input.
		*/
		public void set_ClientSecret(String value) {
			this.setInput("ClientSecret", value);
		}



		/** 
		Set the value of the OauthToken input for this Choreo. 

		@param String - (required, string) The Foursquare API Oauth token string. Required unless specifying the ClientID and ClientSecret.
		*/
		public void set_OauthToken(String value) {
			this.setInput("OauthToken", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that response should be in. Can be set to xml or json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Likes Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class LikesResultSet extends ResultSet {
		public LikesResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Foursquare. Corresponds to the ResponseFormat input. Defaults to JSON.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** Get the response status code
		*/
		public FoursquareMeta getMeta() {
		    return new FoursquareMeta(((JSONObject)getJSONFromString(this.getResult("Response"))).opt("meta"));
		}
		/** Get likes for the checkin
		*/
		public FoursquareLikes getLikes() {
		    return new FoursquareLikes(getJSONObject(((JSONObject)getJSONFromString(this.getResult("Response"))), "response").opt("likes"));
		}
	}
	
}
