package com.temboo.Library.Foursquare.Lists;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;
import com.temboo.outputs.Foursquare.FoursquareList;
import com.temboo.outputs.Foursquare.FoursquareMeta;
import com.temboo.outputs.Foursquare.FoursquareNotification;

/** 
UnfollowList

Allows a user to unfollow a list.
*/
public class UnfollowList extends Choreography {

	/**
	Create a new instance of the UnfollowList Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public UnfollowList(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Foursquare/Lists/UnfollowList"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return UnfollowListInputSet
	*/
	public UnfollowListInputSet newInputSet() {
		return new UnfollowListInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public UnfollowListResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new UnfollowListResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the UnfollowList
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class UnfollowListInputSet extends InputSet {
		/** 
		Set the value of the ListID input for this Choreo. 

		@param String - (required, string) The id of a user-created list.
		*/
		public void set_ListID(String value) {
			this.setInput("ListID", value);
		}



		/** 
		Set the value of the OauthToken input for this Choreo. 

		@param String - (required, string) The FourSquare API Oauth token string.
		*/
		public void set_OauthToken(String value) {
			this.setInput("OauthToken", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that response should be in. Can be set to xml or json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the UnfollowList Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class UnfollowListResultSet extends ResultSet {
		public UnfollowListResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Foursquare. Corresponds to the ResponseFormat input. Defaults to JSON.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** Get the response status code
		*/
		public FoursquareMeta getMeta() {
		    return new FoursquareMeta(((JSONObject)getJSONFromString(this.getResult("Response"))).opt("meta"));
		}
		/** Get the count of unread notifications for the authenticated user
		*/
		public FoursquareNotification[] getNotifications() {
		    JSONArray list = (JSONArray) ((JSONObject)getJSONFromString(this.getResult("Response"))).opt("notifications");
		    FoursquareNotification[] resultArray = new FoursquareNotification[(list != null) ? list.length() : 0];
		    if(list != null) {
		    	for(int i=0; i<list.length(); i++) {
		    	    try {
		    	        resultArray[i] = new FoursquareNotification(list.get(i));
		    	    } catch (JSONException e) {}
		    	}
		    }
		    return resultArray;

		}
		/** Get get list details
		*/
		public FoursquareList getList() {
		    return new FoursquareList(getJSONObject(((JSONObject)getJSONFromString(this.getResult("Response"))), "response").opt("list"));
		}
	}
	
}
