package com.temboo.Library.Foursquare.Lists;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;
import com.temboo.outputs.Foursquare.FoursquareItem;
import com.temboo.outputs.Foursquare.FoursquareMeta;
import com.temboo.outputs.Foursquare.FoursquareNotification;

/** 
UpdateItem

Allows you to add or remove photos and tips from items on user-created lists.
*/
public class UpdateItem extends Choreography {

	/**
	Create a new instance of the UpdateItem Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public UpdateItem(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Foursquare/Lists/UpdateItem"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return UpdateItemInputSet
	*/
	public UpdateItemInputSet newInputSet() {
		return new UpdateItemInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public UpdateItemResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new UpdateItemResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the UpdateItem
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class UpdateItemInputSet extends InputSet {
		/** 
		Set the value of the ItemID input for this Choreo. 

		@param String - (required, string) The id of an item on a list that you wish to update.
		*/
		public void set_ItemID(String value) {
			this.setInput("ItemID", value);
		}



		/** 
		Set the value of the ListID input for this Choreo. 

		@param String - (required, string) The ID of a user-created list to update
		*/
		public void set_ListID(String value) {
			this.setInput("ListID", value);
		}



		/** 
		Set the value of the OauthToken input for this Choreo. 

		@param String - (required, string) The FourSquare API Oauth token string.
		*/
		public void set_OauthToken(String value) {
			this.setInput("OauthToken", value);
		}



		/** 
		Set the value of the PhotoID input for this Choreo. 

		@param String - (optional, string) If present and non-empty, adds a photo to this item. If present and empty, will remove the photo on this item. If the photo was a private checkin photo, it will be promoted to a public venue photo.
		*/
		public void set_PhotoID(String value) {
			this.setInput("PhotoID", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that response should be in. Can be set to xml or json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the Text input for this Choreo. 

		@param String - (optional, string) If present, this creates a public tip on the venue and replaces any existing tip on the item. Cannot be used in conjuction with TipID or PhotoID.
		*/
		public void set_Text(String value) {
			this.setInput("Text", value);
		}



		/** 
		Set the value of the TipID input for this Choreo. 

		@param String - (optional, string) The id of a tip to add to the list. Cannot be used in conjunction with the Text and URL inputs. Note that one of the following must be specified: VenueID, TipID, ItemListID, or ItemID.
		*/
		public void set_TipID(String value) {
			this.setInput("TipID", value);
		}



		/** 
		Set the value of the URL input for this Choreo. 

		@param String - (optional, string) If adding a new tip using the Text input, this can associate a url with the tip.
		*/
		public void set_URL(String value) {
			this.setInput("URL", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the UpdateItem Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class UpdateItemResultSet extends ResultSet {
		public UpdateItemResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Foursquare. Corresponds to the ResponseFormat input. Defaults to JSON.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** Get the response status code
		*/
		public FoursquareMeta getMeta() {
		    return new FoursquareMeta(((JSONObject)getJSONFromString(this.getResult("Response"))).opt("meta"));
		}
		/** Get the count of unread notifications for the authenticated user
		*/
		public FoursquareNotification[] getNotifications() {
		    JSONArray list = (JSONArray) ((JSONObject)getJSONFromString(this.getResult("Response"))).opt("notifications");
		    FoursquareNotification[] resultArray = new FoursquareNotification[(list != null) ? list.length() : 0];
		    if(list != null) {
		    	for(int i=0; i<list.length(); i++) {
		    	    try {
		    	        resultArray[i] = new FoursquareNotification(list.get(i));
		    	    } catch (JSONException e) {}
		    	}
		    }
		    return resultArray;

		}
		/** Get the item that was updated
		*/
		public FoursquareItem getItem() {
		    return new FoursquareItem(getJSONObject(((JSONObject)getJSONFromString(this.getResult("Response"))), "response").opt("item"));
		}
	}
	
}
