package com.temboo.Library.Foursquare.Users;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;
import com.temboo.outputs.Foursquare.FoursquareLeaderboardItem;
import com.temboo.outputs.Foursquare.FoursquareMeta;
import com.temboo.outputs.Foursquare.FoursquareNotification;

/** 
Leaderboard

Return the user's Leaderboard
*/
public class Leaderboard extends Choreography {

	/**
	Create a new instance of the Leaderboard Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Leaderboard(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Foursquare/Users/Leaderboard"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return LeaderboardInputSet
	*/
	public LeaderboardInputSet newInputSet() {
		return new LeaderboardInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public LeaderboardResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new LeaderboardResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Leaderboard
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class LeaderboardInputSet extends InputSet {
		/** 
		Set the value of the Neighbors input for this Choreo. 

		@param Integer - (optional, integer) The number of friends' scores to return that are adjacent to your score, in ranked order.
		*/
		public void set_Neighbors(Integer value) {
			this.setInput("Neighbors", value);
		}

		/** 
		Set the value of the Neighbors input for this Choreo as a String. 

		@param String - (optional, integer) The number of friends' scores to return that are adjacent to your score, in ranked order.
		*/
		public void set_Neighbors(String value) {
			this.setInput("Neighbors", value);	
		}

		/** 
		Set the value of the OauthToken input for this Choreo. 

		@param String - (required, string) The FourSquare API Oauth token string.
		*/
		public void set_OauthToken(String value) {
			this.setInput("OauthToken", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that response should be in. Can be set to xml or json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Leaderboard Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class LeaderboardResultSet extends ResultSet {
		public LeaderboardResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Foursquare. Corresponds to the ResponseFormat input. Defaults to JSON.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** Get the response status code
		*/
		public FoursquareMeta getMeta() {
		    return new FoursquareMeta(((JSONObject)getJSONFromString(this.getResult("Response"))).opt("meta"));
		}
		/** Get the count of unread notifications for the authenticated user
		*/
		public FoursquareNotification[] getNotifications() {
		    JSONArray list = (JSONArray) ((JSONObject)getJSONFromString(this.getResult("Response"))).opt("notifications");
		    FoursquareNotification[] resultArray = new FoursquareNotification[(list != null) ? list.length() : 0];
		    if(list != null) {
		    	for(int i=0; i<list.length(); i++) {
		    	    try {
		    	        resultArray[i] = new FoursquareNotification(list.get(i));
		    	    } catch (JSONException e) {}
		    	}
		    }
		    return resultArray;

		}
		/** Get leaderboard items
		*/
		public FoursquareLeaderboardItem[] getLeaderboardItems() {
		    JSONArray list = (JSONArray) getJSONObject(getJSONObject(((JSONObject)getJSONFromString(this.getResult("Response"))), "response"), "leaderboard").opt("items");
		    FoursquareLeaderboardItem[] resultArray = new FoursquareLeaderboardItem[(list != null) ? list.length() : 0];
		    if(list != null) {
		    	for(int i=0; i<list.length(); i++) {
		    	    try {
		    	        resultArray[i] = new FoursquareLeaderboardItem(list.get(i));
		    	    } catch (JSONException e) {}
		    	}
		    }
		    return resultArray;

		}
	}
	
}
