package com.temboo.Library.Foursquare.Users;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;
import com.temboo.outputs.Foursquare.FoursquareListGroup;
import com.temboo.outputs.Foursquare.FoursquareMeta;
import com.temboo.outputs.Foursquare.FoursquareNotification;

/** 
UserLists

Retrieves user lists.
*/
public class UserLists extends Choreography {

	/**
	Create a new instance of the UserLists Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public UserLists(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Foursquare/Users/UserLists"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return UserListsInputSet
	*/
	public UserListsInputSet newInputSet() {
		return new UserListsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public UserListsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new UserListsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the UserLists
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class UserListsInputSet extends InputSet {
		/** 
		Set the value of the Group input for this Choreo. 

		@param String - (optional, string) Used to narrow down the lists to returns. Valid values are: created, edited, followed, friends, and suggested. See documentation for definitions of these parameter values.
		*/
		public void set_Group(String value) {
			this.setInput("Group", value);
		}



		/** 
		Set the value of the Latitude input for this Choreo. 

		@param BigDecimal - (conditional, decimal) Latitude of user's location. Required in order to return the suggested group.
		*/
		public void set_Latitude(BigDecimal value) {
			this.setInput("Latitude", value);
		}

		/** 
		Set the value of the Latitude input for this Choreo as a String. 

		@param String - (conditional, decimal) Latitude of user's location. Required in order to return the suggested group.
		*/
		public void set_Latitude(String value) {
			this.setInput("Latitude", value);	
		}

		/** 
		Set the value of the Longitude input for this Choreo. 

		@param BigDecimal - (conditional, decimal) Longitude of user's location. Required in order to return the suggested group.
		*/
		public void set_Longitude(BigDecimal value) {
			this.setInput("Longitude", value);
		}

		/** 
		Set the value of the Longitude input for this Choreo as a String. 

		@param String - (conditional, decimal) Longitude of user's location. Required in order to return the suggested group.
		*/
		public void set_Longitude(String value) {
			this.setInput("Longitude", value);	
		}

		/** 
		Set the value of the OauthToken input for this Choreo. 

		@param String - (required, string) The Foursquare API Oauth token string.
		*/
		public void set_OauthToken(String value) {
			this.setInput("OauthToken", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that response should be in. Can be set to xml or json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the UserID input for this Choreo. 

		@param String - (optional, string) Identity of the user to get lists for. Defaults to "self" to get lists of the acting user.
		*/
		public void set_UserID(String value) {
			this.setInput("UserID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the UserLists Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class UserListsResultSet extends ResultSet {
		public UserListsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Foursquare. Corresponds to the ResponseFormat input. Defaults to JSON.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** Get the response status code
		*/
		public FoursquareMeta getMeta() {
		    return new FoursquareMeta(((JSONObject)getJSONFromString(this.getResult("Response"))).opt("meta"));
		}
		/** Get the count of unread notifications for the authenticated user
		*/
		public FoursquareNotification[] getNotifications() {
		    JSONArray list = (JSONArray) ((JSONObject)getJSONFromString(this.getResult("Response"))).opt("notifications");
		    FoursquareNotification[] resultArray = new FoursquareNotification[(list != null) ? list.length() : 0];
		    if(list != null) {
		    	for(int i=0; i<list.length(); i++) {
		    	    try {
		    	        resultArray[i] = new FoursquareNotification(list.get(i));
		    	    } catch (JSONException e) {}
		    	}
		    }
		    return resultArray;

		}
		/** Get list groups
		*/
		public FoursquareListGroup[] getListGroups() {
		    JSONArray list = (JSONArray) getJSONObject(getJSONObject(((JSONObject)getJSONFromString(this.getResult("Response"))), "response"), "lists").opt("groups");
		    FoursquareListGroup[] resultArray = new FoursquareListGroup[(list != null) ? list.length() : 0];
		    if(list != null) {
		    	for(int i=0; i<list.length(); i++) {
		    	    try {
		    	        resultArray[i] = new FoursquareListGroup(list.get(i));
		    	    } catch (JSONException e) {}
		    	}
		    }
		    return resultArray;

		}
	}
	
}
