package com.temboo.Library.Foursquare.Venues;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;
import com.temboo.outputs.Foursquare.FoursquareLikes;
import com.temboo.outputs.Foursquare.FoursquareMeta;
import com.temboo.outputs.Foursquare.FoursquareNotification;

/** 
Like

Allows the authenticated user to like or unlike a venue.
*/
public class Like extends Choreography {

	/**
	Create a new instance of the Like Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Like(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Foursquare/Venues/Like"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return LikeInputSet
	*/
	public LikeInputSet newInputSet() {
		return new LikeInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public LikeResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new LikeResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Like
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class LikeInputSet extends InputSet {
		/** 
		Set the value of the OauthToken input for this Choreo. 

		@param String - (required, string) The FourSquare API Oauth token string.
		*/
		public void set_OauthToken(String value) {
			this.setInput("OauthToken", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that response should be in. Can be set to xml or json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the Set input for this Choreo. 

		@param Boolean - (optional, boolean) Set to 1 (the default) to like this checkin. Set to 0 to undo a previous like.
		*/
		public void set_Set(Boolean value) {
			this.setInput("Set", value);
		}

		/** 
		Set the value of the Set input for this Choreo as a String. 

		@param String - (optional, boolean) Set to 1 (the default) to like this checkin. Set to 0 to undo a previous like.
		*/
		public void set_Set(String value) {
			this.setInput("Set", value);	
		}

		/** 
		Set the value of the VenueID input for this Choreo. 

		@param String - (required, string) The ID of the venue to like or unlike.
		*/
		public void set_VenueID(String value) {
			this.setInput("VenueID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Like Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class LikeResultSet extends ResultSet {
		public LikeResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Foursquare. Corresponds to the ResponseFormat input. Defaults to JSON.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** Get the response status code
		*/
		public FoursquareMeta getMeta() {
		    return new FoursquareMeta(((JSONObject)getJSONFromString(this.getResult("Response"))).opt("meta"));
		}
		/** Get the count of unread notifications for the authenticated user
		*/
		public FoursquareNotification[] getNotifications() {
		    JSONArray list = (JSONArray) ((JSONObject)getJSONFromString(this.getResult("Response"))).opt("notifications");
		    FoursquareNotification[] resultArray = new FoursquareNotification[(list != null) ? list.length() : 0];
		    if(list != null) {
		    	for(int i=0; i<list.length(); i++) {
		    	    try {
		    	        resultArray[i] = new FoursquareNotification(list.get(i));
		    	    } catch (JSONException e) {}
		    	}
		    }
		    return resultArray;

		}
		/** Get likes for this venue
		*/
		public FoursquareLikes getLikes() {
		    return new FoursquareLikes(getJSONObject(((JSONObject)getJSONFromString(this.getResult("Response"))), "response").opt("likes"));
		}
	}
	
}
