package com.temboo.Library.Foursquare.Venues;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;
import com.temboo.outputs.Foursquare.FoursquareMeta;
import com.temboo.outputs.Foursquare.FoursquareNotification;
import com.temboo.outputs.Foursquare.FoursquareVenue;

/** 
Similar

Returns a list of venues similar to the specified venue.
*/
public class Similar extends Choreography {

	/**
	Create a new instance of the Similar Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Similar(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Foursquare/Venues/Similar"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return SimilarInputSet
	*/
	public SimilarInputSet newInputSet() {
		return new SimilarInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public SimilarResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new SimilarResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Similar
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class SimilarInputSet extends InputSet {
		/** 
		Set the value of the OauthToken input for this Choreo. 

		@param String - (required, string) The Foursquare API Oauth token string.
		*/
		public void set_OauthToken(String value) {
			this.setInput("OauthToken", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that response should be in. Can be set to xml or json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the VenueID input for this Choreo. 

		@param String - (required, string) The id for the venue you want similar venues for.
		*/
		public void set_VenueID(String value) {
			this.setInput("VenueID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Similar Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class SimilarResultSet extends ResultSet {
		public SimilarResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Foursquare. Corresponds to the ResponseFormat input. Defaults to JSON.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** Get the response status code
		*/
		public FoursquareMeta getMeta() {
		    return new FoursquareMeta(((JSONObject)getJSONFromString(this.getResult("Response"))).opt("meta"));
		}
		/** Get the count of unread notifications for the authenticated user
		*/
		public FoursquareNotification[] getNotifications() {
		    JSONArray list = (JSONArray) ((JSONObject)getJSONFromString(this.getResult("Response"))).opt("notifications");
		    FoursquareNotification[] resultArray = new FoursquareNotification[(list != null) ? list.length() : 0];
		    if(list != null) {
		    	for(int i=0; i<list.length(); i++) {
		    	    try {
		    	        resultArray[i] = new FoursquareNotification(list.get(i));
		    	    } catch (JSONException e) {}
		    	}
		    }
		    return resultArray;

		}
		/** Get similar venues
		*/
		public FoursquareVenue[] getVenues() {
		    JSONArray list = (JSONArray) getJSONObject(getJSONObject(((JSONObject)getJSONFromString(this.getResult("Response"))), "response"), "similarVenues").opt("items");
		    FoursquareVenue[] resultArray = new FoursquareVenue[(list != null) ? list.length() : 0];
		    if(list != null) {
		    	for(int i=0; i<list.length(); i++) {
		    	    try {
		    	        resultArray[i] = new FoursquareVenue(list.get(i));
		    	    } catch (JSONException e) {}
		    	}
		    }
		    return resultArray;

		}
	}
	
}
