package com.temboo.Library.Freebase;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Image

Generates a thumbnail for an image from the content database to the requested size. 
*/
public class Image extends Choreography {

	/**
	Create a new instance of the Image Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Image(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Freebase/Image"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ImageInputSet
	*/
	public ImageInputSet newInputSet() {
		return new ImageInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ImageResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ImageResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Image
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ImageInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Freebase.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the FallbackID input for this Choreo. 

		@param String - (optional, string) Use this second (fallback) image ID, if the primary ID is not available.
		*/
		public void set_FallbackID(String value) {
			this.setInput("FallbackID", value);
		}



		/** 
		Set the value of the ID input for this Choreo. 

		@param String - (required, string) Enter the ID of the entity for which description information will be retrieved. IDs and MIDs can be obtained by running the Search Choreo in this bundle. Example input: /en/bob_dylan
		*/
		public void set_ID(String value) {
			this.setInput("ID", value);
		}



		/** 
		Set the value of the MaximumHeight input for this Choreo. 

		@param Integer - (optional, integer) Enter the desired maximum image height in pixels. Integers must be in the following range: (0 --> 4,096)
		*/
		public void set_MaximumHeight(Integer value) {
			this.setInput("MaximumHeight", value);
		}

		/** 
		Set the value of the MaximumHeight input for this Choreo as a String. 

		@param String - (optional, integer) Enter the desired maximum image height in pixels. Integers must be in the following range: (0 --> 4,096)
		*/
		public void set_MaximumHeight(String value) {
			this.setInput("MaximumHeight", value);	
		}

		/** 
		Set the value of the MaximumWidth input for this Choreo. 

		@param Integer - (optional, integer) Enter the desired maximum image width in pixels. Integers must be in the following range: (0 --> 4,096)
		*/
		public void set_MaximumWidth(Integer value) {
			this.setInput("MaximumWidth", value);
		}

		/** 
		Set the value of the MaximumWidth input for this Choreo as a String. 

		@param String - (optional, integer) Enter the desired maximum image width in pixels. Integers must be in the following range: (0 --> 4,096)
		*/
		public void set_MaximumWidth(String value) {
			this.setInput("MaximumWidth", value);	
		}

		/** 
		Set the value of the Mode input for this Choreo. 

		@param String - (optional, string) Specify the method used to crop or scale images.  Available methods include: fill, fillcrop, fillcropmid, fit.
		*/
		public void set_Mode(String value) {
			this.setInput("Mode", value);
		}



		/** 
		Set the value of the Pad input for this Choreo. 

		@param Boolean - (optional, boolean) Enter 0, or 1 to specify whether the provided image should be padded to the requested dimensions.
		*/
		public void set_Pad(Boolean value) {
			this.setInput("Pad", value);
		}

		/** 
		Set the value of the Pad input for this Choreo as a String. 

		@param String - (optional, boolean) Enter 0, or 1 to specify whether the provided image should be padded to the requested dimensions.
		*/
		public void set_Pad(String value) {
			this.setInput("Pad", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Image Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ImageResultSet extends ResultSet {
		public ImageResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (string) The response from the Freebase Image API returns the thumbnail in base 64-encoded  format.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
