package com.temboo.Library.Freebase;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
MQLRead

Search the Freebase dataset using the Metaweb query language (MQL).
*/
public class MQLRead extends Choreography {

	/**
	Create a new instance of the MQLRead Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public MQLRead(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Freebase/MQLRead"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return MQLReadInputSet
	*/
	public MQLReadInputSet newInputSet() {
		return new MQLReadInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public MQLReadResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new MQLReadResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the MQLRead
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class MQLReadInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Freebase.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the AsOfTime input for this Choreo. 

		@param String - (optional, string) Run a query as it would have run at a specific point in time. Timestamps must be entered in the following format: 2007-01-09T22, or 2007-02.
		*/
		public void set_AsOfTime(String value) {
			this.setInput("AsOfTime", value);
		}



		/** 
		Set the value of the Cost input for this Choreo. 

		@param Boolean - (optional, boolean) If cost is set to true, a key is returned in the results, indicating the computational cost incurred by lower levels of the service. Default value: false
		*/
		public void set_Cost(Boolean value) {
			this.setInput("Cost", value);
		}

		/** 
		Set the value of the Cost input for this Choreo as a String. 

		@param String - (optional, boolean) If cost is set to true, a key is returned in the results, indicating the computational cost incurred by lower levels of the service. Default value: false
		*/
		public void set_Cost(String value) {
			this.setInput("Cost", value);	
		}

		/** 
		Set the value of the Cursor input for this Choreo. 

		@param String - (optional, string) If set. results can be paged.  See examples at: http://wiki.freebase.com/wiki/MQL_Read_Service
		*/
		public void set_Cursor(String value) {
			this.setInput("Cursor", value);
		}



		/** 
		Set the value of the EscapeHTMLResults input for this Choreo. 

		@param Boolean - (optional, boolean) Specify whether html results are to be escaped or not.  Default is set to: true.
		*/
		public void set_EscapeHTMLResults(Boolean value) {
			this.setInput("EscapeHTMLResults", value);
		}

		/** 
		Set the value of the EscapeHTMLResults input for this Choreo as a String. 

		@param String - (optional, boolean) Specify whether html results are to be escaped or not.  Default is set to: true.
		*/
		public void set_EscapeHTMLResults(String value) {
			this.setInput("EscapeHTMLResults", value);	
		}

		/** 
		Set the value of the Indent input for this Choreo. 

		@param Boolean - (optional, boolean) Specify whether the JSON results should be indented, or not. Enter true, or false. Default: false. Range of values: 0-10.
		*/
		public void set_Indent(Boolean value) {
			this.setInput("Indent", value);
		}

		/** 
		Set the value of the Indent input for this Choreo as a String. 

		@param String - (optional, boolean) Specify whether the JSON results should be indented, or not. Enter true, or false. Default: false. Range of values: 0-10.
		*/
		public void set_Indent(String value) {
			this.setInput("Indent", value);	
		}

		/** 
		Set the value of the Language input for this Choreo. 

		@param String - (optional, string) Specify the language in which the searches will be performed.  Multiple languages can be specified. Default is: /lang/en
		*/
		public void set_Language(String value) {
			this.setInput("Language", value);
		}



		/** 
		Set the value of the Query input for this Choreo. 

		@param String - (required, string) Enter a search query  in a valid MQL JSON format.
		*/
		public void set_Query(String value) {
			this.setInput("Query", value);
		}



		/** 
		Set the value of the UniqenessFailure input for this Choreo. 

		@param String - (optional, string) Specify how MQL responds to uniqueness failures. Enter hard, or soft.  Default is set to: hard.
		*/
		public void set_UniqenessFailure(String value) {
			this.setInput("UniqenessFailure", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the MQLRead Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class MQLReadResultSet extends ResultSet {
		public MQLReadResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from the Freebase MQL Read API in JSON format.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
