package com.temboo.Library.Freebase;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Search

Search the Freebase dataset.
*/
public class Search extends Choreography {

	/**
	Create a new instance of the Search Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Search(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Freebase/Search"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return SearchInputSet
	*/
	public SearchInputSet newInputSet() {
		return new SearchInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public SearchResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new SearchResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Search
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class SearchInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Freebase.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Domain input for this Choreo. 

		@param String - (optional, string) Enter a comma separated list of domain IDs.
		*/
		public void set_Domain(String value) {
			this.setInput("Domain", value);
		}



		/** 
		Set the value of the EscapeHTMLResults input for this Choreo. 

		@param Boolean - (optional, boolean) Specify whether html results are to be escaped or not.  Default is set to: true.
		*/
		public void set_EscapeHTMLResults(Boolean value) {
			this.setInput("EscapeHTMLResults", value);
		}

		/** 
		Set the value of the EscapeHTMLResults input for this Choreo as a String. 

		@param String - (optional, boolean) Specify whether html results are to be escaped or not.  Default is set to: true.
		*/
		public void set_EscapeHTMLResults(String value) {
			this.setInput("EscapeHTMLResults", value);	
		}

		/** 
		Set the value of the Exact input for this Choreo. 

		@param Boolean - (optional, boolean) If set to true, the search query will match only the name and keys exactly. No normalization of any kind will be performed at indexing and query time.Default is set to: false.
		*/
		public void set_Exact(Boolean value) {
			this.setInput("Exact", value);
		}

		/** 
		Set the value of the Exact input for this Choreo as a String. 

		@param String - (optional, boolean) If set to true, the search query will match only the name and keys exactly. No normalization of any kind will be performed at indexing and query time.Default is set to: false.
		*/
		public void set_Exact(String value) {
			this.setInput("Exact", value);	
		}

		/** 
		Set the value of the Filter input for this Choreo. 

		@param String - (optional, string) Specify an s-expression to filter search results. For more info, see: http://wiki.freebase.com/wiki/Search_Cookbook
		*/
		public void set_Filter(String value) {
			this.setInput("Filter", value);
		}



		/** 
		Set the value of the Indent input for this Choreo. 

		@param Boolean - (optional, boolean) Specify whether the JSON results should be indented, or not. Enter true, or false. Default: false.
		*/
		public void set_Indent(Boolean value) {
			this.setInput("Indent", value);
		}

		/** 
		Set the value of the Indent input for this Choreo as a String. 

		@param String - (optional, boolean) Specify whether the JSON results should be indented, or not. Enter true, or false. Default: false.
		*/
		public void set_Indent(String value) {
			this.setInput("Indent", value);	
		}

		/** 
		Set the value of the Language input for this Choreo. 

		@param String - (optional, string) Specify the language in which the searches will be performed.  Default is set to English: /lang/en
		*/
		public void set_Language(String value) {
			this.setInput("Language", value);
		}



		/** 
		Set the value of the Limit input for this Choreo. 

		@param Integer - (optional, integer) Specify the number of results to be retrieved.  Default: 20.
		*/
		public void set_Limit(Integer value) {
			this.setInput("Limit", value);
		}

		/** 
		Set the value of the Limit input for this Choreo as a String. 

		@param String - (optional, integer) Specify the number of results to be retrieved.  Default: 20.
		*/
		public void set_Limit(String value) {
			this.setInput("Limit", value);	
		}

		/** 
		Set the value of the MQLOutput input for this Choreo. 

		@param String - (optional, string) Enter an MQL query to extract entity information.
		*/
		public void set_MQLOutput(String value) {
			this.setInput("MQLOutput", value);
		}



		/** 
		Set the value of the Prefixed input for this Choreo. 

		@param Boolean - (optional, boolean) Specify whether or not search queries are to match results by name prefix. Default value: false.
		*/
		public void set_Prefixed(Boolean value) {
			this.setInput("Prefixed", value);
		}

		/** 
		Set the value of the Prefixed input for this Choreo as a String. 

		@param String - (optional, boolean) Specify whether or not search queries are to match results by name prefix. Default value: false.
		*/
		public void set_Prefixed(String value) {
			this.setInput("Prefixed", value);	
		}

		/** 
		Set the value of the Query input for this Choreo. 

		@param String - (required, string) Enter a search query.
		*/
		public void set_Query(String value) {
			this.setInput("Query", value);
		}



		/** 
		Set the value of the Start input for this Choreo. 

		@param Integer - (optional, integer) Enter a value to page through results.  Default is set to 0.
		*/
		public void set_Start(Integer value) {
			this.setInput("Start", value);
		}

		/** 
		Set the value of the Start input for this Choreo as a String. 

		@param String - (optional, integer) Enter a value to page through results.  Default is set to 0.
		*/
		public void set_Start(String value) {
			this.setInput("Start", value);	
		}

		/** 
		Set the value of the Type input for this Choreo. 

		@param String - (optional, string) Enter a comma-seperated list of type IDs.
		*/
		public void set_Type(String value) {
			this.setInput("Type", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Search Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class SearchResultSet extends ResultSet {
		public SearchResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from the Freebase Search API in JSON format.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
