package com.temboo.Library.Freebase;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Text

Access Freebase topic and schema descriptions.
*/
public class Text extends Choreography {

	/**
	Create a new instance of the Text Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Text(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Freebase/Text"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return TextInputSet
	*/
	public TextInputSet newInputSet() {
		return new TextInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public TextResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new TextResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Text
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class TextInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Freebase.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Format input for this Choreo. 

		@param Boolean - (optional, boolean) Specify the retrieved results format.  Enter, html, plan, or raw. Default is set to: raw
		*/
		public void set_Format(Boolean value) {
			this.setInput("Format", value);
		}

		/** 
		Set the value of the Format input for this Choreo as a String. 

		@param String - (optional, boolean) Specify the retrieved results format.  Enter, html, plan, or raw. Default is set to: raw
		*/
		public void set_Format(String value) {
			this.setInput("Format", value);	
		}

		/** 
		Set the value of the ID input for this Choreo. 

		@param String - (required, string) Enter the ID of the entity for which description information will be retrieved. IDs and MIDs can be obtained by running the Search Choreo in this bundle. Example input: /en/bob_dylan
		*/
		public void set_ID(String value) {
			this.setInput("ID", value);
		}



		/** 
		Set the value of the Language input for this Choreo. 

		@param String - (optional, string) Specify the language in which the searches will be performed. Default is set to English: /lang/en
		*/
		public void set_Language(String value) {
			this.setInput("Language", value);
		}



		/** 
		Set the value of the MaximumLength input for this Choreo. 

		@param Integer - (optional, integer) Enter the max number of characters to return with the rage of 0 - 4,294,967,295. Valid only for plan Format. Default is to: 200
		*/
		public void set_MaximumLength(Integer value) {
			this.setInput("MaximumLength", value);
		}

		/** 
		Set the value of the MaximumLength input for this Choreo as a String. 

		@param String - (optional, integer) Enter the max number of characters to return with the rage of 0 - 4,294,967,295. Valid only for plan Format. Default is to: 200
		*/
		public void set_MaximumLength(String value) {
			this.setInput("MaximumLength", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Text Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class TextResultSet extends ResultSet {
		public TextResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from the Freebase Text API in JSON.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
