package com.temboo.Library.Genability.PricingAndCalc;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CalculateTariffInputMetaData

Retrieve inputs required to run a calculation for the specified tariff, within a specified period of time.
*/
public class CalculateTariffInputMetaData extends Choreography {

	/**
	Create a new instance of the CalculateTariffInputMetaData Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CalculateTariffInputMetaData(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Genability/PricingAndCalc/CalculateTariffInputMetaData"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CalculateTariffInputMetaDataInputSet
	*/
	public CalculateTariffInputMetaDataInputSet newInputSet() {
		return new CalculateTariffInputMetaDataInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CalculateTariffInputMetaDataResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CalculateTariffInputMetaDataResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CalculateTariffInputMetaData
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CalculateTariffInputMetaDataInputSet extends InputSet {
		/** 
		Set the value of the AppID input for this Choreo. 

		@param String - (required, string) The App ID provided by Genability.
		*/
		public void set_AppID(String value) {
			this.setInput("AppID", value);
		}



		/** 
		Set the value of the AppKey input for this Choreo. 

		@param String - (required, string) The App Key provided by Genability.
		*/
		public void set_AppKey(String value) {
			this.setInput("AppKey", value);
		}



		/** 
		Set the value of the BillingPeriod input for this Choreo. 

		@param String - (optional, string) Specify whether results retireved should be based on a billing period, or not.  Default is set to: false.
		*/
		public void set_BillingPeriod(String value) {
			this.setInput("BillingPeriod", value);
		}



		/** 
		Set the value of the CityLimits input for this Choreo. 

		@param String - (optional, string) Specify whether electricity pricing information should be restricted to city limits, or not.  Example input value: Inside.
		*/
		public void set_CityLimits(String value) {
			this.setInput("CityLimits", value);
		}



		/** 
		Set the value of the ConnectionType input for this Choreo. 

		@param String - (optional, string) The connection type.  For example: Primary.
		*/
		public void set_ConnectionType(String value) {
			this.setInput("ConnectionType", value);
		}



		/** 
		Set the value of the FromDateTime input for this Choreo. 

		@param String - (required, string) The date and time of the requested start of the price query. Must be in ISO 8601 format.  Example: 2012-06-12T00:00:00.0-0700
		*/
		public void set_FromDateTime(String value) {
			this.setInput("FromDateTime", value);
		}



		/** 
		Set the value of the GroupBy input for this Choreo. 

		@param String - (optional, string) Specify how calculation details are displayed.  For example retrieved details can be grouped by month, or year. Options include: Daily, Weekly, Month, Year.
		*/
		public void set_GroupBy(String value) {
			this.setInput("GroupBy", value);
		}



		/** 
		Set the value of the KeyName input for this Choreo. 

		@param String - (optional, string) An applicability value.  If an error is returned, indicating the need for an extra applicability parameter, use this variable to set the parameter name.  For example: territoryID.
		*/
		public void set_KeyName(String value) {
			this.setInput("KeyName", value);
		}



		/** 
		Set the value of the KeyValue input for this Choreo. 

		@param String - (conditional, string) The value for the specified KeyName variable. For example if KeyName is set to territoryID, you could provide 3385 for the KeyValue input.
		*/
		public void set_KeyValue(String value) {
			this.setInput("KeyValue", value);
		}



		/** 
		Set the value of the MasterTariffID input for this Choreo. 

		@param String - (required, string) A Genability tariff ID.
		*/
		public void set_MasterTariffID(String value) {
			this.setInput("MasterTariffID", value);
		}



		/** 
		Set the value of the ToDateTime input for this Choreo. 

		@param String - (required, string) The date and time of the requested start of the price query. Must be in ISO 8601 format.  Example: 2012-06-12T00:00:00.0-0700
		*/
		public void set_ToDateTime(String value) {
			this.setInput("ToDateTime", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CalculateTariffInputMetaData Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CalculateTariffInputMetaDataResultSet extends ResultSet {
		public CalculateTariffInputMetaDataResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Genability.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
