package com.temboo.Library.Genability.PricingAndCalc;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetTariffPrice

Retrieve summarized rates of a specified electricity tariff, in addition to changes in rates over a specified time span.
*/
public class GetTariffPrice extends Choreography {

	/**
	Create a new instance of the GetTariffPrice Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetTariffPrice(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Genability/PricingAndCalc/GetTariffPrice"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetTariffPriceInputSet
	*/
	public GetTariffPriceInputSet newInputSet() {
		return new GetTariffPriceInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetTariffPriceResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetTariffPriceResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetTariffPrice
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetTariffPriceInputSet extends InputSet {
		/** 
		Set the value of the AccountID input for this Choreo. 

		@param String - (optional, string) The Genability ID for an account. This is optional if MasterTariffID is set.
		*/
		public void set_AccountID(String value) {
			this.setInput("AccountID", value);
		}



		/** 
		Set the value of the AppID input for this Choreo. 

		@param String - (required, string) The App ID provided by Genability.
		*/
		public void set_AppID(String value) {
			this.setInput("AppID", value);
		}



		/** 
		Set the value of the AppKey input for this Choreo. 

		@param String - (required, string) The App Key provided by Genability.
		*/
		public void set_AppKey(String value) {
			this.setInput("AppKey", value);
		}



		/** 
		Set the value of the ConsumptionAmount input for this Choreo. 

		@param BigDecimal - (optional, decimal) Specify a monthly consumption in kWh. By default the highest banded level of consumption is used.
		*/
		public void set_ConsumptionAmount(BigDecimal value) {
			this.setInput("ConsumptionAmount", value);
		}

		/** 
		Set the value of the ConsumptionAmount input for this Choreo as a String. 

		@param String - (optional, decimal) Specify a monthly consumption in kWh. By default the highest banded level of consumption is used.
		*/
		public void set_ConsumptionAmount(String value) {
			this.setInput("ConsumptionAmount", value);	
		}

		/** 
		Set the value of the DemandAmount input for this Choreo. 

		@param BigDecimal - (optional, decimal) Specify a monthly demand in kWh. By default the highest banded level of demand is used.
		*/
		public void set_DemandAmount(BigDecimal value) {
			this.setInput("DemandAmount", value);
		}

		/** 
		Set the value of the DemandAmount input for this Choreo as a String. 

		@param String - (optional, decimal) Specify a monthly demand in kWh. By default the highest banded level of demand is used.
		*/
		public void set_DemandAmount(String value) {
			this.setInput("DemandAmount", value);	
		}

		/** 
		Set the value of the FromDateTime input for this Choreo. 

		@param String - (required, string) The date and time of the requested start of the price query. Must be in ISO 8601 format.  Example: 2012-06-12T00:00:00.0-0700
		*/
		public void set_FromDateTime(String value) {
			this.setInput("FromDateTime", value);
		}



		/** 
		Set the value of the MasterTariffID input for this Choreo. 

		@param String - (optional, string) A Genability tariff ID. This variable is not required, if AccountID is set.
		*/
		public void set_MasterTariffID(String value) {
			this.setInput("MasterTariffID", value);
		}



		/** 
		Set the value of the PageCount input for this Choreo. 

		@param Integer - (optional, integer) The number of results to be returned. Defailt is set to: 25.
		*/
		public void set_PageCount(Integer value) {
			this.setInput("PageCount", value);
		}

		/** 
		Set the value of the PageCount input for this Choreo as a String. 

		@param String - (optional, integer) The number of results to be returned. Defailt is set to: 25.
		*/
		public void set_PageCount(String value) {
			this.setInput("PageCount", value);	
		}

		/** 
		Set the value of the PageStart input for this Choreo. 

		@param Integer - (optional, integer) The page number to start to display results from. If unspecified, the first page of results will be returned.
		*/
		public void set_PageStart(Integer value) {
			this.setInput("PageStart", value);
		}

		/** 
		Set the value of the PageStart input for this Choreo as a String. 

		@param String - (optional, integer) The page number to start to display results from. If unspecified, the first page of results will be returned.
		*/
		public void set_PageStart(String value) {
			this.setInput("PageStart", value);	
		}

		/** 
		Set the value of the TerritoryID input for this Choreo. 

		@param String - (optional, string) Return rate changes for the specified Territory.
		*/
		public void set_TerritoryID(String value) {
			this.setInput("TerritoryID", value);
		}



		/** 
		Set the value of the ToDateTime input for this Choreo. 

		@param String - (optional, string) The date and time of the requested start of the price query. Must be in ISO 8601 format.  Example: 2012-06-12T00:00:00.0-0700
		*/
		public void set_ToDateTime(String value) {
			this.setInput("ToDateTime", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetTariffPrice Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetTariffPriceResultSet extends ResultSet {
		public GetTariffPriceResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Genability.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
