package com.temboo.Library.Genability.PricingAndCalc;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetTerritoryIDFromZipcode

Get a territoryID, by using a consumer's zipcode, LSE ID and master tariff ID.
*/
public class GetTerritoryIDFromZipcode extends Choreography {

	/**
	Create a new instance of the GetTerritoryIDFromZipcode Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetTerritoryIDFromZipcode(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Genability/PricingAndCalc/GetTerritoryIDFromZipcode"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetTerritoryIDFromZipcodeInputSet
	*/
	public GetTerritoryIDFromZipcodeInputSet newInputSet() {
		return new GetTerritoryIDFromZipcodeInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetTerritoryIDFromZipcodeResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetTerritoryIDFromZipcodeResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetTerritoryIDFromZipcode
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetTerritoryIDFromZipcodeInputSet extends InputSet {
		/** 
		Set the value of the AppID input for this Choreo. 

		@param String - (required, string) The App ID provided by Genability.
		*/
		public void set_AppID(String value) {
			this.setInput("AppID", value);
		}



		/** 
		Set the value of the AppKey input for this Choreo. 

		@param String - (required, string) The App Key provided by Genability.
		*/
		public void set_AppKey(String value) {
			this.setInput("AppKey", value);
		}



		/** 
		Set the value of the LSEID input for this Choreo. 

		@param String - (required, string) An LSE ID.
		*/
		public void set_LSEID(String value) {
			this.setInput("LSEID", value);
		}



		/** 
		Set the value of the MasterTariffID input for this Choreo. 

		@param String - (required, string) A Genability tariff ID.
		*/
		public void set_MasterTariffID(String value) {
			this.setInput("MasterTariffID", value);
		}



		/** 
		Set the value of the Zipcode input for this Choreo. 

		@param Integer - (required, integer) A zip code for which a territory ID is to be retrieved.
		*/
		public void set_Zipcode(Integer value) {
			this.setInput("Zipcode", value);
		}

		/** 
		Set the value of the Zipcode input for this Choreo as a String. 

		@param String - (required, integer) A zip code for which a territory ID is to be retrieved.
		*/
		public void set_Zipcode(String value) {
			this.setInput("Zipcode", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetTerritoryIDFromZipcode Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetTerritoryIDFromZipcodeResultSet extends ResultSet {
		public GetTerritoryIDFromZipcodeResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Genability.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
