package com.temboo.Library.Genability.PricingAndCalc;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
RunNewPriceCalculation

Calculate electricity costs based on a POSTed calculation criteria. 
*/
public class RunNewPriceCalculation extends Choreography {

	/**
	Create a new instance of the RunNewPriceCalculation Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public RunNewPriceCalculation(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Genability/PricingAndCalc/RunNewPriceCalculation"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return RunNewPriceCalculationInputSet
	*/
	public RunNewPriceCalculationInputSet newInputSet() {
		return new RunNewPriceCalculationInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public RunNewPriceCalculationResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new RunNewPriceCalculationResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the RunNewPriceCalculation
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class RunNewPriceCalculationInputSet extends InputSet {
		/** 
		Set the value of the POSTData input for this Choreo. 

		@param String - (required, json) The POST payload in JSON format.
		*/
		public void set_POSTData(String value) {
			this.setInput("POSTData", value);
		}



		/** 
		Set the value of the AppID input for this Choreo. 

		@param String - (required, string) The App ID provided by Genability.
		*/
		public void set_AppID(String value) {
			this.setInput("AppID", value);
		}



		/** 
		Set the value of the AppKey input for this Choreo. 

		@param String - (required, string) The App Key provided by Genability.
		*/
		public void set_AppKey(String value) {
			this.setInput("AppKey", value);
		}



		/** 
		Set the value of the MasterTariffID input for this Choreo. 

		@param String - (required, string) A Genability tariff ID.
		*/
		public void set_MasterTariffID(String value) {
			this.setInput("MasterTariffID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the RunNewPriceCalculation Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class RunNewPriceCalculationResultSet extends ResultSet {
		public RunNewPriceCalculationResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Genability.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
