package com.temboo.Library.Genability.TariffData;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetPropertyKey

Returns an individual Property Key using a given key name.
*/
public class GetPropertyKey extends Choreography {

	/**
	Create a new instance of the GetPropertyKey Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetPropertyKey(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Genability/TariffData/GetPropertyKey"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetPropertyKeyInputSet
	*/
	public GetPropertyKeyInputSet newInputSet() {
		return new GetPropertyKeyInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetPropertyKeyResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetPropertyKeyResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetPropertyKey
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetPropertyKeyInputSet extends InputSet {
		/** 
		Set the value of the AppID input for this Choreo. 

		@param String - (conditional, string) The App ID provided by Genability.
		*/
		public void set_AppID(String value) {
			this.setInput("AppID", value);
		}



		/** 
		Set the value of the AppKey input for this Choreo. 

		@param String - (required, string) The App Key provided by Genability.
		*/
		public void set_AppKey(String value) {
			this.setInput("AppKey", value);
		}



		/** 
		Set the value of the KeyName input for this Choreo. 

		@param String - (required, string) The key name for the property key you want to return.
		*/
		public void set_KeyName(String value) {
			this.setInput("KeyName", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetPropertyKey Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetPropertyKeyResultSet extends ResultSet {
		public GetPropertyKeyResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Genability.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
