package com.temboo.Library.Genability.TariffData;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetTariffs

Returns a list of Tariff objects based a specified search criteria.
*/
public class GetTariffs extends Choreography {

	/**
	Create a new instance of the GetTariffs Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetTariffs(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Genability/TariffData/GetTariffs"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetTariffsInputSet
	*/
	public GetTariffsInputSet newInputSet() {
		return new GetTariffsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetTariffsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetTariffsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetTariffs
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetTariffsInputSet extends InputSet {
		/** 
		Set the value of the AccountID input for this Choreo. 

		@param String - (optional, string) The unique ID of the Account to find tariffs for. Values passed in will override those from the Account.
		*/
		public void set_AccountID(String value) {
			this.setInput("AccountID", value);
		}



		/** 
		Set the value of the AppID input for this Choreo. 

		@param String - (conditional, string) The App ID provided by Genability.
		*/
		public void set_AppID(String value) {
			this.setInput("AppID", value);
		}



		/** 
		Set the value of the AppKey input for this Choreo. 

		@param String - (required, string) The App Key provided by Genability.
		*/
		public void set_AppKey(String value) {
			this.setInput("AppKey", value);
		}



		/** 
		Set the value of the CustomerClasses input for this Choreo. 

		@param String - (optional, string) Returns only these customer classes. Valid values are: RESIDENTIAL, GENERAL.
		*/
		public void set_CustomerClasses(String value) {
			this.setInput("CustomerClasses", value);
		}



		/** 
		Set the value of the EffectiveOn input for this Choreo. 

		@param String - (optional, date) Returns only tariffs that are effective on this date.
		*/
		public void set_EffectiveOn(String value) {
			this.setInput("EffectiveOn", value);
		}



		/** 
		Set the value of the EndsWith input for this Choreo. 

		@param String - (optional, string) When true, the search will only return results that end with the specified search string. Otherwise, any match of the search string will be returned as a result.
		*/
		public void set_EndsWith(String value) {
			this.setInput("EndsWith", value);
		}



		/** 
		Set the value of the FromDateTime input for this Choreo. 

		@param String - (optional, date) Returns only tariffs that are effective on or after this date.
		*/
		public void set_FromDateTime(String value) {
			this.setInput("FromDateTime", value);
		}



		/** 
		Set the value of the IsRegex input for this Choreo. 

		@param Boolean - (optional, boolean) When true, the provided search string will be regarded as a regular expression and the search will return results matching the regular expression.
		*/
		public void set_IsRegex(Boolean value) {
			this.setInput("IsRegex", value);
		}

		/** 
		Set the value of the IsRegex input for this Choreo as a String. 

		@param String - (optional, boolean) When true, the provided search string will be regarded as a regular expression and the search will return results matching the regular expression.
		*/
		public void set_IsRegex(String value) {
			this.setInput("IsRegex", value);	
		}

		/** 
		Set the value of the LSEID input for this Choreo. 

		@param Integer - (optional, integer) Filter tariffs for a specific LSE.
		*/
		public void set_LSEID(Integer value) {
			this.setInput("LSEID", value);
		}

		/** 
		Set the value of the LSEID input for this Choreo as a String. 

		@param String - (optional, integer) Filter tariffs for a specific LSE.
		*/
		public void set_LSEID(String value) {
			this.setInput("LSEID", value);	
		}

		/** 
		Set the value of the PageCount input for this Choreo. 

		@param Integer - (optional, integer) The number of results to return. Defaults to 25.
		*/
		public void set_PageCount(Integer value) {
			this.setInput("PageCount", value);
		}

		/** 
		Set the value of the PageCount input for this Choreo as a String. 

		@param String - (optional, integer) The number of results to return. Defaults to 25.
		*/
		public void set_PageCount(String value) {
			this.setInput("PageCount", value);	
		}

		/** 
		Set the value of the PageStart input for this Choreo. 

		@param Integer - (optional, integer) The page number to begin the result set from. Defaults to 1.
		*/
		public void set_PageStart(Integer value) {
			this.setInput("PageStart", value);
		}

		/** 
		Set the value of the PageStart input for this Choreo as a String. 

		@param String - (optional, integer) The page number to begin the result set from. Defaults to 1.
		*/
		public void set_PageStart(String value) {
			this.setInput("PageStart", value);	
		}

		/** 
		Set the value of the PopulateProperties input for this Choreo. 

		@param Boolean - (optional, boolean) Set to "true" to populate the properties for the returned Tariffs.
		*/
		public void set_PopulateProperties(Boolean value) {
			this.setInput("PopulateProperties", value);
		}

		/** 
		Set the value of the PopulateProperties input for this Choreo as a String. 

		@param String - (optional, boolean) Set to "true" to populate the properties for the returned Tariffs.
		*/
		public void set_PopulateProperties(String value) {
			this.setInput("PopulateProperties", value);	
		}

		/** 
		Set the value of the PopulateRates input for this Choreo. 

		@param Boolean - (optional, boolean) Set to "true" to populate the rate details for the returned Tariffs.
		*/
		public void set_PopulateRates(Boolean value) {
			this.setInput("PopulateRates", value);
		}

		/** 
		Set the value of the PopulateRates input for this Choreo as a String. 

		@param String - (optional, boolean) Set to "true" to populate the rate details for the returned Tariffs.
		*/
		public void set_PopulateRates(String value) {
			this.setInput("PopulateRates", value);	
		}

		/** 
		Set the value of the SearchOn input for this Choreo. 

		@param String - (optional, string) Comma separated list of fields to query on. When searchOn is specified, the text provided in the search string field will be searched within these fields.
		*/
		public void set_SearchOn(String value) {
			this.setInput("SearchOn", value);
		}



		/** 
		Set the value of the Search input for this Choreo. 

		@param String - (optional, string) The string of text to search on. This can also be a regular expression, in which case you should set the 'isRegex' flag to true.
		*/
		public void set_Search(String value) {
			this.setInput("Search", value);
		}



		/** 
		Set the value of the SortOn input for this Choreo. 

		@param String - (optional, string) Comma separated list of fields to sort on.
		*/
		public void set_SortOn(String value) {
			this.setInput("SortOn", value);
		}



		/** 
		Set the value of the SortOrder input for this Choreo. 

		@param String - (optional, string) Comma separated list of ordering. Possible values are 'ASC' and 'DESC'. Default is 'ASC'. This list corresponds to the field list used in the SortOn input.
		*/
		public void set_SortOrder(String value) {
			this.setInput("SortOrder", value);
		}



		/** 
		Set the value of the StartsWith input for this Choreo. 

		@param Boolean - (optional, boolean) When true, the search will only return results that begin with the specified search string. Otherwise, any match of the search string will be returned as a result.
		*/
		public void set_StartsWith(Boolean value) {
			this.setInput("StartsWith", value);
		}

		/** 
		Set the value of the StartsWith input for this Choreo as a String. 

		@param String - (optional, boolean) When true, the search will only return results that begin with the specified search string. Otherwise, any match of the search string will be returned as a result.
		*/
		public void set_StartsWith(String value) {
			this.setInput("StartsWith", value);	
		}

		/** 
		Set the value of the TariffTypes input for this Choreo. 

		@param String - (optional, string) Returns only these tariff types. Valid values are: DEFAULT, ALTERNATIVE, OPTIONAL_EXTRA, RIDER.
		*/
		public void set_TariffTypes(String value) {
			this.setInput("TariffTypes", value);
		}



		/** 
		Set the value of the ToDateTime input for this Choreo. 

		@param String - (optional, date) Returns only tariffs that are effective on or before this date.
		*/
		public void set_ToDateTime(String value) {
			this.setInput("ToDateTime", value);
		}



		/** 
		Set the value of the ZipCode input for this Choreo. 

		@param String - (optional, string) Return tariffs for a given zip or post code.
		*/
		public void set_ZipCode(String value) {
			this.setInput("ZipCode", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetTariffs Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetTariffsResultSet extends ResultSet {
		public GetTariffsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Genability.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
