package com.temboo.Library.GitHub.ReposAPI.Comments;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CreateCommitComment

Creates a comment on a specified commit.
*/
public class CreateCommitComment extends Choreography {

	/**
	Create a new instance of the CreateCommitComment Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CreateCommitComment(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/GitHub/ReposAPI/Comments/CreateCommitComment"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CreateCommitCommentInputSet
	*/
	public CreateCommitCommentInputSet newInputSet() {
		return new CreateCommitCommentInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CreateCommitCommentResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CreateCommitCommentResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CreateCommitComment
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CreateCommitCommentInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token retrieved during the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the Body input for this Choreo. 

		@param String - (required, string) The comment text.
		*/
		public void set_Body(String value) {
			this.setInput("Body", value);
		}



		/** 
		Set the value of the Line input for this Choreo. 

		@param Integer - (required, integer) The line number in the file to comment on.
		*/
		public void set_Line(Integer value) {
			this.setInput("Line", value);
		}

		/** 
		Set the value of the Line input for this Choreo as a String. 

		@param String - (required, integer) The line number in the file to comment on.
		*/
		public void set_Line(String value) {
			this.setInput("Line", value);	
		}

		/** 
		Set the value of the Path input for this Choreo. 

		@param String - (required, string) The relative path of the file to comment on.
		*/
		public void set_Path(String value) {
			this.setInput("Path", value);
		}



		/** 
		Set the value of the Position input for this Choreo. 

		@param Integer - (required, integer) The line index in the diff to comment on.
		*/
		public void set_Position(Integer value) {
			this.setInput("Position", value);
		}

		/** 
		Set the value of the Position input for this Choreo as a String. 

		@param String - (required, integer) The line index in the diff to comment on.
		*/
		public void set_Position(String value) {
			this.setInput("Position", value);	
		}

		/** 
		Set the value of the Repo input for this Choreo. 

		@param String - (required, string) The name of the repo that the comment is associated with.
		*/
		public void set_Repo(String value) {
			this.setInput("Repo", value);
		}



		/** 
		Set the value of the SHA input for this Choreo. 

		@param String - (required, string) The SHA or id of the commit.
		*/
		public void set_SHA(String value) {
			this.setInput("SHA", value);
		}



		/** 
		Set the value of the User input for this Choreo. 

		@param String - (required, string) The GitHub username.
		*/
		public void set_User(String value) {
			this.setInput("User", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CreateCommitComment Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CreateCommitCommentResultSet extends ResultSet {
		public CreateCommitCommentResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Limit" output from this Choreo execution

		@return String - (integer) The available rate limit for your account. This is returned in the GitHub response header.
		*/
		public String get_Limit() {
			return this.getResult("Limit");
		}
		/** 
		Retrieve the value for the "Remaining" output from this Choreo execution

		@return String - (integer) The remaining number of API requests available to you. This is returned in the GitHub response header.
		*/
		public String get_Remaining() {
			return this.getResult("Remaining");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from GitHub.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
