package com.temboo.Library.GitHub.ReposAPI.Contents;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetContents

Returns a tarball or zipball archive for a repository. 
*/
public class GetContents extends Choreography {

	/**
	Create a new instance of the GetContents Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetContents(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/GitHub/ReposAPI/Contents/GetContents"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetContentsInputSet
	*/
	public GetContentsInputSet newInputSet() {
		return new GetContentsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetContentsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetContentsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetContents
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetContentsInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token retrieved during the OAuth process. Required when accessing a protected resource.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ArchiveFormat input for this Choreo. 

		@param String - (required, string) Either tarball or zipball. Defaults to "tarball".
		*/
		public void set_ArchiveFormat(String value) {
			this.setInput("ArchiveFormat", value);
		}



		/** 
		Set the value of the Ref input for this Choreo. 

		@param String - (optional, string) A valid Git reference. Defaults to "master".
		*/
		public void set_Ref(String value) {
			this.setInput("Ref", value);
		}



		/** 
		Set the value of the Repo input for this Choreo. 

		@param String - (required, string) The name of the repository.
		*/
		public void set_Repo(String value) {
			this.setInput("Repo", value);
		}



		/** 
		Set the value of the User input for this Choreo. 

		@param String - (required, string) The GitHub username.
		*/
		public void set_User(String value) {
			this.setInput("User", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetContents Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetContentsResultSet extends ResultSet {
		public GetContentsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (string) The response from GitHub.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
