package com.temboo.Library.GitHub.ReposAPI.Repos;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ListReposByOrg

Retrieces a list of repositories for the specified organization.
*/
public class ListReposByOrg extends Choreography {

	/**
	Create a new instance of the ListReposByOrg Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListReposByOrg(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/GitHub/ReposAPI/Repos/ListReposByOrg"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListReposByOrgInputSet
	*/
	public ListReposByOrgInputSet newInputSet() {
		return new ListReposByOrgInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListReposByOrgResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListReposByOrgResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListReposByOrg
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListReposByOrgInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (conditional, string) The Access Token retrieved during the OAuth process. Required when accessing a protected resource.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the Org input for this Choreo. 

		@param String - (required, string) The name of the organization.
		*/
		public void set_Org(String value) {
			this.setInput("Org", value);
		}



		/** 
		Set the value of the Page input for this Choreo. 

		@param Integer - (optional, integer) Indicates the page index that you want to retrieve. This is used to page through many results. Defaults to 1.
		*/
		public void set_Page(Integer value) {
			this.setInput("Page", value);
		}

		/** 
		Set the value of the Page input for this Choreo as a String. 

		@param String - (optional, integer) Indicates the page index that you want to retrieve. This is used to page through many results. Defaults to 1.
		*/
		public void set_Page(String value) {
			this.setInput("Page", value);	
		}

		/** 
		Set the value of the Type input for this Choreo. 

		@param String - (optional, string) The type of repos to return. Valid values are: all (the default), public, member, or private.
		*/
		public void set_Type(String value) {
			this.setInput("Type", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListReposByOrg Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListReposByOrgResultSet extends ResultSet {
		public ListReposByOrgResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "LastPage" output from this Choreo execution

		@return String - (integer) If multiple pages are available for the response, this contains the last available page.
		*/
		public String get_LastPage() {
			return this.getResult("LastPage");
		}
		/** 
		Retrieve the value for the "Limit" output from this Choreo execution

		@return String - (integer) The available rate limit for your account. This is returned in the GitHub response header.
		*/
		public String get_Limit() {
			return this.getResult("Limit");
		}
		/** 
		Retrieve the value for the "NextPage" output from this Choreo execution

		@return String - (integer) If multiple pages are available for the response, this contains the next page that you should retrieve.
		*/
		public String get_NextPage() {
			return this.getResult("NextPage");
		}
		/** 
		Retrieve the value for the "Remaining" output from this Choreo execution

		@return String - (integer) The remaining number of API requests available to you. This is returned in the GitHub response header.
		*/
		public String get_Remaining() {
			return this.getResult("Remaining");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from GitHub.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
