package com.temboo.Library.GitHub.ReposAPI.Repos;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ListUserRepos

Retrieves a list of public repositories for the specified user.
*/
public class ListUserRepos extends Choreography {

	/**
	Create a new instance of the ListUserRepos Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListUserRepos(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/GitHub/ReposAPI/Repos/ListUserRepos"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListUserReposInputSet
	*/
	public ListUserReposInputSet newInputSet() {
		return new ListUserReposInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListUserReposResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListUserReposResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListUserRepos
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListUserReposInputSet extends InputSet {
		/** 
		Set the value of the Direction input for this Choreo. 

		@param String - (optional, string) Valid values are asc or desc. Default behavior is desc unless sorting by full_name in which case, the direction is asc.
		*/
		public void set_Direction(String value) {
			this.setInput("Direction", value);
		}



		/** 
		Set the value of the Page input for this Choreo. 

		@param Integer - (optional, integer) Indicates the page index that you want to retrieve. This is used to page through many results. Defaults to 1.
		*/
		public void set_Page(Integer value) {
			this.setInput("Page", value);
		}

		/** 
		Set the value of the Page input for this Choreo as a String. 

		@param String - (optional, integer) Indicates the page index that you want to retrieve. This is used to page through many results. Defaults to 1.
		*/
		public void set_Page(String value) {
			this.setInput("Page", value);	
		}

		/** 
		Set the value of the Sort input for this Choreo. 

		@param String - (optional, string) The sort order of the results. Valid values are: created, updated, pushed, or full_name (the default).
		*/
		public void set_Sort(String value) {
			this.setInput("Sort", value);
		}



		/** 
		Set the value of the Type input for this Choreo. 

		@param String - (optional, string) The type of repos to return. Valid values are: all (the default), owner, public, or member.
		*/
		public void set_Type(String value) {
			this.setInput("Type", value);
		}



		/** 
		Set the value of the User input for this Choreo. 

		@param String - (required, string) The GitHub username.
		*/
		public void set_User(String value) {
			this.setInput("User", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListUserRepos Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListUserReposResultSet extends ResultSet {
		public ListUserReposResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "LastPage" output from this Choreo execution

		@return String - (integer) If multiple pages are available for the response, this contains the last available page.
		*/
		public String get_LastPage() {
			return this.getResult("LastPage");
		}
		/** 
		Retrieve the value for the "Limit" output from this Choreo execution

		@return String - (integer) The available rate limit for your account. This is returned in the GitHub response header.
		*/
		public String get_Limit() {
			return this.getResult("Limit");
		}
		/** 
		Retrieve the value for the "NextPage" output from this Choreo execution

		@return String - (integer) If multiple pages are available for the response, this contains the next page that you should retrieve.
		*/
		public String get_NextPage() {
			return this.getResult("NextPage");
		}
		/** 
		Retrieve the value for the "Remaining" output from this Choreo execution

		@return String - (integer) The remaining number of API requests available to you. This is returned in the GitHub response header.
		*/
		public String get_Remaining() {
			return this.getResult("Remaining");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from GitHub.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
