package com.temboo.Library.GoodGuide;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Query

Queries the GoodGuide API by keyword and retrieves information on GoodGuide products.
*/
public class Query extends Choreography {

	/**
	Create a new instance of the Query Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Query(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/GoodGuide/Query"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return QueryInputSet
	*/
	public QueryInputSet newInputSet() {
		return new QueryInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public QueryResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new QueryResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Query
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class QueryInputSet extends InputSet {
		/** 
		Set the value of the APIFormat input for this Choreo. 

		@param String - (optional, string) The response type supplied by GoodGuides. Default is reference. Other acceptable inputs are simple and badge.
		*/
		public void set_APIFormat(String value) {
			this.setInput("APIFormat", value);
		}



		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by GoodGuide.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Count input for this Choreo. 

		@param Integer - (optional, integer) The number of entries to return. Default is 20. Up to 50 entries can be returned at once.
		*/
		public void set_Count(Integer value) {
			this.setInput("Count", value);
		}

		/** 
		Set the value of the Count input for this Choreo as a String. 

		@param String - (optional, integer) The number of entries to return. Default is 20. Up to 50 entries can be returned at once.
		*/
		public void set_Count(String value) {
			this.setInput("Count", value);	
		}

		/** 
		Set the value of the Query input for this Choreo. 

		@param String - (required, string) A text string used in the keyword search. By default, queries return product data only. Use the EntityType input to query other types of entities.
		*/
		public void set_Query(String value) {
			this.setInput("Query", value);
		}



		/** 
		Set the value of the SortBy input for this Choreo. 

		@param String - (optional, string) Acceptable values: best_match (for keyword searches, this is the default); rating (the overall GoodGuide rating); and name (sorted alphabetically).
		*/
		public void set_SortBy(String value) {
			this.setInput("SortBy", value);
		}



		/** 
		Set the value of the SortOrder input for this Choreo. 

		@param String - (optional, string) Acceptable values: 'desc' to sort descending (default for sort_by=rating and sort_by is best_match); 'asc' to sort ascending (default for sort_by is name).
		*/
		public void set_SortOrder(String value) {
			this.setInput("SortOrder", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Query Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class QueryResultSet extends ResultSet {
		public QueryResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from GoodGuide.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
