package com.temboo.Library.GoodGuide;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
QueryByID

Retrieves information about products based on a GoodGuide product ID.
*/
public class QueryByID extends Choreography {

	/**
	Create a new instance of the QueryByID Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public QueryByID(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/GoodGuide/QueryByID"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return QueryByIDInputSet
	*/
	public QueryByIDInputSet newInputSet() {
		return new QueryByIDInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public QueryByIDResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new QueryByIDResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the QueryByID
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class QueryByIDInputSet extends InputSet {
		/** 
		Set the value of the APIFormat input for this Choreo. 

		@param String - (optional, string) The response type supplied by GoodGuide. Default is simple. Other acceptable inputs are reference and badge.
		*/
		public void set_APIFormat(String value) {
			this.setInput("APIFormat", value);
		}



		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by GoodGuide.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the ID input for this Choreo. 

		@param String - (required, string) GoodGuide ID number of product.
		*/
		public void set_ID(String value) {
			this.setInput("ID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the QueryByID Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class QueryByIDResultSet extends ResultSet {
		public QueryByIDResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from GoodGuide.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
