package com.temboo.Library.GoodGuide;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
QueryByUPC

Retrieves information about products based on the product's UPC code.
*/
public class QueryByUPC extends Choreography {

	/**
	Create a new instance of the QueryByUPC Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public QueryByUPC(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/GoodGuide/QueryByUPC"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return QueryByUPCInputSet
	*/
	public QueryByUPCInputSet newInputSet() {
		return new QueryByUPCInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public QueryByUPCResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new QueryByUPCResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the QueryByUPC
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class QueryByUPCInputSet extends InputSet {
		/** 
		Set the value of the APIFormat input for this Choreo. 

		@param String - (optional, string) The response type supplied by GoodGuides. Default is simple. Other acceptable inputs are reference and badge.
		*/
		public void set_APIFormat(String value) {
			this.setInput("APIFormat", value);
		}



		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by GoodGuide.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the UPC input for this Choreo. 

		@param String - (required, string) The UPC number of the product. This consists of 12 numerical barcode digits uniquely assigned to most products sold in North America.
		*/
		public void set_UPC(String value) {
			this.setInput("UPC", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the QueryByUPC Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class QueryByUPCResultSet extends ResultSet {
		public QueryByUPCResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from GoodGuide.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
