package com.temboo.Library.Google.Calendar;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;
import com.temboo.outputs.Google.Calendar.GoogleCalendar;

/** 
UpdateCalendar

Updates the metadata for a calendar.
*/
public class UpdateCalendar extends Choreography {

	/**
	Create a new instance of the UpdateCalendar Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public UpdateCalendar(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Calendar/UpdateCalendar"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return UpdateCalendarInputSet
	*/
	public UpdateCalendarInputSet newInputSet() {
		return new UpdateCalendarInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public UpdateCalendarResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new UpdateCalendarResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the UpdateCalendar
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class UpdateCalendarInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the CalendarID input for this Choreo. 

		@param String - (required, string) The ID for the calendar to update.
		*/
		public void set_CalendarID(String value) {
			this.setInput("CalendarID", value);
		}



		/** 
		Set the value of the ClientID input for this Choreo. 

		@param String - (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
		*/
		public void set_ClientID(String value) {
			this.setInput("ClientID", value);
		}



		/** 
		Set the value of the ClientSecret input for this Choreo. 

		@param String - (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
		*/
		public void set_ClientSecret(String value) {
			this.setInput("ClientSecret", value);
		}



		/** 
		Set the value of the NewDescription input for this Choreo. 

		@param String - (optional, string) The new description for the calendar to update.
		*/
		public void set_NewDescription(String value) {
			this.setInput("NewDescription", value);
		}



		/** 
		Set the value of the NewLocation input for this Choreo. 

		@param String - (optional, string) The new location for the calendar to update.
		*/
		public void set_NewLocation(String value) {
			this.setInput("NewLocation", value);
		}



		/** 
		Set the value of the NewSummary input for this Choreo. 

		@param String - (required, string) The new summary for the calendar to update.
		*/
		public void set_NewSummary(String value) {
			this.setInput("NewSummary", value);
		}



		/** 
		Set the value of the NewTimezone input for this Choreo. 

		@param String - (optional, string) The new timezone for the calendar to update.
		*/
		public void set_NewTimezone(String value) {
			this.setInput("NewTimezone", value);
		}



		/** 
		Set the value of the RefreshToken input for this Choreo. 

		@param String - (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
		*/
		public void set_RefreshToken(String value) {
			this.setInput("RefreshToken", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that response should be in. Can be set to xml or json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the UpdateCalendar Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class UpdateCalendarResultSet extends ResultSet {
		public UpdateCalendarResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "NewAccessToken" output from this Choreo execution

		@return String - (string) Contains a new AccessToken when the RefreshToken is provided.
		*/
		public String get_NewAccessToken() {
			return this.getResult("NewAccessToken");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Google. Corresponds to the ResponseFormat input. Defaults to JSON.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** Represents a Google Calendar Resource.
		*/
		public GoogleCalendar getCalendar() {
		    return new GoogleCalendar(((JSONObject)getJSONFromString(this.getResult("Response"))));
		}
	}
	
}
