package com.temboo.Library.Google.Checkout;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CancelOrder

Cancels an order that's been submitted to a Google Checkout merchant account.
*/
public class CancelOrder extends Choreography {

	/**
	Create a new instance of the CancelOrder Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CancelOrder(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Checkout/CancelOrder"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CancelOrderInputSet
	*/
	public CancelOrderInputSet newInputSet() {
		return new CancelOrderInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CancelOrderResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CancelOrderResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CancelOrder
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CancelOrderInputSet extends InputSet {
		/** 
		Set the value of the Comment input for this Choreo. 

		@param String - (required, string) The comment for the order cancellation
		*/
		public void set_Comment(String value) {
			this.setInput("Comment", value);
		}



		/** 
		Set the value of the Endpoint input for this Choreo. 

		@param String - (optional, string) Set to checkout.google.com when running in production. Defaults to sandbox.google.com for sandbox testing.
		*/
		public void set_Endpoint(String value) {
			this.setInput("Endpoint", value);
		}



		/** 
		Set the value of the MerchantId input for this Choreo. 

		@param Integer - (required, integer) The Merchant Id provided by Google
		*/
		public void set_MerchantId(Integer value) {
			this.setInput("MerchantId", value);
		}

		/** 
		Set the value of the MerchantId input for this Choreo as a String. 

		@param String - (required, integer) The Merchant Id provided by Google
		*/
		public void set_MerchantId(String value) {
			this.setInput("MerchantId", value);	
		}

		/** 
		Set the value of the MerchantKey input for this Choreo. 

		@param String - (required, string) The Merchant Key provided by Google
		*/
		public void set_MerchantKey(String value) {
			this.setInput("MerchantKey", value);
		}



		/** 
		Set the value of the OrderNumber input for this Choreo. 

		@param Integer - (required, integer) The unique identifier for the order (There is an order number column in your Google Checkout Inbox).
		*/
		public void set_OrderNumber(Integer value) {
			this.setInput("OrderNumber", value);
		}

		/** 
		Set the value of the OrderNumber input for this Choreo as a String. 

		@param String - (required, integer) The unique identifier for the order (There is an order number column in your Google Checkout Inbox).
		*/
		public void set_OrderNumber(String value) {
			this.setInput("OrderNumber", value);	
		}

		/** 
		Set the value of the Reason input for this Choreo. 

		@param String - (required, string) The reason for the cancellation
		*/
		public void set_Reason(String value) {
			this.setInput("Reason", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CancelOrder Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CancelOrderResultSet extends ResultSet {
		public CancelOrderResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Google
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
