package com.temboo.Library.Google.Checkout;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ChargeAndShipOrder

Charge and ship an order once a shopping cart order has arrived in your Google Checkout Inbox.
*/
public class ChargeAndShipOrder extends Choreography {

	/**
	Create a new instance of the ChargeAndShipOrder Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ChargeAndShipOrder(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Checkout/ChargeAndShipOrder"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ChargeAndShipOrderInputSet
	*/
	public ChargeAndShipOrderInputSet newInputSet() {
		return new ChargeAndShipOrderInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ChargeAndShipOrderResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ChargeAndShipOrderResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ChargeAndShipOrder
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ChargeAndShipOrderInputSet extends InputSet {
		/** 
		Set the value of the Amount input for this Choreo. 

		@param BigDecimal - (decimal) The dollar amount to charge (i.e. 25.50)
		*/
		public void set_Amount(BigDecimal value) {
			this.setInput("Amount", value);
		}

		/** 
		Set the value of the Amount input for this Choreo as a String. 

		@param String - (decimal) The dollar amount to charge (i.e. 25.50)
		*/
		public void set_Amount(String value) {
			this.setInput("Amount", value);	
		}

		/** 
		Set the value of the Carrier input for this Choreo. 

		@param String - (string) The desired postal carrier (i.e. UPS)
		*/
		public void set_Carrier(String value) {
			this.setInput("Carrier", value);
		}



		/** 
		Set the value of the Endpoint input for this Choreo. 

		@param String - (optional, string) Set to checkout.google.com when running in production. Defaults to sandbox.google.com for sandbox testing.
		*/
		public void set_Endpoint(String value) {
			this.setInput("Endpoint", value);
		}



		/** 
		Set the value of the MerchantId input for this Choreo. 

		@param Integer - (integer) The Merchant Id provided by Google
		*/
		public void set_MerchantId(Integer value) {
			this.setInput("MerchantId", value);
		}

		/** 
		Set the value of the MerchantId input for this Choreo as a String. 

		@param String - (integer) The Merchant Id provided by Google
		*/
		public void set_MerchantId(String value) {
			this.setInput("MerchantId", value);	
		}

		/** 
		Set the value of the MerchantKey input for this Choreo. 

		@param String - (string) The Merchant Key provided by Google
		*/
		public void set_MerchantKey(String value) {
			this.setInput("MerchantKey", value);
		}



		/** 
		Set the value of the OrderNumber input for this Choreo. 

		@param Integer - (integer) The unique identifier for the order (There is an order number column in your Google Checkout Inbox).
		*/
		public void set_OrderNumber(Integer value) {
			this.setInput("OrderNumber", value);
		}

		/** 
		Set the value of the OrderNumber input for this Choreo as a String. 

		@param String - (integer) The unique identifier for the order (There is an order number column in your Google Checkout Inbox).
		*/
		public void set_OrderNumber(String value) {
			this.setInput("OrderNumber", value);	
		}

		/** 
		Set the value of the TrackingNumber input for this Choreo. 

		@param String - (string) The tracking number for the order package
		*/
		public void set_TrackingNumber(String value) {
			this.setInput("TrackingNumber", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ChargeAndShipOrder Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ChargeAndShipOrderResultSet extends ResultSet {
		public ChargeAndShipOrderResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (XML) The response from Google
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
