package com.temboo.Library.Google.Checkout;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CreateOrder

Populates a shopping cart and sends order information to your merchant  account allowing a user to complete an order using Google Checkout.
*/
public class CreateOrder extends Choreography {

	/**
	Create a new instance of the CreateOrder Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CreateOrder(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Checkout/CreateOrder"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CreateOrderInputSet
	*/
	public CreateOrderInputSet newInputSet() {
		return new CreateOrderInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CreateOrderResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CreateOrderResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CreateOrder
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CreateOrderInputSet extends InputSet {
		/** 
		Set the value of the Endpoint input for this Choreo. 

		@param String - (optional, string) Set to checkout.google.com when running in production. Defaults to sandbox.google.com for sandbox testing.
		*/
		public void set_Endpoint(String value) {
			this.setInput("Endpoint", value);
		}



		/** 
		Set the value of the ItemDescription input for this Choreo. 

		@param String - (string) The description of the shopping cart item
		*/
		public void set_ItemDescription(String value) {
			this.setInput("ItemDescription", value);
		}



		/** 
		Set the value of the ItemName input for this Choreo. 

		@param String - (string) A name of the shopping cart item
		*/
		public void set_ItemName(String value) {
			this.setInput("ItemName", value);
		}



		/** 
		Set the value of the MerchantId input for this Choreo. 

		@param Integer - (integer) The Merchant Id provided by Google
		*/
		public void set_MerchantId(Integer value) {
			this.setInput("MerchantId", value);
		}

		/** 
		Set the value of the MerchantId input for this Choreo as a String. 

		@param String - (integer) The Merchant Id provided by Google
		*/
		public void set_MerchantId(String value) {
			this.setInput("MerchantId", value);	
		}

		/** 
		Set the value of the MerchantKey input for this Choreo. 

		@param String - (string) The Merchant Key provided by Google
		*/
		public void set_MerchantKey(String value) {
			this.setInput("MerchantKey", value);
		}



		/** 
		Set the value of the Quanity input for this Choreo. 

		@param Integer - (integer) The quantity of the shopping cart item
		*/
		public void set_Quanity(Integer value) {
			this.setInput("Quanity", value);
		}

		/** 
		Set the value of the Quanity input for this Choreo as a String. 

		@param String - (integer) The quantity of the shopping cart item
		*/
		public void set_Quanity(String value) {
			this.setInput("Quanity", value);	
		}

		/** 
		Set the value of the ShippingMethod input for this Choreo. 

		@param String - (string) The shipping method for the order (i.e. SuperShip Ground)
		*/
		public void set_ShippingMethod(String value) {
			this.setInput("ShippingMethod", value);
		}



		/** 
		Set the value of the ShippingPrice input for this Choreo. 

		@param BigDecimal - (decimal) The shipping price for the order
		*/
		public void set_ShippingPrice(BigDecimal value) {
			this.setInput("ShippingPrice", value);
		}

		/** 
		Set the value of the ShippingPrice input for this Choreo as a String. 

		@param String - (decimal) The shipping price for the order
		*/
		public void set_ShippingPrice(String value) {
			this.setInput("ShippingPrice", value);	
		}

		/** 
		Set the value of the UnitPrice input for this Choreo. 

		@param BigDecimal - (decimal) The unit price of the item that is added to the shopping cart
		*/
		public void set_UnitPrice(BigDecimal value) {
			this.setInput("UnitPrice", value);
		}

		/** 
		Set the value of the UnitPrice input for this Choreo as a String. 

		@param String - (decimal) The unit price of the item that is added to the shopping cart
		*/
		public void set_UnitPrice(String value) {
			this.setInput("UnitPrice", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CreateOrder Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CreateOrderResultSet extends ResultSet {
		public CreateOrderResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (XML) The response from Google.  Contains the redirect URL that a customer will use to complete the order.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
