package com.temboo.Library.Google.Checkout;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
RefundOrder

Allows you to refund an order that's been submitted to your Google Checkout merchant account.
*/
public class RefundOrder extends Choreography {

	/**
	Create a new instance of the RefundOrder Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public RefundOrder(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Checkout/RefundOrder"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return RefundOrderInputSet
	*/
	public RefundOrderInputSet newInputSet() {
		return new RefundOrderInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public RefundOrderResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new RefundOrderResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the RefundOrder
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class RefundOrderInputSet extends InputSet {
		/** 
		Set the value of the Amount input for this Choreo. 

		@param BigDecimal - (decimal) The amount to refund
		*/
		public void set_Amount(BigDecimal value) {
			this.setInput("Amount", value);
		}

		/** 
		Set the value of the Amount input for this Choreo as a String. 

		@param String - (decimal) The amount to refund
		*/
		public void set_Amount(String value) {
			this.setInput("Amount", value);	
		}

		/** 
		Set the value of the Comment input for this Choreo. 

		@param String - (string) The comment for the order refund
		*/
		public void set_Comment(String value) {
			this.setInput("Comment", value);
		}



		/** 
		Set the value of the Endpoint input for this Choreo. 

		@param String - (optional, string) Set to checkout.google.com when running in production. Defaults to sandbox.google.com for sandbox testing.
		*/
		public void set_Endpoint(String value) {
			this.setInput("Endpoint", value);
		}



		/** 
		Set the value of the MerchantId input for this Choreo. 

		@param Integer - (integer) The Merchant Id provided by Google
		*/
		public void set_MerchantId(Integer value) {
			this.setInput("MerchantId", value);
		}

		/** 
		Set the value of the MerchantId input for this Choreo as a String. 

		@param String - (integer) The Merchant Id provided by Google
		*/
		public void set_MerchantId(String value) {
			this.setInput("MerchantId", value);	
		}

		/** 
		Set the value of the MerchantKey input for this Choreo. 

		@param String - (string) The Merchant Key provided by Google
		*/
		public void set_MerchantKey(String value) {
			this.setInput("MerchantKey", value);
		}



		/** 
		Set the value of the OrderNumber input for this Choreo. 

		@param Integer - (integer) The unique identifier for the order (There is an order number column in your Google Checkout Inbox).
		*/
		public void set_OrderNumber(Integer value) {
			this.setInput("OrderNumber", value);
		}

		/** 
		Set the value of the OrderNumber input for this Choreo as a String. 

		@param String - (integer) The unique identifier for the order (There is an order number column in your Google Checkout Inbox).
		*/
		public void set_OrderNumber(String value) {
			this.setInput("OrderNumber", value);	
		}

		/** 
		Set the value of the Reason input for this Choreo. 

		@param String - (string) The reason for the refund
		*/
		public void set_Reason(String value) {
			this.setInput("Reason", value);
		}



		/** 
		Set the value of the SandboxMode input for this Choreo. 

		@param Boolean - (optional, boolean) Set this flag to 1 when using this Choreo with the Google Checkout sandbox endpoint (i.e. sandbox.google.com). Defaults to 0.
		*/
		public void set_SandboxMode(Boolean value) {
			this.setInput("SandboxMode", value);
		}

		/** 
		Set the value of the SandboxMode input for this Choreo as a String. 

		@param String - (optional, boolean) Set this flag to 1 when using this Choreo with the Google Checkout sandbox endpoint (i.e. sandbox.google.com). Defaults to 0.
		*/
		public void set_SandboxMode(String value) {
			this.setInput("SandboxMode", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the RefundOrder Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class RefundOrderResultSet extends ResultSet {
		public RefundOrderResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "ExecutionStatus" output from this Choreo execution

		@return String - Contains status information on the Choreo execution
		*/
		public String get_ExecutionStatus() {
			return this.getResult("ExecutionStatus");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (XML) The response from Google
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
