package com.temboo.Library.Google.Checkout;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
TestAccount

Allows you to perform simple test to verify connectivity with your Google Checkout account.
*/
public class TestAccount extends Choreography {

	/**
	Create a new instance of the TestAccount Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public TestAccount(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Checkout/TestAccount"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return TestAccountInputSet
	*/
	public TestAccountInputSet newInputSet() {
		return new TestAccountInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public TestAccountResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new TestAccountResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the TestAccount
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class TestAccountInputSet extends InputSet {
		/** 
		Set the value of the Endpoint input for this Choreo. 

		@param String - (optional, string) Set to checkout.google.com when running in production. Defaults to sandbox.google.com for sandbox testing.
		*/
		public void set_Endpoint(String value) {
			this.setInput("Endpoint", value);
		}



		/** 
		Set the value of the MerchantId input for this Choreo. 

		@param Integer - (required, integer) The Merchant Id provided by Google
		*/
		public void set_MerchantId(Integer value) {
			this.setInput("MerchantId", value);
		}

		/** 
		Set the value of the MerchantId input for this Choreo as a String. 

		@param String - (required, integer) The Merchant Id provided by Google
		*/
		public void set_MerchantId(String value) {
			this.setInput("MerchantId", value);	
		}

		/** 
		Set the value of the MerchantKey input for this Choreo. 

		@param String - (required, string) The Merchant Key provided by Google
		*/
		public void set_MerchantKey(String value) {
			this.setInput("MerchantKey", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the TestAccount Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class TestAccountResultSet extends ResultSet {
		public TestAccountResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Google
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
