package com.temboo.Library.Google.DistanceMatrix;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
WalkingDistanceMatrix

Obtain walking distances and times for a matrix of addresses and/or latitude/longitude coordinates.
*/
public class WalkingDistanceMatrix extends Choreography {

	/**
	Create a new instance of the WalkingDistanceMatrix Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public WalkingDistanceMatrix(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/DistanceMatrix/WalkingDistanceMatrix"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return WalkingDistanceMatrixInputSet
	*/
	public WalkingDistanceMatrixInputSet newInputSet() {
		return new WalkingDistanceMatrixInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public WalkingDistanceMatrixResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new WalkingDistanceMatrixResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the WalkingDistanceMatrix
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class WalkingDistanceMatrixInputSet extends InputSet {
		/** 
		Set the value of the Alternatives input for this Choreo. 

		@param String - (optional, string) If set to true, additional routes will be returned.
		*/
		public void set_Alternatives(String value) {
			this.setInput("Alternatives", value);
		}



		/** 
		Set the value of the Destinations input for this Choreo. 

		@param String - (required, string) Enter the address or latitude/longitude coordinates to which directions will be generated. Multiple destinations can be separated by pipes (|).  For example: Boston, MA|New Haven|40.7160,-74.0037.
		*/
		public void set_Destinations(String value) {
			this.setInput("Destinations", value);
		}



		/** 
		Set the value of the Language input for this Choreo. 

		@param String - (optional, string) Set the language in which to return restults.  A list of supported languages is available here: https://spreadsheets.google.com/pub?key=p9pdwsai2hDMsLkXsoM05KQ&gid=1
		*/
		public void set_Language(String value) {
			this.setInput("Language", value);
		}



		/** 
		Set the value of the Origins input for this Choreo. 

		@param String - (required, string) Enter the address(es) or geo-coordinates from which distance and time will be computed. Multiple destinations can be separated by pipes (|).  For example: Boston, MA|New Haven|40.7160,-74.0037.
		*/
		public void set_Origins(String value) {
			this.setInput("Origins", value);
		}



		/** 
		Set the value of the Region input for this Choreo. 

		@param String - (optional, string) Enter the region code for the directions, specified as a ccTLD two-character value.
		*/
		public void set_Region(String value) {
			this.setInput("Region", value);
		}



		/** 
		Set the value of the Sensor input for this Choreo. 

		@param Boolean - (optional, boolean) Indicates whether or not the directions request is from a device with a location sensor. Value must be either 1 or 0. Defaults to 0 (false).
		*/
		public void set_Sensor(Boolean value) {
			this.setInput("Sensor", value);
		}

		/** 
		Set the value of the Sensor input for this Choreo as a String. 

		@param String - (optional, boolean) Indicates whether or not the directions request is from a device with a location sensor. Value must be either 1 or 0. Defaults to 0 (false).
		*/
		public void set_Sensor(String value) {
			this.setInput("Sensor", value);	
		}

		/** 
		Set the value of the Units input for this Choreo. 

		@param String - (optional, string) Specify the units to be used when displaying results.  Options include, metric, or imperial.
		*/
		public void set_Units(String value) {
			this.setInput("Units", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the WalkingDistanceMatrix Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class WalkingDistanceMatrixResultSet extends ResultSet {
		public WalkingDistanceMatrixResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Google.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
