package com.temboo.Library.Google.Documents;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CreateSharingPermission

Grants a new user read/write access to an existing document.
*/
public class CreateSharingPermission extends Choreography {

	/**
	Create a new instance of the CreateSharingPermission Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CreateSharingPermission(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Documents/CreateSharingPermission"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CreateSharingPermissionInputSet
	*/
	public CreateSharingPermissionInputSet newInputSet() {
		return new CreateSharingPermissionInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CreateSharingPermissionResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CreateSharingPermissionResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CreateSharingPermission
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CreateSharingPermissionInputSet extends InputSet {
		/** 
		Set the value of the NewUserEmail input for this Choreo. 

		@param String - (required, string) The email address of the user to whom you want to grant permission.
		*/
		public void set_NewUserEmail(String value) {
			this.setInput("NewUserEmail", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Google passsword.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Role input for this Choreo. 

		@param String - (optional, string) The role that will be given to the new user permission (i.e., writer, reader, etc). Defaults to "writer".
		*/
		public void set_Role(String value) {
			this.setInput("Role", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) Your Google email address.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CreateSharingPermission Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CreateSharingPermissionResultSet extends ResultSet {
		public CreateSharingPermissionResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "ResourceID" output from this Choreo execution

		@return String - (string) The resource ID of the document to which you want to add a user.
		*/
		public String get_ResourceID() {
			return this.getResult("ResourceID");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Google.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
