package com.temboo.Library.Google.Documents;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
DeleteDocumentOrFile

Permanently deletes the document or file you specify.
*/
public class DeleteDocumentOrFile extends Choreography {

	/**
	Create a new instance of the DeleteDocumentOrFile Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DeleteDocumentOrFile(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Documents/DeleteDocumentOrFile"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DeleteDocumentOrFileInputSet
	*/
	public DeleteDocumentOrFileInputSet newInputSet() {
		return new DeleteDocumentOrFileInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DeleteDocumentOrFileResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DeleteDocumentOrFileResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DeleteDocumentOrFile
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DeleteDocumentOrFileInputSet extends InputSet {
		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Google account password.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the ResourceID input for this Choreo. 

		@param String - (required, string) The resource ID for the document or file to delete.
		*/
		public void set_ResourceID(String value) {
			this.setInput("ResourceID", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) Your Google account username.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DeleteDocumentOrFile Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DeleteDocumentOrFileResultSet extends ResultSet {
		public DeleteDocumentOrFileResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - There is no XML response for delete requests.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
