package com.temboo.Library.Google.Documents;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
DownloadBase64EncodedDocument

Downloads a document with the title you specify, and returns the content as Base64 encoded data.
*/
public class DownloadBase64EncodedDocument extends Choreography {

	/**
	Create a new instance of the DownloadBase64EncodedDocument Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DownloadBase64EncodedDocument(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Documents/DownloadBase64EncodedDocument"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DownloadBase64EncodedDocumentInputSet
	*/
	public DownloadBase64EncodedDocumentInputSet newInputSet() {
		return new DownloadBase64EncodedDocumentInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DownloadBase64EncodedDocumentResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DownloadBase64EncodedDocumentResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DownloadBase64EncodedDocument
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DownloadBase64EncodedDocumentInputSet extends InputSet {
		/** 
		Set the value of the Format input for this Choreo. 

		@param String - (optional, string) The format you want to export the document to, such as "doc", "txt", "pdf", etc. The default download format is HTML.
		*/
		public void set_Format(String value) {
			this.setInput("Format", value);
		}



		/** 
		Set the value of the Link input for this Choreo. 

		@param String - (conditional, string) Enter the source links for the document to be retrieved. Required unless specifying the Title.
		*/
		public void set_Link(String value) {
			this.setInput("Link", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Google account password.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Title input for this Choreo. 

		@param String - (conditional, string) The title of the document to download. Required unless specifying the download Link.
		*/
		public void set_Title(String value) {
			this.setInput("Title", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) Your Google account username.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DownloadBase64EncodedDocument Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DownloadBase64EncodedDocumentResultSet extends ResultSet {
		public DownloadBase64EncodedDocumentResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "FileContents" output from this Choreo execution

		@return String - (string) The Base64 encoded file content of the downloaded file.
		*/
		public String get_FileContents() {
			return this.getResult("FileContents");
		}
	}
	
}
