package com.temboo.Library.Google.Documents;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetAllDocuments

Retrieves a list of all documents, files, and collections in a Google account.
*/
public class GetAllDocuments extends Choreography {

	/**
	Create a new instance of the GetAllDocuments Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetAllDocuments(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Documents/GetAllDocuments"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetAllDocumentsInputSet
	*/
	public GetAllDocumentsInputSet newInputSet() {
		return new GetAllDocumentsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetAllDocumentsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetAllDocumentsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetAllDocuments
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetAllDocumentsInputSet extends InputSet {
		/** 
		Set the value of the Deleted input for this Choreo. 

		@param Boolean - (optional, boolean) Returns deleted documents when set to "true" (the default). Skips deleted documents when set to "false".
		*/
		public void set_Deleted(Boolean value) {
			this.setInput("Deleted", value);
		}

		/** 
		Set the value of the Deleted input for this Choreo as a String. 

		@param String - (optional, boolean) Returns deleted documents when set to "true" (the default). Skips deleted documents when set to "false".
		*/
		public void set_Deleted(String value) {
			this.setInput("Deleted", value);	
		}

		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Google account password.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) Your Google account username.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetAllDocuments Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetAllDocumentsResultSet extends ResultSet {
		public GetAllDocumentsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from the Google Documents API.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
