package com.temboo.Library.Google.Documents;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
RenameDocumentOrFile

Rename a document or file with the new title you specify.
*/
public class RenameDocumentOrFile extends Choreography {

	/**
	Create a new instance of the RenameDocumentOrFile Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public RenameDocumentOrFile(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Documents/RenameDocumentOrFile"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return RenameDocumentOrFileInputSet
	*/
	public RenameDocumentOrFileInputSet newInputSet() {
		return new RenameDocumentOrFileInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public RenameDocumentOrFileResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new RenameDocumentOrFileResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the RenameDocumentOrFile
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class RenameDocumentOrFileInputSet extends InputSet {
		/** 
		Set the value of the NewTitle input for this Choreo. 

		@param String - (required, string) The new title for the document. It will appear exactly as you type it, so be sure to use the proper capitalization.
		*/
		public void set_NewTitle(String value) {
			this.setInput("NewTitle", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Google account password.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Title input for this Choreo. 

		@param String - (required, string) The title of the document to rename.
		*/
		public void set_Title(String value) {
			this.setInput("Title", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) Your Google account username.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the RenameDocumentOrFile Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class RenameDocumentOrFileResultSet extends ResultSet {
		public RenameDocumentOrFileResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "EditLink" output from this Choreo execution

		@return String - (string) The edit link URL for the document to rename, parsed from the Google response.
		*/
		public String get_EditLink() {
			return this.getResult("EditLink");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from the Google Documents API.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
