package com.temboo.Library.Google.Documents;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
SearchByCategory

Retrieves a list of all resources in a category you specify.
*/
public class SearchByCategory extends Choreography {

	/**
	Create a new instance of the SearchByCategory Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public SearchByCategory(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Documents/SearchByCategory"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return SearchByCategoryInputSet
	*/
	public SearchByCategoryInputSet newInputSet() {
		return new SearchByCategoryInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public SearchByCategoryResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new SearchByCategoryResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the SearchByCategory
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class SearchByCategoryInputSet extends InputSet {
		/** 
		Set the value of the Category input for this Choreo. 

		@param String - (required, string) The category to list: "document", "spreadsheet", "presentation", "drawing", "folder", "starred", or "trashed". Combine multiple categories with "/".
		*/
		public void set_Category(String value) {
			this.setInput("Category", value);
		}



		/** 
		Set the value of the MyDocs input for this Choreo. 

		@param Boolean - (optional, boolean) Enter "true" to return resources for the requesting user only. The default is "false" (returns all account resources).
		*/
		public void set_MyDocs(Boolean value) {
			this.setInput("MyDocs", value);
		}

		/** 
		Set the value of the MyDocs input for this Choreo as a String. 

		@param String - (optional, boolean) Enter "true" to return resources for the requesting user only. The default is "false" (returns all account resources).
		*/
		public void set_MyDocs(String value) {
			this.setInput("MyDocs", value);	
		}

		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Google account password.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) Your Google account username.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



		/** 
		Set the value of the Viewed input for this Choreo. 

		@param Boolean - (optional, boolean) Enter "true" to return only viewed resources for the specified category. The default is "false" (viewed and unviewed category resources).
		*/
		public void set_Viewed(Boolean value) {
			this.setInput("Viewed", value);
		}

		/** 
		Set the value of the Viewed input for this Choreo as a String. 

		@param String - (optional, boolean) Enter "true" to return only viewed resources for the specified category. The default is "false" (viewed and unviewed category resources).
		*/
		public void set_Viewed(String value) {
			this.setInput("Viewed", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the SearchByCategory Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class SearchByCategoryResultSet extends ResultSet {
		public SearchByCategoryResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from the Google Documents API.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
