package com.temboo.Library.Google.Documents;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
SearchByTitle

Retrieves information for a file with the title you specify.
*/
public class SearchByTitle extends Choreography {

	/**
	Create a new instance of the SearchByTitle Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public SearchByTitle(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Documents/SearchByTitle"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return SearchByTitleInputSet
	*/
	public SearchByTitleInputSet newInputSet() {
		return new SearchByTitleInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public SearchByTitleResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new SearchByTitleResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the SearchByTitle
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class SearchByTitleInputSet extends InputSet {
		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Google account password.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Title input for this Choreo. 

		@param String - (required, string) The title of the document to search for. Enclose in quotation marks for an exact, non-case-sensitive match.
		*/
		public void set_Title(String value) {
			this.setInput("Title", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) Your Google account username.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the SearchByTitle Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class SearchByTitleResultSet extends ResultSet {
		public SearchByTitleResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "EditMediaLink" output from this Choreo execution

		@return String - (string) The 'resumable-edit-media' link of the document. This link is used when editing the content of an existing Google doc.
		*/
		public String get_EditMediaLink() {
			return this.getResult("EditMediaLink");
		}
		/** 
		Retrieve the value for the "EditMetaDataLink" output from this Choreo execution

		@return String - (string) The 'edit' link of the document. This link is used when editing the metadata of an existing Google doc.
		*/
		public String get_EditMetaDataLink() {
			return this.getResult("EditMetaDataLink");
		}
		/** 
		Retrieve the value for the "ResourceID" output from this Choreo execution

		@return String - (string) The document resource ID returned from Google.
		*/
		public String get_ResourceID() {
			return this.getResult("ResourceID");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from the Google Documents API.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
