package com.temboo.Library.Google.Documents;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
SearchByType

Retrieves a list of all files of a MIME type you specify.
*/
public class SearchByType extends Choreography {

	/**
	Create a new instance of the SearchByType Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public SearchByType(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Documents/SearchByType"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return SearchByTypeInputSet
	*/
	public SearchByTypeInputSet newInputSet() {
		return new SearchByTypeInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public SearchByTypeResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new SearchByTypeResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the SearchByType
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class SearchByTypeInputSet extends InputSet {
		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Google account password.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Type input for this Choreo. 

		@param String - (required, string) The MIME type of the files to list: word, excel, powerpoint, pdf, csv, rtf, html, css, xml, plaintext, zip, jpg, or png.
		*/
		public void set_Type(String value) {
			this.setInput("Type", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) Your Google account username.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the SearchByType Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class SearchByTypeResultSet extends ResultSet {
		public SearchByTypeResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from the Google Documents API.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
