package com.temboo.Library.Google.Documents;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
SearchForShared

Retrieves a list of all documents shared by the two users you specify.
*/
public class SearchForShared extends Choreography {

	/**
	Create a new instance of the SearchForShared Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public SearchForShared(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Documents/SearchForShared"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return SearchForSharedInputSet
	*/
	public SearchForSharedInputSet newInputSet() {
		return new SearchForSharedInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public SearchForSharedResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new SearchForSharedResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the SearchForShared
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class SearchForSharedInputSet extends InputSet {
		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Google account password.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the User1 input for this Choreo. 

		@param String - (required, string) The email address of the first document collaborator.
		*/
		public void set_User1(String value) {
			this.setInput("User1", value);
		}



		/** 
		Set the value of the User2 input for this Choreo. 

		@param String - (required, string) The email address for the second document collaborator.
		*/
		public void set_User2(String value) {
			this.setInput("User2", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) Your Google account username.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the SearchForShared Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class SearchForSharedResultSet extends ResultSet {
		public SearchForSharedResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from the Google Documents API.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
