package com.temboo.Library.Google.Documents;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ToggleProperties

Toggle settings for a document or file on or off, depending on its current state.
*/
public class ToggleProperties extends Choreography {

	/**
	Create a new instance of the ToggleProperties Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ToggleProperties(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Documents/ToggleProperties"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return TogglePropertiesInputSet
	*/
	public TogglePropertiesInputSet newInputSet() {
		return new TogglePropertiesInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public TogglePropertiesResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new TogglePropertiesResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ToggleProperties
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class TogglePropertiesInputSet extends InputSet {
		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Google account password.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Title input for this Choreo. 

		@param String - (required, string) The title of the document with the properties you want to toggle. Enclose in quotation marks for an exact, non-case-sensitive match.
		*/
		public void set_Title(String value) {
			this.setInput("Title", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) Your Google account username.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ToggleProperties Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class TogglePropertiesResultSet extends ResultSet {
		public TogglePropertiesResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "EditLink" output from this Choreo execution

		@return String - (string) The edit link URL for the document, parsed from the Google response.
		*/
		public String get_EditLink() {
			return this.getResult("EditLink");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from the Google Documents API.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
