package com.temboo.Library.Google.Documents;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
UploadFile

Uploads MS Word, Excel, or plain text documents to a Google account.
*/
public class UploadFile extends Choreography {

	/**
	Create a new instance of the UploadFile Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public UploadFile(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Documents/UploadFile"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return UploadFileInputSet
	*/
	public UploadFileInputSet newInputSet() {
		return new UploadFileInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public UploadFileResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new UploadFileResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the UploadFile
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class UploadFileInputSet extends InputSet {
		/** 
		Set the value of the FileContents input for this Choreo. 

		@param String - (conditional, string) The base64-encoded contents of the file you want to upload. Required unless using the VaultFile alias input (an advnaced option used when running Choreos in the Temboo Designer).
		*/
		public void set_FileContents(String value) {
			this.setInput("FileContents", value);
		}



		/** 
		Set the value of the ContentType input for this Choreo. 

		@param String - (required, string) Enter the content type for the file. Currently, the supported content types are: application/pdf, application/rtf, application/msword, application/vnd.ms-excel, text/plain, and text/csv.
		*/
		public void set_ContentType(String value) {
			this.setInput("ContentType", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The password for your Google account.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Title input for this Choreo. 

		@param String - (required, string) The name for the file you're uploading.
		*/
		public void set_Title(String value) {
			this.setInput("Title", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) The email address for your Google account.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



		/** 
		Set the value of the VaultFile input for this Choreo. 

		@param TembooPath - The path to the Vault file to upload. Required unless using the FileContents input variable instead.
		*/
		public void set_VaultFile(TembooPath value) {
			this.setAlias("VaultFile", value);
		}
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the UploadFile Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class UploadFileResultSet extends ResultSet {
		public UploadFileResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from the Google Documents API.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
