package com.temboo.Library.Google.Drive.Changes;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;
import com.temboo.outputs.Google.Drive.GoogleChangeList;

/** 
List

Lists the changes for a user.
*/
public class List extends Choreography {

	/**
	Create a new instance of the List Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public List(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Drive/Changes/List"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListInputSet
	*/
	public ListInputSet newInputSet() {
		return new ListInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the List
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ClientID input for this Choreo. 

		@param String - (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
		*/
		public void set_ClientID(String value) {
			this.setInput("ClientID", value);
		}



		/** 
		Set the value of the ClientSecret input for this Choreo. 

		@param String - (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
		*/
		public void set_ClientSecret(String value) {
			this.setInput("ClientSecret", value);
		}



		/** 
		Set the value of the Fields input for this Choreo. 

		@param String - (optional, string) Selector specifying a subset of fields to include in the response.
		*/
		public void set_Fields(String value) {
			this.setInput("Fields", value);
		}



		/** 
		Set the value of the IncludeDeleted input for this Choreo. 

		@param Boolean - (optional, boolean) Whether to include deleted items. (Default: true).
		*/
		public void set_IncludeDeleted(Boolean value) {
			this.setInput("IncludeDeleted", value);
		}

		/** 
		Set the value of the IncludeDeleted input for this Choreo as a String. 

		@param String - (optional, boolean) Whether to include deleted items. (Default: true).
		*/
		public void set_IncludeDeleted(String value) {
			this.setInput("IncludeDeleted", value);	
		}

		/** 
		Set the value of the IncludeSubscribed input for this Choreo. 

		@param Boolean - (optional, boolean) Whether to include shared files and public files the user opened. If false, the list includes owned files plus any shared or public files the user explictly added to a folder in Drive. (Default: true)
		*/
		public void set_IncludeSubscribed(Boolean value) {
			this.setInput("IncludeSubscribed", value);
		}

		/** 
		Set the value of the IncludeSubscribed input for this Choreo as a String. 

		@param String - (optional, boolean) Whether to include shared files and public files the user opened. If false, the list includes owned files plus any shared or public files the user explictly added to a folder in Drive. (Default: true)
		*/
		public void set_IncludeSubscribed(String value) {
			this.setInput("IncludeSubscribed", value);	
		}

		/** 
		Set the value of the MaxResults input for this Choreo. 

		@param Boolean - (optional, boolean) Maximum number of changes to return.
		*/
		public void set_MaxResults(Boolean value) {
			this.setInput("MaxResults", value);
		}

		/** 
		Set the value of the MaxResults input for this Choreo as a String. 

		@param String - (optional, boolean) Maximum number of changes to return.
		*/
		public void set_MaxResults(String value) {
			this.setInput("MaxResults", value);	
		}

		/** 
		Set the value of the PageToken input for this Choreo. 

		@param String - (optional, string) Page token for changes.
		*/
		public void set_PageToken(String value) {
			this.setInput("PageToken", value);
		}



		/** 
		Set the value of the RefreshToken input for this Choreo. 

		@param String - (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
		*/
		public void set_RefreshToken(String value) {
			this.setInput("RefreshToken", value);
		}



		/** 
		Set the value of the StartChangeID input for this Choreo. 

		@param String - (optional, multiline) Change ID to start listing changes from.
		*/
		public void set_StartChangeID(String value) {
			this.setInput("StartChangeID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the List Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListResultSet extends ResultSet {
		public ListResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "NewAccessToken" output from this Choreo execution

		@return String - (string) Contains a new AccessToken when the RefreshToken is provided.
		*/
		public String get_NewAccessToken() {
			return this.getResult("NewAccessToken");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Google.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** Get the change listing for the Google Drive account
		*/
		public GoogleChangeList getChangeList() {
		    return new GoogleChangeList(((JSONObject)getJSONFromString(this.getResult("Response"))));
		}
	}
	
}
