package com.temboo.Library.Google.Drive.Parents;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;
import com.temboo.outputs.Google.Drive.GoogleParent;

/** 
Get

Gets a specific parent reference.
*/
public class Get extends Choreography {

	/**
	Create a new instance of the Get Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Get(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Drive/Parents/Get"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetInputSet
	*/
	public GetInputSet newInputSet() {
		return new GetInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Get
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ClientID input for this Choreo. 

		@param String - (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
		*/
		public void set_ClientID(String value) {
			this.setInput("ClientID", value);
		}



		/** 
		Set the value of the ClientSecret input for this Choreo. 

		@param String - (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
		*/
		public void set_ClientSecret(String value) {
			this.setInput("ClientSecret", value);
		}



		/** 
		Set the value of the FileID input for this Choreo. 

		@param String - (required, string) The ID of the file.
		*/
		public void set_FileID(String value) {
			this.setInput("FileID", value);
		}



		/** 
		Set the value of the ParentID input for this Choreo. 

		@param String - (required, string) The ID of the parent.
		*/
		public void set_ParentID(String value) {
			this.setInput("ParentID", value);
		}



		/** 
		Set the value of the RefreshToken input for this Choreo. 

		@param String - (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
		*/
		public void set_RefreshToken(String value) {
			this.setInput("RefreshToken", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Get Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetResultSet extends ResultSet {
		public GetResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "NewAccessToken" output from this Choreo execution

		@return String - (string) Contains a new AccessToken when the RefreshToken is provided.
		*/
		public String get_NewAccessToken() {
			return this.getResult("NewAccessToken");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Google.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** A Google Drive parent resource
		*/
		public GoogleParent getParent() {
		    return new GoogleParent(((JSONObject)getJSONFromString(this.getResult("Response"))));
		}
	}
	
}
