package com.temboo.Library.Google.Drive.Replies;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;
import com.temboo.outputs.Google.Drive.GoogleReplyList;

/** 
List

Lists all of the replies to a comment.
*/
public class List extends Choreography {

	/**
	Create a new instance of the List Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public List(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Drive/Replies/List"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListInputSet
	*/
	public ListInputSet newInputSet() {
		return new ListInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the List
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ClientID input for this Choreo. 

		@param String - (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
		*/
		public void set_ClientID(String value) {
			this.setInput("ClientID", value);
		}



		/** 
		Set the value of the ClientSecret input for this Choreo. 

		@param String - (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
		*/
		public void set_ClientSecret(String value) {
			this.setInput("ClientSecret", value);
		}



		/** 
		Set the value of the CommentID input for this Choreo. 

		@param String - (required, string) The ID of the comment.
		*/
		public void set_CommentID(String value) {
			this.setInput("CommentID", value);
		}



		/** 
		Set the value of the Fields input for this Choreo. 

		@param String - (optional, string) Selector specifying a subset of fields to include in the response.
		*/
		public void set_Fields(String value) {
			this.setInput("Fields", value);
		}



		/** 
		Set the value of the FileID input for this Choreo. 

		@param String - (required, string) The ID of the file.
		*/
		public void set_FileID(String value) {
			this.setInput("FileID", value);
		}



		/** 
		Set the value of the IncludeDeleted input for this Choreo. 

		@param Boolean - (optional, boolean) If set, this will succeed when retrieving a deleted reply. (Default: false)
		*/
		public void set_IncludeDeleted(Boolean value) {
			this.setInput("IncludeDeleted", value);
		}

		/** 
		Set the value of the IncludeDeleted input for this Choreo as a String. 

		@param String - (optional, boolean) If set, this will succeed when retrieving a deleted reply. (Default: false)
		*/
		public void set_IncludeDeleted(String value) {
			this.setInput("IncludeDeleted", value);	
		}

		/** 
		Set the value of the MaxResults input for this Choreo. 

		@param Integer - (optional, integer) The maximum number of replies to include in the response, used for paging. Acceptable values are 0 to 100, inclusive. (Default: 20).
		*/
		public void set_MaxResults(Integer value) {
			this.setInput("MaxResults", value);
		}

		/** 
		Set the value of the MaxResults input for this Choreo as a String. 

		@param String - (optional, integer) The maximum number of replies to include in the response, used for paging. Acceptable values are 0 to 100, inclusive. (Default: 20).
		*/
		public void set_MaxResults(String value) {
			this.setInput("MaxResults", value);	
		}

		/** 
		Set the value of the PageToken input for this Choreo. 

		@param String - (optional, string) The continuation token, used to page through large result sets. To get the next page of results, set this parameter to the value of "nextPageToken" from the previous response.
		*/
		public void set_PageToken(String value) {
			this.setInput("PageToken", value);
		}



		/** 
		Set the value of the RefreshToken input for this Choreo. 

		@param String - (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
		*/
		public void set_RefreshToken(String value) {
			this.setInput("RefreshToken", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the List Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListResultSet extends ResultSet {
		public ListResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "NewAccessToken" output from this Choreo execution

		@return String - (string) Contains a new AccessToken when the RefreshToken is provided.
		*/
		public String get_NewAccessToken() {
			return this.getResult("NewAccessToken");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Google.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** Get a list of replies
		*/
		public GoogleReplyList getReplyList() {
		    return new GoogleReplyList(((JSONObject)getJSONFromString(this.getResult("Response"))));
		}
	}
	
}
