package com.temboo.Library.Google.Elevation;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetLocationElevation

Obtain elevation information for a path generated by a set of geo-coordinates.
*/
public class GetLocationElevation extends Choreography {

	/**
	Create a new instance of the GetLocationElevation Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetLocationElevation(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Elevation/GetLocationElevation"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetLocationElevationInputSet
	*/
	public GetLocationElevationInputSet newInputSet() {
		return new GetLocationElevationInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetLocationElevationResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetLocationElevationResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetLocationElevation
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetLocationElevationInputSet extends InputSet {
		/** 
		Set the value of the Locations input for this Choreo. 

		@param String - (required, string) Enter the location(s) for which elevation data will be obtained.  Input formats: a single latitude/longitude coordinate pair; an array of coordinates separated by a |. A set of encoded coordinates.
		*/
		public void set_Locations(String value) {
			this.setInput("Locations", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that response should be in. Can be set to xml or json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the Sensor input for this Choreo. 

		@param Boolean - (optional, boolean) Indicates whether or not the directions request is from a device with a location sensor. Value must be either 1 or 0. Defaults to 0 (false).
		*/
		public void set_Sensor(Boolean value) {
			this.setInput("Sensor", value);
		}

		/** 
		Set the value of the Sensor input for this Choreo as a String. 

		@param String - (optional, boolean) Indicates whether or not the directions request is from a device with a location sensor. Value must be either 1 or 0. Defaults to 0 (false).
		*/
		public void set_Sensor(String value) {
			this.setInput("Sensor", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetLocationElevation Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetLocationElevationResultSet extends ResultSet {
		public GetLocationElevationResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Google.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
