package com.temboo.Library.Google.Latitude;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
InsertPastLocation

Updates or creates an entry in an authenticated user's location history.
*/
public class InsertPastLocation extends Choreography {

	/**
	Create a new instance of the InsertPastLocation Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public InsertPastLocation(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Latitude/InsertPastLocation"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return InsertPastLocationInputSet
	*/
	public InsertPastLocationInputSet newInputSet() {
		return new InsertPastLocationInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public InsertPastLocationResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new InsertPastLocationResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the InsertPastLocation
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class InsertPastLocationInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ClientID input for this Choreo. 

		@param String - (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
		*/
		public void set_ClientID(String value) {
			this.setInput("ClientID", value);
		}



		/** 
		Set the value of the ClientSecret input for this Choreo. 

		@param String - (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
		*/
		public void set_ClientSecret(String value) {
			this.setInput("ClientSecret", value);
		}



		/** 
		Set the value of the Latitide input for this Choreo. 

		@param BigDecimal - (required, decimal) Enter latitude coordinates. For example: 37.420352.
		*/
		public void set_Latitide(BigDecimal value) {
			this.setInput("Latitide", value);
		}

		/** 
		Set the value of the Latitide input for this Choreo as a String. 

		@param String - (required, decimal) Enter latitude coordinates. For example: 37.420352.
		*/
		public void set_Latitide(String value) {
			this.setInput("Latitide", value);	
		}

		/** 
		Set the value of the Longitude input for this Choreo. 

		@param BigDecimal - (required, decimal) Enter longitude coordinates.  For example: -122.083389.
		*/
		public void set_Longitude(BigDecimal value) {
			this.setInput("Longitude", value);
		}

		/** 
		Set the value of the Longitude input for this Choreo as a String. 

		@param String - (required, decimal) Enter longitude coordinates.  For example: -122.083389.
		*/
		public void set_Longitude(String value) {
			this.setInput("Longitude", value);	
		}

		/** 
		Set the value of the RefreshToken input for this Choreo. 

		@param String - (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
		*/
		public void set_RefreshToken(String value) {
			this.setInput("RefreshToken", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the TimestampMs input for this Choreo. 

		@param String - (required, date) Enter a timestamp value (in epoch time).  Example: 1325715558.
		*/
		public void set_TimestampMs(String value) {
			this.setInput("TimestampMs", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the InsertPastLocation Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class InsertPastLocationResultSet extends ResultSet {
		public InsertPastLocationResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "NewAccessToken" output from this Choreo execution

		@return String - (string) 
		*/
		public String get_NewAccessToken() {
			return this.getResult("NewAccessToken");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Google.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
