package com.temboo.Library.Google.Latitude;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ListLocationHistory

Returns a list of a user's location history.
*/
public class ListLocationHistory extends Choreography {

	/**
	Create a new instance of the ListLocationHistory Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListLocationHistory(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Latitude/ListLocationHistory"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListLocationHistoryInputSet
	*/
	public ListLocationHistoryInputSet newInputSet() {
		return new ListLocationHistoryInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListLocationHistoryResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListLocationHistoryResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListLocationHistory
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListLocationHistoryInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ClientID input for this Choreo. 

		@param String - (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
		*/
		public void set_ClientID(String value) {
			this.setInput("ClientID", value);
		}



		/** 
		Set the value of the ClientSecret input for this Choreo. 

		@param String - (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
		*/
		public void set_ClientSecret(String value) {
			this.setInput("ClientSecret", value);
		}



		/** 
		Set the value of the Granularity input for this Choreo. 

		@param String - (optional, string) Specify the level of detailed returned.  Enter: best, or city.  Default is city.
		*/
		public void set_Granularity(String value) {
			this.setInput("Granularity", value);
		}



		/** 
		Set the value of the MaxResults input for this Choreo. 

		@param Integer - (optional, integer) Enter the maximum number of results to return.  If unspecified, 100 results will be returned.  The maximum results returned is 1000.
		*/
		public void set_MaxResults(Integer value) {
			this.setInput("MaxResults", value);
		}

		/** 
		Set the value of the MaxResults input for this Choreo as a String. 

		@param String - (optional, integer) Enter the maximum number of results to return.  If unspecified, 100 results will be returned.  The maximum results returned is 1000.
		*/
		public void set_MaxResults(String value) {
			this.setInput("MaxResults", value);	
		}

		/** 
		Set the value of the MaxTime input for this Choreo. 

		@param Integer - (optional, integer) The maximum timestamp of the locations to return (in milliseconds since the epoch).
		*/
		public void set_MaxTime(Integer value) {
			this.setInput("MaxTime", value);
		}

		/** 
		Set the value of the MaxTime input for this Choreo as a String. 

		@param String - (optional, integer) The maximum timestamp of the locations to return (in milliseconds since the epoch).
		*/
		public void set_MaxTime(String value) {
			this.setInput("MaxTime", value);	
		}

		/** 
		Set the value of the MinTime input for this Choreo. 

		@param Integer - (optional, integer) The minimum timestamp of the locations to return (in milliseconds since the epoch).
		*/
		public void set_MinTime(Integer value) {
			this.setInput("MinTime", value);
		}

		/** 
		Set the value of the MinTime input for this Choreo as a String. 

		@param String - (optional, integer) The minimum timestamp of the locations to return (in milliseconds since the epoch).
		*/
		public void set_MinTime(String value) {
			this.setInput("MinTime", value);	
		}

		/** 
		Set the value of the RefreshToken input for this Choreo. 

		@param String - (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
		*/
		public void set_RefreshToken(String value) {
			this.setInput("RefreshToken", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListLocationHistory Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListLocationHistoryResultSet extends ResultSet {
		public ListLocationHistoryResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "NewAccessToken" output from this Choreo execution

		@return String - (string) Contains a new AccessToken when the RefreshToken is provided.
		*/
		public String get_NewAccessToken() {
			return this.getResult("NewAccessToken");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Google.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
