package com.temboo.Library.Google.Picasa;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
AddCommentToPhoto

Adds a comment to a specified photo in Google Picasa.
*/
public class AddCommentToPhoto extends Choreography {

	/**
	Create a new instance of the AddCommentToPhoto Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public AddCommentToPhoto(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Picasa/AddCommentToPhoto"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return AddCommentToPhotoInputSet
	*/
	public AddCommentToPhotoInputSet newInputSet() {
		return new AddCommentToPhotoInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public AddCommentToPhotoResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new AddCommentToPhotoResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the AddCommentToPhoto
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class AddCommentToPhotoInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the AlbumID input for this Choreo. 

		@param Integer - (required, integer) The id of the album which contains the photo you want to add a comment to.
		*/
		public void set_AlbumID(Integer value) {
			this.setInput("AlbumID", value);
		}

		/** 
		Set the value of the AlbumID input for this Choreo as a String. 

		@param String - (required, integer) The id of the album which contains the photo you want to add a comment to.
		*/
		public void set_AlbumID(String value) {
			this.setInput("AlbumID", value);	
		}

		/** 
		Set the value of the ClientID input for this Choreo. 

		@param String - (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
		*/
		public void set_ClientID(String value) {
			this.setInput("ClientID", value);
		}



		/** 
		Set the value of the ClientSecret input for this Choreo. 

		@param String - (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
		*/
		public void set_ClientSecret(String value) {
			this.setInput("ClientSecret", value);
		}



		/** 
		Set the value of the Comment input for this Choreo. 

		@param String - (required, string) The comment that you want to add to a photo.
		*/
		public void set_Comment(String value) {
			this.setInput("Comment", value);
		}



		/** 
		Set the value of the PhotoID input for this Choreo. 

		@param Integer - (required, integer) The id of the photo you want to add a comment to.
		*/
		public void set_PhotoID(Integer value) {
			this.setInput("PhotoID", value);
		}

		/** 
		Set the value of the PhotoID input for this Choreo as a String. 

		@param String - (required, integer) The id of the photo you want to add a comment to.
		*/
		public void set_PhotoID(String value) {
			this.setInput("PhotoID", value);	
		}

		/** 
		Set the value of the RefreshToken input for this Choreo. 

		@param String - (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
		*/
		public void set_RefreshToken(String value) {
			this.setInput("RefreshToken", value);
		}



		/** 
		Set the value of the UserID input for this Choreo. 

		@param String - (optional, string) Google Picasa username. Defaults to 'default' which means the server will use the UserID of the user whose access token was specified.
		*/
		public void set_UserID(String value) {
			this.setInput("UserID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the AddCommentToPhoto Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class AddCommentToPhotoResultSet extends ResultSet {
		public AddCommentToPhotoResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "NewAccessToken" output from this Choreo execution

		@return String - (string) Contains a new AccessToken when the RefreshToken is provided.
		*/
		public String get_NewAccessToken() {
			return this.getResult("NewAccessToken");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Google Picasa.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
