package com.temboo.Library.Google.Picasa;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CreateAlbum

Creates a photo album in a Google Picasa account.
*/
public class CreateAlbum extends Choreography {

	/**
	Create a new instance of the CreateAlbum Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CreateAlbum(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Picasa/CreateAlbum"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CreateAlbumInputSet
	*/
	public CreateAlbumInputSet newInputSet() {
		return new CreateAlbumInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CreateAlbumResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CreateAlbumResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CreateAlbum
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CreateAlbumInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ClientID input for this Choreo. 

		@param String - (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
		*/
		public void set_ClientID(String value) {
			this.setInput("ClientID", value);
		}



		/** 
		Set the value of the ClientSecret input for this Choreo. 

		@param String - (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
		*/
		public void set_ClientSecret(String value) {
			this.setInput("ClientSecret", value);
		}



		/** 
		Set the value of the Keywords input for this Choreo. 

		@param String - (optional, string) Keywords to associate with the album you are creating separated by commas.
		*/
		public void set_Keywords(String value) {
			this.setInput("Keywords", value);
		}



		/** 
		Set the value of the PhotoAccess input for this Choreo. 

		@param String - (optional, string) The perssion level to specify for photo access. Defaults to 'public'.
		*/
		public void set_PhotoAccess(String value) {
			this.setInput("PhotoAccess", value);
		}



		/** 
		Set the value of the PhotoLocation input for this Choreo. 

		@param String - (optional, string) The location to associate with the photo (i.e. Italy).
		*/
		public void set_PhotoLocation(String value) {
			this.setInput("PhotoLocation", value);
		}



		/** 
		Set the value of the RefreshToken input for this Choreo. 

		@param String - (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
		*/
		public void set_RefreshToken(String value) {
			this.setInput("RefreshToken", value);
		}



		/** 
		Set the value of the Summary input for this Choreo. 

		@param String - (optional, string) The album summary.
		*/
		public void set_Summary(String value) {
			this.setInput("Summary", value);
		}



		/** 
		Set the value of the Timestamp input for this Choreo. 

		@param String - (optional, date) The timestamp to associate with the photo.  Defaults to the current timestamp. Should be an epoch timestamp in milliseconds.
		*/
		public void set_Timestamp(String value) {
			this.setInput("Timestamp", value);
		}



		/** 
		Set the value of the Title input for this Choreo. 

		@param String - (required, string) The title of the album.
		*/
		public void set_Title(String value) {
			this.setInput("Title", value);
		}



		/** 
		Set the value of the UserID input for this Choreo. 

		@param String - (optional, string) Google Picasa username. Defaults to 'default' which means the server will use the UserID of the user whose access token was specified.
		*/
		public void set_UserID(String value) {
			this.setInput("UserID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CreateAlbum Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CreateAlbumResultSet extends ResultSet {
		public CreateAlbumResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "NewAccessToken" output from this Choreo execution

		@return String - (string) Contains a new AccessToken when the RefreshToken is provided.
		*/
		public String get_NewAccessToken() {
			return this.getResult("NewAccessToken");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Google Picasa.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
