package com.temboo.Library.Google.Picasa;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
PostPhoto

Uploads a photo to Google Picasa.
*/
public class PostPhoto extends Choreography {

	/**
	Create a new instance of the PostPhoto Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public PostPhoto(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Picasa/PostPhoto"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return PostPhotoInputSet
	*/
	public PostPhotoInputSet newInputSet() {
		return new PostPhotoInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public PostPhotoResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new PostPhotoResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the PostPhoto
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class PostPhotoInputSet extends InputSet {
		/** 
		Set the value of the FileContents input for this Choreo. 

		@param String - (conditional, string) The base64 encoded file contents of the photo you want to upload.
		*/
		public void set_FileContents(String value) {
			this.setInput("FileContents", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the AlbumID input for this Choreo. 

		@param Integer - (optional, integer) The id of the album that you want to upload the photo to. Defaults to 'default' which means the photo will be uploaded to the dropbox album.
		*/
		public void set_AlbumID(Integer value) {
			this.setInput("AlbumID", value);
		}

		/** 
		Set the value of the AlbumID input for this Choreo as a String. 

		@param String - (optional, integer) The id of the album that you want to upload the photo to. Defaults to 'default' which means the photo will be uploaded to the dropbox album.
		*/
		public void set_AlbumID(String value) {
			this.setInput("AlbumID", value);	
		}

		/** 
		Set the value of the ClientID input for this Choreo. 

		@param String - (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
		*/
		public void set_ClientID(String value) {
			this.setInput("ClientID", value);
		}



		/** 
		Set the value of the ClientSecret input for this Choreo. 

		@param String - (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
		*/
		public void set_ClientSecret(String value) {
			this.setInput("ClientSecret", value);
		}



		/** 
		Set the value of the ImageName input for this Choreo. 

		@param String - (required, string) The name of the image you want to upload.
		*/
		public void set_ImageName(String value) {
			this.setInput("ImageName", value);
		}



		/** 
		Set the value of the RefreshToken input for this Choreo. 

		@param String - (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
		*/
		public void set_RefreshToken(String value) {
			this.setInput("RefreshToken", value);
		}



		/** 
		Set the value of the UserID input for this Choreo. 

		@param String - (optional, string) Google Picasa username. Defaults to "default" which means the server will use the UserID of the user whose access token was specified.
		*/
		public void set_UserID(String value) {
			this.setInput("UserID", value);
		}



		/** 
		Set the value of the VaultFile input for this Choreo. 

		@param TembooPath - (vault file) The path to the vault file you want to upload. Required unless using the FileContents input.
		*/
		public void set_VaultFile(TembooPath value) {
			this.setAlias("VaultFile", value);
		}
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the PostPhoto Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class PostPhotoResultSet extends ResultSet {
		public PostPhotoResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "NewAccessToken" output from this Choreo execution

		@return String - (string) Contains a new AccessToken when the RefreshToken is provided.
		*/
		public String get_NewAccessToken() {
			return this.getResult("NewAccessToken");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Google Picasa.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
