package com.temboo.Library.Google.Spreadsheets;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
AddWorksheet

Creates a new worksheet within an existing spreadsheet.
*/
public class AddWorksheet extends Choreography {

	/**
	Create a new instance of the AddWorksheet Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public AddWorksheet(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Spreadsheets/AddWorksheet"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return AddWorksheetInputSet
	*/
	public AddWorksheetInputSet newInputSet() {
		return new AddWorksheetInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public AddWorksheetResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new AddWorksheetResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the AddWorksheet
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class AddWorksheetInputSet extends InputSet {
		/** 
		Set the value of the ColumnCount input for this Choreo. 

		@param Integer - (required, integer) The number of columns that you want to specify for the new worksheet
		*/
		public void set_ColumnCount(Integer value) {
			this.setInput("ColumnCount", value);
		}

		/** 
		Set the value of the ColumnCount input for this Choreo as a String. 

		@param String - (required, integer) The number of columns that you want to specify for the new worksheet
		*/
		public void set_ColumnCount(String value) {
			this.setInput("ColumnCount", value);	
		}

		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Google password
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the RowCount input for this Choreo. 

		@param Integer - (required, integer) The number of rows that you want to specify for the new worksheet
		*/
		public void set_RowCount(Integer value) {
			this.setInput("RowCount", value);
		}

		/** 
		Set the value of the RowCount input for this Choreo as a String. 

		@param String - (required, integer) The number of rows that you want to specify for the new worksheet
		*/
		public void set_RowCount(String value) {
			this.setInput("RowCount", value);	
		}

		/** 
		Set the value of the SpreadsheetKey input for this Choreo. 

		@param String - (required, string) The unique key associated with the spreadsheet that you want to add a worksheet to
		*/
		public void set_SpreadsheetKey(String value) {
			this.setInput("SpreadsheetKey", value);
		}



		/** 
		Set the value of the Title input for this Choreo. 

		@param String - (required, string) The title of the new document to create
		*/
		public void set_Title(String value) {
			this.setInput("Title", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) Your Google username
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the AddWorksheet Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class AddWorksheetResultSet extends ResultSet {
		public AddWorksheetResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Google
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
