package com.temboo.Library.Google.Spreadsheets;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
AppendRow

Appends a simple comma-separated row of data to a given Google Spreadsheet.
*/
public class AppendRow extends Choreography {

	/**
	Create a new instance of the AppendRow Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public AppendRow(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Spreadsheets/AppendRow"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return AppendRowInputSet
	*/
	public AppendRowInputSet newInputSet() {
		return new AppendRowInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public AppendRowResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new AppendRowResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the AppendRow
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class AppendRowInputSet extends InputSet {
		/** 
		Set the value of the RowData input for this Choreo. 

		@param String - (required, string) A comma separated list of items to be added as a new row to the spreadsheet.
		*/
		public void set_RowData(String value) {
			this.setInput("RowData", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Google password.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the SheetName input for this Choreo. 

		@param String - (optional, string) The name of the sheet to write to. If not specified, rows are written to the first sheet.
		*/
		public void set_SheetName(String value) {
			this.setInput("SheetName", value);
		}



		/** 
		Set the value of the SpreadsheetTitle input for this Choreo. 

		@param String - (required, string) The title of the spreadsheet that you want to write rows to.
		*/
		public void set_SpreadsheetTitle(String value) {
			this.setInput("SpreadsheetTitle", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) Your Google username.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the AppendRow Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class AppendRowResultSet extends ResultSet {
		public AppendRowResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (string) Returns the string "success" if no error occurs.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
