package com.temboo.Library.Google.Spreadsheets;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ClientLoginAuthentication

Request an authorization token for Google Documents.
*/
public class ClientLoginAuthentication extends Choreography {

	/**
	Create a new instance of the ClientLoginAuthentication Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ClientLoginAuthentication(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Spreadsheets/ClientLoginAuthentication"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ClientLoginAuthenticationInputSet
	*/
	public ClientLoginAuthenticationInputSet newInputSet() {
		return new ClientLoginAuthenticationInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ClientLoginAuthenticationResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ClientLoginAuthenticationResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ClientLoginAuthentication
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ClientLoginAuthenticationInputSet extends InputSet {
		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Google password
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Service input for this Choreo. 

		@param String - (required, string) The service that you are requesting an authorization token for. Defaults to 'wise' for Spreadsheets API.
		*/
		public void set_Service(String value) {
			this.setInput("Service", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) Your Google email address
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ClientLoginAuthentication Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ClientLoginAuthenticationResultSet extends ResultSet {
		public ClientLoginAuthenticationResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "AuthorizationKey" output from this Choreo execution

		@return String - (string) The auth token parsed from the Google login response
		*/
		public String get_AuthorizationKey() {
			return this.getResult("AuthorizationKey");
		}
	}
	
}
