package com.temboo.Library.Google.Spreadsheets;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CreateSpreadsheet

Creates a Google spreadsheet from a CSV file.
*/
public class CreateSpreadsheet extends Choreography {

	/**
	Create a new instance of the CreateSpreadsheet Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CreateSpreadsheet(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Spreadsheets/CreateSpreadsheet"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CreateSpreadsheetInputSet
	*/
	public CreateSpreadsheetInputSet newInputSet() {
		return new CreateSpreadsheetInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CreateSpreadsheetResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CreateSpreadsheetResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CreateSpreadsheet
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CreateSpreadsheetInputSet extends InputSet {
		/** 
		Set the value of the UploadFile input for this Choreo. 

		@param String - (conditional, multiline) The data to be written to the Google spreadsheet. Should be in CSV format. This is required unless using the VaultCSVFile alias (an advanced option used when running Choreos in the Temboo Designer).
		*/
		public void set_UploadFile(String value) {
			this.setInput("UploadFile", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Google password
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Title input for this Choreo. 

		@param String - (required, string) The name of the new document.
		*/
		public void set_Title(String value) {
			this.setInput("Title", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) Your Google email address
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



		/** 
		Set the value of the VaultCSVFile input for this Choreo. 

		@param TembooPath - (optional, vault file) The path to a CSV file stored in the vault. This is required unless you are using the UploadFile input variable. 
		*/
		public void set_VaultCSVFile(TembooPath value) {
			this.setAlias("VaultCSVFile", value);
		}
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CreateSpreadsheet Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CreateSpreadsheetResultSet extends ResultSet {
		public CreateSpreadsheetResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) Response from Google upload
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
