package com.temboo.Library.Google.Spreadsheets;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
DeleteListRow

Deletes a specified worksheet row from a Google spreadsheet.
*/
public class DeleteListRow extends Choreography {

	/**
	Create a new instance of the DeleteListRow Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DeleteListRow(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Spreadsheets/DeleteListRow"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DeleteListRowInputSet
	*/
	public DeleteListRowInputSet newInputSet() {
		return new DeleteListRowInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DeleteListRowResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DeleteListRowResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DeleteListRow
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DeleteListRowInputSet extends InputSet {
		/** 
		Set the value of the EditLink input for this Choreo. 

		@param String - (conditional, string) The entry's edit link URL. Can be retrieved by running RetrieveListFeed and parsing the 'edit' link returned. When the edit link is provided, SpreadsheetKey, WorksheetId, and RowId are not needed.
		*/
		public void set_EditLink(String value) {
			this.setInput("EditLink", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Google password.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the RowId input for this Choreo. 

		@param String - (conditional, string) The unique id of the row you want to delete. Required unless providing the EditLink.
		*/
		public void set_RowId(String value) {
			this.setInput("RowId", value);
		}



		/** 
		Set the value of the SpreadsheetKey input for this Choreo. 

		@param String - (conditional, string) The unique key of the spreadsheet associated with the row you want to delete. Required unless providing the EditLink.
		*/
		public void set_SpreadsheetKey(String value) {
			this.setInput("SpreadsheetKey", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) Your Google username.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



		/** 
		Set the value of the WorksheetId input for this Choreo. 

		@param String - (conditional, string) The unique id of the worksheet associated with the row you want to delete. Required unless providing the EditLink.
		*/
		public void set_WorksheetId(String value) {
			this.setInput("WorksheetId", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DeleteListRow Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DeleteListRowResultSet extends ResultSet {
		public DeleteListRowResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Google
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
