package com.temboo.Library.Google.Spreadsheets;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
RetrieveSpecificRowsOrColumns

Retrieves specific rows or columns based on a specified range.
*/
public class RetrieveSpecificRowsOrColumns extends Choreography {

	/**
	Create a new instance of the RetrieveSpecificRowsOrColumns Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public RetrieveSpecificRowsOrColumns(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Spreadsheets/RetrieveSpecificRowsOrColumns"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return RetrieveSpecificRowsOrColumnsInputSet
	*/
	public RetrieveSpecificRowsOrColumnsInputSet newInputSet() {
		return new RetrieveSpecificRowsOrColumnsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public RetrieveSpecificRowsOrColumnsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new RetrieveSpecificRowsOrColumnsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the RetrieveSpecificRowsOrColumns
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class RetrieveSpecificRowsOrColumnsInputSet extends InputSet {
		/** 
		Set the value of the MaxColumn input for this Choreo. 

		@param Integer - (optional, integer) The max column number to return.
		*/
		public void set_MaxColumn(Integer value) {
			this.setInput("MaxColumn", value);
		}

		/** 
		Set the value of the MaxColumn input for this Choreo as a String. 

		@param String - (optional, integer) The max column number to return.
		*/
		public void set_MaxColumn(String value) {
			this.setInput("MaxColumn", value);	
		}

		/** 
		Set the value of the MaxRow input for this Choreo. 

		@param Integer - (optional, integer) The max row number to return.
		*/
		public void set_MaxRow(Integer value) {
			this.setInput("MaxRow", value);
		}

		/** 
		Set the value of the MaxRow input for this Choreo as a String. 

		@param String - (optional, integer) The max row number to return.
		*/
		public void set_MaxRow(String value) {
			this.setInput("MaxRow", value);	
		}

		/** 
		Set the value of the MinColumn input for this Choreo. 

		@param Integer - (optional, integer) The minimum column number to return.
		*/
		public void set_MinColumn(Integer value) {
			this.setInput("MinColumn", value);
		}

		/** 
		Set the value of the MinColumn input for this Choreo as a String. 

		@param String - (optional, integer) The minimum column number to return.
		*/
		public void set_MinColumn(String value) {
			this.setInput("MinColumn", value);	
		}

		/** 
		Set the value of the MinRow input for this Choreo. 

		@param Integer - (optional, integer) The minimum row number to return.
		*/
		public void set_MinRow(Integer value) {
			this.setInput("MinRow", value);
		}

		/** 
		Set the value of the MinRow input for this Choreo as a String. 

		@param String - (optional, integer) The minimum row number to return.
		*/
		public void set_MinRow(String value) {
			this.setInput("MinRow", value);	
		}

		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Google password
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the SpreadsheetKey input for this Choreo. 

		@param String - (required, string) The unique for key for the spreadsheet associated with the feed you want to retrieve
		*/
		public void set_SpreadsheetKey(String value) {
			this.setInput("SpreadsheetKey", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) Your Google email address
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



		/** 
		Set the value of the WorksheetId input for this Choreo. 

		@param String - (required, string) The unique id of the worksheet associated with the feed you want to retrieve
		*/
		public void set_WorksheetId(String value) {
			this.setInput("WorksheetId", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the RetrieveSpecificRowsOrColumns Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class RetrieveSpecificRowsOrColumnsResultSet extends ResultSet {
		public RetrieveSpecificRowsOrColumnsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Google
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
