package com.temboo.Library.Google.Spreadsheets;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
RetrieveSpreadsheetDetailsByName

Retrieves spreadsheet and worksheet IDs with a given spreadsheet name.
*/
public class RetrieveSpreadsheetDetailsByName extends Choreography {

	/**
	Create a new instance of the RetrieveSpreadsheetDetailsByName Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public RetrieveSpreadsheetDetailsByName(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Spreadsheets/RetrieveSpreadsheetDetailsByName"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return RetrieveSpreadsheetDetailsByNameInputSet
	*/
	public RetrieveSpreadsheetDetailsByNameInputSet newInputSet() {
		return new RetrieveSpreadsheetDetailsByNameInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public RetrieveSpreadsheetDetailsByNameResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new RetrieveSpreadsheetDetailsByNameResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the RetrieveSpreadsheetDetailsByName
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class RetrieveSpreadsheetDetailsByNameInputSet extends InputSet {
		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Google password.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the SpreadsheetName input for this Choreo. 

		@param String - (required, string) The title of the spreadsheet you want to retrieve details for.
		*/
		public void set_SpreadsheetName(String value) {
			this.setInput("SpreadsheetName", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) Your Google email address.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the RetrieveSpreadsheetDetailsByName Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class RetrieveSpreadsheetDetailsByNameResultSet extends ResultSet {
		public RetrieveSpreadsheetDetailsByNameResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "SpreadsheetDetails" output from this Choreo execution

		@return String - (xml) The spreadsheet details including spreadsheet name and key. Worksheet names and IDs associated with the spreadsheet are also included.
		*/
		public String get_SpreadsheetDetails() {
			return this.getResult("SpreadsheetDetails");
		}
	}
	
}
