package com.temboo.Library.Google.Spreadsheets;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
StructuredQuery

Retrieves a list-based feed containing data in your Google spreadsheet that meets a specified criteria.
*/
public class StructuredQuery extends Choreography {

	/**
	Create a new instance of the StructuredQuery Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public StructuredQuery(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Spreadsheets/StructuredQuery"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return StructuredQueryInputSet
	*/
	public StructuredQueryInputSet newInputSet() {
		return new StructuredQueryInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public StructuredQueryResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new StructuredQueryResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the StructuredQuery
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class StructuredQueryInputSet extends InputSet {
		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Google password
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Query input for this Choreo. 

		@param String - (required, string) A valid structured query (i.e. id>4)
		*/
		public void set_Query(String value) {
			this.setInput("Query", value);
		}



		/** 
		Set the value of the SpreadsheetKey input for this Choreo. 

		@param String - (required, string) The unique for key for the spreadsheet associated with the feed you want to retrieve
		*/
		public void set_SpreadsheetKey(String value) {
			this.setInput("SpreadsheetKey", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) Your Google email address
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



		/** 
		Set the value of the WorksheetId input for this Choreo. 

		@param String - (required, string) The unique id of the worksheet associated with the feed you want to retrieve
		*/
		public void set_WorksheetId(String value) {
			this.setInput("WorksheetId", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the StructuredQuery Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class StructuredQueryResultSet extends ResultSet {
		public StructuredQueryResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Google
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
