package com.temboo.Library.Google.Spreadsheets;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
UpdateCells

Updates a specified cell in a Google worksheet.
*/
public class UpdateCells extends Choreography {

	/**
	Create a new instance of the UpdateCells Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public UpdateCells(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Spreadsheets/UpdateCells"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return UpdateCellsInputSet
	*/
	public UpdateCellsInputSet newInputSet() {
		return new UpdateCellsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public UpdateCellsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new UpdateCellsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the UpdateCells
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class UpdateCellsInputSet extends InputSet {
		/** 
		Set the value of the Column input for this Choreo. 

		@param Integer - (required, integer) The column number of the cell location that you want to update (for example, column A = 1, columnB = 2, etc).
		*/
		public void set_Column(Integer value) {
			this.setInput("Column", value);
		}

		/** 
		Set the value of the Column input for this Choreo as a String. 

		@param String - (required, integer) The column number of the cell location that you want to update (for example, column A = 1, columnB = 2, etc).
		*/
		public void set_Column(String value) {
			this.setInput("Column", value);	
		}

		/** 
		Set the value of the InputValue input for this Choreo. 

		@param String - (required, string) The new value for the cell
		*/
		public void set_InputValue(String value) {
			this.setInput("InputValue", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Google password
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Row input for this Choreo. 

		@param Integer - (required, integer) The row number of the cell location that you want to update
		*/
		public void set_Row(Integer value) {
			this.setInput("Row", value);
		}

		/** 
		Set the value of the Row input for this Choreo as a String. 

		@param String - (required, integer) The row number of the cell location that you want to update
		*/
		public void set_Row(String value) {
			this.setInput("Row", value);	
		}

		/** 
		Set the value of the SpreadsheetKey input for this Choreo. 

		@param String - (required, string) The unique for key for the spreadsheet associated with the cell you want to update
		*/
		public void set_SpreadsheetKey(String value) {
			this.setInput("SpreadsheetKey", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) Your Google email address
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



		/** 
		Set the value of the WorksheetId input for this Choreo. 

		@param String - (required, string) The unique id of the worksheet associated with the cell you want to update
		*/
		public void set_WorksheetId(String value) {
			this.setInput("WorksheetId", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the UpdateCells Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class UpdateCellsResultSet extends ResultSet {
		public UpdateCellsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Google
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
