package com.temboo.Library.GovTrack;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Bill

Retrieves bills and resolutions in the U.S. Congress since 1973 (the 93rd Congress).
*/
public class Bill extends Choreography {

	/**
	Create a new instance of the Bill Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Bill(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/GovTrack/Bill"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return BillInputSet
	*/
	public BillInputSet newInputSet() {
		return new BillInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public BillResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new BillResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Bill
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class BillInputSet extends InputSet {
		/** 
		Set the value of the BillID input for this Choreo. 

		@param Integer - (optional, integer) Specify the ID number of the bill to return only the record for that bill.
		*/
		public void set_BillID(Integer value) {
			this.setInput("BillID", value);
		}

		/** 
		Set the value of the BillID input for this Choreo as a String. 

		@param String - (optional, integer) Specify the ID number of the bill to return only the record for that bill.
		*/
		public void set_BillID(String value) {
			this.setInput("BillID", value);	
		}

		/** 
		Set the value of the BillType input for this Choreo. 

		@param String - (optional, string) The bill's type. See documentation for acceptable bill types.
		*/
		public void set_BillType(String value) {
			this.setInput("BillType", value);
		}



		/** 
		Set the value of the Congress input for this Choreo. 

		@param Integer - (optional, integer) The number of the congress in which the bill was introduced. The current congress is 112.
		*/
		public void set_Congress(Integer value) {
			this.setInput("Congress", value);
		}

		/** 
		Set the value of the Congress input for this Choreo as a String. 

		@param String - (optional, integer) The number of the congress in which the bill was introduced. The current congress is 112.
		*/
		public void set_Congress(String value) {
			this.setInput("Congress", value);	
		}

		/** 
		Set the value of the CurrentStatusDate input for this Choreo. 

		@param String - (optional, string) The date of the last major action on the bill corresponding to the CurrentStatus (in YYYY-MM-DD format).
		*/
		public void set_CurrentStatusDate(String value) {
			this.setInput("CurrentStatusDate", value);
		}



		/** 
		Set the value of the CurrentStatus input for this Choreo. 

		@param String - (optional, string) The current status of the bill. See documentation for acceptable inputs.
		*/
		public void set_CurrentStatus(String value) {
			this.setInput("CurrentStatus", value);
		}



		/** 
		Set the value of the IntroducedDate input for this Choreo. 

		@param String - (optional, string) The date the bill was introduced (in YYYY-MM-DD format).
		*/
		public void set_IntroducedDate(String value) {
			this.setInput("IntroducedDate", value);
		}



		/** 
		Set the value of the Limit input for this Choreo. 

		@param Integer - (optional, integer) Results are paged 20 per call by default. Set the limit input to a high value to get all of the results at once.
		*/
		public void set_Limit(Integer value) {
			this.setInput("Limit", value);
		}

		/** 
		Set the value of the Limit input for this Choreo as a String. 

		@param String - (optional, integer) Results are paged 20 per call by default. Set the limit input to a high value to get all of the results at once.
		*/
		public void set_Limit(String value) {
			this.setInput("Limit", value);	
		}

		/** 
		Set the value of the Number input for this Choreo. 

		@param Integer - (optional, integer) The bill's number (just the integer part).
		*/
		public void set_Number(Integer value) {
			this.setInput("Number", value);
		}

		/** 
		Set the value of the Number input for this Choreo as a String. 

		@param String - (optional, integer) The bill's number (just the integer part).
		*/
		public void set_Number(String value) {
			this.setInput("Number", value);	
		}

		/** 
		Set the value of the Order input for this Choreo. 

		@param String - (optional, string) You can order the results using fieldname (ascending) or -fieldname (descending) where "fieldname" is one of these values: current_status_date, introduced_date, senate_floor_schedule_postdate.
		*/
		public void set_Order(String value) {
			this.setInput("Order", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) Specify the format of the response. Default is JSON, but XML is also possible.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the SchedulePostdate input for this Choreo. 

		@param String - (optional, string) The date on which the bill was posted on the Senate Floor Schedule which is different from the date it was expected to be debated (in YYYY-MM-DD format).
		*/
		public void set_SchedulePostdate(String value) {
			this.setInput("SchedulePostdate", value);
		}



		/** 
		Set the value of the Sponsor input for this Choreo. 

		@param Integer - (optional, integer) The ID of the sponsor of the bill.
		*/
		public void set_Sponsor(Integer value) {
			this.setInput("Sponsor", value);
		}

		/** 
		Set the value of the Sponsor input for this Choreo as a String. 

		@param String - (optional, integer) The ID of the sponsor of the bill.
		*/
		public void set_Sponsor(String value) {
			this.setInput("Sponsor", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Bill Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class BillResultSet extends ResultSet {
		public BillResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The resopnse from GovTrack.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
