package com.temboo.Library.GovTrack;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Person

Returns members of Congress and U.S. Presidents since the founding of the nation.
*/
public class Person extends Choreography {

	/**
	Create a new instance of the Person Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Person(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/GovTrack/Person"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return PersonInputSet
	*/
	public PersonInputSet newInputSet() {
		return new PersonInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public PersonResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new PersonResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Person
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class PersonInputSet extends InputSet {
		/** 
		Set the value of the FirstName input for this Choreo. 

		@param String - (optional, string) First name of the representative to find.
		*/
		public void set_FirstName(String value) {
			this.setInput("FirstName", value);
		}



		/** 
		Set the value of the Gender input for this Choreo. 

		@param String - (optional, string) The person's gender (male or female). For historical data, gender is sometimes not specified.
		*/
		public void set_Gender(String value) {
			this.setInput("Gender", value);
		}



		/** 
		Set the value of the LastName input for this Choreo. 

		@param String - (optional, string) The representative's last name.
		*/
		public void set_LastName(String value) {
			this.setInput("LastName", value);
		}



		/** 
		Set the value of the Limit input for this Choreo. 

		@param Integer - (optional, integer) Results are paged 20 per call by default. Set the limit input to a high value to get all of the results at once.
		*/
		public void set_Limit(Integer value) {
			this.setInput("Limit", value);
		}

		/** 
		Set the value of the Limit input for this Choreo as a String. 

		@param String - (optional, integer) Results are paged 20 per call by default. Set the limit input to a high value to get all of the results at once.
		*/
		public void set_Limit(String value) {
			this.setInput("Limit", value);	
		}

		/** 
		Set the value of the MetaVidID input for this Choreo. 

		@param String - (optional, string) The person's ID on metavid.org.
		*/
		public void set_MetaVidID(String value) {
			this.setInput("MetaVidID", value);
		}



		/** 
		Set the value of the MiddleName input for this Choreo. 

		@param String - (optional, string) The representative's middle name.
		*/
		public void set_MiddleName(String value) {
			this.setInput("MiddleName", value);
		}



		/** 
		Set the value of the NameMod input for this Choreo. 

		@param String - (optional, string) The suffix of the person's name, ususally one of Jr., Sr., I, II, etc.
		*/
		public void set_NameMod(String value) {
			this.setInput("NameMod", value);
		}



		/** 
		Set the value of the OSID input for this Choreo. 

		@param Integer - (optional, integer) The person's ID on opensecrets.org (The Center for Responsive Politics).
		*/
		public void set_OSID(Integer value) {
			this.setInput("OSID", value);
		}

		/** 
		Set the value of the OSID input for this Choreo as a String. 

		@param String - (optional, integer) The person's ID on opensecrets.org (The Center for Responsive Politics).
		*/
		public void set_OSID(String value) {
			this.setInput("OSID", value);	
		}

		/** 
		Set the value of the PVSID input for this Choreo. 

		@param Integer - (optional, integer) The person's ID on vote-smart.org (Project Vote Smart).
		*/
		public void set_PVSID(Integer value) {
			this.setInput("PVSID", value);
		}

		/** 
		Set the value of the PVSID input for this Choreo as a String. 

		@param String - (optional, integer) The person's ID on vote-smart.org (Project Vote Smart).
		*/
		public void set_PVSID(String value) {
			this.setInput("PVSID", value);	
		}

		/** 
		Set the value of the PersonID input for this Choreo. 

		@param Integer - (optional, integer) Specify the ID number for a person to retrieve only that person.
		*/
		public void set_PersonID(Integer value) {
			this.setInput("PersonID", value);
		}

		/** 
		Set the value of the PersonID input for this Choreo as a String. 

		@param String - (optional, integer) Specify the ID number for a person to retrieve only that person.
		*/
		public void set_PersonID(String value) {
			this.setInput("PersonID", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) Specify the format of the response. Default is JSON, but XML is also possible.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the Roles input for this Choreo. 

		@param String - (optional, string) ID number of a term in Congress or as President that this person has been elected to.
		*/
		public void set_Roles(String value) {
			this.setInput("Roles", value);
		}



		/** 
		Set the value of the TwitterID input for this Choreo. 

		@param String - (optional, string) Official Twitter handle of the representative.
		*/
		public void set_TwitterID(String value) {
			this.setInput("TwitterID", value);
		}



		/** 
		Set the value of the YoutubeID input for this Choreo. 

		@param String - (optional, string) The name of the person't official YouTube channel.
		*/
		public void set_YoutubeID(String value) {
			this.setInput("YoutubeID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Person Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class PersonResultSet extends ResultSet {
		public PersonResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The resopnse from GovTrack.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
