package com.temboo.Library.GovTrack;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Vote

Returns roll call votes in the U.S. Congress since 1789.
*/
public class Vote extends Choreography {

	/**
	Create a new instance of the Vote Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Vote(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/GovTrack/Vote"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return VoteInputSet
	*/
	public VoteInputSet newInputSet() {
		return new VoteInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public VoteResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new VoteResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Vote
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class VoteInputSet extends InputSet {
		/** 
		Set the value of the Category input for this Choreo. 

		@param String - (optional, string) The type of the vote. See documentation for acceptable inputs.
		*/
		public void set_Category(String value) {
			this.setInput("Category", value);
		}



		/** 
		Set the value of the Chamber input for this Choreo. 

		@param String - (optional, string) The chamber in which the vote was held, house or senate.
		*/
		public void set_Chamber(String value) {
			this.setInput("Chamber", value);
		}



		/** 
		Set the value of the Congress input for this Choreo. 

		@param Integer - (optional, integer) The number of the congress in which the bill was introduced. The current congress is 112.
		*/
		public void set_Congress(Integer value) {
			this.setInput("Congress", value);
		}

		/** 
		Set the value of the Congress input for this Choreo as a String. 

		@param String - (optional, integer) The number of the congress in which the bill was introduced. The current congress is 112.
		*/
		public void set_Congress(String value) {
			this.setInput("Congress", value);	
		}

		/** 
		Set the value of the Created input for this Choreo. 

		@param String - (optional, string) The date (and in recent history also the time) on which the vote was held.
		*/
		public void set_Created(String value) {
			this.setInput("Created", value);
		}



		/** 
		Set the value of the Limit input for this Choreo. 

		@param Integer - (optional, integer) Results are paged 20 per call by default. Set the limit input to a high value to get all of the results at once.
		*/
		public void set_Limit(Integer value) {
			this.setInput("Limit", value);
		}

		/** 
		Set the value of the Limit input for this Choreo as a String. 

		@param String - (optional, integer) Results are paged 20 per call by default. Set the limit input to a high value to get all of the results at once.
		*/
		public void set_Limit(String value) {
			this.setInput("Limit", value);	
		}

		/** 
		Set the value of the Number input for this Choreo. 

		@param Integer - (optional, integer) The number of the vote, unique to a Congress and session pair.
		*/
		public void set_Number(Integer value) {
			this.setInput("Number", value);
		}

		/** 
		Set the value of the Number input for this Choreo as a String. 

		@param String - (optional, integer) The number of the vote, unique to a Congress and session pair.
		*/
		public void set_Number(String value) {
			this.setInput("Number", value);	
		}

		/** 
		Set the value of the Order input for this Choreo. 

		@param String - (optional, string) You can order the results using created (ascending) or -created (descending) for the dates that each vote was held.
		*/
		public void set_Order(String value) {
			this.setInput("Order", value);
		}



		/** 
		Set the value of the RelatedBill input for this Choreo. 

		@param String - (optional, string) A bill related to this vote.
		*/
		public void set_RelatedBill(String value) {
			this.setInput("RelatedBill", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) Specify the format of the response. Default is JSON, but XML is also possible.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the Session input for this Choreo. 

		@param Integer - (optional, integer) Session of congress. For congress = 112 roughly covers the period 2011-2012, so session=2011 and session=2012 can each be specified. In historical data sessions may be named in other ways.
		*/
		public void set_Session(Integer value) {
			this.setInput("Session", value);
		}

		/** 
		Set the value of the Session input for this Choreo as a String. 

		@param String - (optional, integer) Session of congress. For congress = 112 roughly covers the period 2011-2012, so session=2011 and session=2012 can each be specified. In historical data sessions may be named in other ways.
		*/
		public void set_Session(String value) {
			this.setInput("Session", value);	
		}

		/** 
		Set the value of the VoteID input for this Choreo. 

		@param Integer - (optional, integer) Specify the ID of a vote object to retrieve the record for just that object.
		*/
		public void set_VoteID(Integer value) {
			this.setInput("VoteID", value);
		}

		/** 
		Set the value of the VoteID input for this Choreo as a String. 

		@param String - (optional, integer) Specify the ID of a vote object to retrieve the record for just that object.
		*/
		public void set_VoteID(String value) {
			this.setInput("VoteID", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Vote Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class VoteResultSet extends ResultSet {
		public VoteResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The resopnse from GovTrack.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
