package com.temboo.Library.GovTrack;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
VoteAndVoter

Retrieves how people voted on roll call votes in the U.S. Congress since 1789. 
*/
public class VoteAndVoter extends Choreography {

	/**
	Create a new instance of the VoteAndVoter Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public VoteAndVoter(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/GovTrack/VoteAndVoter"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return VoteAndVoterInputSet
	*/
	public VoteAndVoterInputSet newInputSet() {
		return new VoteAndVoterInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public VoteAndVoterResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new VoteAndVoterResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the VoteAndVoter
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class VoteAndVoterInputSet extends InputSet {
		/** 
		Set the value of the Created input for this Choreo. 

		@param String - (optional, string) The date (and in recent history also the time) on which the vote was held (in YYYY-MM-DD format).
		*/
		public void set_Created(String value) {
			this.setInput("Created", value);
		}



		/** 
		Set the value of the Limit input for this Choreo. 

		@param Integer - (optional, integer) Results are paged 20 per call by default. Set the limit input to a high value to get all of the results at once.
		*/
		public void set_Limit(Integer value) {
			this.setInput("Limit", value);
		}

		/** 
		Set the value of the Limit input for this Choreo as a String. 

		@param String - (optional, integer) Results are paged 20 per call by default. Set the limit input to a high value to get all of the results at once.
		*/
		public void set_Limit(String value) {
			this.setInput("Limit", value);	
		}

		/** 
		Set the value of the ObjectID input for this Choreo. 

		@param Integer - (optional, integer) Specify the ID of a vote object to retrieve just that object's record.
		*/
		public void set_ObjectID(Integer value) {
			this.setInput("ObjectID", value);
		}

		/** 
		Set the value of the ObjectID input for this Choreo as a String. 

		@param String - (optional, integer) Specify the ID of a vote object to retrieve just that object's record.
		*/
		public void set_ObjectID(String value) {
			this.setInput("ObjectID", value);	
		}

		/** 
		Set the value of the Option input for this Choreo. 

		@param String - (optional, string) The way a particular person voted. The value corresponds to the key of an option returned on the Vote Choreo. See documentation for details.
		*/
		public void set_Option(String value) {
			this.setInput("Option", value);
		}



		/** 
		Set the value of the Order input for this Choreo. 

		@param String - (optional, string) You can order the results by date using fieldname (ascending) or -fieldname (descending), where "fieldname" is either startdate or enddate.
		*/
		public void set_Order(String value) {
			this.setInput("Order", value);
		}



		/** 
		Set the value of the Person input for this Choreo. 

		@param Integer - (optional, integer) The person making this vote. This is an ID number.
		*/
		public void set_Person(Integer value) {
			this.setInput("Person", value);
		}

		/** 
		Set the value of the Person input for this Choreo as a String. 

		@param String - (optional, integer) The person making this vote. This is an ID number.
		*/
		public void set_Person(String value) {
			this.setInput("Person", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) Specify the format of the response. Default is JSON, but XML is also possible.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the Vote input for this Choreo. 

		@param String - (optional, string) The ID number of the vote that this was part of. This is in the form of an ID number.
		*/
		public void set_Vote(String value) {
			this.setInput("Vote", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the VoteAndVoter Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class VoteAndVoterResultSet extends ResultSet {
		public VoteAndVoterResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The resopnse from GovTrack.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
