package com.temboo.Library.InfluenceExplorer;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
EntityOverview

Returns general information about a particular politician, individual, or organization with a given entity id.
*/
public class EntityOverview extends Choreography {

	/**
	Create a new instance of the EntityOverview Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public EntityOverview(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/InfluenceExplorer/EntityOverview"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return EntityOverviewInputSet
	*/
	public EntityOverviewInputSet newInputSet() {
		return new EntityOverviewInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public EntityOverviewResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new EntityOverviewResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the EntityOverview
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class EntityOverviewInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API key provided by Sunlight Data Services.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Cycle input for this Choreo. 

		@param String - (optional, date) Specify a yyyy-formatted election cycle. Example: 2012, or 2008|2012 to limit results between 2008 and 2012.
		*/
		public void set_Cycle(String value) {
			this.setInput("Cycle", value);
		}



		/** 
		Set the value of the EntityID input for this Choreo. 

		@param String - (required, string) The ID for the Entity that you want to return information for. This ID can be retrieved by running the SearchByName Choreo.
		*/
		public void set_EntityID(String value) {
			this.setInput("EntityID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the EntityOverview Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class EntityOverviewResultSet extends ResultSet {
		public EntityOverviewResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Influence Explorer.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
