package com.temboo.Library.Instagram;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetMediaComments

Retrieves a full list of comments for a specified media object.
*/
public class GetMediaComments extends Choreography {

	/**
	Create a new instance of the GetMediaComments Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetMediaComments(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Instagram/GetMediaComments"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetMediaCommentsInputSet
	*/
	public GetMediaCommentsInputSet newInputSet() {
		return new GetMediaCommentsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetMediaCommentsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetMediaCommentsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetMediaComments
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetMediaCommentsInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (conditional, string) The access token retrieved during the OAuth 2.0 process. Required unless you provide the ClientID.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ClientID input for this Choreo. 

		@param String - (conditional, string) The Client ID provided by Instagram after registering your application. Required unless you provide the AccessToken.
		*/
		public void set_ClientID(String value) {
			this.setInput("ClientID", value);
		}



		/** 
		Set the value of the MediaID input for this Choreo. 

		@param Integer - (required, integer) The ID of the media object that you want to get comments for. For example, a valid MediaID could be 3.
		*/
		public void set_MediaID(Integer value) {
			this.setInput("MediaID", value);
		}

		/** 
		Set the value of the MediaID input for this Choreo as a String. 

		@param String - (required, integer) The ID of the media object that you want to get comments for. For example, a valid MediaID could be 3.
		*/
		public void set_MediaID(String value) {
			this.setInput("MediaID", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetMediaComments Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetMediaCommentsResultSet extends ResultSet {
		public GetMediaCommentsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Instagram.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
