package com.temboo.Library.Instagram;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetRecentMediaForUser

Retrieves the most recent media published by a user.
*/
public class GetRecentMediaForUser extends Choreography {

	/**
	Create a new instance of the GetRecentMediaForUser Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetRecentMediaForUser(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Instagram/GetRecentMediaForUser"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetRecentMediaForUserInputSet
	*/
	public GetRecentMediaForUserInputSet newInputSet() {
		return new GetRecentMediaForUserInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetRecentMediaForUserResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetRecentMediaForUserResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetRecentMediaForUser
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetRecentMediaForUserInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The access token retrieved during the OAuth 2.0 process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the Count input for this Choreo. 

		@param Integer - (optional, integer) Count of media to return.
		*/
		public void set_Count(Integer value) {
			this.setInput("Count", value);
		}

		/** 
		Set the value of the Count input for this Choreo as a String. 

		@param String - (optional, integer) Count of media to return.
		*/
		public void set_Count(String value) {
			this.setInput("Count", value);	
		}

		/** 
		Set the value of the MaxID input for this Choreo. 

		@param Integer - (optional, integer) Return media liked before this id.
		*/
		public void set_MaxID(Integer value) {
			this.setInput("MaxID", value);
		}

		/** 
		Set the value of the MaxID input for this Choreo as a String. 

		@param String - (optional, integer) Return media liked before this id.
		*/
		public void set_MaxID(String value) {
			this.setInput("MaxID", value);	
		}

		/** 
		Set the value of the MinID input for this Choreo. 

		@param Integer - (optional, integer) Returns media later than this min_id.
		*/
		public void set_MinID(Integer value) {
			this.setInput("MinID", value);
		}

		/** 
		Set the value of the MinID input for this Choreo as a String. 

		@param String - (optional, integer) Returns media later than this min_id.
		*/
		public void set_MinID(String value) {
			this.setInput("MinID", value);	
		}

		/** 
		Set the value of the MinTimestamp input for this Choreo. 

		@param String - (optional, date) Returns media after this UNIX timestamp.
		*/
		public void set_MinTimestamp(String value) {
			this.setInput("MinTimestamp", value);
		}



		/** 
		Set the value of the UserID input for this Choreo. 

		@param String - (optional, string) The ID of the user that you want to retrieve. Defaults to 'self' which will return the user associated with the access token.
		*/
		public void set_UserID(String value) {
			this.setInput("UserID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetRecentMediaForUser Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetRecentMediaForUserResultSet extends ResultSet {
		public GetRecentMediaForUserResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Instagram.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
