package com.temboo.Library.Instagram.OAuth;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
FinalizeOAuth

Completes the OAuth 2 process by retrieving a Instagram access token for a user, after they have visited the authorization URL returned by the InitializeOAuth choreo and clicked "allow."
*/
public class FinalizeOAuth extends Choreography {

	/**
	Create a new instance of the FinalizeOAuth Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public FinalizeOAuth(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Instagram/OAuth/FinalizeOAuth"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return FinalizeOAuthInputSet
	*/
	public FinalizeOAuthInputSet newInputSet() {
		return new FinalizeOAuthInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public FinalizeOAuthResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new FinalizeOAuthResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the FinalizeOAuth
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class FinalizeOAuthInputSet extends InputSet {
		/** 
		Set the value of the AccountName input for this Choreo. 

		@param String - (required, string) Your Temboo account name.
		*/
		public void set_AccountName(String value) {
			this.setInput("AccountName", value);
		}



		/** 
		Set the value of the AppKeyName input for this Choreo. 

		@param String - (required, string) The name of your Temboo application key.
		*/
		public void set_AppKeyName(String value) {
			this.setInput("AppKeyName", value);
		}



		/** 
		Set the value of the AppKeyValue input for this Choreo. 

		@param String - (required, string) Your Temboo application key.
		*/
		public void set_AppKeyValue(String value) {
			this.setInput("AppKeyValue", value);
		}



		/** 
		Set the value of the CallbackID input for this Choreo. 

		@param String - (required, string) The callback token returned by the InitializeOAuth Choreo. Used to retrieve the authorization code after the user authorizes.
		*/
		public void set_CallbackID(String value) {
			this.setInput("CallbackID", value);
		}



		/** 
		Set the value of the ClientID input for this Choreo. 

		@param String - (required, string) The Client ID provided by Instagram after registering your application.
		*/
		public void set_ClientID(String value) {
			this.setInput("ClientID", value);
		}



		/** 
		Set the value of the ClientSecret input for this Choreo. 

		@param String - (required, string) The Client Secret provided by Instagram after registering your application.
		*/
		public void set_ClientSecret(String value) {
			this.setInput("ClientSecret", value);
		}



		/** 
		Set the value of the Timeout input for this Choreo. 

		@param Integer - (optional, integer) The amount of time (in seconds) to poll your Temboo callback URL to see if your app's user has allowed or denied the request for access. Defaults to 20. Max is 60.
		*/
		public void set_Timeout(Integer value) {
			this.setInput("Timeout", value);
		}

		/** 
		Set the value of the Timeout input for this Choreo as a String. 

		@param String - (optional, integer) The amount of time (in seconds) to poll your Temboo callback URL to see if your app's user has allowed or denied the request for access. Defaults to 20. Max is 60.
		*/
		public void set_Timeout(String value) {
			this.setInput("Timeout", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the FinalizeOAuth Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class FinalizeOAuthResultSet extends ResultSet {
		public FinalizeOAuthResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "AccessToken" output from this Choreo execution

		@return String - (string) The access token for the user that has granted access to your application.
		*/
		public String get_AccessToken() {
			return this.getResult("AccessToken");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Instagram.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
