package com.temboo.Library.Instagram;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
UserFollows

Retrieve the list of users that this user is following.
*/
public class UserFollows extends Choreography {

	/**
	Create a new instance of the UserFollows Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public UserFollows(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Instagram/UserFollows"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return UserFollowsInputSet
	*/
	public UserFollowsInputSet newInputSet() {
		return new UserFollowsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public UserFollowsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new UserFollowsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the UserFollows
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class UserFollowsInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The access token retrieved during the OAuth 2.0 process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the UserID input for this Choreo. 

		@param String - (required, string) The ID of the user that you want to retrieve. Defaults to 'self' which will return the user associated with the access token.
		*/
		public void set_UserID(String value) {
			this.setInput("UserID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the UserFollows Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class UserFollowsResultSet extends ResultSet {
		public UserFollowsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Instagram.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
