package com.temboo.Library.Instagram;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
UserIsFollowedBy

Retrieve the list of users following this user.
*/
public class UserIsFollowedBy extends Choreography {

	/**
	Create a new instance of the UserIsFollowedBy Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public UserIsFollowedBy(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Instagram/UserIsFollowedBy"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return UserIsFollowedByInputSet
	*/
	public UserIsFollowedByInputSet newInputSet() {
		return new UserIsFollowedByInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public UserIsFollowedByResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new UserIsFollowedByResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the UserIsFollowedBy
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class UserIsFollowedByInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (conditional, string) The access token retrieved during the OAuth 2.0 process. Required unless you provide the ClientID.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ClientID input for this Choreo. 

		@param String - (conditional, string) The Client ID provided by Instagram after registering your application. Required unless you provide the AccessToken.
		*/
		public void set_ClientID(String value) {
			this.setInput("ClientID", value);
		}



		/** 
		Set the value of the UserID input for this Choreo. 

		@param String - (required, string) The ID of the user that you want to retrieve. Defaults to 'self' which will return the user associated with the access token.
		*/
		public void set_UserID(String value) {
			this.setInput("UserID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the UserIsFollowedBy Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class UserIsFollowedByResultSet extends ResultSet {
		public UserIsFollowedByResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Instagram.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
