package com.temboo.Library.KhanAcademy.Exercises;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetExercise

Retrieves the specified exercise.
*/
public class GetExercise extends Choreography {

	/**
	Create a new instance of the GetExercise Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetExercise(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/KhanAcademy/Exercises/GetExercise"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetExerciseInputSet
	*/
	public GetExerciseInputSet newInputSet() {
		return new GetExerciseInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetExerciseResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetExerciseResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetExercise
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetExerciseInputSet extends InputSet {
		/** 
		Set the value of the ExerciseName input for this Choreo. 

		@param String - (required, string) The name of the exercise to retrieve (e.g. logarithms_1)
		*/
		public void set_ExerciseName(String value) {
			this.setInput("ExerciseName", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetExercise Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetExerciseResultSet extends ResultSet {
		public GetExerciseResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Khan Academy.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
