package com.temboo.Library.KhanAcademy.Topics;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
TopicTree

Retrieves the hierarchical organization of all topics in the Khan Academy library.
*/
public class TopicTree extends Choreography {

	/**
	Create a new instance of the TopicTree Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public TopicTree(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/KhanAcademy/Topics/TopicTree"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return TopicTreeInputSet
	*/
	public TopicTreeInputSet newInputSet() {
		return new TopicTreeInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public TopicTreeResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new TopicTreeResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the TopicTree
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class TopicTreeInputSet extends InputSet {
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the TopicTree Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class TopicTreeResultSet extends ResultSet {
		public TopicTreeResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Khan Academy.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
