package com.temboo.Library.KhanAcademy.Users;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetVideoLog

Retrieves user log data about a specific video, such as when the log of watching a video was started, how long the session lasted, etc.
*/
public class GetVideoLog extends Choreography {

	/**
	Create a new instance of the GetVideoLog Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetVideoLog(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/KhanAcademy/Users/GetVideoLog"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetVideoLogInputSet
	*/
	public GetVideoLogInputSet newInputSet() {
		return new GetVideoLogInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetVideoLogResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetVideoLogResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetVideoLog
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetVideoLogInputSet extends InputSet {
		/** 
		Set the value of the ConsumerKey input for this Choreo. 

		@param String - (required, string) The Consumer Key provided by Khan Academy.
		*/
		public void set_ConsumerKey(String value) {
			this.setInput("ConsumerKey", value);
		}



		/** 
		Set the value of the ConsumerSecret input for this Choreo. 

		@param String - (required, string) The OAuth Consumer Secret provided by Khan Academy.
		*/
		public void set_ConsumerSecret(String value) {
			this.setInput("ConsumerSecret", value);
		}



		/** 
		Set the value of the Email input for this Choreo. 

		@param String - (optional, string) The email address (coach or student ID) of user. If not provided, defaults to currently logged in user.
		*/
		public void set_Email(String value) {
			this.setInput("Email", value);
		}



		/** 
		Set the value of the EndTime input for this Choreo. 

		@param String - (optional, string) The date/time to end searching for logs in UTC format: YYYY-mm-ddTHH:MM:SS (e.g., 2011-10-18T02:41:53).
		*/
		public void set_EndTime(String value) {
			this.setInput("EndTime", value);
		}



		/** 
		Set the value of the OAuthTokenSecret input for this Choreo. 

		@param String - (required, string) The OAuth Token Secret retrieved during the OAuth process.
		*/
		public void set_OAuthTokenSecret(String value) {
			this.setInput("OAuthTokenSecret", value);
		}



		/** 
		Set the value of the OAuthToken input for this Choreo. 

		@param String - (required, string) The OAuth Token retrieved during the OAuth process.
		*/
		public void set_OAuthToken(String value) {
			this.setInput("OAuthToken", value);
		}



		/** 
		Set the value of the StartTime input for this Choreo. 

		@param String - (optional, string) The date/time to start searching for logs in UTC format: YYYY-mm-ddTHH:MM:SS (e.g., 2011-10-18T02:41:53).
		*/
		public void set_StartTime(String value) {
			this.setInput("StartTime", value);
		}



		/** 
		Set the value of the YouTubeID input for this Choreo. 

		@param String - (required, string) The YouTube ID of the video for which you want to retrieve information.
		*/
		public void set_YouTubeID(String value) {
			this.setInput("YouTubeID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetVideoLog Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetVideoLogResultSet extends ResultSet {
		public GetVideoLogResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Khan Academy.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
