package com.temboo.Library.KhanAcademy.Videos;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetVideoExercises

Retrieves all the exercises associated with a given video.
*/
public class GetVideoExercises extends Choreography {

	/**
	Create a new instance of the GetVideoExercises Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetVideoExercises(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/KhanAcademy/Videos/GetVideoExercises"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetVideoExercisesInputSet
	*/
	public GetVideoExercisesInputSet newInputSet() {
		return new GetVideoExercisesInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetVideoExercisesResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetVideoExercisesResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetVideoExercises
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetVideoExercisesInputSet extends InputSet {
		/** 
		Set the value of the YouTubeID input for this Choreo. 

		@param String - (required, string) The Youtube ID of the video for which you want data.
		*/
		public void set_YouTubeID(String value) {
			this.setInput("YouTubeID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetVideoExercises Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetVideoExercisesResultSet extends ResultSet {
		public GetVideoExercisesResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Khan Academy.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
