package com.temboo.Library.Kiva.Lenders;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetLenderDetails

Returns details for lenders.
*/
public class GetLenderDetails extends Choreography {

	/**
	Create a new instance of the GetLenderDetails Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetLenderDetails(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Kiva/Lenders/GetLenderDetails"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetLenderDetailsInputSet
	*/
	public GetLenderDetailsInputSet newInputSet() {
		return new GetLenderDetailsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetLenderDetailsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetLenderDetailsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetLenderDetails
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetLenderDetailsInputSet extends InputSet {
		/** 
		Set the value of the AppID input for this Choreo. 

		@param String - (optional, string) Your unique application ID, usually in reverse DNS notation.
		*/
		public void set_AppID(String value) {
			this.setInput("AppID", value);
		}



		/** 
		Set the value of the LenderName input for this Choreo. 

		@param String - (required, string) List of comma-delimited lender names for which to return details. Maximum list items: 50.
		*/
		public void set_LenderName(String value) {
			this.setInput("LenderName", value);
		}



		/** 
		Set the value of the ResponseType input for this Choreo. 

		@param String - (optional, string) Output returned can be XML or JSON. Defaults to JSON.
		*/
		public void set_ResponseType(String value) {
			this.setInput("ResponseType", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetLenderDetails Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetLenderDetailsResultSet extends ResultSet {
		public GetLenderDetailsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Kiva.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
