package com.temboo.Library.Klout.Identity;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ByGooglePlusID

Performs a lookup for a user's identity using a Google+ ID.
*/
public class ByGooglePlusID extends Choreography {

	/**
	Create a new instance of the ByGooglePlusID Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ByGooglePlusID(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Klout/Identity/ByGooglePlusID"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ByGooglePlusIDInputSet
	*/
	public ByGooglePlusIDInputSet newInputSet() {
		return new ByGooglePlusIDInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ByGooglePlusIDResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ByGooglePlusIDResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ByGooglePlusID
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ByGooglePlusIDInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Klout.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the GooglePlusID input for this Choreo. 

		@param Integer - (required, integer) The numeric ID for a Google+ user.
		*/
		public void set_GooglePlusID(Integer value) {
			this.setInput("GooglePlusID", value);
		}

		/** 
		Set the value of the GooglePlusID input for this Choreo as a String. 

		@param String - (required, integer) The numeric ID for a Google+ user.
		*/
		public void set_GooglePlusID(String value) {
			this.setInput("GooglePlusID", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ByGooglePlusID Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ByGooglePlusIDResultSet extends ResultSet {
		public ByGooglePlusIDResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Klout.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
