package com.temboo.Library.Labs.Social;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
UpdateAllStatuses

Shares a post across multiple social networks such as Facebook, Tumblr, and Twitter.
*/
public class UpdateAllStatuses extends Choreography {

	/**
	Create a new instance of the UpdateAllStatuses Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public UpdateAllStatuses(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Labs/Social/UpdateAllStatuses"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return UpdateAllStatusesInputSet
	*/
	public UpdateAllStatusesInputSet newInputSet() {
		return new UpdateAllStatusesInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public UpdateAllStatusesResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new UpdateAllStatusesResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the UpdateAllStatuses
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class UpdateAllStatusesInputSet extends InputSet {
		/** 
		Set the value of the APICredentials input for this Choreo. 

		@param String - (required, json) A list of credentials for the APIs you wish to access. See Choreo documentation for formatting examples.
		*/
		public void set_APICredentials(String value) {
			this.setInput("APICredentials", value);
		}



		/** 
		Set the value of the Message input for this Choreo. 

		@param String - (required, string) The message to be posted across social networks.
		*/
		public void set_Message(String value) {
			this.setInput("Message", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the UpdateAllStatuses Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class UpdateAllStatusesResultSet extends ResultSet {
		public UpdateAllStatusesResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) A list of results for each API.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
