package com.temboo.Library.LastFm.Album;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetShouts

Retrieves a list of shouts for a specified album.
*/
public class GetShouts extends Choreography {

	/**
	Create a new instance of the GetShouts Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetShouts(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/LastFm/Album/GetShouts"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetShoutsInputSet
	*/
	public GetShoutsInputSet newInputSet() {
		return new GetShoutsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetShoutsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetShoutsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetShouts
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetShoutsInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) Your Last.fm API Key.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Album input for this Choreo. 

		@param String - (conditional, string) The album title. Required unless providing MbID.
		*/
		public void set_Album(String value) {
			this.setInput("Album", value);
		}



		/** 
		Set the value of the Artist input for this Choreo. 

		@param String - (conditional, string) The artist name. Required unless providing MbID.
		*/
		public void set_Artist(String value) {
			this.setInput("Artist", value);
		}



		/** 
		Set the value of the AutoCorrect input for this Choreo. 

		@param Boolean - (optional, boolean) Transform misspelled artist names into correct artist names. The corrected artist name will be returned in the response. Defaults to 0.
		*/
		public void set_AutoCorrect(Boolean value) {
			this.setInput("AutoCorrect", value);
		}

		/** 
		Set the value of the AutoCorrect input for this Choreo as a String. 

		@param String - (optional, boolean) Transform misspelled artist names into correct artist names. The corrected artist name will be returned in the response. Defaults to 0.
		*/
		public void set_AutoCorrect(String value) {
			this.setInput("AutoCorrect", value);	
		}

		/** 
		Set the value of the MbID input for this Choreo. 

		@param String - (conditional, string) The musicbrainz id for the album. Required unless providing the Album and Artist.
		*/
		public void set_MbID(String value) {
			this.setInput("MbID", value);
		}



		/** 
		Set the value of the Page input for this Choreo. 

		@param Integer - (optional, integer) The page number to fetch. Defaults to first page.
		*/
		public void set_Page(Integer value) {
			this.setInput("Page", value);
		}

		/** 
		Set the value of the Page input for this Choreo as a String. 

		@param String - (optional, integer) The page number to fetch. Defaults to first page.
		*/
		public void set_Page(String value) {
			this.setInput("Page", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetShouts Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetShoutsResultSet extends ResultSet {
		public GetShoutsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Last.fm.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
