package com.temboo.Library.LastFm.Artist;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetSimilar

Retrieves a list of all the artists similar to the specified artist.
*/
public class GetSimilar extends Choreography {

	/**
	Create a new instance of the GetSimilar Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetSimilar(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/LastFm/Artist/GetSimilar"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetSimilarInputSet
	*/
	public GetSimilarInputSet newInputSet() {
		return new GetSimilarInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetSimilarResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetSimilarResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetSimilar
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetSimilarInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) Your Last.fm API Key.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Artist input for this Choreo. 

		@param String - (conditional, string) The artist name. Required unless providing MbID.
		*/
		public void set_Artist(String value) {
			this.setInput("Artist", value);
		}



		/** 
		Set the value of the AutoCorrect input for this Choreo. 

		@param Boolean - (optional, boolean) Transform misspelled artist names into correct artist names. The corrected artist name will be returned in the response. Defaults to 0.
		*/
		public void set_AutoCorrect(Boolean value) {
			this.setInput("AutoCorrect", value);
		}

		/** 
		Set the value of the AutoCorrect input for this Choreo as a String. 

		@param String - (optional, boolean) Transform misspelled artist names into correct artist names. The corrected artist name will be returned in the response. Defaults to 0.
		*/
		public void set_AutoCorrect(String value) {
			this.setInput("AutoCorrect", value);	
		}

		/** 
		Set the value of the Limit input for this Choreo. 

		@param Integer - (optional, integer) The number of results to fetch per page. Defaults to 50.
		*/
		public void set_Limit(Integer value) {
			this.setInput("Limit", value);
		}

		/** 
		Set the value of the Limit input for this Choreo as a String. 

		@param String - (optional, integer) The number of results to fetch per page. Defaults to 50.
		*/
		public void set_Limit(String value) {
			this.setInput("Limit", value);	
		}

		/** 
		Set the value of the MbID input for this Choreo. 

		@param String - (conditional, string) The musicbrainz id for the artist. Required unless providing Artist.
		*/
		public void set_MbID(String value) {
			this.setInput("MbID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetSimilar Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetSimilarResultSet extends ResultSet {
		public GetSimilarResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Last.fm.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
