package com.temboo.Library.LastFm.User;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetArtistTracks

Retrieves a list of tracks by a given artist scrobbled by this user, including scrobble time.
*/
public class GetArtistTracks extends Choreography {

	/**
	Create a new instance of the GetArtistTracks Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetArtistTracks(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/LastFm/User/GetArtistTracks"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetArtistTracksInputSet
	*/
	public GetArtistTracksInputSet newInputSet() {
		return new GetArtistTracksInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetArtistTracksResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetArtistTracksResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetArtistTracks
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetArtistTracksInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) Your Last.fm API Key.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Artist input for this Choreo. 

		@param String - (required, string) The artist name you are interested in.
		*/
		public void set_Artist(String value) {
			this.setInput("Artist", value);
		}



		/** 
		Set the value of the EndTimestamp input for this Choreo. 

		@param String - (optional, date) A unix timestamp to end at.
		*/
		public void set_EndTimestamp(String value) {
			this.setInput("EndTimestamp", value);
		}



		/** 
		Set the value of the Page input for this Choreo. 

		@param Integer - (optional, integer) The page number to fetch. Defaults to 1.
		*/
		public void set_Page(Integer value) {
			this.setInput("Page", value);
		}

		/** 
		Set the value of the Page input for this Choreo as a String. 

		@param String - (optional, integer) The page number to fetch. Defaults to 1.
		*/
		public void set_Page(String value) {
			this.setInput("Page", value);	
		}

		/** 
		Set the value of the StartTimestamp input for this Choreo. 

		@param String - (optional, date) A unix timestamp to start at.
		*/
		public void set_StartTimestamp(String value) {
			this.setInput("StartTimestamp", value);
		}



		/** 
		Set the value of the User input for this Choreo. 

		@param String - (required, string) The last.fm username to fetch the recent tracks of.
		*/
		public void set_User(String value) {
			this.setInput("User", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetArtistTracks Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetArtistTracksResultSet extends ResultSet {
		public GetArtistTracksResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Last.fm.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
