package com.temboo.Library.LastFm.User;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetEvents

Retrieves a list of upcoming events that a user is attending.
*/
public class GetEvents extends Choreography {

	/**
	Create a new instance of the GetEvents Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetEvents(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/LastFm/User/GetEvents"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetEventsInputSet
	*/
	public GetEventsInputSet newInputSet() {
		return new GetEventsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetEventsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetEventsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetEvents
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetEventsInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (string) Your Last.fm API Key.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the FestivalsOnly input for this Choreo. 

		@param Boolean - (optional, boolean) Whether only festivals should be returned, or all events. Defaults to 0 to return all events.
		*/
		public void set_FestivalsOnly(Boolean value) {
			this.setInput("FestivalsOnly", value);
		}

		/** 
		Set the value of the FestivalsOnly input for this Choreo as a String. 

		@param String - (optional, boolean) Whether only festivals should be returned, or all events. Defaults to 0 to return all events.
		*/
		public void set_FestivalsOnly(String value) {
			this.setInput("FestivalsOnly", value);	
		}

		/** 
		Set the value of the Limit input for this Choreo. 

		@param Integer - (optional, integer) The number of results to fetch per page. Defaults to 50.
		*/
		public void set_Limit(Integer value) {
			this.setInput("Limit", value);
		}

		/** 
		Set the value of the Limit input for this Choreo as a String. 

		@param String - (optional, integer) The number of results to fetch per page. Defaults to 50.
		*/
		public void set_Limit(String value) {
			this.setInput("Limit", value);	
		}

		/** 
		Set the value of the Page input for this Choreo. 

		@param Integer - (optional, integer) The page number to fetch. Defaults to 1.
		*/
		public void set_Page(Integer value) {
			this.setInput("Page", value);
		}

		/** 
		Set the value of the Page input for this Choreo as a String. 

		@param String - (optional, integer) The page number to fetch. Defaults to 1.
		*/
		public void set_Page(String value) {
			this.setInput("Page", value);	
		}

		/** 
		Set the value of the User input for this Choreo. 

		@param String - (string) The user to fetch the events for.
		*/
		public void set_User(String value) {
			this.setInput("User", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetEvents Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetEventsResultSet extends ResultSet {
		public GetEventsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (XML) The response from Last.fm.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
