package com.temboo.Library.LastFm.User;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetInfo

Get information about a user profile.
*/
public class GetInfo extends Choreography {

	/**
	Create a new instance of the GetInfo Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetInfo(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/LastFm/User/GetInfo"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetInfoInputSet
	*/
	public GetInfoInputSet newInputSet() {
		return new GetInfoInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetInfoResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetInfoResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetInfo
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetInfoInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) Your Last.fm API Key.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the User input for this Choreo. 

		@param String - (required, string) The user to fetch info for.
		*/
		public void set_User(String value) {
			this.setInput("User", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetInfo Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetInfoResultSet extends ResultSet {
		public GetInfoResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Last.fm.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
