package com.temboo.Library.LinkedIn.Companies;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetCompanyProfileByID

Retrieve a company profile by ID.
*/
public class GetCompanyProfileByID extends Choreography {

	/**
	Create a new instance of the GetCompanyProfileByID Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetCompanyProfileByID(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/LinkedIn/Companies/GetCompanyProfileByID"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetCompanyProfileByIDInputSet
	*/
	public GetCompanyProfileByIDInputSet newInputSet() {
		return new GetCompanyProfileByIDInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetCompanyProfileByIDResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetCompanyProfileByIDResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetCompanyProfileByID
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetCompanyProfileByIDInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by LinkedIn (AKA the OAuth Consumer Key).
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the AccessTokenSecret input for this Choreo. 

		@param String - (required, string) The Access Token Secret retrieved during the OAuth process.
		*/
		public void set_AccessTokenSecret(String value) {
			this.setInput("AccessTokenSecret", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token retrieved during the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the CompanyID input for this Choreo. 

		@param Integer - (required, integer) A LinkedIn assigned ID associated with the company that you want to retrieve.
		*/
		public void set_CompanyID(Integer value) {
			this.setInput("CompanyID", value);
		}

		/** 
		Set the value of the CompanyID input for this Choreo as a String. 

		@param String - (required, integer) A LinkedIn assigned ID associated with the company that you want to retrieve.
		*/
		public void set_CompanyID(String value) {
			this.setInput("CompanyID", value);	
		}

		/** 
		Set the value of the SecretKey input for this Choreo. 

		@param String - (required, string) The Secret Key provided by LinkedIn (AKA the OAuth Consumer Secret).
		*/
		public void set_SecretKey(String value) {
			this.setInput("SecretKey", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetCompanyProfileByID Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetCompanyProfileByIDResultSet extends ResultSet {
		public GetCompanyProfileByIDResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from LinkedIn in XML format.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
