package com.temboo.Library.LinkedIn.Jobs;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
DeleteJobBookmark

Delete a job bookmark by specifying a job ID.
*/
public class DeleteJobBookmark extends Choreography {

	/**
	Create a new instance of the DeleteJobBookmark Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DeleteJobBookmark(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/LinkedIn/Jobs/DeleteJobBookmark"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DeleteJobBookmarkInputSet
	*/
	public DeleteJobBookmarkInputSet newInputSet() {
		return new DeleteJobBookmarkInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DeleteJobBookmarkResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DeleteJobBookmarkResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DeleteJobBookmark
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DeleteJobBookmarkInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by LinkedIn (AKA the OAuth Consumer Key).
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the AccessTokenSecret input for this Choreo. 

		@param String - (required, string) The Access Token Secret retrieved during the OAuth process.
		*/
		public void set_AccessTokenSecret(String value) {
			this.setInput("AccessTokenSecret", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token retrieved during the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the JobID input for this Choreo. 

		@param Integer - (required, integer) Enter a LinkedIn job ID.
		*/
		public void set_JobID(Integer value) {
			this.setInput("JobID", value);
		}

		/** 
		Set the value of the JobID input for this Choreo as a String. 

		@param String - (required, integer) Enter a LinkedIn job ID.
		*/
		public void set_JobID(String value) {
			this.setInput("JobID", value);	
		}

		/** 
		Set the value of the SecretKey input for this Choreo. 

		@param String - (required, string) The Secret Key provided by LinkedIn (AKA the OAuth Consumer Secret).
		*/
		public void set_SecretKey(String value) {
			this.setInput("SecretKey", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DeleteJobBookmark Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DeleteJobBookmarkResultSet extends ResultSet {
		public DeleteJobBookmarkResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) Stores the response from LinkedIn. Note that for a successful delete operation, no content is a returned and this output variable should be empty.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
