package com.temboo.Library.LinkedIn.Jobs;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
SearchJobsByJobTitle

Retrieve jobs matching specified job title.
*/
public class SearchJobsByJobTitle extends Choreography {

	/**
	Create a new instance of the SearchJobsByJobTitle Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public SearchJobsByJobTitle(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/LinkedIn/Jobs/SearchJobsByJobTitle"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return SearchJobsByJobTitleInputSet
	*/
	public SearchJobsByJobTitleInputSet newInputSet() {
		return new SearchJobsByJobTitleInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public SearchJobsByJobTitleResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new SearchJobsByJobTitleResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the SearchJobsByJobTitle
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class SearchJobsByJobTitleInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by LinkedIn (AKA the OAuth Consumer Key).
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the AccessTokenSecret input for this Choreo. 

		@param String - (required, string) The Access Token Secret retrieved during the OAuth process.
		*/
		public void set_AccessTokenSecret(String value) {
			this.setInput("AccessTokenSecret", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token retrieved during the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the Count input for this Choreo. 

		@param Integer - (optional, integer) Specify the number of jobs to be returned.  Default is 10.  The maximum is 20.
		*/
		public void set_Count(Integer value) {
			this.setInput("Count", value);
		}

		/** 
		Set the value of the Count input for this Choreo as a String. 

		@param String - (optional, integer) Specify the number of jobs to be returned.  Default is 10.  The maximum is 20.
		*/
		public void set_Count(String value) {
			this.setInput("Count", value);	
		}

		/** 
		Set the value of the JobTitle input for this Choreo. 

		@param Integer - (required, integer) Search by job title.
		*/
		public void set_JobTitle(Integer value) {
			this.setInput("JobTitle", value);
		}

		/** 
		Set the value of the JobTitle input for this Choreo as a String. 

		@param String - (required, integer) Search by job title.
		*/
		public void set_JobTitle(String value) {
			this.setInput("JobTitle", value);	
		}

		/** 
		Set the value of the SecretKey input for this Choreo. 

		@param String - (required, string) The Secret Key provided by LinkedIn (AKA the OAuth Consumer Secret).
		*/
		public void set_SecretKey(String value) {
			this.setInput("SecretKey", value);
		}



		/** 
		Set the value of the Sort input for this Choreo. 

		@param String - (optional, string) Specify the ordering of results. Enter R (for relationship from job to member); DA (dated posted in ascending order); DO (job posted in descending order).
		*/
		public void set_Sort(String value) {
			this.setInput("Sort", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the SearchJobsByJobTitle Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class SearchJobsByJobTitleResultSet extends ResultSet {
		public SearchJobsByJobTitleResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from LinkedIn in XML format.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
