package com.temboo.Library.LinkedIn.Jobs;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
SearchJobsByZipcodeAndCountryCode

Retrieve jobs filtered by zipcode (postal code) and country code.
*/
public class SearchJobsByZipcodeAndCountryCode extends Choreography {

	/**
	Create a new instance of the SearchJobsByZipcodeAndCountryCode Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public SearchJobsByZipcodeAndCountryCode(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/LinkedIn/Jobs/SearchJobsByZipcodeAndCountryCode"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return SearchJobsByZipcodeAndCountryCodeInputSet
	*/
	public SearchJobsByZipcodeAndCountryCodeInputSet newInputSet() {
		return new SearchJobsByZipcodeAndCountryCodeInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public SearchJobsByZipcodeAndCountryCodeResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new SearchJobsByZipcodeAndCountryCodeResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the SearchJobsByZipcodeAndCountryCode
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class SearchJobsByZipcodeAndCountryCodeInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by LinkedIn (AKA the OAuth Consumer Key).
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the AccessTokenSecret input for this Choreo. 

		@param String - (required, string) The Access Token Secret retrieved during the OAuth process.
		*/
		public void set_AccessTokenSecret(String value) {
			this.setInput("AccessTokenSecret", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token retrieved during the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the Count input for this Choreo. 

		@param Integer - (optional, integer) Specify the number of jobs to be returned.  Default is 10.  The maximum is 20.
		*/
		public void set_Count(Integer value) {
			this.setInput("Count", value);
		}

		/** 
		Set the value of the Count input for this Choreo as a String. 

		@param String - (optional, integer) Specify the number of jobs to be returned.  Default is 10.  The maximum is 20.
		*/
		public void set_Count(String value) {
			this.setInput("Count", value);	
		}

		/** 
		Set the value of the CountryCode input for this Choreo. 

		@param String - (optional, string) Enter an ISO 3166 country code.  Default is set to U.S. (US).
		*/
		public void set_CountryCode(String value) {
			this.setInput("CountryCode", value);
		}



		/** 
		Set the value of the PostalCode input for this Choreo. 

		@param Integer - (required, integer) Enter a postal (zip) code.  Don't forget to also set the CountryCode variable.
		*/
		public void set_PostalCode(Integer value) {
			this.setInput("PostalCode", value);
		}

		/** 
		Set the value of the PostalCode input for this Choreo as a String. 

		@param String - (required, integer) Enter a postal (zip) code.  Don't forget to also set the CountryCode variable.
		*/
		public void set_PostalCode(String value) {
			this.setInput("PostalCode", value);	
		}

		/** 
		Set the value of the SecretKey input for this Choreo. 

		@param String - (required, string) The Secret Key provided by LinkedIn (AKA the OAuth Consumer Secret).
		*/
		public void set_SecretKey(String value) {
			this.setInput("SecretKey", value);
		}



		/** 
		Set the value of the Sort input for this Choreo. 

		@param String - (optional, string) Specify the ordering of results. Enter R (for relationship from job to member); DA (dated posted in ascending order); DO (job posted in descending order).
		*/
		public void set_Sort(String value) {
			this.setInput("Sort", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the SearchJobsByZipcodeAndCountryCode Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class SearchJobsByZipcodeAndCountryCodeResultSet extends ResultSet {
		public SearchJobsByZipcodeAndCountryCodeResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from LinkedIn in XML format.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
