package com.temboo.Library.LinkedIn.PeopleAndConnections;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetConnectionsByMemberID

Retrieve all connections linked to a  member ID.
*/
public class GetConnectionsByMemberID extends Choreography {

	/**
	Create a new instance of the GetConnectionsByMemberID Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetConnectionsByMemberID(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/LinkedIn/PeopleAndConnections/GetConnectionsByMemberID"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetConnectionsByMemberIDInputSet
	*/
	public GetConnectionsByMemberIDInputSet newInputSet() {
		return new GetConnectionsByMemberIDInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetConnectionsByMemberIDResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetConnectionsByMemberIDResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetConnectionsByMemberID
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetConnectionsByMemberIDInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by LinkedIn (AKA the OAuth Consumer Key).
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the AccessTokenSecret input for this Choreo. 

		@param String - (required, string) The Access Token Secret retrieved during the OAuth process.
		*/
		public void set_AccessTokenSecret(String value) {
			this.setInput("AccessTokenSecret", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token retrieved during the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the MemberID input for this Choreo. 

		@param Integer - (required, integer) Enter a LinkedIn Member ID.
		*/
		public void set_MemberID(Integer value) {
			this.setInput("MemberID", value);
		}

		/** 
		Set the value of the MemberID input for this Choreo as a String. 

		@param String - (required, integer) Enter a LinkedIn Member ID.
		*/
		public void set_MemberID(String value) {
			this.setInput("MemberID", value);	
		}

		/** 
		Set the value of the SecretKey input for this Choreo. 

		@param String - (required, string) The Secret Key provided by LinkedIn (AKA the OAuth Consumer Secret).
		*/
		public void set_SecretKey(String value) {
			this.setInput("SecretKey", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetConnectionsByMemberID Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetConnectionsByMemberIDResultSet extends ResultSet {
		public GetConnectionsByMemberIDResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from LinkedIn in XML format.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
