package com.temboo.Library.LinkedIn.ShareAndSocialStream;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetShare

Retrieves a newly created shared item.
*/
public class GetShare extends Choreography {

	/**
	Create a new instance of the GetShare Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetShare(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/LinkedIn/ShareAndSocialStream/GetShare"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetShareInputSet
	*/
	public GetShareInputSet newInputSet() {
		return new GetShareInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetShareResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetShareResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetShare
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetShareInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by LinkedIn (AKA the OAuth Consumer Key).
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the AccessTokenSecret input for this Choreo. 

		@param String - (required, string) The Access Token Secret retrieved during the OAuth process.
		*/
		public void set_AccessTokenSecret(String value) {
			this.setInput("AccessTokenSecret", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token retrieved during the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the SecretKey input for this Choreo. 

		@param String - (required, string) The Secret Key provided by LinkedIn (AKA the OAuth Consumer Secret).
		*/
		public void set_SecretKey(String value) {
			this.setInput("SecretKey", value);
		}



		/** 
		Set the value of the UpdateKey input for this Choreo. 

		@param String - (required, string) The UpdateKey used to retrieve the share. This is returned by the CreateShare Choreo.
		*/
		public void set_UpdateKey(String value) {
			this.setInput("UpdateKey", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetShare Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetShareResultSet extends ResultSet {
		public GetShareResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from LinkedIn.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
