package com.temboo.Library.LittleSis.Entity;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Categories

Retrieves a list of all the Relationships possible among people and organizations in LittleSis.
*/
public class Categories extends Choreography {

	/**
	Create a new instance of the Categories Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Categories(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/LittleSis/Entity/Categories"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CategoriesInputSet
	*/
	public CategoriesInputSet newInputSet() {
		return new CategoriesInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CategoriesResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CategoriesResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Categories
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CategoriesInputSet extends InputSet {
		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format of the response from LittleSis.org. Acceptable inputs: xml or json. Defautls to xml.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Categories Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CategoriesResultSet extends ResultSet {
		public CategoriesResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from LittleSis.org.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
