package com.temboo.Library.LittleSis.Entity;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetEntitiesWithRelationship

Retrieves a list of Entities (person or organization) to which a known relationship exists in LittleSis for any Entity.
*/
public class GetEntitiesWithRelationship extends Choreography {

	/**
	Create a new instance of the GetEntitiesWithRelationship Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetEntitiesWithRelationship(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/LittleSis/Entity/GetEntitiesWithRelationship"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetEntitiesWithRelationshipInputSet
	*/
	public GetEntitiesWithRelationshipInputSet newInputSet() {
		return new GetEntitiesWithRelationshipInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetEntitiesWithRelationshipResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetEntitiesWithRelationshipResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetEntitiesWithRelationship
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetEntitiesWithRelationshipInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key obtained from LittleSis.org.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the CategoryIDs input for this Choreo. 

		@param String - (optional, string) Comma delimited list of category IDs of the categories to which the resulting Entities should belong.
		*/
		public void set_CategoryIDs(String value) {
			this.setInput("CategoryIDs", value);
		}



		/** 
		Set the value of the Current input for this Choreo. 

		@param Integer - (optional, integer) Set to 1 to limit the relationships returned to only past relationships. Set to 0 to limit relationships returned to only current relationships. Defaults to all.
		*/
		public void set_Current(Integer value) {
			this.setInput("Current", value);
		}

		/** 
		Set the value of the Current input for this Choreo as a String. 

		@param String - (optional, integer) Set to 1 to limit the relationships returned to only past relationships. Set to 0 to limit relationships returned to only current relationships. Defaults to all.
		*/
		public void set_Current(String value) {
			this.setInput("Current", value);	
		}

		/** 
		Set the value of the EntityID input for this Choreo. 

		@param Integer - (required, integer) The ID of the person or organization fro which a record is to be returned.
		*/
		public void set_EntityID(Integer value) {
			this.setInput("EntityID", value);
		}

		/** 
		Set the value of the EntityID input for this Choreo as a String. 

		@param String - (required, integer) The ID of the person or organization fro which a record is to be returned.
		*/
		public void set_EntityID(String value) {
			this.setInput("EntityID", value);	
		}

		/** 
		Set the value of the Number input for this Choreo. 

		@param Integer - (optional, integer) Specifies what number of results to show. Used in conjunction with Page parameter, a Number of 20 and a Page of 6 will show results 100-120.
		*/
		public void set_Number(Integer value) {
			this.setInput("Number", value);
		}

		/** 
		Set the value of the Number input for this Choreo as a String. 

		@param String - (optional, integer) Specifies what number of results to show. Used in conjunction with Page parameter, a Number of 20 and a Page of 6 will show results 100-120.
		*/
		public void set_Number(String value) {
			this.setInput("Number", value);	
		}

		/** 
		Set the value of the Order input for this Choreo. 

		@param Integer - (optional, integer) Specifies what order the given entity must have in the relationship.
		*/
		public void set_Order(Integer value) {
			this.setInput("Order", value);
		}

		/** 
		Set the value of the Order input for this Choreo as a String. 

		@param String - (optional, integer) Specifies what order the given entity must have in the relationship.
		*/
		public void set_Order(String value) {
			this.setInput("Order", value);	
		}

		/** 
		Set the value of the Page input for this Choreo. 

		@param Integer - (optional, integer) Specifies what page of results to show. Used in conjunction with Number parameter. A number of 20 and a Page of 6 will show results 100-120.
		*/
		public void set_Page(Integer value) {
			this.setInput("Page", value);
		}

		/** 
		Set the value of the Page input for this Choreo as a String. 

		@param String - (optional, integer) Specifies what page of results to show. Used in conjunction with Number parameter. A number of 20 and a Page of 6 will show results 100-120.
		*/
		public void set_Page(String value) {
			this.setInput("Page", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) Format of the response returned by LittleSis.org. Acceptable inputs: xml or json. Defaults to xml
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the SortBy input for this Choreo. 

		@param String - (optional, string) Defaults to sorting by entity, which returns a list of relationships grouped by related entity. Specify another sort order for the results. Acceptable inputs: category or relationship.
		*/
		public void set_SortBy(String value) {
			this.setInput("SortBy", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetEntitiesWithRelationship Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetEntitiesWithRelationshipResultSet extends ResultSet {
		public GetEntitiesWithRelationshipResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from LittleSis.org.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
