package com.temboo.Library.LittleSis.Entity;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetListsByEntity

Retrieves a list of Lists in LittleSis the given Entity (person or organization) belongs to.
*/
public class GetListsByEntity extends Choreography {

	/**
	Create a new instance of the GetListsByEntity Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetListsByEntity(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/LittleSis/Entity/GetListsByEntity"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetListsByEntityInputSet
	*/
	public GetListsByEntityInputSet newInputSet() {
		return new GetListsByEntityInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetListsByEntityResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetListsByEntityResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetListsByEntity
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetListsByEntityInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key obtained from LittleSis.org.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the EntityID input for this Choreo. 

		@param Integer - (required, integer) The ID of the record to be returned.
		*/
		public void set_EntityID(Integer value) {
			this.setInput("EntityID", value);
		}

		/** 
		Set the value of the EntityID input for this Choreo as a String. 

		@param String - (required, integer) The ID of the record to be returned.
		*/
		public void set_EntityID(String value) {
			this.setInput("EntityID", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) Format of the response returned by LittleSis.org. Acceptable inputs: xml or json. Defaults to xml
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetListsByEntity Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetListsByEntityResultSet extends ResultSet {
		public GetListsByEntityResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from LittleSis.org.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
