package com.temboo.Library.MailChimp;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ListMergeVars

Get field names from a MailChimp list.
*/
public class ListMergeVars extends Choreography {

	/**
	Create a new instance of the ListMergeVars Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListMergeVars(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/MailChimp/ListMergeVars"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListMergeVarsInputSet
	*/
	public ListMergeVarsInputSet newInputSet() {
		return new ListMergeVarsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListMergeVarsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListMergeVarsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListMergeVars
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListMergeVarsInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Mailchimp.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the ListId input for this Choreo. 

		@param String - (required, string) The id of the Mailchimp list associated with the merge vars to retrieve.
		*/
		public void set_ListId(String value) {
			this.setInput("ListId", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) Indicates the desired format for the response. Accepted values are "json" or "xml" (the default).
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListMergeVars Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListMergeVarsResultSet extends ResultSet {
		public ListMergeVarsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Mailchimp. Corresponds to the format specified in the ResponseFormat parameter. Defaults to "xml".
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
