package com.temboo.Library.MailChimp;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Ping

Test connection to MailChimp services.
*/
public class Ping extends Choreography {

	/**
	Create a new instance of the Ping Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Ping(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/MailChimp/Ping"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return PingInputSet
	*/
	public PingInputSet newInputSet() {
		return new PingInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public PingResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new PingResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Ping
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class PingInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Mailchimp
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Ping Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class PingResultSet extends ResultSet {
		public PingResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (string) The response from Mailchimp.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
