package com.temboo.Library.NOAA;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
WeatherByCenterPointSubgridSummarized

Retrieve weather information for a rectangle defined by a center point and distances in the latitudinal and longitudinal directions.
*/
public class WeatherByCenterPointSubgridSummarized extends Choreography {

	/**
	Create a new instance of the WeatherByCenterPointSubgridSummarized Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public WeatherByCenterPointSubgridSummarized(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/NOAA/WeatherByCenterPointSubgridSummarized"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return WeatherByCenterPointSubgridSummarizedInputSet
	*/
	public WeatherByCenterPointSubgridSummarizedInputSet newInputSet() {
		return new WeatherByCenterPointSubgridSummarizedInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public WeatherByCenterPointSubgridSummarizedResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new WeatherByCenterPointSubgridSummarizedResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the WeatherByCenterPointSubgridSummarized
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class WeatherByCenterPointSubgridSummarizedInputSet extends InputSet {
		/** 
		Set the value of the CenterPointLatitude input for this Choreo. 

		@param BigDecimal - (required, decimal) Enter the latitude specifying the rectangle or the grid center that defines the area being queried. North latitude is positive.
		*/
		public void set_CenterPointLatitude(BigDecimal value) {
			this.setInput("CenterPointLatitude", value);
		}

		/** 
		Set the value of the CenterPointLatitude input for this Choreo as a String. 

		@param String - (required, decimal) Enter the latitude specifying the rectangle or the grid center that defines the area being queried. North latitude is positive.
		*/
		public void set_CenterPointLatitude(String value) {
			this.setInput("CenterPointLatitude", value);	
		}

		/** 
		Set the value of the CenterPointLongitude input for this Choreo. 

		@param BigDecimal - (required, decimal) Enter the longitute specifying the rectangle or the grid center that defines the area being queried. West longitude is negative.
		*/
		public void set_CenterPointLongitude(BigDecimal value) {
			this.setInput("CenterPointLongitude", value);
		}

		/** 
		Set the value of the CenterPointLongitude input for this Choreo as a String. 

		@param String - (required, decimal) Enter the longitute specifying the rectangle or the grid center that defines the area being queried. West longitude is negative.
		*/
		public void set_CenterPointLongitude(String value) {
			this.setInput("CenterPointLongitude", value);	
		}

		/** 
		Set the value of the Format input for this Choreo. 

		@param String - (required, string) Specify a timespan for which NDFD data will be summarized. Enter: 24 hourly, for a 24 hour summary, or: 12 hourly, for a 12 hour weather summary.
		*/
		public void set_Format(String value) {
			this.setInput("Format", value);
		}



		/** 
		Set the value of the LatitudeDistance input for this Choreo. 

		@param BigDecimal - (required, decimal) Specify the distance from the center point in the latitudinal direction to the rectangle's East/West oriented sides.
		*/
		public void set_LatitudeDistance(BigDecimal value) {
			this.setInput("LatitudeDistance", value);
		}

		/** 
		Set the value of the LatitudeDistance input for this Choreo as a String. 

		@param String - (required, decimal) Specify the distance from the center point in the latitudinal direction to the rectangle's East/West oriented sides.
		*/
		public void set_LatitudeDistance(String value) {
			this.setInput("LatitudeDistance", value);	
		}

		/** 
		Set the value of the LongitudeDistance input for this Choreo. 

		@param BigDecimal - (required, decimal) Specify the distance from the center point in the longitudinal direction to the rectangle's North/South oriented side.
		*/
		public void set_LongitudeDistance(BigDecimal value) {
			this.setInput("LongitudeDistance", value);
		}

		/** 
		Set the value of the LongitudeDistance input for this Choreo as a String. 

		@param String - (required, decimal) Specify the distance from the center point in the longitudinal direction to the rectangle's North/South oriented side.
		*/
		public void set_LongitudeDistance(String value) {
			this.setInput("LongitudeDistance", value);	
		}

		/** 
		Set the value of the NumberOfDays input for this Choreo. 

		@param Integer - (optional, integer) Specify the number of days to retieve data for. If null, data from the earliest date in the dabase is returned.
		*/
		public void set_NumberOfDays(Integer value) {
			this.setInput("NumberOfDays", value);
		}

		/** 
		Set the value of the NumberOfDays input for this Choreo as a String. 

		@param String - (optional, integer) Specify the number of days to retieve data for. If null, data from the earliest date in the dabase is returned.
		*/
		public void set_NumberOfDays(String value) {
			this.setInput("NumberOfDays", value);	
		}

		/** 
		Set the value of the SquareResolution input for this Choreo. 

		@param BigDecimal - (optional, decimal) Enter desired data resolution in kilometers.  Default is 5km.
		*/
		public void set_SquareResolution(BigDecimal value) {
			this.setInput("SquareResolution", value);
		}

		/** 
		Set the value of the SquareResolution input for this Choreo as a String. 

		@param String - (optional, decimal) Enter desired data resolution in kilometers.  Default is 5km.
		*/
		public void set_SquareResolution(String value) {
			this.setInput("SquareResolution", value);	
		}

		/** 
		Set the value of the StartDate input for this Choreo. 

		@param String - (required, date) Enter the start time for retrieval of NDWD data in following format: 2004-04-27 If null, the earliest date in the database is returned.
		*/
		public void set_StartDate(String value) {
			this.setInput("StartDate", value);
		}



		/** 
		Set the value of the Unit input for this Choreo. 

		@param String - (optional, string) Enter the unit format the data will be displayed in. Default is: e, for Standard English (U.S. Standard).  Or: m, for Metric (SI Units).
		*/
		public void set_Unit(String value) {
			this.setInput("Unit", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the WeatherByCenterPointSubgridSummarized Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class WeatherByCenterPointSubgridSummarizedResultSet extends ResultSet {
		public WeatherByCenterPointSubgridSummarizedResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) Response from NDFD servers.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
