package com.temboo.Library.NOAA;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
WeatherByCitiesUnsummarized

Retrieve weather information for a specific list of cities.
*/
public class WeatherByCitiesUnsummarized extends Choreography {

	/**
	Create a new instance of the WeatherByCitiesUnsummarized Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public WeatherByCitiesUnsummarized(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/NOAA/WeatherByCitiesUnsummarized"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return WeatherByCitiesUnsummarizedInputSet
	*/
	public WeatherByCitiesUnsummarizedInputSet newInputSet() {
		return new WeatherByCitiesUnsummarizedInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public WeatherByCitiesUnsummarizedResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new WeatherByCitiesUnsummarizedResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the WeatherByCitiesUnsummarized
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class WeatherByCitiesUnsummarizedInputSet extends InputSet {
		/** 
		Set the value of the CitiesLevel input for this Choreo. 

		@param Integer - (required, integer) Enter a city grouping number. For example: enter 1, to obtain weather information for primary U.S. cities. See documentation for additional numbers.
		*/
		public void set_CitiesLevel(Integer value) {
			this.setInput("CitiesLevel", value);
		}

		/** 
		Set the value of the CitiesLevel input for this Choreo as a String. 

		@param String - (required, integer) Enter a city grouping number. For example: enter 1, to obtain weather information for primary U.S. cities. See documentation for additional numbers.
		*/
		public void set_CitiesLevel(String value) {
			this.setInput("CitiesLevel", value);	
		}

		/** 
		Set the value of the EndDate input for this Choreo. 

		@param String - (required, date) Enter the end time for retrieval of NDWD information in UTC format. Time must be today's date, or a future date.  Format: 2004-04-27T12:00.
		*/
		public void set_EndDate(String value) {
			this.setInput("EndDate", value);
		}



		/** 
		Set the value of the NDFDParameterName input for this Choreo. 

		@param String - (optional, string) Enter an additional weather parameter in the following format: phail=phail. Use only if Product is set to: glance.
		*/
		public void set_NDFDParameterName(String value) {
			this.setInput("NDFDParameterName", value);
		}



		/** 
		Set the value of the Product input for this Choreo. 

		@param String - (required, string) Enter one of two parameters: time-series (to return all data between the Begin and End time parameters); glance for a subset of 5 often used parameters
		*/
		public void set_Product(String value) {
			this.setInput("Product", value);
		}



		/** 
		Set the value of the StartDate input for this Choreo. 

		@param String - (optional, date) Enter the start time for retrieval of NDWD information in UTC format. If null, the earliest date in the database is returned. Format: 2004-04-27T12:00.
		*/
		public void set_StartDate(String value) {
			this.setInput("StartDate", value);
		}



		/** 
		Set the value of the Unit input for this Choreo. 

		@param String - (optional, string) Enter the unit format the data will be displayed in. Default is: e, for Standard English (U.S. Standard).  Or: m, for Metric (SI Units).
		*/
		public void set_Unit(String value) {
			this.setInput("Unit", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the WeatherByCitiesUnsummarized Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class WeatherByCitiesUnsummarizedResultSet extends ResultSet {
		public WeatherByCitiesUnsummarizedResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) Response from NDFD servers.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
