package com.temboo.Library.NOAA;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
WeatherForPointsOnLineSummarized

Retrieve weather information for all points on a line defined by a set of latitude and longitude coordinates.
*/
public class WeatherForPointsOnLineSummarized extends Choreography {

	/**
	Create a new instance of the WeatherForPointsOnLineSummarized Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public WeatherForPointsOnLineSummarized(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/NOAA/WeatherForPointsOnLineSummarized"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return WeatherForPointsOnLineSummarizedInputSet
	*/
	public WeatherForPointsOnLineSummarizedInputSet newInputSet() {
		return new WeatherForPointsOnLineSummarizedInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public WeatherForPointsOnLineSummarizedResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new WeatherForPointsOnLineSummarizedResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the WeatherForPointsOnLineSummarized
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class WeatherForPointsOnLineSummarizedInputSet extends InputSet {
		/** 
		Set the value of the Endpoint1Latitude input for this Choreo. 

		@param Integer - (required, integer) Enter the latitude of the first endpoint of the line for which weather data is requested. North latitude is positive.
		*/
		public void set_Endpoint1Latitude(Integer value) {
			this.setInput("Endpoint1Latitude", value);
		}

		/** 
		Set the value of the Endpoint1Latitude input for this Choreo as a String. 

		@param String - (required, integer) Enter the latitude of the first endpoint of the line for which weather data is requested. North latitude is positive.
		*/
		public void set_Endpoint1Latitude(String value) {
			this.setInput("Endpoint1Latitude", value);	
		}

		/** 
		Set the value of the Endpoint1Longitude input for this Choreo. 

		@param Integer - (required, integer) Enter the longitude of the first endpoint of the line for which weather data is requested. West longitude is negative.
		*/
		public void set_Endpoint1Longitude(Integer value) {
			this.setInput("Endpoint1Longitude", value);
		}

		/** 
		Set the value of the Endpoint1Longitude input for this Choreo as a String. 

		@param String - (required, integer) Enter the longitude of the first endpoint of the line for which weather data is requested. West longitude is negative.
		*/
		public void set_Endpoint1Longitude(String value) {
			this.setInput("Endpoint1Longitude", value);	
		}

		/** 
		Set the value of the Endpoint2Latitude input for this Choreo. 

		@param Integer - (required, integer) Enter the latitude of the second endpoint of the line for which weather data is requested. North latitude is positive.
		*/
		public void set_Endpoint2Latitude(Integer value) {
			this.setInput("Endpoint2Latitude", value);
		}

		/** 
		Set the value of the Endpoint2Latitude input for this Choreo as a String. 

		@param String - (required, integer) Enter the latitude of the second endpoint of the line for which weather data is requested. North latitude is positive.
		*/
		public void set_Endpoint2Latitude(String value) {
			this.setInput("Endpoint2Latitude", value);	
		}

		/** 
		Set the value of the Endpoint2Longitude input for this Choreo. 

		@param Integer - (required, integer) Enter the longitude of the second endpoint of the line for which weather data is requested. West longitude is negative.
		*/
		public void set_Endpoint2Longitude(Integer value) {
			this.setInput("Endpoint2Longitude", value);
		}

		/** 
		Set the value of the Endpoint2Longitude input for this Choreo as a String. 

		@param String - (required, integer) Enter the longitude of the second endpoint of the line for which weather data is requested. West longitude is negative.
		*/
		public void set_Endpoint2Longitude(String value) {
			this.setInput("Endpoint2Longitude", value);	
		}

		/** 
		Set the value of the Format input for this Choreo. 

		@param String - (required, string) Specify a timespan for which NDFD data will be summarized. Enter: 24 hourly, for a 24 hour summary, or: 12 hourly, for a 12 hour weather summary.
		*/
		public void set_Format(String value) {
			this.setInput("Format", value);
		}



		/** 
		Set the value of the NumberOfDays input for this Choreo. 

		@param Integer - (optional, integer) Specify the number of days to retieve data for. If null, data from the earliest date in the dabase is returned.
		*/
		public void set_NumberOfDays(Integer value) {
			this.setInput("NumberOfDays", value);
		}

		/** 
		Set the value of the NumberOfDays input for this Choreo as a String. 

		@param String - (optional, integer) Specify the number of days to retieve data for. If null, data from the earliest date in the dabase is returned.
		*/
		public void set_NumberOfDays(String value) {
			this.setInput("NumberOfDays", value);	
		}

		/** 
		Set the value of the StartDate input for this Choreo. 

		@param String - (optional, date) Enter the start time for retrieval of NDWD information in UTC format. If null, the earliest date in the database is returned. Format: 2004-04-27T12:00.
		*/
		public void set_StartDate(String value) {
			this.setInput("StartDate", value);
		}



		/** 
		Set the value of the Unit input for this Choreo. 

		@param String - (optional, string) Enter the unit format the data will be displayed in. Default is: e, for Standard English (U.S. Standard).  Or: m, for Metric (SI Units).
		*/
		public void set_Unit(String value) {
			this.setInput("Unit", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the WeatherForPointsOnLineSummarized Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class WeatherForPointsOnLineSummarizedResultSet extends ResultSet {
		public WeatherForPointsOnLineSummarizedResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) Response from NDFD servers.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
