package com.temboo.Library.NPR.StationFinder;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
SearchByCallLetters

Retrieves local NPR member stations based on uniquely identifying call letters.
*/
public class SearchByCallLetters extends Choreography {

	/**
	Create a new instance of the SearchByCallLetters Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public SearchByCallLetters(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/NPR/StationFinder/SearchByCallLetters"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return SearchByCallLettersInputSet
	*/
	public SearchByCallLettersInputSet newInputSet() {
		return new SearchByCallLettersInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public SearchByCallLettersResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new SearchByCallLettersResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the SearchByCallLetters
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class SearchByCallLettersInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by NPR.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Band input for this Choreo. 

		@param String - (optional, string) Enter AM or FM.
		*/
		public void set_Band(String value) {
			this.setInput("Band", value);
		}



		/** 
		Set the value of the CallLetters input for this Choreo. 

		@param String - (required, string) Enter the unique identifier associated with a station.
		*/
		public void set_CallLetters(String value) {
			this.setInput("CallLetters", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the SearchByCallLetters Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class SearchByCallLettersResultSet extends ResultSet {
		public SearchByCallLettersResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) 
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
