package com.temboo.Library.NPR.StationFinder;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
SearchByLocation

Retrieves local NPR member stations near the specified lattitude and longitude location coordinates.
*/
public class SearchByLocation extends Choreography {

	/**
	Create a new instance of the SearchByLocation Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public SearchByLocation(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/NPR/StationFinder/SearchByLocation"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return SearchByLocationInputSet
	*/
	public SearchByLocationInputSet newInputSet() {
		return new SearchByLocationInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public SearchByLocationResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new SearchByLocationResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the SearchByLocation
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class SearchByLocationInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by NPR.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Lattitude input for this Choreo. 

		@param BigDecimal - (required, decimal) The lattitude point of a station's location. Must be used together with the longitude parameter. This must be a positive value.
		*/
		public void set_Lattitude(BigDecimal value) {
			this.setInput("Lattitude", value);
		}

		/** 
		Set the value of the Lattitude input for this Choreo as a String. 

		@param String - (required, decimal) The lattitude point of a station's location. Must be used together with the longitude parameter. This must be a positive value.
		*/
		public void set_Lattitude(String value) {
			this.setInput("Lattitude", value);	
		}

		/** 
		Set the value of the Longitude input for this Choreo. 

		@param BigDecimal - (required, decimal) The longitude point of a station's location. Must be used together with the lattitude parameter. This must be a positive value.
		*/
		public void set_Longitude(BigDecimal value) {
			this.setInput("Longitude", value);
		}

		/** 
		Set the value of the Longitude input for this Choreo as a String. 

		@param String - (required, decimal) The longitude point of a station's location. Must be used together with the lattitude parameter. This must be a positive value.
		*/
		public void set_Longitude(String value) {
			this.setInput("Longitude", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the SearchByLocation Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class SearchByLocationResultSet extends ResultSet {
		public SearchByLocationResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) 
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
