package com.temboo.Library.NPR.StoryFinder;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Topics

Retrieves a list of NPR topics and corresponding IDs. Also used to look up the IDs of specific NPR topics by specifying them as an optional parameter.
*/
public class Topics extends Choreography {

	/**
	Create a new instance of the Topics Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Topics(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/NPR/StoryFinder/Topics"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return TopicsInputSet
	*/
	public TopicsInputSet newInputSet() {
		return new TopicsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public TopicsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new TopicsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Topics
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class TopicsInputSet extends InputSet {
		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that you want the response to be in. Set to json or xml (the default). Note that when specifying Topic, only xml is returned.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the StoryCountAll input for this Choreo. 

		@param Integer - (optional, integer) Returns only items with at least this number of associated stories.
		*/
		public void set_StoryCountAll(Integer value) {
			this.setInput("StoryCountAll", value);
		}

		/** 
		Set the value of the StoryCountAll input for this Choreo as a String. 

		@param String - (optional, integer) Returns only items with at least this number of associated stories.
		*/
		public void set_StoryCountAll(String value) {
			this.setInput("StoryCountAll", value);	
		}

		/** 
		Set the value of the StoryCountMonth input for this Choreo. 

		@param Integer - (optional, integer) Returns only items with at least this number of associated stories published in the last month.
		*/
		public void set_StoryCountMonth(Integer value) {
			this.setInput("StoryCountMonth", value);
		}

		/** 
		Set the value of the StoryCountMonth input for this Choreo as a String. 

		@param String - (optional, integer) Returns only items with at least this number of associated stories published in the last month.
		*/
		public void set_StoryCountMonth(String value) {
			this.setInput("StoryCountMonth", value);	
		}

		/** 
		Set the value of the StoryCountToday input for this Choreo. 

		@param Integer - (optional, integer) Returns only items with at least this number of associated stories published today.
		*/
		public void set_StoryCountToday(Integer value) {
			this.setInput("StoryCountToday", value);
		}

		/** 
		Set the value of the StoryCountToday input for this Choreo as a String. 

		@param String - (optional, integer) Returns only items with at least this number of associated stories published today.
		*/
		public void set_StoryCountToday(String value) {
			this.setInput("StoryCountToday", value);	
		}

		/** 
		Set the value of the Topic input for this Choreo. 

		@param String - (optional, string) The specific topic title to return. Multiple topics can be specified separated by commas (i.e. Energy,Europe). Topic IDs are returned when this input is used.
		*/
		public void set_Topic(String value) {
			this.setInput("Topic", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Topics Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class TopicsResultSet extends ResultSet {
		public TopicsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Id" output from this Choreo execution

		@return String - (integer) The ID of the topic. This is only returned when the Topic input is specified. When topics are specified, this will be a list of IDs separated by commas.
		*/
		public String get_Id() {
			return this.getResult("Id");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from NPR.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
