package com.temboo.Library.NYTimes.CampaignFinance.IndependentExpenditures;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
IndependentExpenditureOnlyCommittees

Retrieves 20 of the most recent committees that have registered as independent expenditure-only (commonly known as "Super PACs").
*/
public class IndependentExpenditureOnlyCommittees extends Choreography {

	/**
	Create a new instance of the IndependentExpenditureOnlyCommittees Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public IndependentExpenditureOnlyCommittees(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/NYTimes/CampaignFinance/IndependentExpenditures/IndependentExpenditureOnlyCommittees"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return IndependentExpenditureOnlyCommitteesInputSet
	*/
	public IndependentExpenditureOnlyCommitteesInputSet newInputSet() {
		return new IndependentExpenditureOnlyCommitteesInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public IndependentExpenditureOnlyCommitteesResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new IndependentExpenditureOnlyCommitteesResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the IndependentExpenditureOnlyCommittees
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class IndependentExpenditureOnlyCommitteesInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by NY Times.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the CampaignCycle input for this Choreo. 

		@param Integer - (required, integer) Enter the campaign cycle year in YYYY format.  This must be an even year.
		*/
		public void set_CampaignCycle(Integer value) {
			this.setInput("CampaignCycle", value);
		}

		/** 
		Set the value of the CampaignCycle input for this Choreo as a String. 

		@param String - (required, integer) Enter the campaign cycle year in YYYY format.  This must be an even year.
		*/
		public void set_CampaignCycle(String value) {
			this.setInput("CampaignCycle", value);	
		}

		/** 
		Set the value of the Offset input for this Choreo. 

		@param Integer - (optional, integer) The first 20 results are shown by default. To page through the results, set Offset to the appropriate value (e.g., Offset=40 displays results 41–60).
		*/
		public void set_Offset(Integer value) {
			this.setInput("Offset", value);
		}

		/** 
		Set the value of the Offset input for this Choreo as a String. 

		@param String - (optional, integer) The first 20 results are shown by default. To page through the results, set Offset to the appropriate value (e.g., Offset=40 displays results 41–60).
		*/
		public void set_Offset(String value) {
			this.setInput("Offset", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) Enter json or xml.  Default is json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the IndependentExpenditureOnlyCommittees Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class IndependentExpenditureOnlyCommitteesResultSet extends ResultSet {
		public IndependentExpenditureOnlyCommitteesResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from the NY Times API corresponds to the setting (json, or xml) entered in the ResponseFormat variable.  Default is set to json.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
