package com.temboo.Library.NYTimes.TimesNewswire;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetRecentNewsItems

Retrieves recent news items.
*/
public class GetRecentNewsItems extends Choreography {

	/**
	Create a new instance of the GetRecentNewsItems Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetRecentNewsItems(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/NYTimes/TimesNewswire/GetRecentNewsItems"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetRecentNewsItemsInputSet
	*/
	public GetRecentNewsItemsInputSet newInputSet() {
		return new GetRecentNewsItemsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetRecentNewsItemsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetRecentNewsItemsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetRecentNewsItems
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetRecentNewsItemsInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by NY Times.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Limit input for this Choreo. 

		@param Integer - (optional, integer) The number of results to return. Defaults to 20.
		*/
		public void set_Limit(Integer value) {
			this.setInput("Limit", value);
		}

		/** 
		Set the value of the Limit input for this Choreo as a String. 

		@param String - (optional, integer) The number of results to return. Defaults to 20.
		*/
		public void set_Limit(String value) {
			this.setInput("Limit", value);	
		}

		/** 
		Set the value of the Offset input for this Choreo. 

		@param Integer - (optional, integer) A numeric value indicating the starting point of the result set. This can be used in combination with the Limit input to page through results.
		*/
		public void set_Offset(Integer value) {
			this.setInput("Offset", value);
		}

		/** 
		Set the value of the Offset input for this Choreo as a String. 

		@param String - (optional, integer) A numeric value indicating the starting point of the result set. This can be used in combination with the Limit input to page through results.
		*/
		public void set_Offset(String value) {
			this.setInput("Offset", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and xml.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the Section input for this Choreo. 

		@param String - (optional, string) Limits the set of items by one or more sections. Separate sections by semicolons. Defaults to "all" to get all sections. See Choreo documentation for more options for this input.
		*/
		public void set_Section(String value) {
			this.setInput("Section", value);
		}



		/** 
		Set the value of the Source input for this Choreo. 

		@param String - (optional, string) Limits the set of items by originating source. Set to "nyt" for New York Times items only and "iht" for International Herald Tribune items. Set to "all" for both (the default).
		*/
		public void set_Source(String value) {
			this.setInput("Source", value);
		}



		/** 
		Set the value of the TimePeriod input for this Choreo. 

		@param Integer - (optional, integer) Limits the set of items by time published. Valid range is number of hours, 1–720 (in hours). Defaults to 24.
		*/
		public void set_TimePeriod(Integer value) {
			this.setInput("TimePeriod", value);
		}

		/** 
		Set the value of the TimePeriod input for this Choreo as a String. 

		@param String - (optional, integer) Limits the set of items by time published. Valid range is number of hours, 1–720 (in hours). Defaults to 24.
		*/
		public void set_TimePeriod(String value) {
			this.setInput("TimePeriod", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetRecentNewsItems Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetRecentNewsItemsResultSet extends ResultSet {
		public GetRecentNewsItemsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from the NY Times API.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
