package com.temboo.Library.Netflix;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetDiscQueue

Retrieves the contents of a subscriber's disc queue.
*/
public class GetDiscQueue extends Choreography {

	/**
	Create a new instance of the GetDiscQueue Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetDiscQueue(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Netflix/GetDiscQueue"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetDiscQueueInputSet
	*/
	public GetDiscQueueInputSet newInputSet() {
		return new GetDiscQueueInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetDiscQueueResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetDiscQueueResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetDiscQueue
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetDiscQueueInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Netflix (AKA the OAuth Consumer Key).
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the AccessTokenSecret input for this Choreo. 

		@param String - (required, string) The Access Token Secret retrieved during the OAuth process.
		*/
		public void set_AccessTokenSecret(String value) {
			this.setInput("AccessTokenSecret", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token retrieved during the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the MaxResults input for this Choreo. 

		@param Integer - (optional, integer) Set this to the maximum number of results to return. This number cannot be greater than 500. If you do not specify max_results, the default value is 25
		*/
		public void set_MaxResults(Integer value) {
			this.setInput("MaxResults", value);
		}

		/** 
		Set the value of the MaxResults input for this Choreo as a String. 

		@param String - (optional, integer) Set this to the maximum number of results to return. This number cannot be greater than 500. If you do not specify max_results, the default value is 25
		*/
		public void set_MaxResults(String value) {
			this.setInput("MaxResults", value);	
		}

		/** 
		Set the value of the SharedSecret input for this Choreo. 

		@param String - (required, string) The Shared Secret provided by Netflix (AKA the OAuth Consumer Secret).
		*/
		public void set_SharedSecret(String value) {
			this.setInput("SharedSecret", value);
		}



		/** 
		Set the value of the Sort input for this Choreo. 

		@param String - (optional, string) Use this to specify the sort order for the queue entries. Sort order may be by queue_sequence, date_added, or alphabetical. The default sort order, if you do not specify one, is queue_sequence.
		*/
		public void set_Sort(String value) {
			this.setInput("Sort", value);
		}



		/** 
		Set the value of the StartIndex input for this Choreo. 

		@param Integer - (optional, integer) The offset number of the results from the query.
		*/
		public void set_StartIndex(Integer value) {
			this.setInput("StartIndex", value);
		}

		/** 
		Set the value of the StartIndex input for this Choreo as a String. 

		@param String - (optional, integer) The offset number of the results from the query.
		*/
		public void set_StartIndex(String value) {
			this.setInput("StartIndex", value);	
		}

		/** 
		Set the value of the UpdatedMin input for this Choreo. 

		@param String - (optional, date) If set, the response will include only those items with updated timestamps greater than or equal to the timestamp provided. Specify this value either in Unix time format (seconds since epoch).
		*/
		public void set_UpdatedMin(String value) {
			this.setInput("UpdatedMin", value);
		}



		/** 
		Set the value of the UserID input for this Choreo. 

		@param String - (required, string) The ID associated with the user whose queue information you want to retrieve.
		*/
		public void set_UserID(String value) {
			this.setInput("UserID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetDiscQueue Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetDiscQueueResultSet extends ResultSet {
		public GetDiscQueueResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Netflix.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
