package com.temboo.Library.Netflix;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetRecommendations

Retrieves a list of catalog title recommendations for a subscriber.
*/
public class GetRecommendations extends Choreography {

	/**
	Create a new instance of the GetRecommendations Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetRecommendations(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Netflix/GetRecommendations"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetRecommendationsInputSet
	*/
	public GetRecommendationsInputSet newInputSet() {
		return new GetRecommendationsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetRecommendationsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetRecommendationsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetRecommendations
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetRecommendationsInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Netflix (AKA the OAuth Consumer Key).
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the AccessTokenSecret input for this Choreo. 

		@param String - (required, string) The Access Token Secret retrieved during the OAuth process.
		*/
		public void set_AccessTokenSecret(String value) {
			this.setInput("AccessTokenSecret", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token retrieved during the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the MaxResults input for this Choreo. 

		@param Integer - (optional, integer) Set this to the maximum number of results to return. This number cannot be greater than 500. If you do not specify max_results, the default value is 25
		*/
		public void set_MaxResults(Integer value) {
			this.setInput("MaxResults", value);
		}

		/** 
		Set the value of the MaxResults input for this Choreo as a String. 

		@param String - (optional, integer) Set this to the maximum number of results to return. This number cannot be greater than 500. If you do not specify max_results, the default value is 25
		*/
		public void set_MaxResults(String value) {
			this.setInput("MaxResults", value);	
		}

		/** 
		Set the value of the SharedSecret input for this Choreo. 

		@param String - (required, string) The Shared Secret provided by Netflix (AKA the OAuth Consumer Secret).
		*/
		public void set_SharedSecret(String value) {
			this.setInput("SharedSecret", value);
		}



		/** 
		Set the value of the StartIndex input for this Choreo. 

		@param Integer - (optional, integer) The offset number of the results from the query.
		*/
		public void set_StartIndex(Integer value) {
			this.setInput("StartIndex", value);
		}

		/** 
		Set the value of the StartIndex input for this Choreo as a String. 

		@param String - (optional, integer) The offset number of the results from the query.
		*/
		public void set_StartIndex(String value) {
			this.setInput("StartIndex", value);	
		}

		/** 
		Set the value of the UserID input for this Choreo. 

		@param String - (required, string) The ID associated with the user whose recommendations you want to retrieve.
		*/
		public void set_UserID(String value) {
			this.setInput("UserID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetRecommendations Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetRecommendationsResultSet extends ResultSet {
		public GetRecommendationsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Netflix.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
