package com.temboo.Library.ObadMobileMarketing;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
AddCSVData

Transfer a csv file to add records to a specified group.
*/
public class AddCSVData extends Choreography {

	/**
	Create a new instance of the AddCSVData Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public AddCSVData(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/ObadMobileMarketing/AddCSVData"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return AddCSVDataInputSet
	*/
	public AddCSVDataInputSet newInputSet() {
		return new AddCSVDataInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public AddCSVDataResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new AddCSVDataResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the AddCSVData
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class AddCSVDataInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (string) Private Key for 1 unique distributor - provided by Obad Mobile Marketing
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the ClientID input for this Choreo. 

		@param Integer - (integer) Private Key for 1 unique customer to connect with - provided by Obad Mobile Marketing
		*/
		public void set_ClientID(Integer value) {
			this.setInput("ClientID", value);
		}

		/** 
		Set the value of the ClientID input for this Choreo as a String. 

		@param String - (integer) Private Key for 1 unique customer to connect with - provided by Obad Mobile Marketing
		*/
		public void set_ClientID(String value) {
			this.setInput("ClientID", value);	
		}

		/** 
		Set the value of the Endpoint input for this Choreo. 

		@param String - (string) The base URL for the server you want to access (i.e. http://10.10.10.1). Set this to the appropriate host for the demo sandbox or production.
		*/
		public void set_Endpoint(String value) {
			this.setInput("Endpoint", value);
		}



		/** 
		Set the value of the GroupID input for this Choreo. 

		@param Integer - (integer) Unique ID for the group you want to update
		*/
		public void set_GroupID(Integer value) {
			this.setInput("GroupID", value);
		}

		/** 
		Set the value of the GroupID input for this Choreo as a String. 

		@param String - (integer) Unique ID for the group you want to update
		*/
		public void set_GroupID(String value) {
			this.setInput("GroupID", value);	
		}

		/** 
		Set the value of the Type input for this Choreo. 

		@param String - (string) Specify the desired item list (i.e. camp, coupon, usergroup, shopgroup, or coupongroup). Defaults to 'shopgroup'.
		*/
		public void set_Type(String value) {
			this.setInput("Type", value);
		}



		/** 
		Set the value of the URLSource input for this Choreo. 

		@param String - (string) The URL where you are hosting the CSV data (i.e. http://mybucket.s3.amazonaws.com/my_new_users.csv)
		*/
		public void set_URLSource(String value) {
			this.setInput("URLSource", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the AddCSVData Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class AddCSVDataResultSet extends ResultSet {
		public AddCSVDataResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (XML) The response from Obad
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
