package com.temboo.Library.ObadMobileMarketing;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CouponGroupData

Allows you to add or remove a coupon from a coupon group.
*/
public class CouponGroupData extends Choreography {

	/**
	Create a new instance of the CouponGroupData Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CouponGroupData(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/ObadMobileMarketing/CouponGroupData"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CouponGroupDataInputSet
	*/
	public CouponGroupDataInputSet newInputSet() {
		return new CouponGroupDataInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CouponGroupDataResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CouponGroupDataResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CouponGroupData
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CouponGroupDataInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (string) Private Key for 1 unique distributor - provided by Obad Mobile Marketing
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the ClientID input for this Choreo. 

		@param Integer - (integer) Private Key for 1 unique customer to connect with - provided by Obad Mobile Marketing
		*/
		public void set_ClientID(Integer value) {
			this.setInput("ClientID", value);
		}

		/** 
		Set the value of the ClientID input for this Choreo as a String. 

		@param String - (integer) Private Key for 1 unique customer to connect with - provided by Obad Mobile Marketing
		*/
		public void set_ClientID(String value) {
			this.setInput("ClientID", value);	
		}

		/** 
		Set the value of the CouponGroupID input for this Choreo. 

		@param Integer - (integer) The ID of the coupongroup you need to update
		*/
		public void set_CouponGroupID(Integer value) {
			this.setInput("CouponGroupID", value);
		}

		/** 
		Set the value of the CouponGroupID input for this Choreo as a String. 

		@param String - (integer) The ID of the coupongroup you need to update
		*/
		public void set_CouponGroupID(String value) {
			this.setInput("CouponGroupID", value);	
		}

		/** 
		Set the value of the CouponID input for this Choreo. 

		@param Integer - (integer) The ID of the coupon you need to update
		*/
		public void set_CouponID(Integer value) {
			this.setInput("CouponID", value);
		}

		/** 
		Set the value of the CouponID input for this Choreo as a String. 

		@param String - (integer) The ID of the coupon you need to update
		*/
		public void set_CouponID(String value) {
			this.setInput("CouponID", value);	
		}

		/** 
		Set the value of the Endpoint input for this Choreo. 

		@param String - (string) The base URL for the server you want to access (i.e. http://10.10.10.1). Set this to the appropriate host for the demo sandbox or production.
		*/
		public void set_Endpoint(String value) {
			this.setInput("Endpoint", value);
		}



		/** 
		Set the value of the Mode input for this Choreo. 

		@param Boolean - (optional, boolean) Specify 0 for removing or 1 for adding. Defaults to 1.
		*/
		public void set_Mode(Boolean value) {
			this.setInput("Mode", value);
		}

		/** 
		Set the value of the Mode input for this Choreo as a String. 

		@param String - (optional, boolean) Specify 0 for removing or 1 for adding. Defaults to 1.
		*/
		public void set_Mode(String value) {
			this.setInput("Mode", value);	
		}

		/** 
		Set the value of the CSVData input for this Choreo. 

		@param TembooPath - 
		*/
		public void set_CSVData(TembooPath value) {
			this.setAlias("CSVData", value);
		}
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CouponGroupData Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CouponGroupDataResultSet extends ResultSet {
		public CouponGroupDataResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (XML) The response from Obad
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
