package com.temboo.Library.ObadMobileMarketing;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
EditCoupon

Allows you to create a new coupon or update an existing one.
*/
public class EditCoupon extends Choreography {

	/**
	Create a new instance of the EditCoupon Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public EditCoupon(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/ObadMobileMarketing/EditCoupon"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return EditCouponInputSet
	*/
	public EditCouponInputSet newInputSet() {
		return new EditCouponInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public EditCouponResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new EditCouponResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the EditCoupon
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class EditCouponInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (string) Private Key for 1 unique distributor - provided by Obad Mobile Marketing
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the ClientID input for this Choreo. 

		@param Integer - (integer) Private Key for 1 unique customer to connect with - provided by Obad Mobile Marketing
		*/
		public void set_ClientID(Integer value) {
			this.setInput("ClientID", value);
		}

		/** 
		Set the value of the ClientID input for this Choreo as a String. 

		@param String - (integer) Private Key for 1 unique customer to connect with - provided by Obad Mobile Marketing
		*/
		public void set_ClientID(String value) {
			this.setInput("ClientID", value);	
		}

		/** 
		Set the value of the CouponId input for this Choreo. 

		@param Integer - (integer) The ID of the coupon you need to update.  In creation mode, leave this blank, and the ID will be returned in the response.
		*/
		public void set_CouponId(Integer value) {
			this.setInput("CouponId", value);
		}

		/** 
		Set the value of the CouponId input for this Choreo as a String. 

		@param String - (integer) The ID of the coupon you need to update.  In creation mode, leave this blank, and the ID will be returned in the response.
		*/
		public void set_CouponId(String value) {
			this.setInput("CouponId", value);	
		}

		/** 
		Set the value of the Desc1 input for this Choreo. 

		@param String - (string) Description at the TOP of the coupon
		*/
		public void set_Desc1(String value) {
			this.setInput("Desc1", value);
		}



		/** 
		Set the value of the Desc2 input for this Choreo. 

		@param String - (string) Description at the BOTTOM line 1 of the coupon
		*/
		public void set_Desc2(String value) {
			this.setInput("Desc2", value);
		}



		/** 
		Set the value of the Desc3 input for this Choreo. 

		@param String - (string) Description of the BOTTOM line 2 of the coupon
		*/
		public void set_Desc3(String value) {
			this.setInput("Desc3", value);
		}



		/** 
		Set the value of the Endpoint input for this Choreo. 

		@param String - (string) The base URL for the server you want to access (i.e. http://10.10.10.1). Set this to the appropriate host for the demo sandbox or production.
		*/
		public void set_Endpoint(String value) {
			this.setInput("Endpoint", value);
		}



		/** 
		Set the value of the From input for this Choreo. 

		@param String - (date) The first date that the coupon is available (formatted like YYYY/MM/DD)
		*/
		public void set_From(String value) {
			this.setInput("From", value);
		}



		/** 
		Set the value of the Mode input for this Choreo. 

		@param Boolean - (optional, boolean) Specify the writing mode. Use '0' for creating or '1'  for updating. Defaults to 0.
		*/
		public void set_Mode(Boolean value) {
			this.setInput("Mode", value);
		}

		/** 
		Set the value of the Mode input for this Choreo as a String. 

		@param String - (optional, boolean) Specify the writing mode. Use '0' for creating or '1'  for updating. Defaults to 0.
		*/
		public void set_Mode(String value) {
			this.setInput("Mode", value);	
		}

		/** 
		Set the value of the Title input for this Choreo. 

		@param String - (string) The title of the coupon that will be only used for the console
		*/
		public void set_Title(String value) {
			this.setInput("Title", value);
		}



		/** 
		Set the value of the To input for this Choreo. 

		@param String - (date) The final date that the coupon is available (formatted like YYYY/MM/DD)
		*/
		public void set_To(String value) {
			this.setInput("To", value);
		}



		/** 
		Set the value of the UseOnce input for this Choreo. 

		@param Boolean - (optional, boolean) Use '1' for use and burn coupon one time only and '0' for unlimited use and burn. Defaults to 0.
		*/
		public void set_UseOnce(Boolean value) {
			this.setInput("UseOnce", value);
		}

		/** 
		Set the value of the UseOnce input for this Choreo as a String. 

		@param String - (optional, boolean) Use '1' for use and burn coupon one time only and '0' for unlimited use and burn. Defaults to 0.
		*/
		public void set_UseOnce(String value) {
			this.setInput("UseOnce", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the EditCoupon Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class EditCouponResultSet extends ResultSet {
		public EditCouponResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (XML) The response from Obad
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
