package com.temboo.Library.ObadMobileMarketing;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
EditGroup

Allows you to create a new group or update an existing one.
*/
public class EditGroup extends Choreography {

	/**
	Create a new instance of the EditGroup Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public EditGroup(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/ObadMobileMarketing/EditGroup"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return EditGroupInputSet
	*/
	public EditGroupInputSet newInputSet() {
		return new EditGroupInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public EditGroupResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new EditGroupResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the EditGroup
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class EditGroupInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (string) Private Key for 1 unique distributor - provided by Obad Mobile Marketing
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the ClientID input for this Choreo. 

		@param Integer - (integer) Private Key for 1 unique customer to connect with - provided by Obad Mobile Marketing
		*/
		public void set_ClientID(Integer value) {
			this.setInput("ClientID", value);
		}

		/** 
		Set the value of the ClientID input for this Choreo as a String. 

		@param String - (integer) Private Key for 1 unique customer to connect with - provided by Obad Mobile Marketing
		*/
		public void set_ClientID(String value) {
			this.setInput("ClientID", value);	
		}

		/** 
		Set the value of the Description input for this Choreo. 

		@param String - (string) The description of the group
		*/
		public void set_Description(String value) {
			this.setInput("Description", value);
		}



		/** 
		Set the value of the Endpoint input for this Choreo. 

		@param String - (string) The base URL for the server you want to access (i.e. http://10.10.10.1). Set this to the appropriate host for the demo sandbox or production.
		*/
		public void set_Endpoint(String value) {
			this.setInput("Endpoint", value);
		}



		/** 
		Set the value of the GroupID input for this Choreo. 

		@param Integer - (integer) The id of the group you need to update. In creation mode, leave blank and the id will be returned in the response.
		*/
		public void set_GroupID(Integer value) {
			this.setInput("GroupID", value);
		}

		/** 
		Set the value of the GroupID input for this Choreo as a String. 

		@param String - (integer) The id of the group you need to update. In creation mode, leave blank and the id will be returned in the response.
		*/
		public void set_GroupID(String value) {
			this.setInput("GroupID", value);	
		}

		/** 
		Set the value of the Mode input for this Choreo. 

		@param Boolean - (optional, boolean) Specify 0 for creating and 1 for updating. Defaults to 0.
		*/
		public void set_Mode(Boolean value) {
			this.setInput("Mode", value);
		}

		/** 
		Set the value of the Mode input for this Choreo as a String. 

		@param String - (optional, boolean) Specify 0 for creating and 1 for updating. Defaults to 0.
		*/
		public void set_Mode(String value) {
			this.setInput("Mode", value);	
		}

		/** 
		Set the value of the Title input for this Choreo. 

		@param String - (string) The title of the group
		*/
		public void set_Title(String value) {
			this.setInput("Title", value);
		}



		/** 
		Set the value of the Type input for this Choreo. 

		@param String - (optional, string) The type of group to perform the action on.  Can be usergroup, shopgroup, or coupongroup. Defaults to usergroup.
		*/
		public void set_Type(String value) {
			this.setInput("Type", value);
		}



		/** 
		Set the value of the CSVData input for this Choreo. 

		@param TembooPath - 
		*/
		public void set_CSVData(TembooPath value) {
			this.setAlias("CSVData", value);
		}
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the EditGroup Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class EditGroupResultSet extends ResultSet {
		public EditGroupResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (XML) The response from Obad
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
