package com.temboo.Library.ObadMobileMarketing;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetList

Returns the list and parameters of a specified list type (i.e. campaigns, coupons, user groups, shop groups, or coupons groups).
*/
public class GetList extends Choreography {

	/**
	Create a new instance of the GetList Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetList(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/ObadMobileMarketing/GetList"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetListInputSet
	*/
	public GetListInputSet newInputSet() {
		return new GetListInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetListResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetListResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetList
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetListInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (string) Private Key for 1 unique distributor - provided by Obad Mobile Marketing
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the ClientID input for this Choreo. 

		@param Integer - (integer) Private Key for 1 unique customer to connect with - provided by Obad Mobile Marketing
		*/
		public void set_ClientID(Integer value) {
			this.setInput("ClientID", value);
		}

		/** 
		Set the value of the ClientID input for this Choreo as a String. 

		@param String - (integer) Private Key for 1 unique customer to connect with - provided by Obad Mobile Marketing
		*/
		public void set_ClientID(String value) {
			this.setInput("ClientID", value);	
		}

		/** 
		Set the value of the Endpoint input for this Choreo. 

		@param String - (string) The base URL for the server you want to access (i.e. http://10.10.10.1). Set this to the appropriate host for the demo sandbox or production.
		*/
		public void set_Endpoint(String value) {
			this.setInput("Endpoint", value);
		}



		/** 
		Set the value of the ID input for this Choreo. 

		@param Integer - (optional, integer) Unique ID for an item.  Defaults to 0 which returns ALL.
		*/
		public void set_ID(Integer value) {
			this.setInput("ID", value);
		}

		/** 
		Set the value of the ID input for this Choreo as a String. 

		@param String - (optional, integer) Unique ID for an item.  Defaults to 0 which returns ALL.
		*/
		public void set_ID(String value) {
			this.setInput("ID", value);	
		}

		/** 
		Set the value of the Type input for this Choreo. 

		@param String - (optional, string) Specify the desired item list (i.e. camp, coupon, usergroup, shopgroup, or coupongroup). Defaults to coupon.
		*/
		public void set_Type(String value) {
			this.setInput("Type", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetList Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetListResultSet extends ResultSet {
		public GetListResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (XML) The response from Obad
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
