package com.temboo.Library.ObadMobileMarketing;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ImageCampaign

Transfer an image for updating the email body image or the wap banner of a campaign.
*/
public class ImageCampaign extends Choreography {

	/**
	Create a new instance of the ImageCampaign Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ImageCampaign(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/ObadMobileMarketing/ImageCampaign"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ImageCampaignInputSet
	*/
	public ImageCampaignInputSet newInputSet() {
		return new ImageCampaignInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ImageCampaignResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ImageCampaignResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ImageCampaign
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ImageCampaignInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (string) Private Key for 1 unique distributor - provided by Obad Mobile Marketing
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the CampaignID input for this Choreo. 

		@param Integer - (integer) The ID of the campaign you want to update
		*/
		public void set_CampaignID(Integer value) {
			this.setInput("CampaignID", value);
		}

		/** 
		Set the value of the CampaignID input for this Choreo as a String. 

		@param String - (integer) The ID of the campaign you want to update
		*/
		public void set_CampaignID(String value) {
			this.setInput("CampaignID", value);	
		}

		/** 
		Set the value of the ClientID input for this Choreo. 

		@param Integer - (integer) Private Key for 1 unique customer to connect with - provided by Obad Mobile Marketing
		*/
		public void set_ClientID(Integer value) {
			this.setInput("ClientID", value);
		}

		/** 
		Set the value of the ClientID input for this Choreo as a String. 

		@param String - (integer) Private Key for 1 unique customer to connect with - provided by Obad Mobile Marketing
		*/
		public void set_ClientID(String value) {
			this.setInput("ClientID", value);	
		}

		/** 
		Set the value of the Endpoint input for this Choreo. 

		@param String - (string) The base URL for the server you want to access (i.e. http://10.10.10.1). Set this to the appropriate host for the demo sandbox or production.
		*/
		public void set_Endpoint(String value) {
			this.setInput("Endpoint", value);
		}



		/** 
		Set the value of the Type input for this Choreo. 

		@param String - (optional, string) Specify the desired image type to modify (i.e. mailimage or wapban). Defaults to mailimage.
		*/
		public void set_Type(String value) {
			this.setInput("Type", value);
		}



		/** 
		Set the value of the URLSource input for this Choreo. 

		@param String - (string) The URL where you are hosting the JPG file (i.e. http://mybucket.s3.amazonaws.com/my_image.jpg)
		*/
		public void set_URLSource(String value) {
			this.setInput("URLSource", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ImageCampaign Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ImageCampaignResultSet extends ResultSet {
		public ImageCampaignResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (XML) The response from Obad
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
