package com.temboo.Library.OneLogin.Accounts;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
UpdateAccount

Updates an existing account.
*/
public class UpdateAccount extends Choreography {

	/**
	Create a new instance of the UpdateAccount Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public UpdateAccount(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/OneLogin/Accounts/UpdateAccount"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return UpdateAccountInputSet
	*/
	public UpdateAccountInputSet newInputSet() {
		return new UpdateAccountInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public UpdateAccountResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new UpdateAccountResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the UpdateAccount
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class UpdateAccountInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by OneLogin.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the AccountName input for this Choreo. 

		@param String - (required, string) The account name.
		*/
		public void set_AccountName(String value) {
			this.setInput("AccountName", value);
		}



		/** 
		Set the value of the Address input for this Choreo. 

		@param String - (optional, string) The street address for the new account.
		*/
		public void set_Address(String value) {
			this.setInput("Address", value);
		}



		/** 
		Set the value of the City input for this Choreo. 

		@param String - (optional, string) The city associated with the address.
		*/
		public void set_City(String value) {
			this.setInput("City", value);
		}



		/** 
		Set the value of the Country input for this Choreo. 

		@param String - (optional, string) The country associated with the address of the new account.
		*/
		public void set_Country(String value) {
			this.setInput("Country", value);
		}



		/** 
		Set the value of the Email input for this Choreo. 

		@param String - (required, string) The email address for the new account.
		*/
		public void set_Email(String value) {
			this.setInput("Email", value);
		}



		/** 
		Set the value of the FirstName input for this Choreo. 

		@param String - (required, string) The first name on the new account.
		*/
		public void set_FirstName(String value) {
			this.setInput("FirstName", value);
		}



		/** 
		Set the value of the ID input for this Choreo. 

		@param Integer - (required, integer) The id of the account to update.
		*/
		public void set_ID(Integer value) {
			this.setInput("ID", value);
		}

		/** 
		Set the value of the ID input for this Choreo as a String. 

		@param String - (required, integer) The id of the account to update.
		*/
		public void set_ID(String value) {
			this.setInput("ID", value);	
		}

		/** 
		Set the value of the LastName input for this Choreo. 

		@param String - (required, string) The last name on the new account.
		*/
		public void set_LastName(String value) {
			this.setInput("LastName", value);
		}



		/** 
		Set the value of the Phone input for this Choreo. 

		@param String - (optional, string) The phone number for the new account.
		*/
		public void set_Phone(String value) {
			this.setInput("Phone", value);
		}



		/** 
		Set the value of the Plan input for this Choreo. 

		@param String - (required, string) Indicates which plan the new account has (i.e. enterprise).
		*/
		public void set_Plan(String value) {
			this.setInput("Plan", value);
		}



		/** 
		Set the value of the State input for this Choreo. 

		@param String - (optional, string) The state associated with the address of the new account.
		*/
		public void set_State(String value) {
			this.setInput("State", value);
		}



		/** 
		Set the value of the Zip input for this Choreo. 

		@param String - (optional, string) The postal code associated with the address of the new account.
		*/
		public void set_Zip(String value) {
			this.setInput("Zip", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the UpdateAccount Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class UpdateAccountResultSet extends ResultSet {
		public UpdateAccountResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from OneLogin.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
