package com.temboo.Library.OneLogin.Groups;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ListAll

Retrieves a list of all groups.
*/
public class ListAll extends Choreography {

	/**
	Create a new instance of the ListAll Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListAll(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/OneLogin/Groups/ListAll"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListAllInputSet
	*/
	public ListAllInputSet newInputSet() {
		return new ListAllInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListAllResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListAllResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListAll
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListAllInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by OneLogin.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListAll Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListAllResultSet extends ResultSet {
		public ListAllResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from OneLogin.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
