package com.temboo.Library.OneLogin.Roles;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ShowRole

Retrieves information for a single role.
*/
public class ShowRole extends Choreography {

	/**
	Create a new instance of the ShowRole Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ShowRole(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/OneLogin/Roles/ShowRole"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ShowRoleInputSet
	*/
	public ShowRoleInputSet newInputSet() {
		return new ShowRoleInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ShowRoleResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ShowRoleResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ShowRole
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ShowRoleInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by OneLogin.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the ID input for this Choreo. 

		@param Integer - (required, integer) The id the role you want to return.
		*/
		public void set_ID(Integer value) {
			this.setInput("ID", value);
		}

		/** 
		Set the value of the ID input for this Choreo as a String. 

		@param String - (required, integer) The id the role you want to return.
		*/
		public void set_ID(String value) {
			this.setInput("ID", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ShowRole Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ShowRoleResultSet extends ResultSet {
		public ShowRoleResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from OneLogin.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
