package com.temboo.Library.OneLogin.Users;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ShowUser

Retrieves information for a single user.
*/
public class ShowUser extends Choreography {

	/**
	Create a new instance of the ShowUser Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ShowUser(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/OneLogin/Users/ShowUser"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ShowUserInputSet
	*/
	public ShowUserInputSet newInputSet() {
		return new ShowUserInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ShowUserResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ShowUserResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ShowUser
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ShowUserInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by OneLogin.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the ID input for this Choreo. 

		@param Integer - (required, integer) The id the user you want to return.
		*/
		public void set_ID(Integer value) {
			this.setInput("ID", value);
		}

		/** 
		Set the value of the ID input for this Choreo as a String. 

		@param String - (required, integer) The id the user you want to return.
		*/
		public void set_ID(String value) {
			this.setInput("ID", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ShowUser Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ShowUserResultSet extends ResultSet {
		public ShowUserResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from OneLogin.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
