package com.temboo.Library.Parse.Files;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
AssociateWithObject

Allows you to associate a previously uploaded file with Parse objects.
*/
public class AssociateWithObject extends Choreography {

	/**
	Create a new instance of the AssociateWithObject Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public AssociateWithObject(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Parse/Files/AssociateWithObject"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return AssociateWithObjectInputSet
	*/
	public AssociateWithObjectInputSet newInputSet() {
		return new AssociateWithObjectInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public AssociateWithObjectResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new AssociateWithObjectResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the AssociateWithObject
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class AssociateWithObjectInputSet extends InputSet {
		/** 
		Set the value of the Association input for this Choreo. 

		@param String - (required, json) A JSON string containing the file information that is to be associated with the Parse object. See documentation for formatting examples.
		*/
		public void set_Association(String value) {
			this.setInput("Association", value);
		}



		/** 
		Set the value of the ApplicationID input for this Choreo. 

		@param String - (required, string) The Application ID provided by Parse.
		*/
		public void set_ApplicationID(String value) {
			this.setInput("ApplicationID", value);
		}



		/** 
		Set the value of the ClassName input for this Choreo. 

		@param String - (required, string) The name of the class that a file is being associated with.
		*/
		public void set_ClassName(String value) {
			this.setInput("ClassName", value);
		}



		/** 
		Set the value of the RESTAPIKey input for this Choreo. 

		@param String - (required, string) The REST API Key provided by Parse.
		*/
		public void set_RESTAPIKey(String value) {
			this.setInput("RESTAPIKey", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the AssociateWithObject Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class AssociateWithObjectResultSet extends ResultSet {
		public AssociateWithObjectResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Parse.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
