package com.temboo.Library.Parse.Files;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
DeleteFile

Deletes a file stored on Parse.
*/
public class DeleteFile extends Choreography {

	/**
	Create a new instance of the DeleteFile Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DeleteFile(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Parse/Files/DeleteFile"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DeleteFileInputSet
	*/
	public DeleteFileInputSet newInputSet() {
		return new DeleteFileInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DeleteFileResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DeleteFileResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DeleteFile
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DeleteFileInputSet extends InputSet {
		/** 
		Set the value of the FileName input for this Choreo. 

		@param String - (required, json) The name of the file to delete. Note that this is the name generated and returned by Parse after uploading the file.
		*/
		public void set_FileName(String value) {
			this.setInput("FileName", value);
		}



		/** 
		Set the value of the ApplicationID input for this Choreo. 

		@param String - (required, string) The Application ID provided by Parse.
		*/
		public void set_ApplicationID(String value) {
			this.setInput("ApplicationID", value);
		}



		/** 
		Set the value of the MasterKey input for this Choreo. 

		@param String - (required, string) The Master Key provided by Parse.
		*/
		public void set_MasterKey(String value) {
			this.setInput("MasterKey", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DeleteFile Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DeleteFileResultSet extends ResultSet {
		public DeleteFileResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Parse.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
