package com.temboo.Library.Parse.Files;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
UploadFile

Uploads a file to Parse.
*/
public class UploadFile extends Choreography {

	/**
	Create a new instance of the UploadFile Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public UploadFile(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Parse/Files/UploadFile"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return UploadFileInputSet
	*/
	public UploadFileInputSet newInputSet() {
		return new UploadFileInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public UploadFileResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new UploadFileResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the UploadFile
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class UploadFileInputSet extends InputSet {
		/** 
		Set the value of the FileContents input for this Choreo. 

		@param String - (conditional, string) The Base64-encoded contents of the file you want to upload.
		*/
		public void set_FileContents(String value) {
			this.setInput("FileContents", value);
		}



		/** 
		Set the value of the ApplicationID input for this Choreo. 

		@param String - (required, string) The Application ID provided by Parse.
		*/
		public void set_ApplicationID(String value) {
			this.setInput("ApplicationID", value);
		}



		/** 
		Set the value of the ContentType input for this Choreo. 

		@param String - (required, string) The content type of the file that is being uploaded (i.e. text/plain, image/jpeg, etc).
		*/
		public void set_ContentType(String value) {
			this.setInput("ContentType", value);
		}



		/** 
		Set the value of the FileName input for this Choreo. 

		@param String - (required, string) The name of the file you are uploading to Parse.
		*/
		public void set_FileName(String value) {
			this.setInput("FileName", value);
		}



		/** 
		Set the value of the RESTAPIKey input for this Choreo. 

		@param String - (required, string) The REST API Key provided by Parse.
		*/
		public void set_RESTAPIKey(String value) {
			this.setInput("RESTAPIKey", value);
		}



		/** 
		Set the value of the VaultFile input for this Choreo. 

		@param TembooPath - A path to a vault file to upload. Can be used as an alternative to the FileContents input.
		*/
		public void set_VaultFile(TembooPath value) {
			this.setAlias("VaultFile", value);
		}
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the UploadFile Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class UploadFileResultSet extends ResultSet {
		public UploadFileResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Parse.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
