package com.temboo.Library.Parse.PushNotifications;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
SendNotification

Sends a push notification.
*/
public class SendNotification extends Choreography {

	/**
	Create a new instance of the SendNotification Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public SendNotification(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Parse/PushNotifications/SendNotification"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return SendNotificationInputSet
	*/
	public SendNotificationInputSet newInputSet() {
		return new SendNotificationInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public SendNotificationResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new SendNotificationResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the SendNotification
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class SendNotificationInputSet extends InputSet {
		/** 
		Set the value of the Notifcation input for this Choreo. 

		@param String - (required, json) A JSON string containing the push notification data. See documentation for syntax examples.
		*/
		public void set_Notifcation(String value) {
			this.setInput("Notifcation", value);
		}



		/** 
		Set the value of the ApplicationID input for this Choreo. 

		@param String - (required, string) The Application ID provided by Parse.
		*/
		public void set_ApplicationID(String value) {
			this.setInput("ApplicationID", value);
		}



		/** 
		Set the value of the RESTAPIKey input for this Choreo. 

		@param String - (required, string) The REST API Key provided by Parse.
		*/
		public void set_RESTAPIKey(String value) {
			this.setInput("RESTAPIKey", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the SendNotification Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class SendNotificationResultSet extends ResultSet {
		public SendNotificationResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Parse.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
