package com.temboo.Library.Parse.Roles;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
RetrieveRole

Deletes a specified role.
*/
public class RetrieveRole extends Choreography {

	/**
	Create a new instance of the RetrieveRole Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public RetrieveRole(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Parse/Roles/RetrieveRole"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return RetrieveRoleInputSet
	*/
	public RetrieveRoleInputSet newInputSet() {
		return new RetrieveRoleInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public RetrieveRoleResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new RetrieveRoleResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the RetrieveRole
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class RetrieveRoleInputSet extends InputSet {
		/** 
		Set the value of the ObjectID input for this Choreo. 

		@param String - (required, json) The ID of the role to be retrieved.
		*/
		public void set_ObjectID(String value) {
			this.setInput("ObjectID", value);
		}



		/** 
		Set the value of the ApplicationID input for this Choreo. 

		@param String - (required, string) The Application ID provided by Parse.
		*/
		public void set_ApplicationID(String value) {
			this.setInput("ApplicationID", value);
		}



		/** 
		Set the value of the RESTAPIKey input for this Choreo. 

		@param String - (required, string) The REST API Key provided by Parse.
		*/
		public void set_RESTAPIKey(String value) {
			this.setInput("RESTAPIKey", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the RetrieveRole Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class RetrieveRoleResultSet extends ResultSet {
		public RetrieveRoleResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Parse.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
