package com.temboo.Library.Parse.Users;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Login

Allows your application to authenticate a given user; returns user information, user-provided fields, and a session token.
*/
public class Login extends Choreography {

	/**
	Create a new instance of the Login Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Login(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Parse/Users/Login"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return LoginInputSet
	*/
	public LoginInputSet newInputSet() {
		return new LoginInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public LoginResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new LoginResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Login
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class LoginInputSet extends InputSet {
		/** 
		Set the value of the ApplicationID input for this Choreo. 

		@param String - (required, string) The Application ID provided by Parse.
		*/
		public void set_ApplicationID(String value) {
			this.setInput("ApplicationID", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, string) The password for the user that is loggin in.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the RESTAPIKey input for this Choreo. 

		@param String - (required, string) The REST API Key provided by Parse.
		*/
		public void set_RESTAPIKey(String value) {
			this.setInput("RESTAPIKey", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) The username for the user that is authenticating.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Login Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class LoginResultSet extends ResultSet {
		public LoginResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Parse.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
