package com.temboo.Library.Parse.Users;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
SignUp

Allows your application to sign up a new user.
*/
public class SignUp extends Choreography {

	/**
	Create a new instance of the SignUp Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public SignUp(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Parse/Users/SignUp"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return SignUpInputSet
	*/
	public SignUpInputSet newInputSet() {
		return new SignUpInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public SignUpResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new SignUpResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the SignUp
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class SignUpInputSet extends InputSet {
		/** 
		Set the value of the User input for this Choreo. 

		@param String - (required, json) A JSON string containing the new user information.
		*/
		public void set_User(String value) {
			this.setInput("User", value);
		}



		/** 
		Set the value of the ApplicationID input for this Choreo. 

		@param String - (required, string) The Application ID provided by Parse.
		*/
		public void set_ApplicationID(String value) {
			this.setInput("ApplicationID", value);
		}



		/** 
		Set the value of the RESTAPIKey input for this Choreo. 

		@param String - (required, string) The REST API Key provided by Parse.
		*/
		public void set_RESTAPIKey(String value) {
			this.setInput("RESTAPIKey", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the SignUp Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class SignUpResultSet extends ResultSet {
		public SignUpResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Parse.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
