package com.temboo.Library.Patch;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
FindLocationByName

Return Patch location information for a specified U.S. region.
*/
public class FindLocationByName extends Choreography {

	/**
	Create a new instance of the FindLocationByName Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public FindLocationByName(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Patch/FindLocationByName"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return FindLocationByNameInputSet
	*/
	public FindLocationByNameInputSet newInputSet() {
		return new FindLocationByNameInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public FindLocationByNameResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new FindLocationByNameResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the FindLocationByName
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class FindLocationByNameInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) A valid API key provided by Patch.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the APISecret input for this Choreo. 

		@param String - (required, string) The API shared secret provided by Patch.
		*/
		public void set_APISecret(String value) {
			this.setInput("APISecret", value);
		}



		/** 
		Set the value of the Limit input for this Choreo. 

		@param Integer - (optional, integer) Specify a maximum number of locations to return, between 1 and 100. The default is 10.
		*/
		public void set_Limit(Integer value) {
			this.setInput("Limit", value);
		}

		/** 
		Set the value of the Limit input for this Choreo as a String. 

		@param String - (optional, integer) Specify a maximum number of locations to return, between 1 and 100. The default is 10.
		*/
		public void set_Limit(String value) {
			this.setInput("Limit", value);	
		}

		/** 
		Set the value of the RegionName input for this Choreo. 

		@param String - (required, string) Enter a state, city, neighborhood, district (county), locality (borough), or metro area name; a place name, such as a business, landmark, or park; or a ZIP code. Separate multiple names with commas.
		*/
		public void set_RegionName(String value) {
			this.setInput("RegionName", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) Specify "xml" to convert the Patch JSON response to XML, or "json" (the default) to not convert.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the FindLocationByName Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class FindLocationByNameResultSet extends ResultSet {
		public FindLocationByNameResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Coordinates" output from this Choreo execution

		@return String - (string) The concatenated location latitude and longitude returned by Patch.
		*/
		public String get_Coordinates() {
			return this.getResult("Coordinates");
		}
		/** 
		Retrieve the value for the "Latitude" output from this Choreo execution

		@return String - (decimal) The latitude for the location returned by Patch.
		*/
		public String get_Latitude() {
			return this.getResult("Latitude");
		}
		/** 
		Retrieve the value for the "LocationID" output from this Choreo execution

		@return String - (string) 
		*/
		public String get_LocationID() {
			return this.getResult("LocationID");
		}
		/** 
		Retrieve the value for the "Longitude" output from this Choreo execution

		@return String - (decimal) The longitude for the location returned by Patch.
		*/
		public String get_Longitude() {
			return this.getResult("Longitude");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response returned from Patch.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
