package com.temboo.Library.Patch;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
FindStoriesByNeighborhood

Return the most recent stories from a specified U.S. neighborhood.
*/
public class FindStoriesByNeighborhood extends Choreography {

	/**
	Create a new instance of the FindStoriesByNeighborhood Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public FindStoriesByNeighborhood(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Patch/FindStoriesByNeighborhood"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return FindStoriesByNeighborhoodInputSet
	*/
	public FindStoriesByNeighborhoodInputSet newInputSet() {
		return new FindStoriesByNeighborhoodInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public FindStoriesByNeighborhoodResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new FindStoriesByNeighborhoodResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the FindStoriesByNeighborhood
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class FindStoriesByNeighborhoodInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) A valid API key provided by Patch.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the APISecret input for this Choreo. 

		@param String - (required, string) The API shared secret provided by Patch.
		*/
		public void set_APISecret(String value) {
			this.setInput("APISecret", value);
		}



		/** 
		Set the value of the City input for this Choreo. 

		@param String - (required, string) The name of the city to return stories for.
		*/
		public void set_City(String value) {
			this.setInput("City", value);
		}



		/** 
		Set the value of the Keyword input for this Choreo. 

		@param String - (optional, string) Specify one or more words or phrases to find in the story title, story summary, and topic tags of the stories to return.
		*/
		public void set_Keyword(String value) {
			this.setInput("Keyword", value);
		}



		/** 
		Set the value of the Limit input for this Choreo. 

		@param Integer - (optional, integer) Specify how many stories to return, between 1 and 100. The default is 10.
		*/
		public void set_Limit(Integer value) {
			this.setInput("Limit", value);
		}

		/** 
		Set the value of the Limit input for this Choreo as a String. 

		@param String - (optional, integer) Specify how many stories to return, between 1 and 100. The default is 10.
		*/
		public void set_Limit(String value) {
			this.setInput("Limit", value);	
		}

		/** 
		Set the value of the MaximumAge input for this Choreo. 

		@param Integer - (optional, integer) Specify the maximum age in days of the stories to return, between 1 and 30. The default is 10.
		*/
		public void set_MaximumAge(Integer value) {
			this.setInput("MaximumAge", value);
		}

		/** 
		Set the value of the MaximumAge input for this Choreo as a String. 

		@param String - (optional, integer) Specify the maximum age in days of the stories to return, between 1 and 30. The default is 10.
		*/
		public void set_MaximumAge(String value) {
			this.setInput("MaximumAge", value);	
		}

		/** 
		Set the value of the Neighborhood input for this Choreo. 

		@param String - (required, string) The name of the neighborhood in the corresponding city to return stories for. Common values include "downtown", "midtown", etc.
		*/
		public void set_Neighborhood(String value) {
			this.setInput("Neighborhood", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) Specify "xml" to convert the Patch JSON response to XML. The default is "json".
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the State input for this Choreo. 

		@param String - (required, string) The U.S. state name or abbreviation corresponding to the city to return stories for.
		*/
		public void set_State(String value) {
			this.setInput("State", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the FindStoriesByNeighborhood Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class FindStoriesByNeighborhoodResultSet extends ResultSet {
		public FindStoriesByNeighborhoodResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response returned from Patch.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
