package com.temboo.Library.Patch;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
FindStoriesByZIPCode

Return the most recent stories from a specified U.S. ZIP code.
*/
public class FindStoriesByZIPCode extends Choreography {

	/**
	Create a new instance of the FindStoriesByZIPCode Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public FindStoriesByZIPCode(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Patch/FindStoriesByZIPCode"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return FindStoriesByZIPCodeInputSet
	*/
	public FindStoriesByZIPCodeInputSet newInputSet() {
		return new FindStoriesByZIPCodeInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public FindStoriesByZIPCodeResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new FindStoriesByZIPCodeResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the FindStoriesByZIPCode
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class FindStoriesByZIPCodeInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) A valid API key provided by Patch.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the APISecret input for this Choreo. 

		@param String - (required, string) The API shared secret provided by Patch.
		*/
		public void set_APISecret(String value) {
			this.setInput("APISecret", value);
		}



		/** 
		Set the value of the Keyword input for this Choreo. 

		@param String - (optional, string) Specify one or more words or phrases to find in the story title, story summary, and topic tags of the stories to return.
		*/
		public void set_Keyword(String value) {
			this.setInput("Keyword", value);
		}



		/** 
		Set the value of the Limit input for this Choreo. 

		@param Integer - (optional, integer) Specify how many stories to return, between 1 and 100. The default is 10.
		*/
		public void set_Limit(Integer value) {
			this.setInput("Limit", value);
		}

		/** 
		Set the value of the Limit input for this Choreo as a String. 

		@param String - (optional, integer) Specify how many stories to return, between 1 and 100. The default is 10.
		*/
		public void set_Limit(String value) {
			this.setInput("Limit", value);	
		}

		/** 
		Set the value of the MaximumAge input for this Choreo. 

		@param Integer - (optional, integer) Specify the maximum age in days of the stories to return, between 1 and 30. The default is 10.
		*/
		public void set_MaximumAge(Integer value) {
			this.setInput("MaximumAge", value);
		}

		/** 
		Set the value of the MaximumAge input for this Choreo as a String. 

		@param String - (optional, integer) Specify the maximum age in days of the stories to return, between 1 and 30. The default is 10.
		*/
		public void set_MaximumAge(String value) {
			this.setInput("MaximumAge", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) Specify "xml" to convert the Patch JSON response to XML. The default is "json".
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the ZIPCode input for this Choreo. 

		@param String - (required, string) The ZIP code to return stories from.
		*/
		public void set_ZIPCode(String value) {
			this.setInput("ZIPCode", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the FindStoriesByZIPCode Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class FindStoriesByZIPCodeResultSet extends ResultSet {
		public FindStoriesByZIPCodeResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response returned from Patch.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
