package com.temboo.Library.PayPal.Payments;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
AcceptPayPalPayment

Creates a new PayPal payment which can then be approved and executed.
*/
public class AcceptPayPalPayment extends Choreography {

	/**
	Create a new instance of the AcceptPayPalPayment Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public AcceptPayPalPayment(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/PayPal/Payments/AcceptPayPalPayment"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return AcceptPayPalPaymentInputSet
	*/
	public AcceptPayPalPaymentInputSet newInputSet() {
		return new AcceptPayPalPaymentInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public AcceptPayPalPaymentResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new AcceptPayPalPaymentResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the AcceptPayPalPayment
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class AcceptPayPalPaymentInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (optional, string) A valid access token retrieved from PayPal. Required unless providing the ClientID and ClientSecret which can be used to generate a new access token.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the CancelURL input for this Choreo. 

		@param String - (required, string) URL to which the customer is returned if they do not approve the use of PayPal to pay you.
		*/
		public void set_CancelURL(String value) {
			this.setInput("CancelURL", value);
		}



		/** 
		Set the value of the ClientID input for this Choreo. 

		@param String - (conditional, string) The Client ID provided by PayPal. Required unless a valid Access Token is provided.
		*/
		public void set_ClientID(String value) {
			this.setInput("ClientID", value);
		}



		/** 
		Set the value of the ClientSecret input for this Choreo. 

		@param String - (conditional, string) The Client Secret provided by PayPal. Required unless a valid Access Token is provided.
		*/
		public void set_ClientSecret(String value) {
			this.setInput("ClientSecret", value);
		}



		/** 
		Set the value of the Currency input for this Choreo. 

		@param String - (required, string) The currency for the payment (i.e.  USD).
		*/
		public void set_Currency(String value) {
			this.setInput("Currency", value);
		}



		/** 
		Set the value of the Description input for this Choreo. 

		@param String - (optional, string) A description for this payment.
		*/
		public void set_Description(String value) {
			this.setInput("Description", value);
		}



		/** 
		Set the value of the ReturnURL input for this Choreo. 

		@param String - (required, string) The URL to which the customer's browser is returned after choosing to pay with PayPal.
		*/
		public void set_ReturnURL(String value) {
			this.setInput("ReturnURL", value);
		}



		/** 
		Set the value of the Scope input for this Choreo. 

		@param String - (optional, string) A space delimited list of resource URL endpoints that the token should have access for. This is only used when providing the ClientID and Client Secret in order to generate a new access token.
		*/
		public void set_Scope(String value) {
			this.setInput("Scope", value);
		}



		/** 
		Set the value of the Total input for this Choreo. 

		@param BigDecimal - (required, decimal) The total of the payment.
		*/
		public void set_Total(BigDecimal value) {
			this.setInput("Total", value);
		}

		/** 
		Set the value of the Total input for this Choreo as a String. 

		@param String - (required, decimal) The total of the payment.
		*/
		public void set_Total(String value) {
			this.setInput("Total", value);	
		}

		/** 
		Set the value of the UseSandbox input for this Choreo. 

		@param Boolean - (optional, boolean) Set to 1 to indicate that you're testing against the PayPal sandbox instead of production. Set to 0 (the default) when moving to production.
		*/
		public void set_UseSandbox(Boolean value) {
			this.setInput("UseSandbox", value);
		}

		/** 
		Set the value of the UseSandbox input for this Choreo as a String. 

		@param String - (optional, boolean) Set to 1 to indicate that you're testing against the PayPal sandbox instead of production. Set to 0 (the default) when moving to production.
		*/
		public void set_UseSandbox(String value) {
			this.setInput("UseSandbox", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the AcceptPayPalPayment Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class AcceptPayPalPaymentResultSet extends ResultSet {
		public AcceptPayPalPaymentResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "ApprovalURL" output from this Choreo execution

		@return String - (string) The approval url that the application should redirect the user to in order to approve the payment.
		*/
		public String get_ApprovalURL() {
			return this.getResult("ApprovalURL");
		}
		/** 
		Retrieve the value for the "NewAccessToken" output from this Choreo execution

		@return String - (string) The new access token retrieved from PayPal when providing the Client ID and Client Secret.
		*/
		public String get_NewAccessToken() {
			return this.getResult("NewAccessToken");
		}
		/** 
		Retrieve the value for the "PaymentID" output from this Choreo execution

		@return String - (string) The id of the payment that was created. This is used to execute the payment after the buyer has approved.
		*/
		public String get_PaymentID() {
			return this.getResult("PaymentID");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from PayPal.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
