package com.temboo.Library.PayPal.Payments;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
LookupPayment

Retrieves a specific payment resource by ID.
*/
public class LookupPayment extends Choreography {

	/**
	Create a new instance of the LookupPayment Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public LookupPayment(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/PayPal/Payments/LookupPayment"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return LookupPaymentInputSet
	*/
	public LookupPaymentInputSet newInputSet() {
		return new LookupPaymentInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public LookupPaymentResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new LookupPaymentResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the LookupPayment
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class LookupPaymentInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (optional, string) A valid access token retrieved from PayPal. Required unless providing the ClientID and ClientSecret which can be used to generate a new access token.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ClientID input for this Choreo. 

		@param String - (conditional, string) The Client ID provided by PayPal. Required unless a valid Access Token is provided.
		*/
		public void set_ClientID(String value) {
			this.setInput("ClientID", value);
		}



		/** 
		Set the value of the ClientSecret input for this Choreo. 

		@param String - (conditional, string) The Client Secret provided by PayPal. Required unless a valid Access Token is provided.
		*/
		public void set_ClientSecret(String value) {
			this.setInput("ClientSecret", value);
		}



		/** 
		Set the value of the PaymentID input for this Choreo. 

		@param String - (required, string) The id of the payment to retrieve.
		*/
		public void set_PaymentID(String value) {
			this.setInput("PaymentID", value);
		}



		/** 
		Set the value of the Scope input for this Choreo. 

		@param String - (optional, string) A space delimited list of resource URL endpoints that the token should have access for. This is only used when providing the ClientID and Client Secret in order to generate a new access token.
		*/
		public void set_Scope(String value) {
			this.setInput("Scope", value);
		}



		/** 
		Set the value of the UseSandbox input for this Choreo. 

		@param Boolean - (optional, boolean) Set to 1 to indicate that you're testing against the PayPal sandbox instead of production. Set to 0 (the default) when moving to production.
		*/
		public void set_UseSandbox(Boolean value) {
			this.setInput("UseSandbox", value);
		}

		/** 
		Set the value of the UseSandbox input for this Choreo as a String. 

		@param String - (optional, boolean) Set to 1 to indicate that you're testing against the PayPal sandbox instead of production. Set to 0 (the default) when moving to production.
		*/
		public void set_UseSandbox(String value) {
			this.setInput("UseSandbox", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the LookupPayment Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class LookupPaymentResultSet extends ResultSet {
		public LookupPaymentResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Currency" output from this Choreo execution

		@return String - (string) The payment currency.
		*/
		public String get_Currency() {
			return this.getResult("Currency");
		}
		/** 
		Retrieve the value for the "NewAccessToken" output from this Choreo execution

		@return String - (string) The new access token retrieved from PayPal when providing the Client ID and Client Secret.
		*/
		public String get_NewAccessToken() {
			return this.getResult("NewAccessToken");
		}
		/** 
		Retrieve the value for the "PaymentState" output from this Choreo execution

		@return String - (string) The state of the payment.
		*/
		public String get_PaymentState() {
			return this.getResult("PaymentState");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from PayPal.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** 
		Retrieve the value for the "SaleState" output from this Choreo execution

		@return String - (string) The state of the sale.
		*/
		public String get_SaleState() {
			return this.getResult("SaleState");
		}
		/** 
		Retrieve the value for the "Total" output from this Choreo execution

		@return String - (decimal) The total amount of the payment.
		*/
		public String get_Total() {
			return this.getResult("Total");
		}
	}
	
}
