package com.temboo.Library.PayPal.Payments;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
VerifyPayPalPayment

Verifies that a PayPal payment from the Adaptive Payments API has been successfully completed.
*/
public class VerifyPayPalPayment extends Choreography {

	/**
	Create a new instance of the VerifyPayPalPayment Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public VerifyPayPalPayment(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/PayPal/Payments/VerifyPayPalPayment"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return VerifyPayPalPaymentInputSet
	*/
	public VerifyPayPalPaymentInputSet newInputSet() {
		return new VerifyPayPalPaymentInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public VerifyPayPalPaymentResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new VerifyPayPalPaymentResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the VerifyPayPalPayment
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class VerifyPayPalPaymentInputSet extends InputSet {
		/** 
		Set the value of the AppID input for this Choreo. 

		@param String - (conditional, string) Your PayPal AppID (or the default AppID for the PayPal sandbox: APP-80W284485P519543T). This is used to authenticate PayPal's Adaptive Payments API.
		*/
		public void set_AppID(String value) {
			this.setInput("AppID", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (conditional, string) The API Password provided by PayPal. This is used to authenticate PayPal's Adaptive Payments API.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the ProofOfPayment input for this Choreo. 

		@param String - (required, json) The proof of payment received from the client SDK. This can be a proof of payment received from the Adaptive Payment API or the REST API.
		*/
		public void set_ProofOfPayment(String value) {
			this.setInput("ProofOfPayment", value);
		}



		/** 
		Set the value of the Signature input for this Choreo. 

		@param String - (conditional, string) The API Signature provided by PayPal. This is used to authenticate PayPal's Adaptive Payments API.
		*/
		public void set_Signature(String value) {
			this.setInput("Signature", value);
		}



		/** 
		Set the value of the UseSandbox input for this Choreo. 

		@param Boolean - (optional, boolean) Set to 1 to indicate that you're testing against the PayPal sandbox instead of production. Set to 0 (the default) when moving to production.
		*/
		public void set_UseSandbox(Boolean value) {
			this.setInput("UseSandbox", value);
		}

		/** 
		Set the value of the UseSandbox input for this Choreo as a String. 

		@param String - (optional, boolean) Set to 1 to indicate that you're testing against the PayPal sandbox instead of production. Set to 0 (the default) when moving to production.
		*/
		public void set_UseSandbox(String value) {
			this.setInput("UseSandbox", value);	
		}

		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (conditional, string) The API Username provided by PayPal. This is used to authenticate PayPal's Adaptive Payments API.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the VerifyPayPalPayment Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class VerifyPayPalPaymentResultSet extends ResultSet {
		public VerifyPayPalPaymentResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "FailureDescription" output from this Choreo execution

		@return String - (json) When the payment details indicate that the payment status is not complete, this will contain a JSON dictionary of payment status descriptions.
		*/
		public String get_FailureDescription() {
			return this.getResult("FailureDescription");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from PayPal. This includes the full response from retrieving payment details from the AdaptivePayments API.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** 
		Retrieve the value for the "VerificationStatus" output from this Choreo execution

		@return String - (string) The status of the payment verification. This will set to either "verified" or "unverified" depending on the status of the payment details.
		*/
		public String get_VerificationStatus() {
			return this.getResult("VerificationStatus");
		}
	}
	
}
