package com.temboo.Library.PayPal.SaleTransactions;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
LookupSale

Retrieves details about a sale transaction.
*/
public class LookupSale extends Choreography {

	/**
	Create a new instance of the LookupSale Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public LookupSale(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/PayPal/SaleTransactions/LookupSale"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return LookupSaleInputSet
	*/
	public LookupSaleInputSet newInputSet() {
		return new LookupSaleInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public LookupSaleResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new LookupSaleResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the LookupSale
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class LookupSaleInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (optional, string) A valid access token retrieved from PayPal. Required unless providing the ClientID and ClientSecret which can be used to generate a new access token.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ClientID input for this Choreo. 

		@param String - (conditional, string) The Client ID provided by PayPal. Required unless a valid Access Token is provided.
		*/
		public void set_ClientID(String value) {
			this.setInput("ClientID", value);
		}



		/** 
		Set the value of the ClientSecret input for this Choreo. 

		@param String - (conditional, string) The Client Secret provided by PayPal. Required unless a valid Access Token is provided.
		*/
		public void set_ClientSecret(String value) {
			this.setInput("ClientSecret", value);
		}



		/** 
		Set the value of the SaleID input for this Choreo. 

		@param String - (required, string) The id of the sale to retrieve.
		*/
		public void set_SaleID(String value) {
			this.setInput("SaleID", value);
		}



		/** 
		Set the value of the Scope input for this Choreo. 

		@param String - (optional, string) A space delimited list of resource URL endpoints that the token should have access for. This is only used when providing the ClientID and Client Secret in order to generate a new access token.
		*/
		public void set_Scope(String value) {
			this.setInput("Scope", value);
		}



		/** 
		Set the value of the UseSandbox input for this Choreo. 

		@param Boolean - (optional, boolean) Set to 1 to indicate that you're testing against the PayPal sandbox instead of production. Set to 0 (the default) when moving to production.
		*/
		public void set_UseSandbox(Boolean value) {
			this.setInput("UseSandbox", value);
		}

		/** 
		Set the value of the UseSandbox input for this Choreo as a String. 

		@param String - (optional, boolean) Set to 1 to indicate that you're testing against the PayPal sandbox instead of production. Set to 0 (the default) when moving to production.
		*/
		public void set_UseSandbox(String value) {
			this.setInput("UseSandbox", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the LookupSale Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class LookupSaleResultSet extends ResultSet {
		public LookupSaleResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "NewAccessToken" output from this Choreo execution

		@return String - (string) The new access token retrieved from PayPal when providing the Client ID and Client Secret.
		*/
		public String get_NewAccessToken() {
			return this.getResult("NewAccessToken");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from PayPal.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
