package com.temboo.Library.PostgreSQL;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
JSONToDB

Performs a batch operation in PostgreSQL with a set of records in JSON format.
*/
public class JSONToDB extends Choreography {

	/**
	Create a new instance of the JSONToDB Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public JSONToDB(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/PostgreSQL/JSONToDB"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return JSONToDBInputSet
	*/
	public JSONToDBInputSet newInputSet() {
		return new JSONToDBInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public JSONToDBResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new JSONToDBResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the JSONToDB
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class JSONToDBInputSet extends InputSet {
		/** 
		Set the value of the BatchFile input for this Choreo. 

		@param String - (required, json) The records to send to the database for the batch operation.
		*/
		public void set_BatchFile(String value) {
			this.setInput("BatchFile", value);
		}



		/** 
		Set the value of the BatchMode input for this Choreo. 

		@param String - (optional, string) The type of batch operation to perform. Accepted values are: insert, update, or upsert.
		*/
		public void set_BatchMode(String value) {
			this.setInput("BatchMode", value);
		}



		/** 
		Set the value of the DatabaseName input for this Choreo. 

		@param String - (required, string) The name of the database to connect to.
		*/
		public void set_DatabaseName(String value) {
			this.setInput("DatabaseName", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The password for the database user.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Port input for this Choreo. 

		@param Integer - (optional, integer) The database port. Defaults to 5432.
		*/
		public void set_Port(Integer value) {
			this.setInput("Port", value);
		}

		/** 
		Set the value of the Port input for this Choreo as a String. 

		@param String - (optional, integer) The database port. Defaults to 5432.
		*/
		public void set_Port(String value) {
			this.setInput("Port", value);	
		}

		/** 
		Set the value of the RollbackOnError input for this Choreo. 

		@param Boolean - (optional, boolean) Rollback if error occurs. Set to 1 to enable. Defaults to 0 (false).
		*/
		public void set_RollbackOnError(Boolean value) {
			this.setInput("RollbackOnError", value);
		}

		/** 
		Set the value of the RollbackOnError input for this Choreo as a String. 

		@param String - (optional, boolean) Rollback if error occurs. Set to 1 to enable. Defaults to 0 (false).
		*/
		public void set_RollbackOnError(String value) {
			this.setInput("RollbackOnError", value);	
		}

		/** 
		Set the value of the Server input for this Choreo. 

		@param String - (required, string) The name or IP address of the database server.
		*/
		public void set_Server(String value) {
			this.setInput("Server", value);
		}



		/** 
		Set the value of the TableName input for this Choreo. 

		@param String - (required, string) The database table that the batch operation is to be performed on.
		*/
		public void set_TableName(String value) {
			this.setInput("TableName", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) The database username.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



		/** 
		Set the value of the Version input for this Choreo. 

		@param BigDecimal - (optional, decimal) The version of the Postgres database. Allowed values are 8 and 9 (the default).
		*/
		public void set_Version(BigDecimal value) {
			this.setInput("Version", value);
		}

		/** 
		Set the value of the Version input for this Choreo as a String. 

		@param String - (optional, decimal) The version of the Postgres database. Allowed values are 8 and 9 (the default).
		*/
		public void set_Version(String value) {
			this.setInput("Version", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the JSONToDB Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class JSONToDBResultSet extends ResultSet {
		public JSONToDBResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Success" output from this Choreo execution

		@return String - (boolean) Indicates the result of the batch operation. The value will be "true" when the SQL transaction executes successfully.
		*/
		public String get_Success() {
			return this.getResult("Success");
		}
	}
	
}
