package com.temboo.Library.PostgreSQL;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
RunCommand

Executes a SQL command for a Postgres database.
*/
public class RunCommand extends Choreography {

	/**
	Create a new instance of the RunCommand Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public RunCommand(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/PostgreSQL/RunCommand"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return RunCommandInputSet
	*/
	public RunCommandInputSet newInputSet() {
		return new RunCommandInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public RunCommandResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new RunCommandResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the RunCommand
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class RunCommandInputSet extends InputSet {
		/** 
		Set the value of the DatabaseName input for this Choreo. 

		@param String - (required, string) The name of the database to connect to.
		*/
		public void set_DatabaseName(String value) {
			this.setInput("DatabaseName", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The password for the database user.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Port input for this Choreo. 

		@param Integer - (optional, integer) The database port. Defaults to 5432.
		*/
		public void set_Port(Integer value) {
			this.setInput("Port", value);
		}

		/** 
		Set the value of the Port input for this Choreo as a String. 

		@param String - (optional, integer) The database port. Defaults to 5432.
		*/
		public void set_Port(String value) {
			this.setInput("Port", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The preferred format for the database results. Accepted formats are json (the default) and xml. This input only applies when providing a SELECT statement for the SQL input.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the SQL input for this Choreo. 

		@param String - (required, multiline) A SQL statement to execute.
		*/
		public void set_SQL(String value) {
			this.setInput("SQL", value);
		}



		/** 
		Set the value of the Server input for this Choreo. 

		@param String - (required, string) The name or IP address of the database server.
		*/
		public void set_Server(String value) {
			this.setInput("Server", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) The database username.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



		/** 
		Set the value of the Version input for this Choreo. 

		@param BigDecimal - (optional, decimal) The version of the Postgres database. Allowed values are 8 and 9 (the default).
		*/
		public void set_Version(BigDecimal value) {
			this.setInput("Version", value);
		}

		/** 
		Set the value of the Version input for this Choreo as a String. 

		@param String - (optional, decimal) The version of the Postgres database. Allowed values are 8 and 9 (the default).
		*/
		public void set_Version(String value) {
			this.setInput("Version", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the RunCommand Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class RunCommandResultSet extends ResultSet {
		public RunCommandResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "ResultData" output from this Choreo execution

		@return String - The data returned from the database. This output will only contain a value when a SELECT statement is provided. Results are returned as JSON or XML depending on the ResponseFormat.
		*/
		public String get_ResultData() {
			return this.getResult("ResultData");
		}
		/** 
		Retrieve the value for the "Success" output from this Choreo execution

		@return String - (boolean) Indicates the result of the database command. The value will be "true" when the SQL statement executes successfully.
		*/
		public String get_Success() {
			return this.getResult("Success");
		}
	}
	
}
