package com.temboo.Library.RapidShare;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
DeleteFiles

Delete one or more files from RapidShare.
*/
public class DeleteFiles extends Choreography {

	/**
	Create a new instance of the DeleteFiles Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DeleteFiles(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/RapidShare/DeleteFiles"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DeleteFilesInputSet
	*/
	public DeleteFilesInputSet newInputSet() {
		return new DeleteFilesInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DeleteFilesResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DeleteFilesResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DeleteFiles
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DeleteFilesInputSet extends InputSet {
		/** 
		Set the value of the File input for this Choreo. 

		@param Integer - (required, integer) The id of the file to delete. Can be a commas separated list of ids.
		*/
		public void set_File(Integer value) {
			this.setInput("File", value);
		}

		/** 
		Set the value of the File input for this Choreo as a String. 

		@param String - (required, integer) The id of the file to delete. Can be a commas separated list of ids.
		*/
		public void set_File(String value) {
			this.setInput("File", value);	
		}

		/** 
		Set the value of the Login input for this Choreo. 

		@param String - (required, string) Your RapidShare username
		*/
		public void set_Login(String value) {
			this.setInput("Login", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your RapidShare password
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DeleteFiles Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DeleteFilesResultSet extends ResultSet {
		public DeleteFilesResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (string) The response from RapidShare
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
