package com.temboo.Library.RapidShare;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetAccountDetails

Returns details about a RapidShare account in key-value pairs.
*/
public class GetAccountDetails extends Choreography {

	/**
	Create a new instance of the GetAccountDetails Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetAccountDetails(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/RapidShare/GetAccountDetails"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetAccountDetailsInputSet
	*/
	public GetAccountDetailsInputSet newInputSet() {
		return new GetAccountDetailsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetAccountDetailsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetAccountDetailsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetAccountDetails
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetAccountDetailsInputSet extends InputSet {
		/** 
		Set the value of the Login input for this Choreo. 

		@param String - (required, string) Your RapidShare username
		*/
		public void set_Login(String value) {
			this.setInput("Login", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your RapidShare password
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the WithCookie input for this Choreo. 

		@param Boolean - (optional, boolean) If value "1" is specified, a cookie is returned in the response
		*/
		public void set_WithCookie(Boolean value) {
			this.setInput("WithCookie", value);
		}

		/** 
		Set the value of the WithCookie input for this Choreo as a String. 

		@param String - (optional, boolean) If value "1" is specified, a cookie is returned in the response
		*/
		public void set_WithCookie(String value) {
			this.setInput("WithCookie", value);	
		}

		/** 
		Set the value of the WithPublicId input for this Choreo. 

		@param Boolean - (optional, boolean) If value "1" is specified, the public id is returned in the response
		*/
		public void set_WithPublicId(Boolean value) {
			this.setInput("WithPublicId", value);
		}

		/** 
		Set the value of the WithPublicId input for this Choreo as a String. 

		@param String - (optional, boolean) If value "1" is specified, the public id is returned in the response
		*/
		public void set_WithPublicId(String value) {
			this.setInput("WithPublicId", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetAccountDetails Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetAccountDetailsResultSet extends ResultSet {
		public GetAccountDetailsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (string) The response from RapidShare formatted in key / value pairs.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
