package com.temboo.Library.RapidShare;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ListFiles

Lists the files in all folders (or in a specified folder) and allows you to control the database columns returned in the result.
*/
public class ListFiles extends Choreography {

	/**
	Create a new instance of the ListFiles Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListFiles(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/RapidShare/ListFiles"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListFilesInputSet
	*/
	public ListFilesInputSet newInputSet() {
		return new ListFilesInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListFilesResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListFilesResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListFiles
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListFilesInputSet extends InputSet {
		/** 
		Set the value of the Fields input for this Choreo. 

		@param String - (optional, string) The database columns to return separated by commas. (i.e. downloads,lastdownload,filename,size, etc)
		*/
		public void set_Fields(String value) {
			this.setInput("Fields", value);
		}



		/** 
		Set the value of the FileIDs input for this Choreo. 

		@param Integer - (optional, integer) The id of the file to list. Multiple IDs can be entered separated by commas.
		*/
		public void set_FileIDs(Integer value) {
			this.setInput("FileIDs", value);
		}

		/** 
		Set the value of the FileIDs input for this Choreo as a String. 

		@param String - (optional, integer) The id of the file to list. Multiple IDs can be entered separated by commas.
		*/
		public void set_FileIDs(String value) {
			this.setInput("FileIDs", value);	
		}

		/** 
		Set the value of the FileName input for this Choreo. 

		@param String - (optional, string) The name of the file to list
		*/
		public void set_FileName(String value) {
			this.setInput("FileName", value);
		}



		/** 
		Set the value of the FolderID input for this Choreo. 

		@param Integer - (optional, integer) The id of the folder that contains the file you want to list. Defaults to 'all'.
		*/
		public void set_FolderID(Integer value) {
			this.setInput("FolderID", value);
		}

		/** 
		Set the value of the FolderID input for this Choreo as a String. 

		@param String - (optional, integer) The id of the folder that contains the file you want to list. Defaults to 'all'.
		*/
		public void set_FolderID(String value) {
			this.setInput("FolderID", value);	
		}

		/** 
		Set the value of the Login input for this Choreo. 

		@param String - (required, string) Your RapidShare username
		*/
		public void set_Login(String value) {
			this.setInput("Login", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your RapidShare password
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListFiles Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListFilesResultSet extends ResultSet {
		public ListFilesResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (string) The response from RapidShare formatted in commas separated values.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
