package com.temboo.Library.RapidShare;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ListRealFolders

Returns all existing RealFolders
*/
public class ListRealFolders extends Choreography {

	/**
	Create a new instance of the ListRealFolders Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListRealFolders(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/RapidShare/ListRealFolders"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListRealFoldersInputSet
	*/
	public ListRealFoldersInputSet newInputSet() {
		return new ListRealFoldersInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListRealFoldersResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListRealFoldersResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListRealFolders
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListRealFoldersInputSet extends InputSet {
		/** 
		Set the value of the Login input for this Choreo. 

		@param String - (required, string) Your RapidShare username
		*/
		public void set_Login(String value) {
			this.setInput("Login", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your RapidShare password
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListRealFolders Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListRealFoldersResultSet extends ResultSet {
		public ListRealFoldersResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (string) The response from RapidShare formatted in commas separated values.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
