package com.temboo.Library.RapidShare;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
MoveFilesToRealFolder

Move an existing file to a new folder in RapidShare.
*/
public class MoveFilesToRealFolder extends Choreography {

	/**
	Create a new instance of the MoveFilesToRealFolder Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public MoveFilesToRealFolder(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/RapidShare/MoveFilesToRealFolder"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return MoveFilesToRealFolderInputSet
	*/
	public MoveFilesToRealFolderInputSet newInputSet() {
		return new MoveFilesToRealFolderInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public MoveFilesToRealFolderResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new MoveFilesToRealFolderResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the MoveFilesToRealFolder
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class MoveFilesToRealFolderInputSet extends InputSet {
		/** 
		Set the value of the Files input for this Choreo. 

		@param Integer - (required, integer) The id of the file to move. Can be a commas separated list of ids.
		*/
		public void set_Files(Integer value) {
			this.setInput("Files", value);
		}

		/** 
		Set the value of the Files input for this Choreo as a String. 

		@param String - (required, integer) The id of the file to move. Can be a commas separated list of ids.
		*/
		public void set_Files(String value) {
			this.setInput("Files", value);	
		}

		/** 
		Set the value of the Login input for this Choreo. 

		@param String - (required, string) Your RapidShare username
		*/
		public void set_Login(String value) {
			this.setInput("Login", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your RapidShare password
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the RealFolder input for this Choreo. 

		@param Integer - (optional, integer) The ID of the parent folder. Defaults to 0 for 'root'.
		*/
		public void set_RealFolder(Integer value) {
			this.setInput("RealFolder", value);
		}

		/** 
		Set the value of the RealFolder input for this Choreo as a String. 

		@param String - (optional, integer) The ID of the parent folder. Defaults to 0 for 'root'.
		*/
		public void set_RealFolder(String value) {
			this.setInput("RealFolder", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the MoveFilesToRealFolder Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class MoveFilesToRealFolderResultSet extends ResultSet {
		public MoveFilesToRealFolderResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (string) The response from RapidShare. The id of the newly created folder should be returned in the response upon a successful execution.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
