package com.temboo.Library.RapidShare;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
MoveRealFolder

Changes the parent ID of existing RealFolders, enabling the location of the folder to be moved within a RapidShare account file hierarchy.
*/
public class MoveRealFolder extends Choreography {

	/**
	Create a new instance of the MoveRealFolder Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public MoveRealFolder(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/RapidShare/MoveRealFolder"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return MoveRealFolderInputSet
	*/
	public MoveRealFolderInputSet newInputSet() {
		return new MoveRealFolderInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public MoveRealFolderResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new MoveRealFolderResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the MoveRealFolder
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class MoveRealFolderInputSet extends InputSet {
		/** 
		Set the value of the FolderId input for this Choreo. 

		@param Integer - (required, integer) The id of the folder(s) to be moved. Can be a commas separated list of ids.
		*/
		public void set_FolderId(Integer value) {
			this.setInput("FolderId", value);
		}

		/** 
		Set the value of the FolderId input for this Choreo as a String. 

		@param String - (required, integer) The id of the folder(s) to be moved. Can be a commas separated list of ids.
		*/
		public void set_FolderId(String value) {
			this.setInput("FolderId", value);	
		}

		/** 
		Set the value of the Login input for this Choreo. 

		@param String - (required, string) Your RapidShare username
		*/
		public void set_Login(String value) {
			this.setInput("Login", value);
		}



		/** 
		Set the value of the NewParent input for this Choreo. 

		@param Integer - (required, integer) Enter the ID of new parent folder
		*/
		public void set_NewParent(Integer value) {
			this.setInput("NewParent", value);
		}

		/** 
		Set the value of the NewParent input for this Choreo as a String. 

		@param String - (required, integer) Enter the ID of new parent folder
		*/
		public void set_NewParent(String value) {
			this.setInput("NewParent", value);	
		}

		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your RapidShare password
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the MoveRealFolder Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class MoveRealFolderResultSet extends ResultSet {
		public MoveRealFolderResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (string) The response from RapidShare. The id of the newly created folder should be returned in the response upon a successful execution.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
