package com.temboo.Library.RapidShare;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
RenameFile

Renames a file to something else.
*/
public class RenameFile extends Choreography {

	/**
	Create a new instance of the RenameFile Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public RenameFile(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/RapidShare/RenameFile"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return RenameFileInputSet
	*/
	public RenameFileInputSet newInputSet() {
		return new RenameFileInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public RenameFileResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new RenameFileResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the RenameFile
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class RenameFileInputSet extends InputSet {
		/** 
		Set the value of the FileId input for this Choreo. 

		@param Integer - (required, integer) The ID of the file to be renamed. Can be a commas separated list of ids.
		*/
		public void set_FileId(Integer value) {
			this.setInput("FileId", value);
		}

		/** 
		Set the value of the FileId input for this Choreo as a String. 

		@param String - (required, integer) The ID of the file to be renamed. Can be a commas separated list of ids.
		*/
		public void set_FileId(String value) {
			this.setInput("FileId", value);	
		}

		/** 
		Set the value of the Login input for this Choreo. 

		@param String - (required, string) Your RapidShare username
		*/
		public void set_Login(String value) {
			this.setInput("Login", value);
		}



		/** 
		Set the value of the NewFileName input for this Choreo. 

		@param String - (required, string) The new file name.
		*/
		public void set_NewFileName(String value) {
			this.setInput("NewFileName", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your RapidShare password
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the RenameFile Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class RenameFileResultSet extends ResultSet {
		public RenameFileResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (string) The response from RapidShare. The ID of the newly created folder should be returned in the response upon a successful execution.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
