package com.temboo.Library.RapidShare;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
SendMail

Send an email that contains a link to a file available on RapidShare.
*/
public class SendMail extends Choreography {

	/**
	Create a new instance of the SendMail Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public SendMail(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/RapidShare/SendMail"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return SendMailInputSet
	*/
	public SendMailInputSet newInputSet() {
		return new SendMailInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public SendMailResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new SendMailResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the SendMail
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class SendMailInputSet extends InputSet {
		/** 
		Set the value of the Comment input for this Choreo. 

		@param String - (required, string) A comment that you want to send with the email
		*/
		public void set_Comment(String value) {
			this.setInput("Comment", value);
		}



		/** 
		Set the value of the Email1 input for this Choreo. 

		@param String - (required, string) The first email address to send to
		*/
		public void set_Email1(String value) {
			this.setInput("Email1", value);
		}



		/** 
		Set the value of the Email2 input for this Choreo. 

		@param String - (optional, string) The second email address to send to
		*/
		public void set_Email2(String value) {
			this.setInput("Email2", value);
		}



		/** 
		Set the value of the Email3 input for this Choreo. 

		@param String - (optional, string) The third email address to send to
		*/
		public void set_Email3(String value) {
			this.setInput("Email3", value);
		}



		/** 
		Set the value of the FileID1 input for this Choreo. 

		@param Integer - (required, integer) The id for the file to inform the email recipient about
		*/
		public void set_FileID1(Integer value) {
			this.setInput("FileID1", value);
		}

		/** 
		Set the value of the FileID1 input for this Choreo as a String. 

		@param String - (required, integer) The id for the file to inform the email recipient about
		*/
		public void set_FileID1(String value) {
			this.setInput("FileID1", value);	
		}

		/** 
		Set the value of the FileName1 input for this Choreo. 

		@param String - (required, string) The name of the file to inform the email recipient about
		*/
		public void set_FileName1(String value) {
			this.setInput("FileName1", value);
		}



		/** 
		Set the value of the Login input for this Choreo. 

		@param String - (required, string) Your RapidShare username
		*/
		public void set_Login(String value) {
			this.setInput("Login", value);
		}



		/** 
		Set the value of the Name input for this Choreo. 

		@param String - (required, string) The senders name
		*/
		public void set_Name(String value) {
			this.setInput("Name", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your RapidShare password
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the ReplyEmail input for this Choreo. 

		@param String - (required, string) The sender reply email address
		*/
		public void set_ReplyEmail(String value) {
			this.setInput("ReplyEmail", value);
		}



		/** 
		Set the value of the Subject input for this Choreo. 

		@param String - (required, string) The subject line for the email
		*/
		public void set_Subject(String value) {
			this.setInput("Subject", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the SendMail Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class SendMailResultSet extends ResultSet {
		public SendMailResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (string) The response from RapidShare
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
