package com.temboo.Library.RapidShare;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Upload

Upload a file to RapidShare.
*/
public class Upload extends Choreography {

	/**
	Create a new instance of the Upload Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Upload(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/RapidShare/Upload"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return UploadInputSet
	*/
	public UploadInputSet newInputSet() {
		return new UploadInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public UploadResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new UploadResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Upload
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class UploadInputSet extends InputSet {
		/** 
		Set the value of the FileContents input for this Choreo. 

		@param String - (conditional, string) The base64 encoded contents of the file you want to upload. Required unless using the VaultFile alias (an advanced option used when running Choreos in the Temboo Designer).
		*/
		public void set_FileContents(String value) {
			this.setInput("FileContents", value);
		}



		/** 
		Set the value of the FileName input for this Choreo. 

		@param String - (required, string) The name of the file you want to upload
		*/
		public void set_FileName(String value) {
			this.setInput("FileName", value);
		}



		/** 
		Set the value of the Folder input for this Choreo. 

		@param Integer - (optional, integer) The id of the folder you want to upload the file to
		*/
		public void set_Folder(Integer value) {
			this.setInput("Folder", value);
		}

		/** 
		Set the value of the Folder input for this Choreo as a String. 

		@param String - (optional, integer) The id of the folder you want to upload the file to
		*/
		public void set_Folder(String value) {
			this.setInput("Folder", value);	
		}

		/** 
		Set the value of the Login input for this Choreo. 

		@param String - (required, string) Your RapidShare username
		*/
		public void set_Login(String value) {
			this.setInput("Login", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your RapidShare password
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the VaultFile input for this Choreo. 

		@param TembooPath - The path to a file in your vault to upload. Required if FileContents input variable is not specified.
		*/
		public void set_VaultFile(TembooPath value) {
			this.setAlias("VaultFile", value);
		}
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Upload Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class UploadResultSet extends ResultSet {
		public UploadResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (string) The response from RapidShare formatted in commas separated values.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
