package com.temboo.Library.RightScale;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CreateDeployment

Create a RightScale Deployment.
*/
public class CreateDeployment extends Choreography {

	/**
	Create a new instance of the CreateDeployment Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CreateDeployment(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/RightScale/CreateDeployment"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CreateDeploymentInputSet
	*/
	public CreateDeploymentInputSet newInputSet() {
		return new CreateDeploymentInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CreateDeploymentResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CreateDeploymentResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CreateDeployment
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CreateDeploymentInputSet extends InputSet {
		/** 
		Set the value of the AccountID input for this Choreo. 

		@param Integer - (required, integer) The RightScale Account ID.
		*/
		public void set_AccountID(Integer value) {
			this.setInput("AccountID", value);
		}

		/** 
		Set the value of the AccountID input for this Choreo as a String. 

		@param String - (required, integer) The RightScale Account ID.
		*/
		public void set_AccountID(String value) {
			this.setInput("AccountID", value);	
		}

		/** 
		Set the value of the DeploymentDefaultEC2AvailabilityZone input for this Choreo. 

		@param String - (optional, string) The default EC2 availability zone for this deployment.
		*/
		public void set_DeploymentDefaultEC2AvailabilityZone(String value) {
			this.setInput("DeploymentDefaultEC2AvailabilityZone", value);
		}



		/** 
		Set the value of the DeploymentDefaultVPCSubnetHref input for this Choreo. 

		@param String - (optional, string) The href of the vpc subnet.
		*/
		public void set_DeploymentDefaultVPCSubnetHref(String value) {
			this.setInput("DeploymentDefaultVPCSubnetHref", value);
		}



		/** 
		Set the value of the DeploymentDescription input for this Choreo. 

		@param String - (optional, string) The deployment being created.
		*/
		public void set_DeploymentDescription(String value) {
			this.setInput("DeploymentDescription", value);
		}



		/** 
		Set the value of the DeploymentNickname input for this Choreo. 

		@param String - (required, string) The nickname of the deployment being created.
		*/
		public void set_DeploymentNickname(String value) {
			this.setInput("DeploymentNickname", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The RightScale account password.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) The RightScale username.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CreateDeployment Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CreateDeploymentResultSet extends ResultSet {
		public CreateDeploymentResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Rightscale in XML format
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
