package com.temboo.Library.RightScale;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CreateServer

Creates a RightScale server instance.
*/
public class CreateServer extends Choreography {

	/**
	Create a new instance of the CreateServer Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CreateServer(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/RightScale/CreateServer"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CreateServerInputSet
	*/
	public CreateServerInputSet newInputSet() {
		return new CreateServerInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CreateServerResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CreateServerResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CreateServer
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CreateServerInputSet extends InputSet {
		/** 
		Set the value of the AKIImage input for this Choreo. 

		@param String - (optional, string) The URL to the AKI image.
		*/
		public void set_AKIImage(String value) {
			this.setInput("AKIImage", value);
		}



		/** 
		Set the value of the ARIImage input for this Choreo. 

		@param String - (optional, string) The URL to the ARI Image.
		*/
		public void set_ARIImage(String value) {
			this.setInput("ARIImage", value);
		}



		/** 
		Set the value of the AccountID input for this Choreo. 

		@param Integer - (required, integer) The RightScale Account ID.
		*/
		public void set_AccountID(Integer value) {
			this.setInput("AccountID", value);
		}

		/** 
		Set the value of the AccountID input for this Choreo as a String. 

		@param String - (required, integer) The RightScale Account ID.
		*/
		public void set_AccountID(String value) {
			this.setInput("AccountID", value);	
		}

		/** 
		Set the value of the CloudID input for this Choreo. 

		@param Integer - (optional, integer) The cloud region identifier. If undefined, the default is 1 (us-east).
		*/
		public void set_CloudID(Integer value) {
			this.setInput("CloudID", value);
		}

		/** 
		Set the value of the CloudID input for this Choreo as a String. 

		@param String - (optional, integer) The cloud region identifier. If undefined, the default is 1 (us-east).
		*/
		public void set_CloudID(String value) {
			this.setInput("CloudID", value);	
		}

		/** 
		Set the value of the EC2AvailabilityZone input for this Choreo. 

		@param String - (optional, string) The  EC2 availablity zone, for example: us-east-1a, or any.  Do not set, if also passing the vpc_subnet_href parameter.
		*/
		public void set_EC2AvailabilityZone(String value) {
			this.setInput("EC2AvailabilityZone", value);
		}



		/** 
		Set the value of the EC2Image input for this Choreo. 

		@param String - (optional, string) The URL to AMI image.
		*/
		public void set_EC2Image(String value) {
			this.setInput("EC2Image", value);
		}



		/** 
		Set the value of the EC2SSHKeyHref input for this Choreo. 

		@param String - (optional, string) The URL to the SSH Key.
		*/
		public void set_EC2SSHKeyHref(String value) {
			this.setInput("EC2SSHKeyHref", value);
		}



		/** 
		Set the value of the EC2SecurityGroupsHref input for this Choreo. 

		@param String - (optional, string) The URL(s) to security group(s). Do not set, if also passing the vpc_subnet_href parameter.
		*/
		public void set_EC2SecurityGroupsHref(String value) {
			this.setInput("EC2SecurityGroupsHref", value);
		}



		/** 
		Set the value of the InstanceType input for this Choreo. 

		@param String - (optional, string) The AWS instance type: small, medium, etc.
		*/
		public void set_InstanceType(String value) {
			this.setInput("InstanceType", value);
		}



		/** 
		Set the value of the MaxSpotPrice input for this Choreo. 

		@param Integer - (optional, integer) The maximum price (a dollar value) dollars) per hour for the spot server.
		*/
		public void set_MaxSpotPrice(Integer value) {
			this.setInput("MaxSpotPrice", value);
		}

		/** 
		Set the value of the MaxSpotPrice input for this Choreo as a String. 

		@param String - (optional, integer) The maximum price (a dollar value) dollars) per hour for the spot server.
		*/
		public void set_MaxSpotPrice(String value) {
			this.setInput("MaxSpotPrice", value);	
		}

		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The RightScale account password.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Pricing input for this Choreo. 

		@param String - (optional, string) AWS pricing.  Specify on_demand, or spot.
		*/
		public void set_Pricing(String value) {
			this.setInput("Pricing", value);
		}



		/** 
		Set the value of the ServerDeployment input for this Choreo. 

		@param String - (required, string) The URL of the deployment that this server wil be added to.
		*/
		public void set_ServerDeployment(String value) {
			this.setInput("ServerDeployment", value);
		}



		/** 
		Set the value of the ServerNickname input for this Choreo. 

		@param String - (required, string) The nickname for the server being created.
		*/
		public void set_ServerNickname(String value) {
			this.setInput("ServerNickname", value);
		}



		/** 
		Set the value of the ServerTemplate input for this Choreo. 

		@param String - (required, string) The URL to a server template.
		*/
		public void set_ServerTemplate(String value) {
			this.setInput("ServerTemplate", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) The username obtained from RightScale.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



		/** 
		Set the value of the VPCSubnet input for this Choreo. 

		@param String - (optional, string) The href to the VPC subnet.
		*/
		public void set_VPCSubnet(String value) {
			this.setInput("VPCSubnet", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CreateServer Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CreateServerResultSet extends ResultSet {
		public CreateServerResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Rightscale in XML format.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
