package com.temboo.Library.RightScale;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetServerSettings

Retrieve server settings for a specified RightScale Server ID.
*/
public class GetServerSettings extends Choreography {

	/**
	Create a new instance of the GetServerSettings Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetServerSettings(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/RightScale/GetServerSettings"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetServerSettingsInputSet
	*/
	public GetServerSettingsInputSet newInputSet() {
		return new GetServerSettingsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetServerSettingsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetServerSettingsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetServerSettings
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetServerSettingsInputSet extends InputSet {
		/** 
		Set the value of the AccountID input for this Choreo. 

		@param String - (required, string) The RightScale Account ID.
		*/
		public void set_AccountID(String value) {
			this.setInput("AccountID", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The RightScale account password.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the ServerID input for this Choreo. 

		@param Integer - (required, integer) The RightScale Server ID that is to be stopped.
		*/
		public void set_ServerID(Integer value) {
			this.setInput("ServerID", value);
		}

		/** 
		Set the value of the ServerID input for this Choreo as a String. 

		@param String - (required, integer) The RightScale Server ID that is to be stopped.
		*/
		public void set_ServerID(String value) {
			this.setInput("ServerID", value);	
		}

		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) The RightScale username.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetServerSettings Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetServerSettingsResultSet extends ResultSet {
		public GetServerSettingsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Rightscale in XML format.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
