package com.temboo.Library.RightScale;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
IndexDeployments

Retrieve a list of server assets grouped within a particular RightScale Deployment. 
*/
public class IndexDeployments extends Choreography {

	/**
	Create a new instance of the IndexDeployments Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public IndexDeployments(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/RightScale/IndexDeployments"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return IndexDeploymentsInputSet
	*/
	public IndexDeploymentsInputSet newInputSet() {
		return new IndexDeploymentsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public IndexDeploymentsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new IndexDeploymentsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the IndexDeployments
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class IndexDeploymentsInputSet extends InputSet {
		/** 
		Set the value of the AccountID input for this Choreo. 

		@param String - (required, string) The RightScale Account ID.
		*/
		public void set_AccountID(String value) {
			this.setInput("AccountID", value);
		}



		/** 
		Set the value of the Filter input for this Choreo. 

		@param String - (optional, string) An attributeName=AttributeValue filter pair. For example: nickname=mynick; OR description<>mydesc
		*/
		public void set_Filter(String value) {
			this.setInput("Filter", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The RightScale account password.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) The RightScale username.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



		/** 
		Set the value of the inputFile input for this Choreo. 

		@param TembooPath - 
		*/
		public void set_inputFile(TembooPath value) {
			this.setAlias("inputFile", value);
		}
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the IndexDeployments Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class IndexDeploymentsResultSet extends ResultSet {
		public IndexDeploymentsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Rightscale in XML format.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
