package com.temboo.Library.RightScale;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
RunRightScript

Executes a specified RightScript.
*/
public class RunRightScript extends Choreography {

	/**
	Create a new instance of the RunRightScript Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public RunRightScript(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/RightScale/RunRightScript"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return RunRightScriptInputSet
	*/
	public RunRightScriptInputSet newInputSet() {
		return new RunRightScriptInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public RunRightScriptResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new RunRightScriptResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the RunRightScript
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class RunRightScriptInputSet extends InputSet {
		/** 
		Set the value of the AccountID input for this Choreo. 

		@param String - (required, string) The RightScale Account ID.
		*/
		public void set_AccountID(String value) {
			this.setInput("AccountID", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The RightScale account password.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the RightScriptID input for this Choreo. 

		@param Integer - (required, integer) The ID of the RightScript.
		*/
		public void set_RightScriptID(Integer value) {
			this.setInput("RightScriptID", value);
		}

		/** 
		Set the value of the RightScriptID input for this Choreo as a String. 

		@param String - (required, integer) The ID of the RightScript.
		*/
		public void set_RightScriptID(String value) {
			this.setInput("RightScriptID", value);	
		}

		/** 
		Set the value of the ServerID input for this Choreo. 

		@param Integer - (required, integer) The RightScale Server ID that is to be stopped.
		*/
		public void set_ServerID(Integer value) {
			this.setInput("ServerID", value);
		}

		/** 
		Set the value of the ServerID input for this Choreo as a String. 

		@param String - (required, integer) The RightScale Server ID that is to be stopped.
		*/
		public void set_ServerID(String value) {
			this.setInput("ServerID", value);	
		}

		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) The RightScale username.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the RunRightScript Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class RunRightScriptResultSet extends ResultSet {
		public RunRightScriptResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Rightscale in XML format.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
