package com.temboo.Library.RightScale;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
StopServer

Stop a RightScale server instance. Optionally, this Choreo can also poll the stop process and verify server termination.
*/
public class StopServer extends Choreography {

	/**
	Create a new instance of the StopServer Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public StopServer(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/RightScale/StopServer"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return StopServerInputSet
	*/
	public StopServerInputSet newInputSet() {
		return new StopServerInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public StopServerResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new StopServerResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the StopServer
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class StopServerInputSet extends InputSet {
		/** 
		Set the value of the AccountID input for this Choreo. 

		@param Integer - (required, integer) The RightScale Account ID.
		*/
		public void set_AccountID(Integer value) {
			this.setInput("AccountID", value);
		}

		/** 
		Set the value of the AccountID input for this Choreo as a String. 

		@param String - (required, integer) The RightScale Account ID.
		*/
		public void set_AccountID(String value) {
			this.setInput("AccountID", value);	
		}

		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The RightScale account password.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the PollingTimeLimit input for this Choreo. 

		@param Integer - (optional, integer) Server status polling.  Enable by specifying a time limit - in minutes - for the duration of the server state polling.
		*/
		public void set_PollingTimeLimit(Integer value) {
			this.setInput("PollingTimeLimit", value);
		}

		/** 
		Set the value of the PollingTimeLimit input for this Choreo as a String. 

		@param String - (optional, integer) Server status polling.  Enable by specifying a time limit - in minutes - for the duration of the server state polling.
		*/
		public void set_PollingTimeLimit(String value) {
			this.setInput("PollingTimeLimit", value);	
		}

		/** 
		Set the value of the ServerID input for this Choreo. 

		@param Integer - (required, integer) The RightScale Server ID that is to be stopped.
		*/
		public void set_ServerID(Integer value) {
			this.setInput("ServerID", value);
		}

		/** 
		Set the value of the ServerID input for this Choreo as a String. 

		@param String - (required, integer) The RightScale Server ID that is to be stopped.
		*/
		public void set_ServerID(String value) {
			this.setInput("ServerID", value);	
		}

		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) The RightScale username.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the StopServer Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class StopServerResultSet extends ResultSet {
		public StopServerResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Rightscale in XML format.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** 
		Retrieve the value for the "State" output from this Choreo execution

		@return String - (string) The server 'state' parsed from the Rightscale response.
		*/
		public String get_State() {
			return this.getResult("State");
		}
	}
	
}
