package com.temboo.Library.RunKeeper.Profile;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
UpdateProfile

Update's a user's profile.
*/
public class UpdateProfile extends Choreography {

	/**
	Create a new instance of the UpdateProfile Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public UpdateProfile(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/RunKeeper/Profile/UpdateProfile"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return UpdateProfileInputSet
	*/
	public UpdateProfileInputSet newInputSet() {
		return new UpdateProfileInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public UpdateProfileResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new UpdateProfileResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the UpdateProfile
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class UpdateProfileInputSet extends InputSet {
		/** 
		Set the value of the Profile input for this Choreo. 

		@param String - (required, json) A JSON string containing the key/value pairs for the profile fields to update. See documentation for formatting examples.
		*/
		public void set_Profile(String value) {
			this.setInput("Profile", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token retrieved after the final step in the OAuth2 process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the UpdateProfile Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class UpdateProfileResultSet extends ResultSet {
		public UpdateProfileResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from RunKeeper.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
