package com.temboo.Library.RunKeeper.Settings;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
RetrieveSettings

Retrieves a user’s settings including a user's sharing and display preferences.
*/
public class RetrieveSettings extends Choreography {

	/**
	Create a new instance of the RetrieveSettings Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public RetrieveSettings(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/RunKeeper/Settings/RetrieveSettings"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return RetrieveSettingsInputSet
	*/
	public RetrieveSettingsInputSet newInputSet() {
		return new RetrieveSettingsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public RetrieveSettingsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new RetrieveSettingsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the RetrieveSettings
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class RetrieveSettingsInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token retrieved after the final step in the OAuth2 process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the RetrieveSettings Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class RetrieveSettingsResultSet extends ResultSet {
		public RetrieveSettingsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from RunKeeper.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
