package com.temboo.Library.RunKeeper.Settings;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
UpdateSettings

Updates a user’s settings.
*/
public class UpdateSettings extends Choreography {

	/**
	Create a new instance of the UpdateSettings Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public UpdateSettings(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/RunKeeper/Settings/UpdateSettings"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return UpdateSettingsInputSet
	*/
	public UpdateSettingsInputSet newInputSet() {
		return new UpdateSettingsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public UpdateSettingsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new UpdateSettingsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the UpdateSettings
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class UpdateSettingsInputSet extends InputSet {
		/** 
		Set the value of the Settings input for this Choreo. 

		@param String - (required, json) A JSON string containing the key/value pairs for the settings to update. See documentation for formatting examples.
		*/
		public void set_Settings(String value) {
			this.setInput("Settings", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token retrieved after the final step in the OAuth2 process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the UpdateSettings Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class UpdateSettingsResultSet extends ResultSet {
		public UpdateSettingsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from RunKeeper.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
