package com.temboo.Library.RunKeeper.StrengthTrainingActivities;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
UpdateActivity

Updates a past strength training activity.
*/
public class UpdateActivity extends Choreography {

	/**
	Create a new instance of the UpdateActivity Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public UpdateActivity(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/RunKeeper/StrengthTrainingActivities/UpdateActivity"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return UpdateActivityInputSet
	*/
	public UpdateActivityInputSet newInputSet() {
		return new UpdateActivityInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public UpdateActivityResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new UpdateActivityResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the UpdateActivity
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class UpdateActivityInputSet extends InputSet {
		/** 
		Set the value of the Activity input for this Choreo. 

		@param String - (required, json) A JSON string containing the key/value pairs for the activity to update. See documentation for formatting examples.
		*/
		public void set_Activity(String value) {
			this.setInput("Activity", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token retrieved after the final step in the OAuth2 process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ActivityID input for this Choreo. 

		@param Integer - (required, integer) This can be the individual id of the activity, or you can pass the full uri for the activity as returned from RetrieveActivities response (i.e. /strengthTrainingActivities/125927913).
		*/
		public void set_ActivityID(Integer value) {
			this.setInput("ActivityID", value);
		}

		/** 
		Set the value of the ActivityID input for this Choreo as a String. 

		@param String - (required, integer) This can be the individual id of the activity, or you can pass the full uri for the activity as returned from RetrieveActivities response (i.e. /strengthTrainingActivities/125927913).
		*/
		public void set_ActivityID(String value) {
			this.setInput("ActivityID", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the UpdateActivity Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class UpdateActivityResultSet extends ResultSet {
		public UpdateActivityResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from RunKeeper.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
