package com.temboo.Library.Salesforce;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
BatchCSVInsert

Create Salesforce Objects of any type (Account, Lead, Contact, etc) by specifying rows in CSV format.
*/
public class BatchCSVInsert extends Choreography {

	/**
	Create a new instance of the BatchCSVInsert Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public BatchCSVInsert(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Salesforce/BatchCSVInsert"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return BatchCSVInsertInputSet
	*/
	public BatchCSVInsertInputSet newInputSet() {
		return new BatchCSVInsertInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public BatchCSVInsertResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new BatchCSVInsertResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the BatchCSVInsert
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class BatchCSVInsertInputSet extends InputSet {
		/** 
		Set the value of the CSVInput input for this Choreo. 

		@param String - (conditional, multiline) CSV data to insert. Column names must match Salesforce field names exactly. Required unless using the VaultFile alias (an advanced option used when running Choreos in the Temboo Designer).
		*/
		public void set_CSVInput(String value) {
			this.setInput("CSVInput", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Salesforce password.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the SalesforceObjectType input for this Choreo. 

		@param String - (optional, string) The object type that you are inserting (i.e.Lead, Contact, Account). Defaults to Lead.
		*/
		public void set_SalesforceObjectType(String value) {
			this.setInput("SalesforceObjectType", value);
		}



		/** 
		Set the value of the SecurityToken input for this Choreo. 

		@param String - (required, string) Your Salesforce security token for making API calls.
		*/
		public void set_SecurityToken(String value) {
			this.setInput("SecurityToken", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) Your Salesforce username.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



		/** 
		Set the value of the VaultCSVFile input for this Choreo. 

		@param TembooPath - A path to a CSV file in the vault. Required unless specifying your data in CSVInput.
		*/
		public void set_VaultCSVFile(TembooPath value) {
			this.setAlias("VaultCSVFile", value);
		}
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the BatchCSVInsert Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class BatchCSVInsertResultSet extends ResultSet {
		public BatchCSVInsertResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Salesforce
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
