package com.temboo.Library.Salesforce;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
DeleteObject

Deletes a specified Salesforce Object.
*/
public class DeleteObject extends Choreography {

	/**
	Create a new instance of the DeleteObject Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DeleteObject(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Salesforce/DeleteObject"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DeleteObjectInputSet
	*/
	public DeleteObjectInputSet newInputSet() {
		return new DeleteObjectInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DeleteObjectResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DeleteObjectResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DeleteObject
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DeleteObjectInputSet extends InputSet {
		/** 
		Set the value of the ID input for this Choreo. 

		@param String - (required, string) The ID of the Object you wish to delete
		*/
		public void set_ID(String value) {
			this.setInput("ID", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Salesforce password.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the SecurityToken input for this Choreo. 

		@param String - (required, string) Your Salesforce security token used for API calls.
		*/
		public void set_SecurityToken(String value) {
			this.setInput("SecurityToken", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) Your Salesforce username.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DeleteObject Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DeleteObjectResultSet extends ResultSet {
		public DeleteObjectResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The full response from Salesforce
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
