package com.temboo.Library.Salesforce;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
UpdateAccountObject

Updates an Account Object name.
*/
public class UpdateAccountObject extends Choreography {

	/**
	Create a new instance of the UpdateAccountObject Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public UpdateAccountObject(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Salesforce/UpdateAccountObject"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return UpdateAccountObjectInputSet
	*/
	public UpdateAccountObjectInputSet newInputSet() {
		return new UpdateAccountObjectInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public UpdateAccountObjectResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new UpdateAccountObjectResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the UpdateAccountObject
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class UpdateAccountObjectInputSet extends InputSet {
		/** 
		Set the value of the AccountId input for this Choreo. 

		@param String - (required, string) The ID for the account you want to update
		*/
		public void set_AccountId(String value) {
			this.setInput("AccountId", value);
		}



		/** 
		Set the value of the AccountName input for this Choreo. 

		@param String - (required, string) A new name to update the Account with
		*/
		public void set_AccountName(String value) {
			this.setInput("AccountName", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Salesforce password.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the SecurityToken input for this Choreo. 

		@param String - (required, string) Your Salesforce security token used for making API calls.
		*/
		public void set_SecurityToken(String value) {
			this.setInput("SecurityToken", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) Your Salesforce username.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the UpdateAccountObject Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class UpdateAccountObjectResultSet extends ResultSet {
		public UpdateAccountObjectResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Salesforce
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
