package com.temboo.Library.SchoolFinder;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
DistrictSearch

Returns a list of school profiles and related school information for a zip code, city, state, or other criteria in the search parameters.
*/
public class DistrictSearch extends Choreography {

	/**
	Create a new instance of the DistrictSearch Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DistrictSearch(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/SchoolFinder/DistrictSearch"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DistrictSearchInputSet
	*/
	public DistrictSearchInputSet newInputSet() {
		return new DistrictSearchInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DistrictSearchResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DistrictSearchResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DistrictSearch
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DistrictSearchInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) Your School Finder API Key.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the City input for this Choreo. 

		@param String - (conditional, string) The name of a city. City requests must also be accompanied by the corresponding state parameter.
		*/
		public void set_City(String value) {
			this.setInput("City", value);
		}



		/** 
		Set the value of the DistrictID input for this Choreo. 

		@param String - (conditional, string) The internal Education.com id of a school district.
		*/
		public void set_DistrictID(String value) {
			this.setInput("DistrictID", value);
		}



		/** 
		Set the value of the DistrictLEA input for this Choreo. 

		@param String - (conditional, string) The NCES Local Education Agency (LEA) id of a school district.
		*/
		public void set_DistrictLEA(String value) {
			this.setInput("DistrictLEA", value);
		}



		/** 
		Set the value of the DistrictName input for this Choreo. 

		@param String - (conditional, string) The name of the district.
		*/
		public void set_DistrictName(String value) {
			this.setInput("DistrictName", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) Format of the response returned by Education.com. Defaluts to XML. JSON is also possible.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the State input for this Choreo. 

		@param String - (conditional, string) The two letter abbreviation of a state e.g. South Caroline should be formatted “SC”.
		*/
		public void set_State(String value) {
			this.setInput("State", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DistrictSearch Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DistrictSearchResultSet extends ResultSet {
		public DistrictSearchResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Education.com.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
