package com.temboo.Library.SchoolFinder;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetReviews

Returns a list of the most recent school reviews and parent rating for a single school.
*/
public class GetReviews extends Choreography {

	/**
	Create a new instance of the GetReviews Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetReviews(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/SchoolFinder/GetReviews"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetReviewsInputSet
	*/
	public GetReviewsInputSet newInputSet() {
		return new GetReviewsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetReviewsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetReviewsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetReviews
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetReviewsInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) Your School Finder API Key.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the NCES input for this Choreo. 

		@param String - (conditional, string) The National Center for Education Statistics (NCES) id of the school. NCES or SchoolID are required.
		*/
		public void set_NCES(String value) {
			this.setInput("NCES", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) Format of the response returned by Education.com. Defaluts to XML. JSON is also possible.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the SchoolID input for this Choreo. 

		@param String - (conditional, string) The Education.com id of the school you want to find. NCES or SchoolID are required.
		*/
		public void set_SchoolID(String value) {
			this.setInput("SchoolID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetReviews Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetReviewsResultSet extends ResultSet {
		public GetReviewsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Education.com.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
