package com.temboo.Library.SendGrid.NewsletterAPI.Newsletter;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
EditNewsletter

Edit an existing newsletter.
*/
public class EditNewsletter extends Choreography {

	/**
	Create a new instance of the EditNewsletter Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public EditNewsletter(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/SendGrid/NewsletterAPI/Newsletter/EditNewsletter"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return EditNewsletterInputSet
	*/
	public EditNewsletterInputSet newInputSet() {
		return new EditNewsletterInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public EditNewsletterResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new EditNewsletterResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the EditNewsletter
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class EditNewsletterInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key obtained from SendGrid.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the APIUser input for this Choreo. 

		@param String - (required, string) The username registered with SendGrid.
		*/
		public void set_APIUser(String value) {
			this.setInput("APIUser", value);
		}



		/** 
		Set the value of the HTML input for this Choreo. 

		@param String - (required, string) The html portion of the newsletter.
		*/
		public void set_HTML(String value) {
			this.setInput("HTML", value);
		}



		/** 
		Set the value of the Identity input for this Choreo. 

		@param String - (required, string) The new identity Identiy for the newsletter that is being edited.
		*/
		public void set_Identity(String value) {
			this.setInput("Identity", value);
		}



		/** 
		Set the value of the Name input for this Choreo. 

		@param String - (required, string) The name of the newsletter that is being edited.
		*/
		public void set_Name(String value) {
			this.setInput("Name", value);
		}



		/** 
		Set the value of the NewName input for this Choreo. 

		@param String - (required, string) The new name of the newsletter that is being edited.
		*/
		public void set_NewName(String value) {
			this.setInput("NewName", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format of the response from SendGrid, in either json, or xml.  Default is set to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the Subject input for this Choreo. 

		@param String - (required, string) The new subject for the edited newsletter.
		*/
		public void set_Subject(String value) {
			this.setInput("Subject", value);
		}



		/** 
		Set the value of the Text input for this Choreo. 

		@param String - (required, string) The text portion of the newsletter.
		*/
		public void set_Text(String value) {
			this.setInput("Text", value);
		}



		/** 
		Set the value of the VaultFile input for this Choreo. 

		@param TembooPath - 
		*/
		public void set_VaultFile(TembooPath value) {
			this.setAlias("VaultFile", value);
		}
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the EditNewsletter Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class EditNewsletterResultSet extends ResultSet {
		public EditNewsletterResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from SendGrid. The format corresponds to the ResponseFormat input. Default is json.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
