package com.temboo.Library.SendGrid.WebAPI.Bounces;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetBounces

Retrieve a list of bounced emails, with response codes, and optional dates.
*/
public class GetBounces extends Choreography {

	/**
	Create a new instance of the GetBounces Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetBounces(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/SendGrid/WebAPI/Bounces/GetBounces"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetBouncesInputSet
	*/
	public GetBouncesInputSet newInputSet() {
		return new GetBouncesInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetBouncesResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetBouncesResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetBounces
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetBouncesInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key obtained from SendGrid.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the APIUser input for this Choreo. 

		@param String - (required, string) The username registered with SendGrid.
		*/
		public void set_APIUser(String value) {
			this.setInput("APIUser", value);
		}



		/** 
		Set the value of the Date input for this Choreo. 

		@param String - (optional, string) The timestamp of the Block records. Enter 1 to return a date in a MySQL timestamp format - YYYY-MM-DD HH:MM:SS
		*/
		public void set_Date(String value) {
			this.setInput("Date", value);
		}



		/** 
		Set the value of the Days input for this Choreo. 

		@param Integer - (optional, integer) The number of days (greater than 0) for which block data will be retrieved.
		*/
		public void set_Days(Integer value) {
			this.setInput("Days", value);
		}

		/** 
		Set the value of the Days input for this Choreo as a String. 

		@param String - (optional, integer) The number of days (greater than 0) for which block data will be retrieved.
		*/
		public void set_Days(String value) {
			this.setInput("Days", value);	
		}

		/** 
		Set the value of the Email input for this Choreo. 

		@param String - (optional, string) The email to search for.
		*/
		public void set_Email(String value) {
			this.setInput("Email", value);
		}



		/** 
		Set the value of the EndDate input for this Choreo. 

		@param String - (optional, string) The end of the date range for which blocks are to be retireved. The specified date must be in YYYY-MM-DD format.
		*/
		public void set_EndDate(String value) {
			this.setInput("EndDate", value);
		}



		/** 
		Set the value of the Limit input for this Choreo. 

		@param Integer - (optional, integer) The number to limit the number of results returned.
		*/
		public void set_Limit(Integer value) {
			this.setInput("Limit", value);
		}

		/** 
		Set the value of the Limit input for this Choreo as a String. 

		@param String - (optional, integer) The number to limit the number of results returned.
		*/
		public void set_Limit(String value) {
			this.setInput("Limit", value);	
		}

		/** 
		Set the value of the Offset input for this Choreo. 

		@param Integer - (optional, integer) The beginning point in the list to retrieve bounces from.
		*/
		public void set_Offset(Integer value) {
			this.setInput("Offset", value);
		}

		/** 
		Set the value of the Offset input for this Choreo as a String. 

		@param String - (optional, integer) The beginning point in the list to retrieve bounces from.
		*/
		public void set_Offset(String value) {
			this.setInput("Offset", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format of the response from SendGrid, in either json, or xml.  Default is set to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the StartDate input for this Choreo. 

		@param String - (optional, string) The start of the date range for which blocks are to be retireved. The specified date must be in YYYY-MM-DD format, and must be earlier than the EndDate variable value.
		*/
		public void set_StartDate(String value) {
			this.setInput("StartDate", value);
		}



		/** 
		Set the value of the Type input for this Choreo. 

		@param String - (optional, string) The type of bounce to search for. Choice included are: hard, or soft.
		*/
		public void set_Type(String value) {
			this.setInput("Type", value);
		}



		/** 
		Set the value of the VaultFile input for this Choreo. 

		@param TembooPath - 
		*/
		public void set_VaultFile(TembooPath value) {
			this.setAlias("VaultFile", value);
		}
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetBounces Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetBouncesResultSet extends ResultSet {
		public GetBouncesResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from SendGrid. The format corresponds to the ResponseFormat input. Default is json.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
