package com.temboo.Library.SendGrid.WebAPI.FilterCommands;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ListAvailableApps

List all availalbe apps available through the SendGrid Web API.
*/
public class ListAvailableApps extends Choreography {

	/**
	Create a new instance of the ListAvailableApps Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListAvailableApps(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/SendGrid/WebAPI/FilterCommands/ListAvailableApps"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListAvailableAppsInputSet
	*/
	public ListAvailableAppsInputSet newInputSet() {
		return new ListAvailableAppsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListAvailableAppsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListAvailableAppsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListAvailableApps
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListAvailableAppsInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key obtained from SendGrid.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the APIUser input for this Choreo. 

		@param String - (required, string) The username registered with SendGrid.
		*/
		public void set_APIUser(String value) {
			this.setInput("APIUser", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The username registered with SendGrid.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the VaultFile input for this Choreo. 

		@param TembooPath - 
		*/
		public void set_VaultFile(TembooPath value) {
			this.setAlias("VaultFile", value);
		}
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListAvailableApps Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListAvailableAppsResultSet extends ResultSet {
		public ListAvailableAppsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from SendGrid. The format corresponds to the ResponseFormat input. Default is json.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
