package com.temboo.Library.SendGrid.WebAPI.Profile;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ResetPassword

Reset a SendGrid account password.
*/
public class ResetPassword extends Choreography {

	/**
	Create a new instance of the ResetPassword Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ResetPassword(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/SendGrid/WebAPI/Profile/ResetPassword"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ResetPasswordInputSet
	*/
	public ResetPasswordInputSet newInputSet() {
		return new ResetPasswordInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ResetPasswordResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ResetPasswordResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ResetPassword
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ResetPasswordInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key obtained from SendGrid.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the APIUser input for this Choreo. 

		@param String - (required, string) The username registered with SendGrid.
		*/
		public void set_APIUser(String value) {
			this.setInput("APIUser", value);
		}



		/** 
		Set the value of the ConfirmPassword input for this Choreo. 

		@param String - (required, string) The new account password.  Must match the string entered in the Password variable.  Minumum password length is 6 characters.
		*/
		public void set_ConfirmPassword(String value) {
			this.setInput("ConfirmPassword", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, string) The new account password of 6 characters or more.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format of the response from SendGrid, in either json, or xml.  Default is set to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the VaultFile input for this Choreo. 

		@param TembooPath - 
		*/
		public void set_VaultFile(TembooPath value) {
			this.setAlias("VaultFile", value);
		}
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ResetPassword Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ResetPasswordResultSet extends ResultSet {
		public ResetPasswordResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from SendGrid. The format corresponds to the ResponseFormat input. Default is json.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
