package com.temboo.Library.SendGrid.WebAPI.Unsubscribes;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
AddAddressToUnsubscribesList

Add an address to the Unsubscribe list.
*/
public class AddAddressToUnsubscribesList extends Choreography {

	/**
	Create a new instance of the AddAddressToUnsubscribesList Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public AddAddressToUnsubscribesList(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/SendGrid/WebAPI/Unsubscribes/AddAddressToUnsubscribesList"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return AddAddressToUnsubscribesListInputSet
	*/
	public AddAddressToUnsubscribesListInputSet newInputSet() {
		return new AddAddressToUnsubscribesListInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public AddAddressToUnsubscribesListResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new AddAddressToUnsubscribesListResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the AddAddressToUnsubscribesList
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class AddAddressToUnsubscribesListInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key obtained from SendGrid.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the APIUser input for this Choreo. 

		@param String - (required, string) The username registered with SendGrid.
		*/
		public void set_APIUser(String value) {
			this.setInput("APIUser", value);
		}



		/** 
		Set the value of the Email input for this Choreo. 

		@param String - (required, string) The valid email address to be added to the unsubscribed list.
		*/
		public void set_Email(String value) {
			this.setInput("Email", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format of the response from SendGrid, in either json, or xml.  Default is set to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the VaultFile input for this Choreo. 

		@param TembooPath - 
		*/
		public void set_VaultFile(TembooPath value) {
			this.setAlias("VaultFile", value);
		}
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the AddAddressToUnsubscribesList Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class AddAddressToUnsubscribesListResultSet extends ResultSet {
		public AddAddressToUnsubscribesListResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from SendGrid. The format corresponds to the ResponseFormat input. Default is json.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
