package com.temboo.Library.Stripe.Charges;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;
import com.temboo.outputs.Stripe.StripeCharge;

/** 
CreateNewChargeWithToken

Charges a credit card by creating a new charge object using a card token that is associated with the credit card details.
*/
public class CreateNewChargeWithToken extends Choreography {

	/**
	Create a new instance of the CreateNewChargeWithToken Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CreateNewChargeWithToken(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Stripe/Charges/CreateNewChargeWithToken"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CreateNewChargeWithTokenInputSet
	*/
	public CreateNewChargeWithTokenInputSet newInputSet() {
		return new CreateNewChargeWithTokenInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CreateNewChargeWithTokenResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CreateNewChargeWithTokenResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CreateNewChargeWithToken
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CreateNewChargeWithTokenInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Stripe
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Amount input for this Choreo. 

		@param Integer - (required, integer) The amount to charge a customer in cents
		*/
		public void set_Amount(Integer value) {
			this.setInput("Amount", value);
		}

		/** 
		Set the value of the Amount input for this Choreo as a String. 

		@param String - (required, integer) The amount to charge a customer in cents
		*/
		public void set_Amount(String value) {
			this.setInput("Amount", value);	
		}

		/** 
		Set the value of the Currency input for this Choreo. 

		@param String - (optional, string) 3-letter ISO code for currency. Defaults to 'usd' which is currently the only supported currency.
		*/
		public void set_Currency(String value) {
			this.setInput("Currency", value);
		}



		/** 
		Set the value of the Description input for this Choreo. 

		@param String - (optional, string) An arbitrary string of text that will be associated with the charge as a description
		*/
		public void set_Description(String value) {
			this.setInput("Description", value);
		}



		/** 
		Set the value of the Token input for this Choreo. 

		@param String - (required, string) The token associated with a set of credit card details. This can be generated with the CreateCardToken Choreo.
		*/
		public void set_Token(String value) {
			this.setInput("Token", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CreateNewChargeWithToken Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CreateNewChargeWithTokenResultSet extends ResultSet {
		public CreateNewChargeWithTokenResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Stripe
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** To charge a credit or a debit card, you create a new charge object. You can retrieve and refund individual charges as well as list all charges. Charges are identified by a unique random ID.
		*/
		public StripeCharge getCharge() {
		    return new StripeCharge(((JSONObject)getJSONFromString(this.getResult("Response"))));
		}
	}
	
}
