package com.temboo.Library.Stripe.Coupons;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;
import com.temboo.outputs.Stripe.StripeCouponList;

/** 
ListAllCoupons

Retrieves a a list of your coupons.
*/
public class ListAllCoupons extends Choreography {

	/**
	Create a new instance of the ListAllCoupons Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListAllCoupons(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Stripe/Coupons/ListAllCoupons"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListAllCouponsInputSet
	*/
	public ListAllCouponsInputSet newInputSet() {
		return new ListAllCouponsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListAllCouponsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListAllCouponsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListAllCoupons
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListAllCouponsInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Stripe
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Count input for this Choreo. 

		@param Integer - (optional, integer) A limit on the number of coupons to be returned. Valid values are 1 through 100.
		*/
		public void set_Count(Integer value) {
			this.setInput("Count", value);
		}

		/** 
		Set the value of the Count input for this Choreo as a String. 

		@param String - (optional, integer) A limit on the number of coupons to be returned. Valid values are 1 through 100.
		*/
		public void set_Count(String value) {
			this.setInput("Count", value);	
		}

		/** 
		Set the value of the Offset input for this Choreo. 

		@param Integer - (optional, integer) An offset into your coupons array. The API will return the requested number of coupons starting at that the specified offset.
		*/
		public void set_Offset(Integer value) {
			this.setInput("Offset", value);
		}

		/** 
		Set the value of the Offset input for this Choreo as a String. 

		@param String - (optional, integer) An offset into your coupons array. The API will return the requested number of coupons starting at that the specified offset.
		*/
		public void set_Offset(String value) {
			this.setInput("Offset", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListAllCoupons Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListAllCouponsResultSet extends ResultSet {
		public ListAllCouponsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Stripe
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** an array of Coupons
		*/
		public StripeCouponList getCouponList() {
		    return new StripeCouponList(((JSONObject)getJSONFromString(this.getResult("Response"))));
		}
	}
	
}
