package com.temboo.Library.Stripe.Customers;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;
import com.temboo.outputs.Stripe.StripeCustomer;

/** 
RetrieveCustomer

Retrieves the details of an existing customer record.
*/
public class RetrieveCustomer extends Choreography {

	/**
	Create a new instance of the RetrieveCustomer Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public RetrieveCustomer(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Stripe/Customers/RetrieveCustomer"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return RetrieveCustomerInputSet
	*/
	public RetrieveCustomerInputSet newInputSet() {
		return new RetrieveCustomerInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public RetrieveCustomerResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new RetrieveCustomerResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the RetrieveCustomer
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class RetrieveCustomerInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Stripe
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the CustomerID input for this Choreo. 

		@param String - (required, string) The unique identifier of the customer you want to retrieve
		*/
		public void set_CustomerID(String value) {
			this.setInput("CustomerID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the RetrieveCustomer Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class RetrieveCustomerResultSet extends ResultSet {
		public RetrieveCustomerResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Stripe
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** Customer objects allow you to perform recurring charges and track multiple charges that are associated with the same customer. The API allows you to create, delete, and update your customers. You can retrieve individual customers as well as a list of all your customers.
		*/
		public StripeCustomer getCustomer() {
		    return new StripeCustomer(((JSONObject)getJSONFromString(this.getResult("Response"))));
		}
	}
	
}
