package com.temboo.Library.Stripe.Events;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
RetrieveEvent

Retrieves the details of an event.
*/
public class RetrieveEvent extends Choreography {

	/**
	Create a new instance of the RetrieveEvent Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public RetrieveEvent(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Stripe/Events/RetrieveEvent"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return RetrieveEventInputSet
	*/
	public RetrieveEventInputSet newInputSet() {
		return new RetrieveEventInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public RetrieveEventResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new RetrieveEventResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the RetrieveEvent
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class RetrieveEventInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Stripe
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the EventID input for this Choreo. 

		@param String - (required, string) The id of the event to return.
		*/
		public void set_EventID(String value) {
			this.setInput("EventID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the RetrieveEvent Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class RetrieveEventResultSet extends ResultSet {
		public RetrieveEventResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Stripe
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
