package com.temboo.Library.Stripe.InvoiceItems;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;
import com.temboo.outputs.Stripe.StripeDeleteResults;

/** 
DeleteInvoiceItem

Deletes a specified invoice item.
*/
public class DeleteInvoiceItem extends Choreography {

	/**
	Create a new instance of the DeleteInvoiceItem Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DeleteInvoiceItem(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Stripe/InvoiceItems/DeleteInvoiceItem"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DeleteInvoiceItemInputSet
	*/
	public DeleteInvoiceItemInputSet newInputSet() {
		return new DeleteInvoiceItemInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DeleteInvoiceItemResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DeleteInvoiceItemResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DeleteInvoiceItem
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DeleteInvoiceItemInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Stripe
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the InvoiceItemID input for this Choreo. 

		@param String - (required, string) The unique identifier of the invoice item you want to delete
		*/
		public void set_InvoiceItemID(String value) {
			this.setInput("InvoiceItemID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DeleteInvoiceItem Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DeleteInvoiceItemResultSet extends ResultSet {
		public DeleteInvoiceItemResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Stripe
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** 
		*/
		public StripeDeleteResults getDeleteResults() {
		    return new StripeDeleteResults(((JSONObject)getJSONFromString(this.getResult("Response"))));
		}
	}
	
}
