package com.temboo.Library.Stripe.InvoiceItems;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;
import com.temboo.outputs.Stripe.StripeInvoiceItemList;

/** 
ListAllInvoiceItems

Returns a list of all invoice items or a list of invoice items for a specified customer.
*/
public class ListAllInvoiceItems extends Choreography {

	/**
	Create a new instance of the ListAllInvoiceItems Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListAllInvoiceItems(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Stripe/InvoiceItems/ListAllInvoiceItems"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListAllInvoiceItemsInputSet
	*/
	public ListAllInvoiceItemsInputSet newInputSet() {
		return new ListAllInvoiceItemsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListAllInvoiceItemsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListAllInvoiceItemsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListAllInvoiceItems
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListAllInvoiceItemsInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Stripe
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Count input for this Choreo. 

		@param Integer - (optional, integer) The limit of invoice items to be returned. Can range from 1 to 100. Defaults to 10.
		*/
		public void set_Count(Integer value) {
			this.setInput("Count", value);
		}

		/** 
		Set the value of the Count input for this Choreo as a String. 

		@param String - (optional, integer) The limit of invoice items to be returned. Can range from 1 to 100. Defaults to 10.
		*/
		public void set_Count(String value) {
			this.setInput("Count", value);	
		}

		/** 
		Set the value of the CustomerID input for this Choreo. 

		@param String - (optional, string) The unique identifier of the customer whose invoice items to return. If not specified, all invoice items will be returned.
		*/
		public void set_CustomerID(String value) {
			this.setInput("CustomerID", value);
		}



		/** 
		Set the value of the Offset input for this Choreo. 

		@param Integer - (optional, integer) Stripe will return a list of invoice items starting at the specified offset. Defaults to 0.
		*/
		public void set_Offset(Integer value) {
			this.setInput("Offset", value);
		}

		/** 
		Set the value of the Offset input for this Choreo as a String. 

		@param String - (optional, integer) Stripe will return a list of invoice items starting at the specified offset. Defaults to 0.
		*/
		public void set_Offset(String value) {
			this.setInput("Offset", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListAllInvoiceItems Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListAllInvoiceItemsResultSet extends ResultSet {
		public ListAllInvoiceItemsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Stripe
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** A list of InvoiceItems
		*/
		public StripeInvoiceItemList getInvoiceItemList() {
		    return new StripeInvoiceItemList(((JSONObject)getJSONFromString(this.getResult("Response"))));
		}
	}
	
}
