package com.temboo.Library.Stripe.InvoiceItems;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;
import com.temboo.outputs.Stripe.StripeInvoiceItem;

/** 
RetrieveInvoiceItem

Retrieves invoice items with a specified id.
*/
public class RetrieveInvoiceItem extends Choreography {

	/**
	Create a new instance of the RetrieveInvoiceItem Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public RetrieveInvoiceItem(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Stripe/InvoiceItems/RetrieveInvoiceItem"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return RetrieveInvoiceItemInputSet
	*/
	public RetrieveInvoiceItemInputSet newInputSet() {
		return new RetrieveInvoiceItemInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public RetrieveInvoiceItemResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new RetrieveInvoiceItemResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the RetrieveInvoiceItem
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class RetrieveInvoiceItemInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The secret API Key provided by Stripe
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the InvoiceItemID input for this Choreo. 

		@param String - (required, string) The unique identifier of the invoice item you want to retrieve
		*/
		public void set_InvoiceItemID(String value) {
			this.setInput("InvoiceItemID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the RetrieveInvoiceItem Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class RetrieveInvoiceItemResultSet extends ResultSet {
		public RetrieveInvoiceItemResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Stripe
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** Sometimes you want to add a charge or credit to a customer but only actually charge the customer's card at the end of a regular billing cycle. This is useful for combining several charges to minimize per-transaction fees or having Stripe tabulate your usage-based billing totals.
		*/
		public StripeInvoiceItem getInvoiceItem() {
		    return new StripeInvoiceItem(((JSONObject)getJSONFromString(this.getResult("Response"))));
		}
	}
	
}
