package com.temboo.Library.Stripe.Invoices;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;
import com.temboo.outputs.Stripe.StripeInvoice;

/** 
PayInvoice

Allows your application to attempt to collect payment on an invoice outside of the normal recurring payment schedule.
*/
public class PayInvoice extends Choreography {

	/**
	Create a new instance of the PayInvoice Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public PayInvoice(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Stripe/Invoices/PayInvoice"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return PayInvoiceInputSet
	*/
	public PayInvoiceInputSet newInputSet() {
		return new PayInvoiceInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public PayInvoiceResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new PayInvoiceResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the PayInvoice
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class PayInvoiceInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Stripe
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the InvoiceID input for this Choreo. 

		@param String - (required, string) The id of the invoice to pay.
		*/
		public void set_InvoiceID(String value) {
			this.setInput("InvoiceID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the PayInvoice Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class PayInvoiceResultSet extends ResultSet {
		public PayInvoiceResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Stripe
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** A reference to the Stripe Invoice object
		*/
		public StripeInvoice getInvoice() {
		    return new StripeInvoice(((JSONObject)getJSONFromString(this.getResult("Response"))));
		}
	}
	
}
