package com.temboo.Library.Stripe.Invoices;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;
import com.temboo.outputs.Stripe.StripeInvoice;

/** 
RetrieveInvoice

Retrieves invoice details using the invoice id.
*/
public class RetrieveInvoice extends Choreography {

	/**
	Create a new instance of the RetrieveInvoice Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public RetrieveInvoice(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Stripe/Invoices/RetrieveInvoice"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return RetrieveInvoiceInputSet
	*/
	public RetrieveInvoiceInputSet newInputSet() {
		return new RetrieveInvoiceInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public RetrieveInvoiceResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new RetrieveInvoiceResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the RetrieveInvoice
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class RetrieveInvoiceInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Stripe
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the InvoiceID input for this Choreo. 

		@param String - (required, string) The unique identifier of the invoice you want to retrieve
		*/
		public void set_InvoiceID(String value) {
			this.setInput("InvoiceID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the RetrieveInvoice Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class RetrieveInvoiceResultSet extends ResultSet {
		public RetrieveInvoiceResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Stripe
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** A reference to the Stripe Invoice object
		*/
		public StripeInvoice getInvoice() {
		    return new StripeInvoice(((JSONObject)getJSONFromString(this.getResult("Response"))));
		}
	}
	
}
