package com.temboo.Library.Stripe.Invoices;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;
import com.temboo.outputs.Stripe.StripeInvoice;

/** 
RetrieveUpcomingInvoice

Retrieves a customer's upcoming invoice.
*/
public class RetrieveUpcomingInvoice extends Choreography {

	/**
	Create a new instance of the RetrieveUpcomingInvoice Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public RetrieveUpcomingInvoice(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Stripe/Invoices/RetrieveUpcomingInvoice"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return RetrieveUpcomingInvoiceInputSet
	*/
	public RetrieveUpcomingInvoiceInputSet newInputSet() {
		return new RetrieveUpcomingInvoiceInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public RetrieveUpcomingInvoiceResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new RetrieveUpcomingInvoiceResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the RetrieveUpcomingInvoice
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class RetrieveUpcomingInvoiceInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Stripe
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the CustomerID input for this Choreo. 

		@param String - (required, string) The unique identifier of the customer whose upcoming invoice to return
		*/
		public void set_CustomerID(String value) {
			this.setInput("CustomerID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the RetrieveUpcomingInvoice Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class RetrieveUpcomingInvoiceResultSet extends ResultSet {
		public RetrieveUpcomingInvoiceResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Stripe
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** A reference to the Stripe Invoice object
		*/
		public StripeInvoice getInvoice() {
		    return new StripeInvoice(((JSONObject)getJSONFromString(this.getResult("Response"))));
		}
	}
	
}
