package com.temboo.Library.Stripe.Invoices;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;
import com.temboo.outputs.Stripe.StripeInvoice;

/** 
UpdateInvoice

Updates an existing invoice.
*/
public class UpdateInvoice extends Choreography {

	/**
	Create a new instance of the UpdateInvoice Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public UpdateInvoice(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Stripe/Invoices/UpdateInvoice"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return UpdateInvoiceInputSet
	*/
	public UpdateInvoiceInputSet newInputSet() {
		return new UpdateInvoiceInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public UpdateInvoiceResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new UpdateInvoiceResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the UpdateInvoice
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class UpdateInvoiceInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Stripe
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Closed input for this Choreo. 

		@param Boolean - (conditional, boolean) Whether or not the invoice should be closed or not. To close an invoice, set this to "true".
		*/
		public void set_Closed(Boolean value) {
			this.setInput("Closed", value);
		}

		/** 
		Set the value of the Closed input for this Choreo as a String. 

		@param String - (conditional, boolean) Whether or not the invoice should be closed or not. To close an invoice, set this to "true".
		*/
		public void set_Closed(String value) {
			this.setInput("Closed", value);	
		}

		/** 
		Set the value of the InvoiceID input for this Choreo. 

		@param String - (required, string) The id of the invoice to update.
		*/
		public void set_InvoiceID(String value) {
			this.setInput("InvoiceID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the UpdateInvoice Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class UpdateInvoiceResultSet extends ResultSet {
		public UpdateInvoiceResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Stripe
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** A reference to the Stripe Invoice object
		*/
		public StripeInvoice getInvoice() {
		    return new StripeInvoice(((JSONObject)getJSONFromString(this.getResult("Response"))));
		}
	}
	
}
