package com.temboo.Library.Stripe.Plans;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;
import com.temboo.outputs.Stripe.StripePlan;

/** 
RetrievePlan

Retrieves plan details with a specified plan id.
*/
public class RetrievePlan extends Choreography {

	/**
	Create a new instance of the RetrievePlan Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public RetrievePlan(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Stripe/Plans/RetrievePlan"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return RetrievePlanInputSet
	*/
	public RetrievePlanInputSet newInputSet() {
		return new RetrievePlanInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public RetrievePlanResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new RetrievePlanResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the RetrievePlan
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class RetrievePlanInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Stripe
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the PlanID input for this Choreo. 

		@param String - (required, string) The unique identifier of the plan you want to retrieve
		*/
		public void set_PlanID(String value) {
			this.setInput("PlanID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the RetrievePlan Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class RetrievePlanResultSet extends ResultSet {
		public RetrievePlanResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Stripe
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** A subscription plan contains the pricing information for different products and feature levels on your site. For example, you might have a $10/month plan for basic features and a different $20/month plan for premium features.
		*/
		public StripePlan getPlan() {
		    return new StripePlan(((JSONObject)getJSONFromString(this.getResult("Response"))));
		}
	}
	
}
