package com.temboo.Library.Stripe.Subscriptions;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;
import com.temboo.outputs.Stripe.StripeSubscription;

/** 
CancelSubscription

Cancels an existing subscription.
*/
public class CancelSubscription extends Choreography {

	/**
	Create a new instance of the CancelSubscription Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CancelSubscription(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Stripe/Subscriptions/CancelSubscription"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CancelSubscriptionInputSet
	*/
	public CancelSubscriptionInputSet newInputSet() {
		return new CancelSubscriptionInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CancelSubscriptionResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CancelSubscriptionResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CancelSubscription
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CancelSubscriptionInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Stripe
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the AtPeriodEnd input for this Choreo. 

		@param Boolean - (optional, boolean) Delays the cancellation of the subscription until the end of the current period when set to 1. Defaults to 0.
		*/
		public void set_AtPeriodEnd(Boolean value) {
			this.setInput("AtPeriodEnd", value);
		}

		/** 
		Set the value of the AtPeriodEnd input for this Choreo as a String. 

		@param String - (optional, boolean) Delays the cancellation of the subscription until the end of the current period when set to 1. Defaults to 0.
		*/
		public void set_AtPeriodEnd(String value) {
			this.setInput("AtPeriodEnd", value);	
		}

		/** 
		Set the value of the CustomerID input for this Choreo. 

		@param String - (required, string) The id of the customer whose subscription you want to cancel
		*/
		public void set_CustomerID(String value) {
			this.setInput("CustomerID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CancelSubscription Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CancelSubscriptionResultSet extends ResultSet {
		public CancelSubscriptionResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Stripe
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** a Stripe Subscription
		*/
		public StripeSubscription getSubscription() {
		    return new StripeSubscription(((JSONObject)getJSONFromString(this.getResult("Response"))));
		}
	}
	
}
