package com.temboo.Library.Stripe.Tokens;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;
import com.temboo.outputs.Stripe.StripeToken;

/** 
RetrieveCardToken

Retrieves a card token based on a given id.
*/
public class RetrieveCardToken extends Choreography {

	/**
	Create a new instance of the RetrieveCardToken Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public RetrieveCardToken(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Stripe/Tokens/RetrieveCardToken"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return RetrieveCardTokenInputSet
	*/
	public RetrieveCardTokenInputSet newInputSet() {
		return new RetrieveCardTokenInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public RetrieveCardTokenResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new RetrieveCardTokenResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the RetrieveCardToken
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class RetrieveCardTokenInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Stripe
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the TokenID input for this Choreo. 

		@param String - (required, string) The unique identifier of the token you want to retrieve
		*/
		public void set_TokenID(String value) {
			this.setInput("TokenID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the RetrieveCardToken Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class RetrieveCardTokenResultSet extends ResultSet {
		public RetrieveCardTokenResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Stripe
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** Reference to Stripe Token object
		*/
		public StripeToken getToken() {
		    return new StripeToken(((JSONObject)getJSONFromString(this.getResult("Response"))));
		}
	}
	
}
