package com.temboo.Library.SunlightLabs.CapitolWords;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Dates

Returns the popularity of a given phrase in the Congressional Record over time.
*/
public class Dates extends Choreography {

	/**
	Create a new instance of the Dates Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Dates(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/SunlightLabs/CapitolWords/Dates"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DatesInputSet
	*/
	public DatesInputSet newInputSet() {
		return new DatesInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DatesResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DatesResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Dates
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DatesInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Sunlight Labs.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the BioguideID input for this Choreo. 

		@param String - (optional, string) Limit results to the member of Congress with the given Bioguide ID. The Bioguide ID of any current or past congressional member can be found at bioguide.congress.gov.
		*/
		public void set_BioguideID(String value) {
			this.setInput("BioguideID", value);
		}



		/** 
		Set the value of the Chamber input for this Choreo. 

		@param String - (optional, string) Limit results to a particular chamber. Valid values: house, senate, extensions.
		*/
		public void set_Chamber(String value) {
			this.setInput("Chamber", value);
		}



		/** 
		Set the value of the Date input for this Choreo. 

		@param String - (optional, string) Show results for only the given date. Format: YYYY-MM-DD
		*/
		public void set_Date(String value) {
			this.setInput("Date", value);
		}



		/** 
		Set the value of the EndDate input for this Choreo. 

		@param String - (optional, string) Limit results to those on or before the given date. Format: YYYY-MM-DD.
		*/
		public void set_EndDate(String value) {
			this.setInput("EndDate", value);
		}



		/** 
		Set the value of the Granularity input for this Choreo. 

		@param String - (optional, string) The length of time covered by each result. Valid values: year, month, day. Defaults to day.
		*/
		public void set_Granularity(String value) {
			this.setInput("Granularity", value);
		}



		/** 
		Set the value of the MinCount input for this Choreo. 

		@param Boolean - (optional, boolean) Only returns results where mentions are at or above the supplied threshold.
		*/
		public void set_MinCount(Boolean value) {
			this.setInput("MinCount", value);
		}

		/** 
		Set the value of the MinCount input for this Choreo as a String. 

		@param String - (optional, boolean) Only returns results where mentions are at or above the supplied threshold.
		*/
		public void set_MinCount(String value) {
			this.setInput("MinCount", value);	
		}

		/** 
		Set the value of the Party input for this Choreo. 

		@param String - (optional, string) Limit results to members of congress from a given party. Valid values: R, D, I.
		*/
		public void set_Party(String value) {
			this.setInput("Party", value);
		}



		/** 
		Set the value of the Percentages input for this Choreo. 

		@param String - (optional, string) Include the percentage of mentions versus total words in the result objects. Valid values: true, false. Defaults to false.
		*/
		public void set_Percentages(String value) {
			this.setInput("Percentages", value);
		}



		/** 
		Set the value of the Phrase input for this Choreo. 

		@param String - (required, string) The phrase to search for.
		*/
		public void set_Phrase(String value) {
			this.setInput("Phrase", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) Output formats inlcude json and xml. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the StartDate input for this Choreo. 

		@param String - (optional, string) Limit results to those on or after the given date. Format: YYYY-MM-DD
		*/
		public void set_StartDate(String value) {
			this.setInput("StartDate", value);
		}



		/** 
		Set the value of the State input for this Choreo. 

		@param String - (optional, string) Limit results to members from a particular state. Format: 2-letter state abbreviation (e.g. MD, RI, NY)
		*/
		public void set_State(String value) {
			this.setInput("State", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Dates Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DatesResultSet extends ResultSet {
		public DatesResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from CapitolWords.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
