package com.temboo.Library.SunlightLabs.Congress.Committee;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetCommitteesByLegislator

Returns a list of all committees that a specified member serves on, including subcommittes.
*/
public class GetCommitteesByLegislator extends Choreography {

	/**
	Create a new instance of the GetCommitteesByLegislator Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetCommitteesByLegislator(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/SunlightLabs/Congress/Committee/GetCommitteesByLegislator"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetCommitteesByLegislatorInputSet
	*/
	public GetCommitteesByLegislatorInputSet newInputSet() {
		return new GetCommitteesByLegislatorInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetCommitteesByLegislatorResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetCommitteesByLegislatorResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetCommitteesByLegislator
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetCommitteesByLegislatorInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Sunlight Labs.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the BioGuideID input for this Choreo. 

		@param String - (required, string) A legislator's bioguide_id. Note that this can be retrieved by running the Choreos within the Congress.Legislator bundle.
		*/
		public void set_BioGuideID(String value) {
			this.setInput("BioGuideID", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and xml.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetCommitteesByLegislator Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetCommitteesByLegislatorResultSet extends ResultSet {
		public GetCommitteesByLegislatorResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from the Sunlight Congress API.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
