package com.temboo.Library.SunlightLabs.Congress.District;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetDistrictsByZip

Returns all districts that overlap the area for a given zip code.
*/
public class GetDistrictsByZip extends Choreography {

	/**
	Create a new instance of the GetDistrictsByZip Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetDistrictsByZip(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/SunlightLabs/Congress/District/GetDistrictsByZip"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetDistrictsByZipInputSet
	*/
	public GetDistrictsByZipInputSet newInputSet() {
		return new GetDistrictsByZipInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetDistrictsByZipResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetDistrictsByZipResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetDistrictsByZip
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetDistrictsByZipInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Sunlight Labs.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and xml.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the Zip input for this Choreo. 

		@param String - (required, string) The zip code for the districts to return.
		*/
		public void set_Zip(String value) {
			this.setInput("Zip", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetDistrictsByZip Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetDistrictsByZipResultSet extends ResultSet {
		public GetDistrictsByZipResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from the Sunlight Congress API.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
