package com.temboo.Library.Tumblr.User;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
FollowUser

Retrieves the user information associated with a given set of Tumblr Oauth credentials.
*/
public class FollowUser extends Choreography {

	/**
	Create a new instance of the FollowUser Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public FollowUser(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Tumblr/User/FollowUser"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return FollowUserInputSet
	*/
	public FollowUserInputSet newInputSet() {
		return new FollowUserInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public FollowUserResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new FollowUserResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the FollowUser
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class FollowUserInputSet extends InputSet {
		/** 
		Set the value of the URL input for this Choreo. 

		@param String - (required, string) The URL of the user / blog to follow, without http:. Ex: username.tumblr.com
		*/
		public void set_URL(String value) {
			this.setInput("URL", value);
		}



		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Tumblr (AKA the OAuth Consumer Key).
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the AccessTokenSecret input for this Choreo. 

		@param String - (required, string) The Access Token Secret retrieved during the OAuth process.
		*/
		public void set_AccessTokenSecret(String value) {
			this.setInput("AccessTokenSecret", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token retrieved during the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the SecretKey input for this Choreo. 

		@param String - (required, string) The Secret Key provided by Tumblr (AKA the OAuth Consumer Secret).
		*/
		public void set_SecretKey(String value) {
			this.setInput("SecretKey", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the FollowUser Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class FollowUserResultSet extends ResultSet {
		public FollowUserResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Tumblr. Default is JSON, can be set to XML by entering 'xml' in ResponseFormat.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
