package com.temboo.Library.Twilio.Accounts;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CreateAccount

Creates a Twilio subaccount.
*/
public class CreateAccount extends Choreography {

	/**
	Create a new instance of the CreateAccount Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CreateAccount(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Twilio/Accounts/CreateAccount"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CreateAccountInputSet
	*/
	public CreateAccountInputSet newInputSet() {
		return new CreateAccountInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CreateAccountResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CreateAccountResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CreateAccount
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CreateAccountInputSet extends InputSet {
		/** 
		Set the value of the AccountSID input for this Choreo. 

		@param String - (required, string) The AccountSID provided by Twilio.
		*/
		public void set_AccountSID(String value) {
			this.setInput("AccountSID", value);
		}



		/** 
		Set the value of the AuthToken input for this Choreo. 

		@param String - (required, string) The authorization token provided by Twilio.
		*/
		public void set_AuthToken(String value) {
			this.setInput("AuthToken", value);
		}



		/** 
		Set the value of the FriendlyName input for this Choreo. 

		@param String - (optional, string) Enter a name for the subaccount being created.
		*/
		public void set_FriendlyName(String value) {
			this.setInput("FriendlyName", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are json (the default) and xml.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CreateAccount Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CreateAccountResultSet extends ResultSet {
		public CreateAccountResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Twilio.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
