package com.temboo.Library.Twilio.Calls;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
MakeCall

Initiates a call from the specified Twilio account.
*/
public class MakeCall extends Choreography {

	/**
	Create a new instance of the MakeCall Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public MakeCall(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Twilio/Calls/MakeCall"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return MakeCallInputSet
	*/
	public MakeCallInputSet newInputSet() {
		return new MakeCallInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public MakeCallResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new MakeCallResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the MakeCall
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class MakeCallInputSet extends InputSet {
		/** 
		Set the value of the AccountSID input for this Choreo. 

		@param String - (required, string) The AccountSID provided when you signed up for a Twilio account.
		*/
		public void set_AccountSID(String value) {
			this.setInput("AccountSID", value);
		}



		/** 
		Set the value of the ApplicationSID input for this Choreo. 

		@param String - (conditional, string) The 34 character sid of the application Twilio should use to handle this phone call. Required unless providing the URL parameter.
		*/
		public void set_ApplicationSID(String value) {
			this.setInput("ApplicationSID", value);
		}



		/** 
		Set the value of the AuthToken input for this Choreo. 

		@param String - (required, string) The authorization token provided when you signed up for a Twilio account.
		*/
		public void set_AuthToken(String value) {
			this.setInput("AuthToken", value);
		}



		/** 
		Set the value of the FallbackMethod input for this Choreo. 

		@param String - (optional, string) 
		*/
		public void set_FallbackMethod(String value) {
			this.setInput("FallbackMethod", value);
		}



		/** 
		Set the value of the FallbackURL input for this Choreo. 

		@param String - (optional, string) A URL that Twilio will request if an error occurs making a request to the URL provided. This is ignored when ApplicationSID is provided.
		*/
		public void set_FallbackURL(String value) {
			this.setInput("FallbackURL", value);
		}



		/** 
		Set the value of the From input for this Choreo. 

		@param String - (required, string) The Twilio phone number or client identifier to use as the caller id.
		*/
		public void set_From(String value) {
			this.setInput("From", value);
		}



		/** 
		Set the value of the IfMachine input for this Choreo. 

		@param String - (optional, string) Indicates if Twilio should to try and determine if a machine (like voicemail) or a human has answered the call. Possible values are "Continue" and "Hangup".
		*/
		public void set_IfMachine(String value) {
			this.setInput("IfMachine", value);
		}



		/** 
		Set the value of the Method input for this Choreo. 

		@param String - (optional, string) This the HTTP method Twilio will use when making its request to the URL (when the URL input is provided). Defaults to POST. This is ignored when ApplicationSID is provided.
		*/
		public void set_Method(String value) {
			this.setInput("Method", value);
		}



		/** 
		Set the value of the Record input for this Choreo. 

		@param Boolean - (optional, boolean) Set this parameter to 'true' to record the entirety of a phone call.
		*/
		public void set_Record(Boolean value) {
			this.setInput("Record", value);
		}

		/** 
		Set the value of the Record input for this Choreo as a String. 

		@param String - (optional, boolean) Set this parameter to 'true' to record the entirety of a phone call.
		*/
		public void set_Record(String value) {
			this.setInput("Record", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and xml.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the SendDigits input for this Choreo. 

		@param String - (optional, string) A string of keys to dial after connecting to the number. Valid digits in the string include: any digit (0-9), '#', '*' and 'w' (to insert a half second pause).
		*/
		public void set_SendDigits(String value) {
			this.setInput("SendDigits", value);
		}



		/** 
		Set the value of the StatusCallbackMethod input for this Choreo. 

		@param String - (optional, string) The HTTP method Twilio should use when requesting the StatusCallback URL. Defaults to POST. If an ApplicationSid parameter is present, this parameter is ignored.
		*/
		public void set_StatusCallbackMethod(String value) {
			this.setInput("StatusCallbackMethod", value);
		}



		/** 
		Set the value of the StatusCallback input for this Choreo. 

		@param String - (optional, string) A URL that Twilio will request when the call ends to notify your app. This is ignored when ApplicationSID is provided.
		*/
		public void set_StatusCallback(String value) {
			this.setInput("StatusCallback", value);
		}



		/** 
		Set the value of the SubAccountSID input for this Choreo. 

		@param String - (optional, string) The SID of the subaccount associated with this call. If not specified, the main AccountSID used to authenticate is used in request.
		*/
		public void set_SubAccountSID(String value) {
			this.setInput("SubAccountSID", value);
		}



		/** 
		Set the value of the Timeout input for this Choreo. 

		@param Integer - (optional, integer) The integer number of seconds that Twilio should allow the phone to ring before assuming there is no answer. Default is 60 seconds, the maximum is 999 seconds.
		*/
		public void set_Timeout(Integer value) {
			this.setInput("Timeout", value);
		}

		/** 
		Set the value of the Timeout input for this Choreo as a String. 

		@param String - (optional, integer) The integer number of seconds that Twilio should allow the phone to ring before assuming there is no answer. Default is 60 seconds, the maximum is 999 seconds.
		*/
		public void set_Timeout(String value) {
			this.setInput("Timeout", value);	
		}

		/** 
		Set the value of the To input for this Choreo. 

		@param String - (required, string) The phone number or client identifier to call.
		*/
		public void set_To(String value) {
			this.setInput("To", value);
		}



		/** 
		Set the value of the URL input for this Choreo. 

		@param String - (conditional, string) The fully qualified URL that should be consulted when the call connects. Required unless providing the ApplicationSID parameter.
		*/
		public void set_URL(String value) {
			this.setInput("URL", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the MakeCall Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class MakeCallResultSet extends ResultSet {
		public MakeCallResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Twilio.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
