package com.temboo.Library.Twilio.Conferences;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetConference

Returns an individual conference.
*/
public class GetConference extends Choreography {

	/**
	Create a new instance of the GetConference Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetConference(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Twilio/Conferences/GetConference"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetConferenceInputSet
	*/
	public GetConferenceInputSet newInputSet() {
		return new GetConferenceInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetConferenceResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetConferenceResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetConference
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetConferenceInputSet extends InputSet {
		/** 
		Set the value of the AccountSID input for this Choreo. 

		@param String - (required, string) The AccountSID provided when you signed up for a Twilio account.
		*/
		public void set_AccountSID(String value) {
			this.setInput("AccountSID", value);
		}



		/** 
		Set the value of the AuthToken input for this Choreo. 

		@param String - (required, string) The authorization token provided when you signed up for a Twilio account.
		*/
		public void set_AuthToken(String value) {
			this.setInput("AuthToken", value);
		}



		/** 
		Set the value of the ConferenceSID input for this Choreo. 

		@param String - (required, string) The id of the conference to retrieve.
		*/
		public void set_ConferenceSID(String value) {
			this.setInput("ConferenceSID", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and xml.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the SubAccountSID input for this Choreo. 

		@param String - (optional, string) The SID of the subaccount associated with the conference. If not specified, the main AccountSID used to authenticate is used in the request.
		*/
		public void set_SubAccountSID(String value) {
			this.setInput("SubAccountSID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetConference Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetConferenceResultSet extends ResultSet {
		public GetConferenceResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Twilio.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
