package com.temboo.Library.Twilio.ConnectApps;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetConnectApp

Retrieves the details for an individual Connect App associated with a Twilio account.
*/
public class GetConnectApp extends Choreography {

	/**
	Create a new instance of the GetConnectApp Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetConnectApp(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Twilio/ConnectApps/GetConnectApp"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetConnectAppInputSet
	*/
	public GetConnectAppInputSet newInputSet() {
		return new GetConnectAppInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetConnectAppResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetConnectAppResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetConnectApp
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetConnectAppInputSet extends InputSet {
		/** 
		Set the value of the AccountSID input for this Choreo. 

		@param String - (required, string) The AccountSID provided when you signed up for a Twilio account.
		*/
		public void set_AccountSID(String value) {
			this.setInput("AccountSID", value);
		}



		/** 
		Set the value of the AuthToken input for this Choreo. 

		@param String - (required, string) The authorization token provided when you signed up for a Twilio account.
		*/
		public void set_AuthToken(String value) {
			this.setInput("AuthToken", value);
		}



		/** 
		Set the value of the ConnectAppSID input for this Choreo. 

		@param String - (required, string) The id of the Connect App to retrieve.
		*/
		public void set_ConnectAppSID(String value) {
			this.setInput("ConnectAppSID", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and xml.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetConnectApp Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetConnectAppResultSet extends ResultSet {
		public GetConnectAppResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Twilio.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
