package com.temboo.Library.Twilio.IncomingPhoneNumbers;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ListPhoneNumbers

Returns a list of Twilio phone numbers purchased from Twilio or ported to Twilio.
*/
public class ListPhoneNumbers extends Choreography {

	/**
	Create a new instance of the ListPhoneNumbers Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListPhoneNumbers(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Twilio/IncomingPhoneNumbers/ListPhoneNumbers"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListPhoneNumbersInputSet
	*/
	public ListPhoneNumbersInputSet newInputSet() {
		return new ListPhoneNumbersInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListPhoneNumbersResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListPhoneNumbersResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListPhoneNumbers
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListPhoneNumbersInputSet extends InputSet {
		/** 
		Set the value of the AccountSID input for this Choreo. 

		@param String - (required, string) The AccountSID provided when you signed up for a Twilio account.
		*/
		public void set_AccountSID(String value) {
			this.setInput("AccountSID", value);
		}



		/** 
		Set the value of the AuthToken input for this Choreo. 

		@param String - (required, string) The authorization token provided when you signed up for a Twilio account.
		*/
		public void set_AuthToken(String value) {
			this.setInput("AuthToken", value);
		}



		/** 
		Set the value of the FriendlyName input for this Choreo. 

		@param String - (optional, string) Only return the incoming phone number resources with friendly names that exactly match this name.
		*/
		public void set_FriendlyName(String value) {
			this.setInput("FriendlyName", value);
		}



		/** 
		Set the value of the PageSize input for this Choreo. 

		@param Integer - (optional, integer) The number of results per page.
		*/
		public void set_PageSize(Integer value) {
			this.setInput("PageSize", value);
		}

		/** 
		Set the value of the PageSize input for this Choreo as a String. 

		@param String - (optional, integer) The number of results per page.
		*/
		public void set_PageSize(String value) {
			this.setInput("PageSize", value);	
		}

		/** 
		Set the value of the Page input for this Choreo. 

		@param Integer - (optional, integer) The page of results to retrieve. Defaults to 0.
		*/
		public void set_Page(Integer value) {
			this.setInput("Page", value);
		}

		/** 
		Set the value of the Page input for this Choreo as a String. 

		@param String - (optional, integer) The page of results to retrieve. Defaults to 0.
		*/
		public void set_Page(String value) {
			this.setInput("Page", value);	
		}

		/** 
		Set the value of the PhoneNumber input for this Choreo. 

		@param String - (optional, string) Only return the incoming phone number resources that match this pattern. You can specify partial numbers and use '*' as a wildcard for any digit.
		*/
		public void set_PhoneNumber(String value) {
			this.setInput("PhoneNumber", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and xml.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the SubAccountSID input for this Choreo. 

		@param String - (optional, string) The SID of the subaccount associated with the list of phone numbers. If not specified, the main AccountSID used to authenticate is used in the request.
		*/
		public void set_SubAccountSID(String value) {
			this.setInput("SubAccountSID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListPhoneNumbers Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListPhoneNumbersResultSet extends ResultSet {
		public ListPhoneNumbersResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Twilio.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
