package com.temboo.Library.Twilio.Queues;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CreateQueue

Creates a new queue within a Twilio account.
*/
public class CreateQueue extends Choreography {

	/**
	Create a new instance of the CreateQueue Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CreateQueue(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Twilio/Queues/CreateQueue"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CreateQueueInputSet
	*/
	public CreateQueueInputSet newInputSet() {
		return new CreateQueueInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CreateQueueResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CreateQueueResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CreateQueue
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CreateQueueInputSet extends InputSet {
		/** 
		Set the value of the AccountSID input for this Choreo. 

		@param String - (required, string) The AccountSID provided when you signed up for a Twilio account.
		*/
		public void set_AccountSID(String value) {
			this.setInput("AccountSID", value);
		}



		/** 
		Set the value of the AuthToken input for this Choreo. 

		@param String - (required, string) The authorization token provided when you signed up for a Twilio account.
		*/
		public void set_AuthToken(String value) {
			this.setInput("AuthToken", value);
		}



		/** 
		Set the value of the FriendlyName input for this Choreo. 

		@param String - (required, string) A unique identifier for this queue.
		*/
		public void set_FriendlyName(String value) {
			this.setInput("FriendlyName", value);
		}



		/** 
		Set the value of the MaxSize input for this Choreo. 

		@param Integer - (optional, integer) The maximum size of this queue. The default is 100. The maximum is 1000.
		*/
		public void set_MaxSize(Integer value) {
			this.setInput("MaxSize", value);
		}

		/** 
		Set the value of the MaxSize input for this Choreo as a String. 

		@param String - (optional, integer) The maximum size of this queue. The default is 100. The maximum is 1000.
		*/
		public void set_MaxSize(String value) {
			this.setInput("MaxSize", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and xml.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the SubAccountSID input for this Choreo. 

		@param String - (optional, string) The SID of the subaccount that the queue should be associated with. If not specified, the main AccountSID used to authenticate is used in the request.
		*/
		public void set_SubAccountSID(String value) {
			this.setInput("SubAccountSID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CreateQueue Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CreateQueueResultSet extends ResultSet {
		public CreateQueueResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Twilio.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
