package com.temboo.Library.Twitter.DirectMessages;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetDirectMessages

Retrieves the 20 most recent direct messages sent to the authenticating user.
*/
public class GetDirectMessages extends Choreography {

	/**
	Create a new instance of the GetDirectMessages Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetDirectMessages(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Twitter/DirectMessages/GetDirectMessages"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetDirectMessagesInputSet
	*/
	public GetDirectMessagesInputSet newInputSet() {
		return new GetDirectMessagesInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetDirectMessagesResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetDirectMessagesResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetDirectMessages
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetDirectMessagesInputSet extends InputSet {
		/** 
		Set the value of the AccessTokenSecret input for this Choreo. 

		@param String - (required, string) The Access Token Secret provided by Twitter or retrieved during the OAuth process.
		*/
		public void set_AccessTokenSecret(String value) {
			this.setInput("AccessTokenSecret", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token provided by Twitter or retrieved during the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ConsumerKey input for this Choreo. 

		@param String - (required, string) The Consumer Key provided by Twitter.
		*/
		public void set_ConsumerKey(String value) {
			this.setInput("ConsumerKey", value);
		}



		/** 
		Set the value of the ConsumerSecret input for this Choreo. 

		@param String - (required, string) The Consumer Secret provided by Twitter.
		*/
		public void set_ConsumerSecret(String value) {
			this.setInput("ConsumerSecret", value);
		}



		/** 
		Set the value of the Count input for this Choreo. 

		@param Integer - (optional, integer) Specifies the number of records to retrieve up to a maximum of 200.
		*/
		public void set_Count(Integer value) {
			this.setInput("Count", value);
		}

		/** 
		Set the value of the Count input for this Choreo as a String. 

		@param String - (optional, integer) Specifies the number of records to retrieve up to a maximum of 200.
		*/
		public void set_Count(String value) {
			this.setInput("Count", value);	
		}

		/** 
		Set the value of the IncludeEntities input for this Choreo. 

		@param Boolean - (optional, boolean) When set to true, the response will include the "entities" node.
		*/
		public void set_IncludeEntities(Boolean value) {
			this.setInput("IncludeEntities", value);
		}

		/** 
		Set the value of the IncludeEntities input for this Choreo as a String. 

		@param String - (optional, boolean) When set to true, the response will include the "entities" node.
		*/
		public void set_IncludeEntities(String value) {
			this.setInput("IncludeEntities", value);	
		}

		/** 
		Set the value of the MaxID input for this Choreo. 

		@param Integer - (optional, integer) Returns results with an ID less than (older than) or equal to the specified ID.
		*/
		public void set_MaxID(Integer value) {
			this.setInput("MaxID", value);
		}

		/** 
		Set the value of the MaxID input for this Choreo as a String. 

		@param String - (optional, integer) Returns results with an ID less than (older than) or equal to the specified ID.
		*/
		public void set_MaxID(String value) {
			this.setInput("MaxID", value);	
		}

		/** 
		Set the value of the Page input for this Choreo. 

		@param Integer - (optional, integer) Specifies the page of results to retrieve.
		*/
		public void set_Page(Integer value) {
			this.setInput("Page", value);
		}

		/** 
		Set the value of the Page input for this Choreo as a String. 

		@param String - (optional, integer) Specifies the page of results to retrieve.
		*/
		public void set_Page(String value) {
			this.setInput("Page", value);	
		}

		/** 
		Set the value of the SinceID input for this Choreo. 

		@param Integer - (optional, integer) Returns results with an ID greater than (more recent than) the specified ID.
		*/
		public void set_SinceID(Integer value) {
			this.setInput("SinceID", value);
		}

		/** 
		Set the value of the SinceID input for this Choreo as a String. 

		@param String - (optional, integer) Returns results with an ID greater than (more recent than) the specified ID.
		*/
		public void set_SinceID(String value) {
			this.setInput("SinceID", value);	
		}

		/** 
		Set the value of the SkipStatus input for this Choreo. 

		@param Boolean - (optional, boolean) When set to true, statuses will not be included in the returned user objects.
		*/
		public void set_SkipStatus(Boolean value) {
			this.setInput("SkipStatus", value);
		}

		/** 
		Set the value of the SkipStatus input for this Choreo as a String. 

		@param String - (optional, boolean) When set to true, statuses will not be included in the returned user objects.
		*/
		public void set_SkipStatus(String value) {
			this.setInput("SkipStatus", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetDirectMessages Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetDirectMessagesResultSet extends ResultSet {
		public GetDirectMessagesResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Twitter.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
