package com.temboo.Library.Twitter.FriendsAndFollowers;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
DeleteFriendship

Allows you to unfollow another Twitter user when you specify a Twitter user ID or screen name.
*/
public class DeleteFriendship extends Choreography {

	/**
	Create a new instance of the DeleteFriendship Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DeleteFriendship(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Twitter/FriendsAndFollowers/DeleteFriendship"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DeleteFriendshipInputSet
	*/
	public DeleteFriendshipInputSet newInputSet() {
		return new DeleteFriendshipInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DeleteFriendshipResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DeleteFriendshipResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DeleteFriendship
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DeleteFriendshipInputSet extends InputSet {
		/** 
		Set the value of the AccessTokenSecret input for this Choreo. 

		@param String - (required, string) The Access Token Secret provided by Twitter or retrieved during the OAuth process.
		*/
		public void set_AccessTokenSecret(String value) {
			this.setInput("AccessTokenSecret", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token provided by Twitter or retrieved during the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ConsumerKey input for this Choreo. 

		@param String - (required, string) The Consumer Key provided by Twitter.
		*/
		public void set_ConsumerKey(String value) {
			this.setInput("ConsumerKey", value);
		}



		/** 
		Set the value of the ConsumerSecret input for this Choreo. 

		@param String - (required, string) The Consumer Secret provided by Twitter.
		*/
		public void set_ConsumerSecret(String value) {
			this.setInput("ConsumerSecret", value);
		}



		/** 
		Set the value of the ScreenName input for this Choreo. 

		@param String - (conditional, string) The screen name for the friend you want to unfollow. Required if UserId isn't specified.
		*/
		public void set_ScreenName(String value) {
			this.setInput("ScreenName", value);
		}



		/** 
		Set the value of the UserId input for this Choreo. 

		@param Integer - (conditional, integer) The user ID for the friend you want to unfollow. Required if ScreenName isn't specified.
		*/
		public void set_UserId(Integer value) {
			this.setInput("UserId", value);
		}

		/** 
		Set the value of the UserId input for this Choreo as a String. 

		@param String - (conditional, integer) The user ID for the friend you want to unfollow. Required if ScreenName isn't specified.
		*/
		public void set_UserId(String value) {
			this.setInput("UserId", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DeleteFriendship Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DeleteFriendshipResultSet extends ResultSet {
		public DeleteFriendshipResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Twitter.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
