package com.temboo.Library.Twitter.FriendsAndFollowers;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
FriendshipsShow

Returns detailed information about the relationship between two users.
*/
public class FriendshipsShow extends Choreography {

	/**
	Create a new instance of the FriendshipsShow Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public FriendshipsShow(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Twitter/FriendsAndFollowers/FriendshipsShow"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return FriendshipsShowInputSet
	*/
	public FriendshipsShowInputSet newInputSet() {
		return new FriendshipsShowInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public FriendshipsShowResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new FriendshipsShowResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the FriendshipsShow
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class FriendshipsShowInputSet extends InputSet {
		/** 
		Set the value of the AccessTokenSecret input for this Choreo. 

		@param String - (required, string) The Access Token Secret provided by Twitter or retrieved during the OAuth process.
		*/
		public void set_AccessTokenSecret(String value) {
			this.setInput("AccessTokenSecret", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token provided by Twitter or retrieved during the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ConsumerKey input for this Choreo. 

		@param String - (required, string) The Consumer Key provided by Twitter.
		*/
		public void set_ConsumerKey(String value) {
			this.setInput("ConsumerKey", value);
		}



		/** 
		Set the value of the ConsumerSecret input for this Choreo. 

		@param String - (required, string) The Consumer Secret provided by Twitter.
		*/
		public void set_ConsumerSecret(String value) {
			this.setInput("ConsumerSecret", value);
		}



		/** 
		Set the value of the SourceScreenName input for this Choreo. 

		@param String - (conditional, string) The screen_name of the subject user. Required unless specifying the SourceUserID instead.
		*/
		public void set_SourceScreenName(String value) {
			this.setInput("SourceScreenName", value);
		}



		/** 
		Set the value of the SourceUserID input for this Choreo. 

		@param Integer - (conditional, integer) The ID of the subject user. Required unless specifying the SourceScreenName instead.
		*/
		public void set_SourceUserID(Integer value) {
			this.setInput("SourceUserID", value);
		}

		/** 
		Set the value of the SourceUserID input for this Choreo as a String. 

		@param String - (conditional, integer) The ID of the subject user. Required unless specifying the SourceScreenName instead.
		*/
		public void set_SourceUserID(String value) {
			this.setInput("SourceUserID", value);	
		}

		/** 
		Set the value of the TargetScreenName input for this Choreo. 

		@param String - (conditional, string) The screen_name of the target user. Required unless specifying the TargetUserID instead.
		*/
		public void set_TargetScreenName(String value) {
			this.setInput("TargetScreenName", value);
		}



		/** 
		Set the value of the TargetUserID input for this Choreo. 

		@param Integer - (conditional, integer) The ID of the target user. Required unless specifying the TargetScreenName instead.
		*/
		public void set_TargetUserID(Integer value) {
			this.setInput("TargetUserID", value);
		}

		/** 
		Set the value of the TargetUserID input for this Choreo as a String. 

		@param String - (conditional, integer) The ID of the target user. Required unless specifying the TargetScreenName instead.
		*/
		public void set_TargetUserID(String value) {
			this.setInput("TargetUserID", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the FriendshipsShow Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class FriendshipsShowResultSet extends ResultSet {
		public FriendshipsShowResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Twitter.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
