package com.temboo.Library.Twitter.FriendsAndFollowers;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
IncomingFriendships

Retrieves a list of numeric IDs for every user who has a pending request to follow the authenticating user.
*/
public class IncomingFriendships extends Choreography {

	/**
	Create a new instance of the IncomingFriendships Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public IncomingFriendships(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Twitter/FriendsAndFollowers/IncomingFriendships"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return IncomingFriendshipsInputSet
	*/
	public IncomingFriendshipsInputSet newInputSet() {
		return new IncomingFriendshipsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public IncomingFriendshipsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new IncomingFriendshipsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the IncomingFriendships
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class IncomingFriendshipsInputSet extends InputSet {
		/** 
		Set the value of the AccessTokenSecret input for this Choreo. 

		@param String - (required, string) The Access Token Secret provided by Twitter or retrieved during the OAuth process.
		*/
		public void set_AccessTokenSecret(String value) {
			this.setInput("AccessTokenSecret", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token provided by Twitter or retrieved during the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ConsumerKey input for this Choreo. 

		@param String - (required, string) The Consumer Key provided by Twitter.
		*/
		public void set_ConsumerKey(String value) {
			this.setInput("ConsumerKey", value);
		}



		/** 
		Set the value of the ConsumerSecret input for this Choreo. 

		@param String - (required, string) The Consumer Secret provided by Twitter.
		*/
		public void set_ConsumerSecret(String value) {
			this.setInput("ConsumerSecret", value);
		}



		/** 
		Set the value of the Cursor input for this Choreo. 

		@param Integer - (optional, integer) Allows you to pass in the previous_cursor or next_cursor in order to page through results.
		*/
		public void set_Cursor(Integer value) {
			this.setInput("Cursor", value);
		}

		/** 
		Set the value of the Cursor input for this Choreo as a String. 

		@param String - (optional, integer) Allows you to pass in the previous_cursor or next_cursor in order to page through results.
		*/
		public void set_Cursor(String value) {
			this.setInput("Cursor", value);	
		}

		/** 
		Set the value of the StringifyIDs input for this Choreo. 

		@param Boolean - (optional, boolean) A boolean flag indicating that Tweet IDs should be returned as strings.
		*/
		public void set_StringifyIDs(Boolean value) {
			this.setInput("StringifyIDs", value);
		}

		/** 
		Set the value of the StringifyIDs input for this Choreo as a String. 

		@param String - (optional, boolean) A boolean flag indicating that Tweet IDs should be returned as strings.
		*/
		public void set_StringifyIDs(String value) {
			this.setInput("StringifyIDs", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the IncomingFriendships Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class IncomingFriendshipsResultSet extends ResultSet {
		public IncomingFriendshipsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Twitter.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
