package com.temboo.Library.Twitter.Timelines;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Mentions

Retrieves the 20 most recent mentions for the authenticating user.
*/
public class Mentions extends Choreography {

	/**
	Create a new instance of the Mentions Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Mentions(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Twitter/Timelines/Mentions"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return MentionsInputSet
	*/
	public MentionsInputSet newInputSet() {
		return new MentionsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public MentionsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new MentionsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Mentions
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class MentionsInputSet extends InputSet {
		/** 
		Set the value of the AccessTokenSecret input for this Choreo. 

		@param String - (required, string) The Access Token Secret provided by Twitter or retrieved during the OAuth process.n
		*/
		public void set_AccessTokenSecret(String value) {
			this.setInput("AccessTokenSecret", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token provided by Twitter or retrieved during the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ConsumerKey input for this Choreo. 

		@param String - (required, string) The Consumer Key provided by Twitter.
		*/
		public void set_ConsumerKey(String value) {
			this.setInput("ConsumerKey", value);
		}



		/** 
		Set the value of the ConsumerSecret input for this Choreo. 

		@param String - (required, string) The Consumer Secret provided by Twitter.
		*/
		public void set_ConsumerSecret(String value) {
			this.setInput("ConsumerSecret", value);
		}



		/** 
		Set the value of the ContributorDetails input for this Choreo. 

		@param Boolean - (optional, boolean) Set to true to include the screen_name of the contributor. By default only the user_id of the contributor is included.
		*/
		public void set_ContributorDetails(Boolean value) {
			this.setInput("ContributorDetails", value);
		}

		/** 
		Set the value of the ContributorDetails input for this Choreo as a String. 

		@param String - (optional, boolean) Set to true to include the screen_name of the contributor. By default only the user_id of the contributor is included.
		*/
		public void set_ContributorDetails(String value) {
			this.setInput("ContributorDetails", value);	
		}

		/** 
		Set the value of the Count input for this Choreo. 

		@param Integer - (optional, integer) Specifies the number of tweets to retrieve. Must be less than or equal to 200. Defaults to 20.
		*/
		public void set_Count(Integer value) {
			this.setInput("Count", value);
		}

		/** 
		Set the value of the Count input for this Choreo as a String. 

		@param String - (optional, integer) Specifies the number of tweets to retrieve. Must be less than or equal to 200. Defaults to 20.
		*/
		public void set_Count(String value) {
			this.setInput("Count", value);	
		}

		/** 
		Set the value of the IncludeEntities input for this Choreo. 

		@param Boolean - (optional, boolean) When set to true, the response will include the "entities" node.
		*/
		public void set_IncludeEntities(Boolean value) {
			this.setInput("IncludeEntities", value);
		}

		/** 
		Set the value of the IncludeEntities input for this Choreo as a String. 

		@param String - (optional, boolean) When set to true, the response will include the "entities" node.
		*/
		public void set_IncludeEntities(String value) {
			this.setInput("IncludeEntities", value);	
		}

		/** 
		Set the value of the MaxId input for this Choreo. 

		@param Integer - (optional, integer) Returns results with an ID less than (older than) or equal to the specified ID.
		*/
		public void set_MaxId(Integer value) {
			this.setInput("MaxId", value);
		}

		/** 
		Set the value of the MaxId input for this Choreo as a String. 

		@param String - (optional, integer) Returns results with an ID less than (older than) or equal to the specified ID.
		*/
		public void set_MaxId(String value) {
			this.setInput("MaxId", value);	
		}

		/** 
		Set the value of the SinceId input for this Choreo. 

		@param Integer - (optional, integer) Returns results with an ID greater than (more recent than) the specified ID.
		*/
		public void set_SinceId(Integer value) {
			this.setInput("SinceId", value);
		}

		/** 
		Set the value of the SinceId input for this Choreo as a String. 

		@param String - (optional, integer) Returns results with an ID greater than (more recent than) the specified ID.
		*/
		public void set_SinceId(String value) {
			this.setInput("SinceId", value);	
		}

		/** 
		Set the value of the TrimUser input for this Choreo. 

		@param Boolean - (optional, boolean) When set to true, each tweet returned in a timeline will include a user object including only the status authors numerical ID. Defaults to false, which returns the complete user object.
		*/
		public void set_TrimUser(Boolean value) {
			this.setInput("TrimUser", value);
		}

		/** 
		Set the value of the TrimUser input for this Choreo as a String. 

		@param String - (optional, boolean) When set to true, each tweet returned in a timeline will include a user object including only the status authors numerical ID. Defaults to false, which returns the complete user object.
		*/
		public void set_TrimUser(String value) {
			this.setInput("TrimUser", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Mentions Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class MentionsResultSet extends ResultSet {
		public MentionsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Twitter.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
