package com.temboo.Library.Twitter.Tweets;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
StatusesDestroy

Deletes a specified status.
*/
public class StatusesDestroy extends Choreography {

	/**
	Create a new instance of the StatusesDestroy Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public StatusesDestroy(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Twitter/Tweets/StatusesDestroy"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return StatusesDestroyInputSet
	*/
	public StatusesDestroyInputSet newInputSet() {
		return new StatusesDestroyInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public StatusesDestroyResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new StatusesDestroyResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the StatusesDestroy
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class StatusesDestroyInputSet extends InputSet {
		/** 
		Set the value of the AccessTokenSecret input for this Choreo. 

		@param String - (required, string) The Access Token Secret provided by Twitter or retrieved during the OAuth process.
		*/
		public void set_AccessTokenSecret(String value) {
			this.setInput("AccessTokenSecret", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token provided by Twitter or retrieved during the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ConsumerKey input for this Choreo. 

		@param String - (required, string) The Consumer Key provided by Twitter.
		*/
		public void set_ConsumerKey(String value) {
			this.setInput("ConsumerKey", value);
		}



		/** 
		Set the value of the ConsumerSecret input for this Choreo. 

		@param String - (required, string) The Consumer Secret provided by Twitter.
		*/
		public void set_ConsumerSecret(String value) {
			this.setInput("ConsumerSecret", value);
		}



		/** 
		Set the value of the ID input for this Choreo. 

		@param String - (required, string) The numerical ID of the status to delete.
		*/
		public void set_ID(String value) {
			this.setInput("ID", value);
		}



		/** 
		Set the value of the TrimUser input for this Choreo. 

		@param Boolean - (optional, boolean) When set to true, each tweet returned in a timeline will include a user object including only the status authors numerical ID.
		*/
		public void set_TrimUser(Boolean value) {
			this.setInput("TrimUser", value);
		}

		/** 
		Set the value of the TrimUser input for this Choreo as a String. 

		@param String - (optional, boolean) When set to true, each tweet returned in a timeline will include a user object including only the status authors numerical ID.
		*/
		public void set_TrimUser(String value) {
			this.setInput("TrimUser", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the StatusesDestroy Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class StatusesDestroyResultSet extends ResultSet {
		public StatusesDestroyResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Twitter.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
