package com.temboo.Library.Twitter.Users;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Lookup

Returns user objects for up to 100 Twitter users.
*/
public class Lookup extends Choreography {

	/**
	Create a new instance of the Lookup Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Lookup(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Twitter/Users/Lookup"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return LookupInputSet
	*/
	public LookupInputSet newInputSet() {
		return new LookupInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public LookupResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new LookupResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Lookup
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class LookupInputSet extends InputSet {
		/** 
		Set the value of the AccessTokenSecret input for this Choreo. 

		@param String - (required, string) The Access Token Secret provided by Twitter or retrieved during the OAuth process.
		*/
		public void set_AccessTokenSecret(String value) {
			this.setInput("AccessTokenSecret", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token provided by Twitter or retrieved during the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ConsumerKey input for this Choreo. 

		@param String - (required, string) The Consumer Key provided by Twitter.
		*/
		public void set_ConsumerKey(String value) {
			this.setInput("ConsumerKey", value);
		}



		/** 
		Set the value of the ConsumerSecret input for this Choreo. 

		@param String - (required, string) The Consumer Secret provided by Twitter.
		*/
		public void set_ConsumerSecret(String value) {
			this.setInput("ConsumerSecret", value);
		}



		/** 
		Set the value of the IncludeEntities input for this Choreo. 

		@param Boolean - (optional, boolean) When set to true, the response will include the "entities" node.
		*/
		public void set_IncludeEntities(Boolean value) {
			this.setInput("IncludeEntities", value);
		}

		/** 
		Set the value of the IncludeEntities input for this Choreo as a String. 

		@param String - (optional, boolean) When set to true, the response will include the "entities" node.
		*/
		public void set_IncludeEntities(String value) {
			this.setInput("IncludeEntities", value);	
		}

		/** 
		Set the value of the ScreenName input for this Choreo. 

		@param String - (conditional, string) A comma-separated list of up to 100 screen names. Required if UserId isn't specified.
		*/
		public void set_ScreenName(String value) {
			this.setInput("ScreenName", value);
		}



		/** 
		Set the value of the UserId input for this Choreo. 

		@param Integer - (conditional, integer) A comma-separated list of up to 100 user IDs. Required if ScreenName isn't specified.
		*/
		public void set_UserId(Integer value) {
			this.setInput("UserId", value);
		}

		/** 
		Set the value of the UserId input for this Choreo as a String. 

		@param String - (conditional, integer) A comma-separated list of up to 100 user IDs. Required if ScreenName isn't specified.
		*/
		public void set_UserId(String value) {
			this.setInput("UserId", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Lookup Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class LookupResultSet extends ResultSet {
		public LookupResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Twitter.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
