package com.temboo.Library.USPS.AddressInformationAPI;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ZipCodeLookup

Lookup zip codes using incomplete address information.
*/
public class ZipCodeLookup extends Choreography {

	/**
	Create a new instance of the ZipCodeLookup Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ZipCodeLookup(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/USPS/AddressInformationAPI/ZipCodeLookup"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ZipCodeLookupInputSet
	*/
	public ZipCodeLookupInputSet newInputSet() {
		return new ZipCodeLookupInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ZipCodeLookupResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ZipCodeLookupResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ZipCodeLookup
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ZipCodeLookupInputSet extends InputSet {
		/** 
		Set the value of the ApyOrSuite input for this Choreo. 

		@param String - (optional, string) Used to provide an apartment or suite number, if applicable. Maximum characters allowed: 38.
		*/
		public void set_ApyOrSuite(String value) {
			this.setInput("ApyOrSuite", value);
		}



		/** 
		Set the value of the City input for this Choreo. 

		@param String - (required, string) Maximum characters allowed: 15.
		*/
		public void set_City(String value) {
			this.setInput("City", value);
		}



		/** 
		Set the value of the Endpoint input for this Choreo. 

		@param String - (optional, string) If you are accessing the production server, set to 'production'. Defaults to 'testing' which indicates that you are using the sandbox.
		*/
		public void set_Endpoint(String value) {
			this.setInput("Endpoint", value);
		}



		/** 
		Set the value of the FirmName input for this Choreo. 

		@param String - (optional, string) Maximum characters allowed: 38.
		*/
		public void set_FirmName(String value) {
			this.setInput("FirmName", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The password assigned by USPS
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the State input for this Choreo. 

		@param String - (required, string) Maximum characters allowed: 2.
		*/
		public void set_State(String value) {
			this.setInput("State", value);
		}



		/** 
		Set the value of the StreetAddress input for this Choreo. 

		@param String - (required, string) Street address.  Maximum characters allowed: 38.
		*/
		public void set_StreetAddress(String value) {
			this.setInput("StreetAddress", value);
		}



		/** 
		Set the value of the UserId input for this Choreo. 

		@param String - (required, string) Alphanumeric ID assigned by USPS
		*/
		public void set_UserId(String value) {
			this.setInput("UserId", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ZipCodeLookup Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ZipCodeLookupResultSet extends ResultSet {
		public ZipCodeLookupResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from USPS Web Service
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
