package com.temboo.Library.USPS.DeliveryInformationAPI;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ExpressMailServiceRequest

Request USPS Express Mail shipping information for a given origin and destination.
*/
public class ExpressMailServiceRequest extends Choreography {

	/**
	Create a new instance of the ExpressMailServiceRequest Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ExpressMailServiceRequest(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/USPS/DeliveryInformationAPI/ExpressMailServiceRequest"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ExpressMailServiceRequestInputSet
	*/
	public ExpressMailServiceRequestInputSet newInputSet() {
		return new ExpressMailServiceRequestInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ExpressMailServiceRequestResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ExpressMailServiceRequestResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ExpressMailServiceRequest
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ExpressMailServiceRequestInputSet extends InputSet {
		/** 
		Set the value of the Date input for this Choreo. 

		@param String - (required, date) Date the package is to be shipped. Must take the form 'MM/DD/YYYY'.
		*/
		public void set_Date(String value) {
			this.setInput("Date", value);
		}



		/** 
		Set the value of the DestinationZip input for this Choreo. 

		@param Integer - (required, integer) Five digit zip code.
		*/
		public void set_DestinationZip(Integer value) {
			this.setInput("DestinationZip", value);
		}

		/** 
		Set the value of the DestinationZip input for this Choreo as a String. 

		@param String - (required, integer) Five digit zip code.
		*/
		public void set_DestinationZip(String value) {
			this.setInput("DestinationZip", value);	
		}

		/** 
		Set the value of the Endpoint input for this Choreo. 

		@param String - (optional, string) If you are accessing the production server, set to 'production'. Defaults to 'testing' which indicates that you are using the sandbox.
		*/
		public void set_Endpoint(String value) {
			this.setInput("Endpoint", value);
		}



		/** 
		Set the value of the OriginZip input for this Choreo. 

		@param Integer - (required, integer) Three or five digit zip code.
		*/
		public void set_OriginZip(Integer value) {
			this.setInput("OriginZip", value);
		}

		/** 
		Set the value of the OriginZip input for this Choreo as a String. 

		@param String - (required, integer) Three or five digit zip code.
		*/
		public void set_OriginZip(String value) {
			this.setInput("OriginZip", value);	
		}

		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The password assigned by USPS
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the UserId input for this Choreo. 

		@param String - (required, string) Alphanumeric ID assigned by USPS
		*/
		public void set_UserId(String value) {
			this.setInput("UserId", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ExpressMailServiceRequest Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ExpressMailServiceRequestResultSet extends ResultSet {
		public ExpressMailServiceRequestResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from USPS Web Service
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
