package com.temboo.Library.Utilities.DataConversions;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CSVToJSON

Converts a CSV formatted file to JSON.
*/
public class CSVToJSON extends Choreography {

	/**
	Create a new instance of the CSVToJSON Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CSVToJSON(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Utilities/DataConversions/CSVToJSON"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CSVToJSONInputSet
	*/
	public CSVToJSONInputSet newInputSet() {
		return new CSVToJSONInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CSVToJSONResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CSVToJSONResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CSVToJSON
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CSVToJSONInputSet extends InputSet {
		/** 
		Set the value of the CSV input for this Choreo. 

		@param String - (required, multiline) The CSV file to convert to XML. Your CSV data must contain column names.
		*/
		public void set_CSV(String value) {
			this.setInput("CSV", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CSVToJSON Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CSVToJSONResultSet extends ResultSet {
		public CSVToJSONResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "JSON" output from this Choreo execution

		@return String - (json) The JSON formatted data.
		*/
		public String get_JSON() {
			return this.getResult("JSON");
		}
	}
	
}
