package com.temboo.Library.Utilities.DataConversions;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
RSSToJSON

Retrieves a specified RSS Feed, and converts it to JSON format.
*/
public class RSSToJSON extends Choreography {

	/**
	Create a new instance of the RSSToJSON Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public RSSToJSON(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Utilities/DataConversions/RSSToJSON"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return RSSToJSONInputSet
	*/
	public RSSToJSONInputSet newInputSet() {
		return new RSSToJSONInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public RSSToJSONResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new RSSToJSONResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the RSSToJSON
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class RSSToJSONInputSet extends InputSet {
		/** 
		Set the value of the RSSFeed input for this Choreo. 

		@param String - (required, string) The URL for an RSS feed that you wish to convert to JSON.
		*/
		public void set_RSSFeed(String value) {
			this.setInput("RSSFeed", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the RSSToJSON Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class RSSToJSONResultSet extends ResultSet {
		public RSSToJSONResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The feed data in JSON format.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
