package com.temboo.Library.Utilities.DataConversions;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
TSVToJSON

Converts a TSV formatted file to JSON.
*/
public class TSVToJSON extends Choreography {

	/**
	Create a new instance of the TSVToJSON Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public TSVToJSON(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Utilities/DataConversions/TSVToJSON"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return TSVToJSONInputSet
	*/
	public TSVToJSONInputSet newInputSet() {
		return new TSVToJSONInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public TSVToJSONResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new TSVToJSONResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the TSVToJSON
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class TSVToJSONInputSet extends InputSet {
		/** 
		Set the value of the TSV input for this Choreo. 

		@param String - (required, multiline) The TSV file to convert to XML. Your TSV data must contain column names.
		*/
		public void set_TSV(String value) {
			this.setInput("TSV", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the TSVToJSON Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class TSVToJSONResultSet extends ResultSet {
		public TSVToJSONResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "JSON" output from this Choreo execution

		@return String - (json) The JSON formatted data.
		*/
		public String get_JSON() {
			return this.getResult("JSON");
		}
	}
	
}
