package com.temboo.Library.Utilities.DataConversions;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
TSVToXML

Converts a TSV formatted file to XML.
*/
public class TSVToXML extends Choreography {

	/**
	Create a new instance of the TSVToXML Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public TSVToXML(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Utilities/DataConversions/TSVToXML"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return TSVToXMLInputSet
	*/
	public TSVToXMLInputSet newInputSet() {
		return new TSVToXMLInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public TSVToXMLResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new TSVToXMLResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the TSVToXML
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class TSVToXMLInputSet extends InputSet {
		/** 
		Set the value of the TSV input for this Choreo. 

		@param String - (required, multiline) The TSV file to convert to XML. Your TSV data must contain column names.
		*/
		public void set_TSV(String value) {
			this.setInput("TSV", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the TSVToXML Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class TSVToXMLResultSet extends ResultSet {
		public TSVToXMLResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "XML" output from this Choreo execution

		@return String - (xml) The XML formatted data.
		*/
		public String get_XML() {
			return this.getResult("XML");
		}
	}
	
}
