package com.temboo.Library.Utilities.DataConversions;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
XLSToCSV

Converts Excel (.xls) formatted data to CSV.
*/
public class XLSToCSV extends Choreography {

	/**
	Create a new instance of the XLSToCSV Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public XLSToCSV(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Utilities/DataConversions/XLSToCSV"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return XLSToCSVInputSet
	*/
	public XLSToCSVInputSet newInputSet() {
		return new XLSToCSVInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public XLSToCSVResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new XLSToCSVResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the XLSToCSV
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class XLSToCSVInputSet extends InputSet {
		/** 
		Set the value of the XLS input for this Choreo. 

		@param String - (conditional, string) The base64-encoded contents of the Excel file that you want to convert to CSV format. Compatible with Excel 97-2003.
		*/
		public void set_XLS(String value) {
			this.setInput("XLS", value);
		}



		/** 
		Set the value of the VaultFile input for this Choreo. 

		@param TembooPath - (optional, vault file) A path to an Excel file you've stored in the Vault. This can be used as an alternative to the ExcelFile input variable.
		*/
		public void set_VaultFile(TembooPath value) {
			this.setAlias("VaultFile", value);
		}
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the XLSToCSV Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class XLSToCSVResultSet extends ResultSet {
		public XLSToCSVResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "CSV" output from this Choreo execution

		@return String - (string) The CSV formatted data.
		*/
		public String get_CSV() {
			return this.getResult("CSV");
		}
	}
	
}
