package com.temboo.Library.Utilities.DataConversions;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
XLSToXML

Converts Excel (.xls) formatted data to XML.
*/
public class XLSToXML extends Choreography {

	/**
	Create a new instance of the XLSToXML Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public XLSToXML(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Utilities/DataConversions/XLSToXML"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return XLSToXMLInputSet
	*/
	public XLSToXMLInputSet newInputSet() {
		return new XLSToXMLInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public XLSToXMLResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new XLSToXMLResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the XLSToXML
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class XLSToXMLInputSet extends InputSet {
		/** 
		Set the value of the XLS input for this Choreo. 

		@param String - (conditional, string) The base64-encoded contents of the Excel file that you want to convert to XML. Compatible with Excel 97-2003.
		*/
		public void set_XLS(String value) {
			this.setInput("XLS", value);
		}



		/** 
		Set the value of the VaultFile input for this Choreo. 

		@param TembooPath - (optional, vault file) A path to an Excel file that has been uploaded to the vault. You can use this input alias as an alternative to the ExcelFile input variable.
		*/
		public void set_VaultFile(TembooPath value) {
			this.setAlias("VaultFile", value);
		}
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the XLSToXML Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class XLSToXMLResultSet extends ResultSet {
		public XLSToXMLResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "XML" output from this Choreo execution

		@return String - (xml) The data in XML format.
		*/
		public String get_XML() {
			return this.getResult("XML");
		}
	}
	
}
