package com.temboo.Library.Utilities.DataConversions;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
XMLToJSON

Converts data from XML format to JSON format.
*/
public class XMLToJSON extends Choreography {

	/**
	Create a new instance of the XMLToJSON Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public XMLToJSON(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Utilities/DataConversions/XMLToJSON"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return XMLToJSONInputSet
	*/
	public XMLToJSONInputSet newInputSet() {
		return new XMLToJSONInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public XMLToJSONResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new XMLToJSONResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the XMLToJSON
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class XMLToJSONInputSet extends InputSet {
		/** 
		Set the value of the XML input for this Choreo. 

		@param String - (required, xml) The XML file that you want to convert to JSON format.
		*/
		public void set_XML(String value) {
			this.setInput("XML", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the XMLToJSON Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class XMLToJSONResultSet extends ResultSet {
		public XMLToJSONResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "JSON" output from this Choreo execution

		@return String - (json) The converted data in JSON format.
		*/
		public String get_JSON() {
			return this.getResult("JSON");
		}
	}
	
}
