package com.temboo.Library.Utilities.DataConversions;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
XMLToTSV

Converts an XML file to TSV format (TAB-separated values).
*/
public class XMLToTSV extends Choreography {

	/**
	Create a new instance of the XMLToTSV Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public XMLToTSV(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Utilities/DataConversions/XMLToTSV"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return XMLToTSVInputSet
	*/
	public XMLToTSVInputSet newInputSet() {
		return new XMLToTSVInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public XMLToTSVResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new XMLToTSVResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the XMLToTSV
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class XMLToTSVInputSet extends InputSet {
		/** 
		Set the value of the XML input for this Choreo. 

		@param String - (required, xml) The XML file to convert to TSV data.
		*/
		public void set_XML(String value) {
			this.setInput("XML", value);
		}



		/** 
		Set the value of the Path input for this Choreo. 

		@param String - (optional, string) If your XML is not in "/rowset/row/column_name" format, specify a path to the rows. See documentation for examples.
		*/
		public void set_Path(String value) {
			this.setInput("Path", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the XMLToTSV Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class XMLToTSVResultSet extends ResultSet {
		public XMLToTSVResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "TSV" output from this Choreo execution

		@return String - (multiline) The tab-separated data generated from the XML input.
		*/
		public String get_TSV() {
			return this.getResult("TSV");
		}
	}
	
}
