package com.temboo.Library.Utilities.DataConversions;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
XMLToXLS

Converts an XML file to a Base64 encoded Excel file.
*/
public class XMLToXLS extends Choreography {

	/**
	Create a new instance of the XMLToXLS Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public XMLToXLS(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Utilities/DataConversions/XMLToXLS"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return XMLToXLSInputSet
	*/
	public XMLToXLSInputSet newInputSet() {
		return new XMLToXLSInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public XMLToXLSResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new XMLToXLSResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the XMLToXLS
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class XMLToXLSInputSet extends InputSet {
		/** 
		Set the value of the XML input for this Choreo. 

		@param String - (required, xml) The XML file you want to convert to XLS format. See documentation for information on the required XML schema.
		*/
		public void set_XML(String value) {
			this.setInput("XML", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the XMLToXLS Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class XMLToXLSResultSet extends ResultSet {
		public XMLToXLSResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "XLS" output from this Choreo execution

		@return String - The Base64 encoded Excel data .
		*/
		public String get_XLS() {
			return this.getResult("XLS");
		}
	}
	
}
