package com.temboo.Library.Utilities.Encoding;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
URLDecode

Removes URL encoding from the specified text string.
*/
public class URLDecode extends Choreography {

	/**
	Create a new instance of the URLDecode Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public URLDecode(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Utilities/Encoding/URLDecode"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return URLDecodeInputSet
	*/
	public URLDecodeInputSet newInputSet() {
		return new URLDecodeInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public URLDecodeResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new URLDecodeResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the URLDecode
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class URLDecodeInputSet extends InputSet {
		/** 
		Set the value of the Text input for this Choreo. 

		@param String - (required, string) The text that should be URL decoded.
		*/
		public void set_Text(String value) {
			this.setInput("Text", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the URLDecode Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class URLDecodeResultSet extends ResultSet {
		public URLDecodeResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "URLDecodedText" output from this Choreo execution

		@return String - (string) The URL decoded text.
		*/
		public String get_URLDecodedText() {
			return this.getResult("URLDecodedText");
		}
	}
	
}
