package com.temboo.Library.Utilities.Encoding;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
URLEncode

Returns the specified text string in the application/x-www-form-urlencoded format.
*/
public class URLEncode extends Choreography {

	/**
	Create a new instance of the URLEncode Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public URLEncode(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Utilities/Encoding/URLEncode"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return URLEncodeInputSet
	*/
	public URLEncodeInputSet newInputSet() {
		return new URLEncodeInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public URLEncodeResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new URLEncodeResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the URLEncode
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class URLEncodeInputSet extends InputSet {
		/** 
		Set the value of the Text input for this Choreo. 

		@param String - (required, string) The text that should be URL encoded.
		*/
		public void set_Text(String value) {
			this.setInput("Text", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the URLEncode Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class URLEncodeResultSet extends ResultSet {
		public URLEncodeResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "URLEncodedText" output from this Choreo execution

		@return String - (string) The URL encoded text.
		*/
		public String get_URLEncodedText() {
			return this.getResult("URLEncodedText");
		}
	}
	
}
