package com.temboo.Library.Utilities.HTTP;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Delete

Generates a HTTP DELETE request.
*/
public class Delete extends Choreography {

	/**
	Create a new instance of the Delete Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Delete(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Utilities/HTTP/Delete"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DeleteInputSet
	*/
	public DeleteInputSet newInputSet() {
		return new DeleteInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DeleteResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DeleteResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Delete
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DeleteInputSet extends InputSet {
		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (optional, string) A valid password. This is used if the request required basic authentication.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the RequestHeaders input for this Choreo. 

		@param String - (optional, json) A JSON object containing up to 10 key/value pairs that will be mapped to the HTTP request headers.
		*/
		public void set_RequestHeaders(String value) {
			this.setInput("RequestHeaders", value);
		}



		/** 
		Set the value of the RequestParameters input for this Choreo. 

		@param String - (optional, json) A JSON object containing up to 10 key/value pairs that will be mapped to the url string as HTTP parameters.
		*/
		public void set_RequestParameters(String value) {
			this.setInput("RequestParameters", value);
		}



		/** 
		Set the value of the URL input for this Choreo. 

		@param String - (required, string) The base URL for the request (including http:// or https://).
		*/
		public void set_URL(String value) {
			this.setInput("URL", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (optional, string) A valid username. This is used if the request required basic authentication.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Delete Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DeleteResultSet extends ResultSet {
		public DeleteResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "HTTPLog" output from this Choreo execution

		@return String - (string) A log of the http request that has been generated.
		*/
		public String get_HTTPLog() {
			return this.getResult("HTTPLog");
		}
		/** 
		Retrieve the value for the "ResponseStatusCode" output from this Choreo execution

		@return String - (integer) The response status code.
		*/
		public String get_ResponseStatusCode() {
			return this.getResult("ResponseStatusCode");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from the server.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
