package com.temboo.Library.Utilities.Hashing;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
HmacSHA1

Generates a SHA1-encrypted HMAC signature for the specified message text using the specified secret key.
*/
public class HmacSHA1 extends Choreography {

	/**
	Create a new instance of the HmacSHA1 Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public HmacSHA1(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Utilities/Hashing/HmacSHA1"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return HmacSHA1InputSet
	*/
	public HmacSHA1InputSet newInputSet() {
		return new HmacSHA1InputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public HmacSHA1ResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new HmacSHA1ResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the HmacSHA1
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class HmacSHA1InputSet extends InputSet {
		/** 
		Set the value of the Key input for this Choreo. 

		@param String - (required, string) The secret key used to generate the SHA1-encrypted HMAC signature.
		*/
		public void set_Key(String value) {
			this.setInput("Key", value);
		}



		/** 
		Set the value of the Text input for this Choreo. 

		@param String - (required, string) The text that should be SHA1-encrypted.
		*/
		public void set_Text(String value) {
			this.setInput("Text", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the HmacSHA1 Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class HmacSHA1ResultSet extends ResultSet {
		public HmacSHA1ResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "HmacSignature" output from this Choreo execution

		@return String - (string) The HMAC Signature for the specified string.
		*/
		public String get_HmacSignature() {
			return this.getResult("HmacSignature");
		}
	}
	
}
