package com.temboo.Library.Utilities.Validation;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CanadianPostalCodes

Verifies that a given zip code matches the format expected for Canadian addresses.
*/
public class CanadianPostalCodes extends Choreography {

	/**
	Create a new instance of the CanadianPostalCodes Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CanadianPostalCodes(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Utilities/Validation/CanadianPostalCodes"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CanadianPostalCodesInputSet
	*/
	public CanadianPostalCodesInputSet newInputSet() {
		return new CanadianPostalCodesInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CanadianPostalCodesResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CanadianPostalCodesResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CanadianPostalCodes
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CanadianPostalCodesInputSet extends InputSet {
		/** 
		Set the value of the ZipCode input for this Choreo. 

		@param String - (required, string) The zip code to validate.
		*/
		public void set_ZipCode(String value) {
			this.setInput("ZipCode", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CanadianPostalCodes Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CanadianPostalCodesResultSet extends ResultSet {
		public CanadianPostalCodesResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Match" output from this Choreo execution

		@return String - (string) Contains a string indicating the result of the match -- "valid" or "invalid".
		*/
		public String get_Match() {
			return this.getResult("Match");
		}
	}
	
}
