package com.temboo.Library.Utilities.Validation;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
PasswordCriteria

Verifies that a given password matches a standard pattern for passwords.
*/
public class PasswordCriteria extends Choreography {

	/**
	Create a new instance of the PasswordCriteria Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public PasswordCriteria(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Utilities/Validation/PasswordCriteria"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return PasswordCriteriaInputSet
	*/
	public PasswordCriteriaInputSet newInputSet() {
		return new PasswordCriteriaInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public PasswordCriteriaResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new PasswordCriteriaResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the PasswordCriteria
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class PasswordCriteriaInputSet extends InputSet {
		/** 
		Set the value of the MaxLength input for this Choreo. 

		@param Integer - (optional, integer) The max length you want to allow for the password. Defaults to 14.
		*/
		public void set_MaxLength(Integer value) {
			this.setInput("MaxLength", value);
		}

		/** 
		Set the value of the MaxLength input for this Choreo as a String. 

		@param String - (optional, integer) The max length you want to allow for the password. Defaults to 14.
		*/
		public void set_MaxLength(String value) {
			this.setInput("MaxLength", value);	
		}

		/** 
		Set the value of the MinLength input for this Choreo. 

		@param Integer - (optional, integer) The minimum length you want to allow for the password. Defaults to 6.
		*/
		public void set_MinLength(Integer value) {
			this.setInput("MinLength", value);
		}

		/** 
		Set the value of the MinLength input for this Choreo as a String. 

		@param String - (optional, integer) The minimum length you want to allow for the password. Defaults to 6.
		*/
		public void set_MinLength(String value) {
			this.setInput("MinLength", value);	
		}

		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, string) The password to validate.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the PasswordCriteria Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class PasswordCriteriaResultSet extends ResultSet {
		public PasswordCriteriaResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Match" output from this Choreo execution

		@return String - (string) Contains a string indicating the result of the match -- "valid" or "invalid".
		*/
		public String get_Match() {
			return this.getResult("Match");
		}
	}
	
}
