package com.temboo.Library.Utilities.Validation;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
XML

Validates XML for basic well-formedness and allows you to check XML against a specified XSD schema file.
*/
public class XML extends Choreography {

	/**
	Create a new instance of the XML Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public XML(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Utilities/Validation/XML"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return XMLInputSet
	*/
	public XMLInputSet newInputSet() {
		return new XMLInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public XMLResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new XMLResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the XML
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class XMLInputSet extends InputSet {
		/** 
		Set the value of the XMLFile input for this Choreo. 

		@param String - (required, xml) The XML file you want to validate.
		*/
		public void set_XMLFile(String value) {
			this.setInput("XMLFile", value);
		}



		/** 
		Set the value of the XSDFile input for this Choreo. 

		@param String - (optional, xml) The XSD file to validate an XML file against.
		*/
		public void set_XSDFile(String value) {
			this.setInput("XSDFile", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the XML Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class XMLResultSet extends ResultSet {
		public XMLResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Error" output from this Choreo execution

		@return String - (string) The error description that is generated if a validation error occurs.
		*/
		public String get_Error() {
			return this.getResult("Error");
		}
		/** 
		Retrieve the value for the "Result" output from this Choreo execution

		@return String - (string) The result of the validation. Returns the string "valid" or "invalid".
		*/
		public String get_Result() {
			return this.getResult("Result");
		}
	}
	
}
