package com.temboo.Library.Wordnik.Account;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetAuthToken

Obtains an authentication token for use in other Wordnik Choreos.
*/
public class GetAuthToken extends Choreography {

	/**
	Create a new instance of the GetAuthToken Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetAuthToken(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Wordnik/Account/GetAuthToken"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetAuthTokenInputSet
	*/
	public GetAuthTokenInputSet newInputSet() {
		return new GetAuthTokenInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetAuthTokenResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetAuthTokenResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetAuthToken
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetAuthTokenInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key obtained from Wordnik.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, string) Password of the Wordnik account.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) Username of the Wordnik account.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetAuthToken Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetAuthTokenResultSet extends ResultSet {
		public GetAuthTokenResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Token" output from this Choreo execution

		@return String - The Token obtained from running this Choreo.
		*/
		public String get_Token() {
			return this.getResult("Token");
		}
	}
	
}
