package com.temboo.Library.Wordnik.Word;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetExamples

Retrieves the examples of a given word.
*/
public class GetExamples extends Choreography {

	/**
	Create a new instance of the GetExamples Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetExamples(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Wordnik/Word/GetExamples"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetExamplesInputSet
	*/
	public GetExamplesInputSet newInputSet() {
		return new GetExamplesInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetExamplesResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetExamplesResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetExamples
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetExamplesInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key from Wordnik.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Cannonical input for this Choreo. 

		@param String - (optional, string) If true will try to return the correct word root ('cats' -> 'cat'). If false returns exactly what was requested. Defaults to false.
		*/
		public void set_Cannonical(String value) {
			this.setInput("Cannonical", value);
		}



		/** 
		Set the value of the Duplicates input for this Choreo. 

		@param String - (optional, string) Shows duplicate examples from different sources when set to true. Defaults to false.
		*/
		public void set_Duplicates(String value) {
			this.setInput("Duplicates", value);
		}



		/** 
		Set the value of the Limit input for this Choreo. 

		@param Integer - (optional, integer) Maximum number of results to return.
		*/
		public void set_Limit(Integer value) {
			this.setInput("Limit", value);
		}

		/** 
		Set the value of the Limit input for this Choreo as a String. 

		@param String - (optional, integer) Maximum number of results to return.
		*/
		public void set_Limit(String value) {
			this.setInput("Limit", value);	
		}

		/** 
		Set the value of the ResponseType input for this Choreo. 

		@param String - (optional, string) Response can be either JSON or XML. Defaults to JSON.
		*/
		public void set_ResponseType(String value) {
			this.setInput("ResponseType", value);
		}



		/** 
		Set the value of the Skip input for this Choreo. 

		@param Integer - (optional, integer) Results to skip. Defaults to 0.
		*/
		public void set_Skip(Integer value) {
			this.setInput("Skip", value);
		}

		/** 
		Set the value of the Skip input for this Choreo as a String. 

		@param String - (optional, integer) Results to skip. Defaults to 0.
		*/
		public void set_Skip(String value) {
			this.setInput("Skip", value);	
		}

		/** 
		Set the value of the Word input for this Choreo. 

		@param String - (required, string) The word you want to look up on Wordnik.
		*/
		public void set_Word(String value) {
			this.setInput("Word", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetExamples Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetExamplesResultSet extends ResultSet {
		public GetExamplesResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Wordnik.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
