package com.temboo.Library.Wordnik.Word;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetRelatedWords

Retrieves the related words of a given word.
*/
public class GetRelatedWords extends Choreography {

	/**
	Create a new instance of the GetRelatedWords Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetRelatedWords(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Wordnik/Word/GetRelatedWords"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetRelatedWordsInputSet
	*/
	public GetRelatedWordsInputSet newInputSet() {
		return new GetRelatedWordsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetRelatedWordsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetRelatedWordsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetRelatedWords
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetRelatedWordsInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key from Wordnik.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Cannonical input for this Choreo. 

		@param String - (optional, string) If true will try to return the correct word root ('cats' -> 'cat'). If false returns exactly what was requested. Defaults to false.
		*/
		public void set_Cannonical(String value) {
			this.setInput("Cannonical", value);
		}



		/** 
		Set the value of the LimitPerType input for this Choreo. 

		@param Integer - (optional, integer) Limits the amount of results returned for each relationship type included in the output. Defaults to 10.
		*/
		public void set_LimitPerType(Integer value) {
			this.setInput("LimitPerType", value);
		}

		/** 
		Set the value of the LimitPerType input for this Choreo as a String. 

		@param String - (optional, integer) Limits the amount of results returned for each relationship type included in the output. Defaults to 10.
		*/
		public void set_LimitPerType(String value) {
			this.setInput("LimitPerType", value);	
		}

		/** 
		Set the value of the RelationshipType input for this Choreo. 

		@param String - (optional, string) Limits the total results per type of relationship. Acceptable values inlcude adjective, noun, etc. See docs for complete list.
		*/
		public void set_RelationshipType(String value) {
			this.setInput("RelationshipType", value);
		}



		/** 
		Set the value of the ResponseType input for this Choreo. 

		@param String - (optional, string) Response can be either JSON or XML. Defaults to JSON.
		*/
		public void set_ResponseType(String value) {
			this.setInput("ResponseType", value);
		}



		/** 
		Set the value of the Word input for this Choreo. 

		@param String - (required, string) The word you want to look up on Wordnik.
		*/
		public void set_Word(String value) {
			this.setInput("Word", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetRelatedWords Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetRelatedWordsResultSet extends ResultSet {
		public GetRelatedWordsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Wordnik.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
