package com.temboo.Library.Wordnik.Words;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetWordOfTheDay

Retrieves the word of the day for specified dates.
*/
public class GetWordOfTheDay extends Choreography {

	/**
	Create a new instance of the GetWordOfTheDay Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetWordOfTheDay(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Wordnik/Words/GetWordOfTheDay"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetWordOfTheDayInputSet
	*/
	public GetWordOfTheDayInputSet newInputSet() {
		return new GetWordOfTheDayInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetWordOfTheDayResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetWordOfTheDayResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetWordOfTheDay
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetWordOfTheDayInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key from Wordnik.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Date input for this Choreo. 

		@param String - (required, string) The date of the Word of the Day to retrieve, in yyyy-MM-dd format.
		*/
		public void set_Date(String value) {
			this.setInput("Date", value);
		}



		/** 
		Set the value of the ResponseType input for this Choreo. 

		@param String - (optional, string) Response can be either JSON or XML. Defaults to JSON.
		*/
		public void set_ResponseType(String value) {
			this.setInput("ResponseType", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetWordOfTheDay Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetWordOfTheDayResultSet extends ResultSet {
		public GetWordOfTheDayResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Wordnik.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
