package com.temboo.Library.Wordnik.Words;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
RandomWords

Retrieves a list of random words.
*/
public class RandomWords extends Choreography {

	/**
	Create a new instance of the RandomWords Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public RandomWords(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Wordnik/Words/RandomWords"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return RandomWordsInputSet
	*/
	public RandomWordsInputSet newInputSet() {
		return new RandomWordsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public RandomWordsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new RandomWordsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the RandomWords
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class RandomWordsInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key from Wordnik.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the ExcludePartOfSpeech input for this Choreo. 

		@param String - (optional, string) Excludes the specified comma-delimited parts of speech from the results returned. Acceptable values include: adjective, noun, etc. See docs for full list.
		*/
		public void set_ExcludePartOfSpeech(String value) {
			this.setInput("ExcludePartOfSpeech", value);
		}



		/** 
		Set the value of the HasDefinition input for this Choreo. 

		@param String - (optional, string) Only returns words that have dictionary definitions when true. Otherwise false. Defaults to true.
		*/
		public void set_HasDefinition(String value) {
			this.setInput("HasDefinition", value);
		}



		/** 
		Set the value of the IncludePartOfSpeech input for this Choreo. 

		@param String - (optional, string) Only includes the specified comma-delimited parts of speech. Acceptable values include: adjective, noun, etc. See docs for full list.
		*/
		public void set_IncludePartOfSpeech(String value) {
			this.setInput("IncludePartOfSpeech", value);
		}



		/** 
		Set the value of the Limit input for this Choreo. 

		@param Integer - (optional, integer) Maximum number of results to return. Defaults to 10.
		*/
		public void set_Limit(Integer value) {
			this.setInput("Limit", value);
		}

		/** 
		Set the value of the Limit input for this Choreo as a String. 

		@param String - (optional, integer) Maximum number of results to return. Defaults to 10.
		*/
		public void set_Limit(String value) {
			this.setInput("Limit", value);	
		}

		/** 
		Set the value of the MaxCorpus input for this Choreo. 

		@param Integer - (optional, integer) Results include a corpus frequency count for each word returned. When this input is specified, results are limited to words with a corpus frequency count below the given number.
		*/
		public void set_MaxCorpus(Integer value) {
			this.setInput("MaxCorpus", value);
		}

		/** 
		Set the value of the MaxCorpus input for this Choreo as a String. 

		@param String - (optional, integer) Results include a corpus frequency count for each word returned. When this input is specified, results are limited to words with a corpus frequency count below the given number.
		*/
		public void set_MaxCorpus(String value) {
			this.setInput("MaxCorpus", value);	
		}

		/** 
		Set the value of the MaxDictionaries input for this Choreo. 

		@param Integer - (optional, integer) Maximum number of dictionaries in which the words appear.
		*/
		public void set_MaxDictionaries(Integer value) {
			this.setInput("MaxDictionaries", value);
		}

		/** 
		Set the value of the MaxDictionaries input for this Choreo as a String. 

		@param String - (optional, integer) Maximum number of dictionaries in which the words appear.
		*/
		public void set_MaxDictionaries(String value) {
			this.setInput("MaxDictionaries", value);	
		}

		/** 
		Set the value of the MaxLength input for this Choreo. 

		@param Integer - (optional, integer) Maximum word length.
		*/
		public void set_MaxLength(Integer value) {
			this.setInput("MaxLength", value);
		}

		/** 
		Set the value of the MaxLength input for this Choreo as a String. 

		@param String - (optional, integer) Maximum word length.
		*/
		public void set_MaxLength(String value) {
			this.setInput("MaxLength", value);	
		}

		/** 
		Set the value of the MinCorpus input for this Choreo. 

		@param Integer - (optional, integer) Results include a corpus frequency count for each word returned. When this input is specified, results are limited to words with a corpus frequency count above the given number.
		*/
		public void set_MinCorpus(Integer value) {
			this.setInput("MinCorpus", value);
		}

		/** 
		Set the value of the MinCorpus input for this Choreo as a String. 

		@param String - (optional, integer) Results include a corpus frequency count for each word returned. When this input is specified, results are limited to words with a corpus frequency count above the given number.
		*/
		public void set_MinCorpus(String value) {
			this.setInput("MinCorpus", value);	
		}

		/** 
		Set the value of the MinDictionaries input for this Choreo. 

		@param Integer - (optional, integer) Minimum number of dictionaries in which the words appear.
		*/
		public void set_MinDictionaries(Integer value) {
			this.setInput("MinDictionaries", value);
		}

		/** 
		Set the value of the MinDictionaries input for this Choreo as a String. 

		@param String - (optional, integer) Minimum number of dictionaries in which the words appear.
		*/
		public void set_MinDictionaries(String value) {
			this.setInput("MinDictionaries", value);	
		}

		/** 
		Set the value of the MinLength input for this Choreo. 

		@param Integer - (optional, integer) ‪Minimum word length.
		*/
		public void set_MinLength(Integer value) {
			this.setInput("MinLength", value);
		}

		/** 
		Set the value of the MinLength input for this Choreo as a String. 

		@param String - (optional, integer) ‪Minimum word length.
		*/
		public void set_MinLength(String value) {
			this.setInput("MinLength", value);	
		}

		/** 
		Set the value of the ResponseType input for this Choreo. 

		@param String - (optional, string) Response can be either JSON or XML. Defaults to JSON.
		*/
		public void set_ResponseType(String value) {
			this.setInput("ResponseType", value);
		}



		/** 
		Set the value of the SortBy input for this Choreo. 

		@param String - (optional, string) Results can be sorted by: alpha, count, or length.
		*/
		public void set_SortBy(String value) {
			this.setInput("SortBy", value);
		}



		/** 
		Set the value of the SortOrder input for this Choreo. 

		@param String - (optional, string) Indicate the order to sort, either asc (ascending) or desc (descending).
		*/
		public void set_SortOrder(String value) {
			this.setInput("SortOrder", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the RandomWords Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class RandomWordsResultSet extends ResultSet {
		public RandomWordsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Wordnik.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
