package com.temboo.Library.Wordnik.Words;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
SearchWords

Searches words.
*/
public class SearchWords extends Choreography {

	/**
	Create a new instance of the SearchWords Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public SearchWords(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Wordnik/Words/SearchWords"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return SearchWordsInputSet
	*/
	public SearchWordsInputSet newInputSet() {
		return new SearchWordsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public SearchWordsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new SearchWordsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the SearchWords
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class SearchWordsInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key from Wordnik.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the CaseSensitive input for this Choreo. 

		@param String - (optional, string) Makes the query case-insensitive when false. Defaults to true, so queries are case-sensitive.
		*/
		public void set_CaseSensitive(String value) {
			this.setInput("CaseSensitive", value);
		}



		/** 
		Set the value of the ExcludePartOfSpeech input for this Choreo. 

		@param String - (optional, string) Excludes the specified comma-delimited parts of speech from the results returned. Acceptable values include: adjective, noun, etc. See docs for full list.
		*/
		public void set_ExcludePartOfSpeech(String value) {
			this.setInput("ExcludePartOfSpeech", value);
		}



		/** 
		Set the value of the IncludePartOfSpeech input for this Choreo. 

		@param String - (optional, string) Only includes the specified comma-delimited parts of speech. Acceptable values include: adjective, noun, etc. See docs for full list.
		*/
		public void set_IncludePartOfSpeech(String value) {
			this.setInput("IncludePartOfSpeech", value);
		}



		/** 
		Set the value of the Limit input for this Choreo. 

		@param Integer - (optional, integer) Maximum number of results to return. Defaults to 10.
		*/
		public void set_Limit(Integer value) {
			this.setInput("Limit", value);
		}

		/** 
		Set the value of the Limit input for this Choreo as a String. 

		@param String - (optional, integer) Maximum number of results to return. Defaults to 10.
		*/
		public void set_Limit(String value) {
			this.setInput("Limit", value);	
		}

		/** 
		Set the value of the MaxCorpus input for this Choreo. 

		@param Integer - (optional, integer) Results include a corpus frequency count for each word returned. When this input is specified, results are limited to words with a corpus frequency count below the given number.
		*/
		public void set_MaxCorpus(Integer value) {
			this.setInput("MaxCorpus", value);
		}

		/** 
		Set the value of the MaxCorpus input for this Choreo as a String. 

		@param String - (optional, integer) Results include a corpus frequency count for each word returned. When this input is specified, results are limited to words with a corpus frequency count below the given number.
		*/
		public void set_MaxCorpus(String value) {
			this.setInput("MaxCorpus", value);	
		}

		/** 
		Set the value of the MaxEntries input for this Choreo. 

		@param Integer - (optional, integer) Limits the results to words that have fewer than the given numner of dictionary entries.
		*/
		public void set_MaxEntries(Integer value) {
			this.setInput("MaxEntries", value);
		}

		/** 
		Set the value of the MaxEntries input for this Choreo as a String. 

		@param String - (optional, integer) Limits the results to words that have fewer than the given numner of dictionary entries.
		*/
		public void set_MaxEntries(String value) {
			this.setInput("MaxEntries", value);	
		}

		/** 
		Set the value of the MaxLength input for this Choreo. 

		@param Integer - (optional, integer) Maximum word length.
		*/
		public void set_MaxLength(Integer value) {
			this.setInput("MaxLength", value);
		}

		/** 
		Set the value of the MaxLength input for this Choreo as a String. 

		@param String - (optional, integer) Maximum word length.
		*/
		public void set_MaxLength(String value) {
			this.setInput("MaxLength", value);	
		}

		/** 
		Set the value of the MinCorpus input for this Choreo. 

		@param Integer - (optional, integer) Results include a corpus frequency count for each word returned. When this input is specified, results are limited to words with a corpus frequency count above the given number.
		*/
		public void set_MinCorpus(Integer value) {
			this.setInput("MinCorpus", value);
		}

		/** 
		Set the value of the MinCorpus input for this Choreo as a String. 

		@param String - (optional, integer) Results include a corpus frequency count for each word returned. When this input is specified, results are limited to words with a corpus frequency count above the given number.
		*/
		public void set_MinCorpus(String value) {
			this.setInput("MinCorpus", value);	
		}

		/** 
		Set the value of the MinEntries input for this Choreo. 

		@param Integer - (optional, integer) Limits the results to words that have more than the given numner of dictionary entries.
		*/
		public void set_MinEntries(Integer value) {
			this.setInput("MinEntries", value);
		}

		/** 
		Set the value of the MinEntries input for this Choreo as a String. 

		@param String - (optional, integer) Limits the results to words that have more than the given numner of dictionary entries.
		*/
		public void set_MinEntries(String value) {
			this.setInput("MinEntries", value);	
		}

		/** 
		Set the value of the MinLength input for this Choreo. 

		@param Integer - (optional, integer) ‪Minimum word length.
		*/
		public void set_MinLength(Integer value) {
			this.setInput("MinLength", value);
		}

		/** 
		Set the value of the MinLength input for this Choreo as a String. 

		@param String - (optional, integer) ‪Minimum word length.
		*/
		public void set_MinLength(String value) {
			this.setInput("MinLength", value);	
		}

		/** 
		Set the value of the Query input for this Choreo. 

		@param String - (required, string) Word or fragment to query for in Wordnik.
		*/
		public void set_Query(String value) {
			this.setInput("Query", value);
		}



		/** 
		Set the value of the ResponseType input for this Choreo. 

		@param String - (optional, string) Response can be either JSON or XML. Defaults to JSON.
		*/
		public void set_ResponseType(String value) {
			this.setInput("ResponseType", value);
		}



		/** 
		Set the value of the Skip input for this Choreo. 

		@param Integer - (optional, integer) Number of results to skip.
		*/
		public void set_Skip(Integer value) {
			this.setInput("Skip", value);
		}

		/** 
		Set the value of the Skip input for this Choreo as a String. 

		@param String - (optional, integer) Number of results to skip.
		*/
		public void set_Skip(String value) {
			this.setInput("Skip", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the SearchWords Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class SearchWordsResultSet extends ResultSet {
		public SearchWordsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Wordnik.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
