package com.temboo.Library.Xively.APIKeys;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
DeleteKey

Deletes a specific API Key.
*/
public class DeleteKey extends Choreography {

	/**
	Create a new instance of the DeleteKey Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DeleteKey(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Xively/APIKeys/DeleteKey"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DeleteKeyInputSet
	*/
	public DeleteKeyInputSet newInputSet() {
		return new DeleteKeyInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DeleteKeyResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DeleteKeyResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DeleteKey
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DeleteKeyInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key you would like to delete.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the MasterAPIKey input for this Choreo. 

		@param String - (optional, string) Specify a MasterAPIKey with more permissions if the APIKey you would like to delete does not have sufficient permissions.
		*/
		public void set_MasterAPIKey(String value) {
			this.setInput("MasterAPIKey", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DeleteKey Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DeleteKeyResultSet extends ResultSet {
		public DeleteKeyResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "ResponseStatusCode" output from this Choreo execution

		@return String - (integer) The response status code returned from Xively. For a valid deletion, the code returned should be 200.
		*/
		public String get_ResponseStatusCode() {
			return this.getResult("ResponseStatusCode");
		}
	}
	
}
