package com.temboo.Library.Xively.APIKeys;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ReadKey

Returns a JSON or XML representation of the specified APIKey.
*/
public class ReadKey extends Choreography {

	/**
	Create a new instance of the ReadKey Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ReadKey(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Xively/APIKeys/ReadKey"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ReadKeyInputSet
	*/
	public ReadKeyInputSet newInputSet() {
		return new ReadKeyInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ReadKeyResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ReadKeyResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ReadKey
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ReadKeyInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key you would like to return information on.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the MasterAPIKey input for this Choreo. 

		@param String - (optional, string) Specify a MasterAPIKey with more permissions if the APIKey you would like to view does not have sufficient (read) permissions.
		*/
		public void set_MasterAPIKey(String value) {
			this.setInput("MasterAPIKey", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are "json" (the default) and "xml".
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ReadKey Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ReadKeyResultSet extends ResultSet {
		public ReadKeyResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Xively.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
