package com.temboo.Library.Xively.Devices;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CreateDevice

Creates a new device in a product batch for each serial number provided. When created, each device will be in a pre-registered state awaiting activation. Creating a non-product-affiliated device is not available through the Xively API, and can only be done through the browser-only Xively Developer Workbench.
*/
public class CreateDevice extends Choreography {

	/**
	Create a new instance of the CreateDevice Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CreateDevice(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Xively/Devices/CreateDevice"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CreateDeviceInputSet
	*/
	public CreateDeviceInputSet newInputSet() {
		return new CreateDeviceInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CreateDeviceResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CreateDeviceResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CreateDevice
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CreateDeviceInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Xively.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the ProductID input for this Choreo. 

		@param String - (required, string) The product ID for the device you would like to add.
		*/
		public void set_ProductID(String value) {
			this.setInput("ProductID", value);
		}



		/** 
		Set the value of the SerialNumbers input for this Choreo. 

		@param String - (required, string) Comma-separated list of device serial numbers to add. Allowed characters: case-sensitive alphanumeric characters (Ab3) and the following characters: "+", "-", "_", and ":". Ex: abc:123,aBc-124.
		*/
		public void set_SerialNumbers(String value) {
			this.setInput("SerialNumbers", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CreateDevice Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CreateDeviceResultSet extends ResultSet {
		public CreateDeviceResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "ResponseStatusCode" output from this Choreo execution

		@return String - (integer) The response status code returned from Xively. For a successful device creation, the code should be 201.
		*/
		public String get_ResponseStatusCode() {
			return this.getResult("ResponseStatusCode");
		}
	}
	
}
