package com.temboo.Library.Xively.Devices;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
DeleteDevice

Deletes the device matching the provided serial number.
*/
public class DeleteDevice extends Choreography {

	/**
	Create a new instance of the DeleteDevice Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DeleteDevice(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Xively/Devices/DeleteDevice"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DeleteDeviceInputSet
	*/
	public DeleteDeviceInputSet newInputSet() {
		return new DeleteDeviceInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DeleteDeviceResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DeleteDeviceResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DeleteDevice
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DeleteDeviceInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Xively.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the ProductID input for this Choreo. 

		@param String - (required, string) The product ID for the device you would like to delete.
		*/
		public void set_ProductID(String value) {
			this.setInput("ProductID", value);
		}



		/** 
		Set the value of the SerialNumber input for this Choreo. 

		@param String - (required, string) The serial number for the device you would like to delete.
		*/
		public void set_SerialNumber(String value) {
			this.setInput("SerialNumber", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DeleteDevice Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DeleteDeviceResultSet extends ResultSet {
		public DeleteDeviceResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "ResponseStatusCode" output from this Choreo execution

		@return String - (integer) The response status code returned from Xively. For a successful deletion, the status code should be 200.
		*/
		public String get_ResponseStatusCode() {
			return this.getResult("ResponseStatusCode");
		}
	}
	
}
