package com.temboo.Library.Xively.Products;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CreateProduct

Creates a new product batch.
*/
public class CreateProduct extends Choreography {

	/**
	Create a new instance of the CreateProduct Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CreateProduct(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Xively/Products/CreateProduct"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CreateProductInputSet
	*/
	public CreateProductInputSet newInputSet() {
		return new CreateProductInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CreateProductResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CreateProductResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CreateProduct
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CreateProductInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Xively.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the CustomProduct input for this Choreo. 

		@param String - (optional, json) Optional custom configuration for creating your product in JSON. If you use this field the other optional parameters will be ignored. See Choreo description and Xively documentation for details.
		*/
		public void set_CustomProduct(String value) {
			this.setInput("CustomProduct", value);
		}



		/** 
		Set the value of the Datastreams input for this Choreo. 

		@param String - (optional, json) Default device datastream JSON array. Every newly created device in this product will have this default datastream. Ex: [{"id":"channel1"},{"id":"demo"}]
		*/
		public void set_Datastreams(String value) {
			this.setInput("Datastreams", value);
		}



		/** 
		Set the value of the Description input for this Choreo. 

		@param String - (optional, string) Description of the product.
		*/
		public void set_Description(String value) {
			this.setInput("Description", value);
		}



		/** 
		Set the value of the Name input for this Choreo. 

		@param String - (conditional, string) Name of the product. Required unless using the CustomProduct JSON input.
		*/
		public void set_Name(String value) {
			this.setInput("Name", value);
		}



		/** 
		Set the value of the Private input for this Choreo. 

		@param String - (optional, string) Default device feed privacy settings. Valid values: "true", "false" (default).
		*/
		public void set_Private(String value) {
			this.setInput("Private", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CreateProduct Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CreateProductResultSet extends ResultSet {
		public CreateProductResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "ProductID" output from this Choreo execution

		@return String - (string) The ProductID obtained from the ProductLocation returned by this Choreo.
		*/
		public String get_ProductID() {
			return this.getResult("ProductID");
		}
		/** 
		Retrieve the value for the "ProductLocation" output from this Choreo execution

		@return String - (string) The URL of the newly created product.
		*/
		public String get_ProductLocation() {
			return this.getResult("ProductLocation");
		}
		/** 
		Retrieve the value for the "ResponseStatusCode" output from this Choreo execution

		@return String - (integer) The response status code returned from Xively. For a successful product creation, the code should be 201.
		*/
		public String get_ResponseStatusCode() {
			return this.getResult("ResponseStatusCode");
		}
	}
	
}
