package com.temboo.Library.Xively.Products;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ReadProduct

Returns a JSON representation of a product. 
*/
public class ReadProduct extends Choreography {

	/**
	Create a new instance of the ReadProduct Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ReadProduct(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Xively/Products/ReadProduct"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ReadProductInputSet
	*/
	public ReadProductInputSet newInputSet() {
		return new ReadProductInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ReadProductResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ReadProductResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ReadProduct
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ReadProductInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Xively.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the ProductID input for this Choreo. 

		@param String - (required, string) The ID of the product you are trying to read information on.
		*/
		public void set_ProductID(String value) {
			this.setInput("ProductID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ReadProduct Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ReadProductResultSet extends ResultSet {
		public ReadProductResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Xively.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
