package com.temboo.Library.Xively.ReadWriteData;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
DeleteDatapoint

Deletes a single existing datapoint for a specific timestamp.
*/
public class DeleteDatapoint extends Choreography {

	/**
	Create a new instance of the DeleteDatapoint Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DeleteDatapoint(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Xively/ReadWriteData/DeleteDatapoint"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DeleteDatapointInputSet
	*/
	public DeleteDatapointInputSet newInputSet() {
		return new DeleteDatapointInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DeleteDatapointResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DeleteDatapointResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DeleteDatapoint
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DeleteDatapointInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Xively.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the DatastreamID input for this Choreo. 

		@param String - (required, string) The ID of the datastream you would like to delete the datapoint for.
		*/
		public void set_DatastreamID(String value) {
			this.setInput("DatastreamID", value);
		}



		/** 
		Set the value of the FeedID input for this Choreo. 

		@param String - (required, string) The ID of the feed you would like to delete the datapoint for.
		*/
		public void set_FeedID(String value) {
			this.setInput("FeedID", value);
		}



		/** 
		Set the value of the Timestamp input for this Choreo. 

		@param String - (required, date) Timestamp of datapoint value to delete. Must be in ISO 8601 format, and can include up to 6 decimal places of resolution (in seconds), default zone is UTC.  Ex: 2013-05-07T00:00:00.123456Z.
		*/
		public void set_Timestamp(String value) {
			this.setInput("Timestamp", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DeleteDatapoint Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DeleteDatapointResultSet extends ResultSet {
		public DeleteDatapointResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "ResponsStatusCode" output from this Choreo execution

		@return String - (integer) The response status code returned from Xively. For a successful datapoint deletion, the code should be 200.
		*/
		public String get_ResponsStatusCode() {
			return this.getResult("ResponsStatusCode");
		}
	}
	
}
