package com.temboo.Library.Xively.ReadWriteData;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
DeleteMultipleDatapoints

Deletes multiple datapoints from a single datastream given a start date, end date, and/or duration.
*/
public class DeleteMultipleDatapoints extends Choreography {

	/**
	Create a new instance of the DeleteMultipleDatapoints Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DeleteMultipleDatapoints(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Xively/ReadWriteData/DeleteMultipleDatapoints"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DeleteMultipleDatapointsInputSet
	*/
	public DeleteMultipleDatapointsInputSet newInputSet() {
		return new DeleteMultipleDatapointsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DeleteMultipleDatapointsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DeleteMultipleDatapointsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DeleteMultipleDatapoints
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DeleteMultipleDatapointsInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Xively.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the DatastreamID input for this Choreo. 

		@param String - (required, string) The ID of the datastream you would like to delete datapoints from.
		*/
		public void set_DatastreamID(String value) {
			this.setInput("DatastreamID", value);
		}



		/** 
		Set the value of the Duration input for this Choreo. 

		@param String - (conditional, string) Specifies the duration of the deletion. Can be used with StartDate or EndDate. Ex: 5seconds, 10minutes, 6hours. See documentation for full description / examples.
		*/
		public void set_Duration(String value) {
			this.setInput("Duration", value);
		}



		/** 
		Set the value of the EndDate input for this Choreo. 

		@param String - (conditional, date) Defines the end point of the deletion as a timestamp. Can be used with Duration. Ex: 2013-05-10T12:00:00Z.
		*/
		public void set_EndDate(String value) {
			this.setInput("EndDate", value);
		}



		/** 
		Set the value of the FeedID input for this Choreo. 

		@param String - (required, string) The ID of the feed you would like to delete datapoints from.
		*/
		public void set_FeedID(String value) {
			this.setInput("FeedID", value);
		}



		/** 
		Set the value of the StartDate input for this Choreo. 

		@param String - (conditional, date) Defines the starting point of the deletion as a timestamp. Can be used with Duration. Ex: 2013-05-10T00:00:00Z.
		*/
		public void set_StartDate(String value) {
			this.setInput("StartDate", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DeleteMultipleDatapoints Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DeleteMultipleDatapointsResultSet extends ResultSet {
		public DeleteMultipleDatapointsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "ResponsStatusCode" output from this Choreo execution

		@return String - (integer) The response status code returned from Xively. For a successful datapoint range deletion, the code should be 200.
		*/
		public String get_ResponsStatusCode() {
			return this.getResult("ResponsStatusCode");
		}
	}
	
}
