package com.temboo.Library.Xively.ReadWriteData;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ReadGraph

Returns a customizable graph (Base64-encoded PNG image file) of datapoints from a specific datastream.
*/
public class ReadGraph extends Choreography {

	/**
	Create a new instance of the ReadGraph Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ReadGraph(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Xively/ReadWriteData/ReadGraph"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ReadGraphInputSet
	*/
	public ReadGraphInputSet newInputSet() {
		return new ReadGraphInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ReadGraphResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ReadGraphResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ReadGraph
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ReadGraphInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Xively.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Color input for this Choreo. 

		@param String - (optional, string) The PNG color in hex. Ex: FFCC33.
		*/
		public void set_Color(String value) {
			this.setInput("Color", value);
		}



		/** 
		Set the value of the DatastreamID input for this Choreo. 

		@param String - (required, string) The ID for the datastream you wish to read.
		*/
		public void set_DatastreamID(String value) {
			this.setInput("DatastreamID", value);
		}



		/** 
		Set the value of the Duration input for this Choreo. 

		@param String - (optional, string) Used for a historical query. If used with EndDate will request data prior to EndDate, if used with StartDate will request data after StartDate. By itself will give most recent data. Ex: 6hours, 2days.
		*/
		public void set_Duration(String value) {
			this.setInput("Duration", value);
		}



		/** 
		Set the value of the EndDate input for this Choreo. 

		@param String - (optional, date) Used for a historical query. Defines the end point of the data returned as a timestamp. Ex: 2013-05-10T12:00:00Z. Default value is set to current timestamp.
		*/
		public void set_EndDate(String value) {
			this.setInput("EndDate", value);
		}



		/** 
		Set the value of the FeedID input for this Choreo. 

		@param Integer - (required, integer) The ID of the feed you wish to read.
		*/
		public void set_FeedID(Integer value) {
			this.setInput("FeedID", value);
		}

		/** 
		Set the value of the FeedID input for this Choreo as a String. 

		@param String - (required, integer) The ID of the feed you wish to read.
		*/
		public void set_FeedID(String value) {
			this.setInput("FeedID", value);	
		}

		/** 
		Set the value of the FindPrevious input for this Choreo. 

		@param Boolean - (optional, boolean) Used for a historical query. Will also return the previous value to the date range being requested. Useful to allow a graph to start a graph with some datapoint. Valid values: "true", blank (default).
		*/
		public void set_FindPrevious(Boolean value) {
			this.setInput("FindPrevious", value);
		}

		/** 
		Set the value of the FindPrevious input for this Choreo as a String. 

		@param String - (optional, boolean) Used for a historical query. Will also return the previous value to the date range being requested. Useful to allow a graph to start a graph with some datapoint. Valid values: "true", blank (default).
		*/
		public void set_FindPrevious(String value) {
			this.setInput("FindPrevious", value);	
		}

		/** 
		Set the value of the Height input for this Choreo. 

		@param Integer - (optional, integer) The PNG height in pixels. Max height: 500. Ex: 400.
		*/
		public void set_Height(Integer value) {
			this.setInput("Height", value);
		}

		/** 
		Set the value of the Height input for this Choreo as a String. 

		@param String - (optional, integer) The PNG height in pixels. Max height: 500. Ex: 400.
		*/
		public void set_Height(String value) {
			this.setInput("Height", value);	
		}

		/** 
		Set the value of the IntervalType input for this Choreo. 

		@param String - (optional, string) Used for a historical query. If set to "discrete" the data will be returned in fixed time interval format according to Interval value. If not set, the raw datapoints will be returned.
		*/
		public void set_IntervalType(String value) {
			this.setInput("IntervalType", value);
		}



		/** 
		Set the value of the Interval input for this Choreo. 

		@param Integer - (optional, integer) Used for a historical query. Determines what interval of data is requested and is defined in seconds between the datapoints. See documentation for full list of possible values. Ex: 0, 30, 60, etc.
		*/
		public void set_Interval(Integer value) {
			this.setInput("Interval", value);
		}

		/** 
		Set the value of the Interval input for this Choreo as a String. 

		@param String - (optional, integer) Used for a historical query. Determines what interval of data is requested and is defined in seconds between the datapoints. See documentation for full list of possible values. Ex: 0, 30, 60, etc.
		*/
		public void set_Interval(String value) {
			this.setInput("Interval", value);	
		}

		/** 
		Set the value of the Legend input for this Choreo. 

		@param String - (optional, string) Label given datapoints on a legend included on the graph.
		*/
		public void set_Legend(String value) {
			this.setInput("Legend", value);
		}



		/** 
		Set the value of the Limit input for this Choreo. 

		@param Integer - (optional, integer) Used for a historical query. LImits the number of results to the number specified here. Defaults to 100, has a maximum of 1000.
		*/
		public void set_Limit(Integer value) {
			this.setInput("Limit", value);
		}

		/** 
		Set the value of the Limit input for this Choreo as a String. 

		@param String - (optional, integer) Used for a historical query. LImits the number of results to the number specified here. Defaults to 100, has a maximum of 1000.
		*/
		public void set_Limit(String value) {
			this.setInput("Limit", value);	
		}

		/** 
		Set the value of the LineSize input for this Choreo. 

		@param Integer - (optional, integer) Size of the lines/strokes in pixels. Ex: 4.
		*/
		public void set_LineSize(Integer value) {
			this.setInput("LineSize", value);
		}

		/** 
		Set the value of the LineSize input for this Choreo as a String. 

		@param String - (optional, integer) Size of the lines/strokes in pixels. Ex: 4.
		*/
		public void set_LineSize(String value) {
			this.setInput("LineSize", value);	
		}

		/** 
		Set the value of the ShowAxisLabels input for this Choreo. 

		@param Boolean - (optional, boolean) Show access labels. Input "true" to turn on, leave blank to keep off (default).
		*/
		public void set_ShowAxisLabels(Boolean value) {
			this.setInput("ShowAxisLabels", value);
		}

		/** 
		Set the value of the ShowAxisLabels input for this Choreo as a String. 

		@param String - (optional, boolean) Show access labels. Input "true" to turn on, leave blank to keep off (default).
		*/
		public void set_ShowAxisLabels(String value) {
			this.setInput("ShowAxisLabels", value);	
		}

		/** 
		Set the value of the ShowDetailedGrid input for this Choreo. 

		@param String - (optional, string) Show detailed grid. Input "true" to turn on, leave blank to keep off (default).
		*/
		public void set_ShowDetailedGrid(String value) {
			this.setInput("ShowDetailedGrid", value);
		}



		/** 
		Set the value of the StartDate input for this Choreo. 

		@param String - (optional, date) Used for a historical query. Defines the starting the point of the query as a timestamp. Ex: 2013-05-10T00:00:00Z.
		*/
		public void set_StartDate(String value) {
			this.setInput("StartDate", value);
		}



		/** 
		Set the value of the Timezone input for this Choreo. 

		@param String - (optional, string) Timezone of the graph. For a list of valid values please see description and API documenation. Ex: Eastern Time (US & Canada), Pacific Time (US & Canada), UTC, Tokyo.
		*/
		public void set_Timezone(String value) {
			this.setInput("Timezone", value);
		}



		/** 
		Set the value of the Title input for this Choreo. 

		@param String - (optional, string) Title of the graph.
		*/
		public void set_Title(String value) {
			this.setInput("Title", value);
		}



		/** 
		Set the value of the Width input for this Choreo. 

		@param Integer - (optional, integer) The PNG width in pixels. Max width: 600. Ex: 600.
		*/
		public void set_Width(Integer value) {
			this.setInput("Width", value);
		}

		/** 
		Set the value of the Width input for this Choreo as a String. 

		@param String - (optional, integer) The PNG width in pixels. Max width: 600. Ex: 600.
		*/
		public void set_Width(String value) {
			this.setInput("Width", value);	
		}

		/** 
		Set the value of the YAxisMax input for this Choreo. 

		@param String - (optional, string) Y-axis maximum value if the YAxisScale is set to "manual".
		*/
		public void set_YAxisMax(String value) {
			this.setInput("YAxisMax", value);
		}



		/** 
		Set the value of the YAxisMin input for this Choreo. 

		@param String - (optional, string) Y-axis minimum value if the YAxisScale is set to "manual".
		*/
		public void set_YAxisMin(String value) {
			this.setInput("YAxisMin", value);
		}



		/** 
		Set the value of the YAxisScale input for this Choreo. 

		@param String - (optional, string) Method used to determine the y-axis scale. Valid values: "auto" (default), "datastream", or "manual".
		*/
		public void set_YAxisScale(String value) {
			this.setInput("YAxisScale", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ReadGraph Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ReadGraphResultSet extends ResultSet {
		public ReadGraphResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Xively, which is a base64-encoded binary .png file. Decode to get the binary PNG graphic.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
