package com.temboo.Library.Xively.ReadWriteData;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
WriteLocationData

Allows you to easily update the location data of your feed.
*/
public class WriteLocationData extends Choreography {

	/**
	Create a new instance of the WriteLocationData Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public WriteLocationData(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Xively/ReadWriteData/WriteLocationData"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return WriteLocationDataInputSet
	*/
	public WriteLocationDataInputSet newInputSet() {
		return new WriteLocationDataInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public WriteLocationDataResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new WriteLocationDataResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the WriteLocationData
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class WriteLocationDataInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Xively.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Disposition input for this Choreo. 

		@param String - (optional, string) Can be set to "mobile" to enable creating waypoints (lat, lon and elevation with timestamp), or "fixed" (default) for a single location. Leave empty to keep existing settings.
		*/
		public void set_Disposition(String value) {
			this.setInput("Disposition", value);
		}



		/** 
		Set the value of the Domain input for this Choreo. 

		@param String - (optional, string) The domain of the location, i.e. physical or virtual. Leave empty to keep existing Domain. Type "BLANK" to clear existing Domain. Ex: "physical".
		*/
		public void set_Domain(String value) {
			this.setInput("Domain", value);
		}



		/** 
		Set the value of the Elevation input for this Choreo. 

		@param BigDecimal - (optional, decimal) Elevation in meters. Leave empty to keep previously existing Elevation. Type "BLANK" to clear existing Elevation. Ex: 20.5.
		*/
		public void set_Elevation(BigDecimal value) {
			this.setInput("Elevation", value);
		}

		/** 
		Set the value of the Elevation input for this Choreo as a String. 

		@param String - (optional, decimal) Elevation in meters. Leave empty to keep previously existing Elevation. Type "BLANK" to clear existing Elevation. Ex: 20.5.
		*/
		public void set_Elevation(String value) {
			this.setInput("Elevation", value);	
		}

		/** 
		Set the value of the FeedID input for this Choreo. 

		@param Integer - (required, integer) The ID for the feed that you would like to update.
		*/
		public void set_FeedID(Integer value) {
			this.setInput("FeedID", value);
		}

		/** 
		Set the value of the FeedID input for this Choreo as a String. 

		@param String - (required, integer) The ID for the feed that you would like to update.
		*/
		public void set_FeedID(String value) {
			this.setInput("FeedID", value);	
		}

		/** 
		Set the value of the Latitude input for this Choreo. 

		@param BigDecimal - (optional, decimal) Latitude coordinates. Leave empty to keep previously existing Latitude. Type "BLANK" to clear existing Latitude. Ex: 40.728194.
		*/
		public void set_Latitude(BigDecimal value) {
			this.setInput("Latitude", value);
		}

		/** 
		Set the value of the Latitude input for this Choreo as a String. 

		@param String - (optional, decimal) Latitude coordinates. Leave empty to keep previously existing Latitude. Type "BLANK" to clear existing Latitude. Ex: 40.728194.
		*/
		public void set_Latitude(String value) {
			this.setInput("Latitude", value);	
		}

		/** 
		Set the value of the Longitude input for this Choreo. 

		@param BigDecimal - (optional, decimal) Longitude coordinates. Leave empty to keep previously existing Location. Type "BLANK" to clear existing settings. Ex: -73.957316.
		*/
		public void set_Longitude(BigDecimal value) {
			this.setInput("Longitude", value);
		}

		/** 
		Set the value of the Longitude input for this Choreo as a String. 

		@param String - (optional, decimal) Longitude coordinates. Leave empty to keep previously existing Location. Type "BLANK" to clear existing settings. Ex: -73.957316.
		*/
		public void set_Longitude(String value) {
			this.setInput("Longitude", value);	
		}

		/** 
		Set the value of the Name input for this Choreo. 

		@param String - (optional, string) Name of Location. Leave empty to keep existing Location. Type "BLANK" to clear existing settings. Ex.: "My Fitbit Tracker".
		*/
		public void set_Name(String value) {
			this.setInput("Name", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the WriteLocationData Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class WriteLocationDataResultSet extends ResultSet {
		public WriteLocationDataResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "ResponseStatusCode" output from this Choreo execution

		@return String - (integer) The response status code returned from Xively. For a successful feed location update, the code should be 200.
		*/
		public String get_ResponseStatusCode() {
			return this.getResult("ResponseStatusCode");
		}
	}
	
}
