package com.temboo.Library.Xively.Triggers;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CreateTrigger

Creates a new trigger.
*/
public class CreateTrigger extends Choreography {

	/**
	Create a new instance of the CreateTrigger Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CreateTrigger(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Xively/Triggers/CreateTrigger"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CreateTriggerInputSet
	*/
	public CreateTriggerInputSet newInputSet() {
		return new CreateTriggerInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CreateTriggerResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CreateTriggerResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CreateTrigger
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CreateTriggerInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Xively.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the DatastreamID input for this Choreo. 

		@param String - (required, string) The ID of the datastream you would like to create a trigger for.
		*/
		public void set_DatastreamID(String value) {
			this.setInput("DatastreamID", value);
		}



		/** 
		Set the value of the FeedID input for this Choreo. 

		@param Integer - (required, integer) The ID of the feed you would like to create a trigger for.
		*/
		public void set_FeedID(Integer value) {
			this.setInput("FeedID", value);
		}

		/** 
		Set the value of the FeedID input for this Choreo as a String. 

		@param String - (required, integer) The ID of the feed you would like to create a trigger for.
		*/
		public void set_FeedID(String value) {
			this.setInput("FeedID", value);	
		}

		/** 
		Set the value of the ThresholdValue input for this Choreo. 

		@param String - (required, string) Threshold that will cause the trigger to activate. Not required if TriggerType = "change", "frozen" or "live". Required for all others.
		*/
		public void set_ThresholdValue(String value) {
			this.setInput("ThresholdValue", value);
		}



		/** 
		Set the value of the TriggerType input for this Choreo. 

		@param String - (required, string) Type of trigger. Possible values: "gt", "gte", "lt", "lte", "eq", "change" (any change), "frozen" (no updates for 15 minutes), or "live" (updated again after being frozen).
		*/
		public void set_TriggerType(String value) {
			this.setInput("TriggerType", value);
		}



		/** 
		Set the value of the URL input for this Choreo. 

		@param String - (required, string) The URL that the Xively trigger will post to when activated. Ex: http://requestb.in
		*/
		public void set_URL(String value) {
			this.setInput("URL", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CreateTrigger Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CreateTriggerResultSet extends ResultSet {
		public CreateTriggerResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "ResponseStatusCode" output from this Choreo execution

		@return String - (integer) The response status code returned from Xively. For a successful trigger creation, the code should be 201.
		*/
		public String get_ResponseStatusCode() {
			return this.getResult("ResponseStatusCode");
		}
		/** 
		Retrieve the value for the "TriggerID" output from this Choreo execution

		@return String - (integer) TriggerID extracted from the TriggerLocation.
		*/
		public String get_TriggerID() {
			return this.getResult("TriggerID");
		}
		/** 
		Retrieve the value for the "TriggerLocation" output from this Choreo execution

		@return String - (string) The URL of the newly created trigger.
		*/
		public String get_TriggerLocation() {
			return this.getResult("TriggerLocation");
		}
	}
	
}
