package com.temboo.Library.Xively.Triggers;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ListAllTriggers

Returns all triggers for the authenticated account.
*/
public class ListAllTriggers extends Choreography {

	/**
	Create a new instance of the ListAllTriggers Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListAllTriggers(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Xively/Triggers/ListAllTriggers"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListAllTriggersInputSet
	*/
	public ListAllTriggersInputSet newInputSet() {
		return new ListAllTriggersInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListAllTriggersResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListAllTriggersResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListAllTriggers
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListAllTriggersInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Xively.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the FeedID input for this Choreo. 

		@param Integer - (optional, integer) Filter the returned triggers to only include those for the specified FeedID.
		*/
		public void set_FeedID(Integer value) {
			this.setInput("FeedID", value);
		}

		/** 
		Set the value of the FeedID input for this Choreo as a String. 

		@param String - (optional, integer) Filter the returned triggers to only include those for the specified FeedID.
		*/
		public void set_FeedID(String value) {
			this.setInput("FeedID", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are "json" (the default) and "xml".
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListAllTriggers Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListAllTriggersResultSet extends ResultSet {
		public ListAllTriggersResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Xively.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
