package com.temboo.Library.Yahoo.Weather;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetWeather

Retrieves the Yahoo! Weather RSS Feed for any specified location.
*/
public class GetWeather extends Choreography {

	/**
	Create a new instance of the GetWeather Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetWeather(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Yahoo/Weather/GetWeather"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetWeatherInputSet
	*/
	public GetWeatherInputSet newInputSet() {
		return new GetWeatherInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetWeatherResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetWeatherResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetWeather
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetWeatherInputSet extends InputSet {
		/** 
		Set the value of the Units input for this Choreo. 

		@param String - (optional, string) The unit of temperature in the response. Acceptable inputs: f for Fahrenheit or c for Celsius. Defaults to f. When c is specified, all units measurements returned are changed to metric.
		*/
		public void set_Units(String value) {
			this.setInput("Units", value);
		}



		/** 
		Set the value of the WOEID input for this Choreo. 

		@param Integer - (required, integer) Where On Earth ID for the desired location. This unique integer can be found by first running the GetWeatherByCoordinates Choreo.
		*/
		public void set_WOEID(Integer value) {
			this.setInput("WOEID", value);
		}

		/** 
		Set the value of the WOEID input for this Choreo as a String. 

		@param String - (required, integer) Where On Earth ID for the desired location. This unique integer can be found by first running the GetWeatherByCoordinates Choreo.
		*/
		public void set_WOEID(String value) {
			this.setInput("WOEID", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetWeather Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetWeatherResultSet extends ResultSet {
		public GetWeatherResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Yahoo! Weather.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
