package com.temboo.Library.Yahoo.Weather;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetWeatherByAddress

Retrieves the Yahoo Weather RSS Feed for any specified location by address.
*/
public class GetWeatherByAddress extends Choreography {

	/**
	Create a new instance of the GetWeatherByAddress Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetWeatherByAddress(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Yahoo/Weather/GetWeatherByAddress"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetWeatherByAddressInputSet
	*/
	public GetWeatherByAddressInputSet newInputSet() {
		return new GetWeatherByAddressInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetWeatherByAddressResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetWeatherByAddressResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetWeatherByAddress
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetWeatherByAddressInputSet extends InputSet {
		/** 
		Set the value of the Address input for this Choreo. 

		@param String - (required, string) The address to be searched.
		*/
		public void set_Address(String value) {
			this.setInput("Address", value);
		}



		/** 
		Set the value of the AppID input for this Choreo. 

		@param String - (optional, string) The App ID provided by Yahoo!
		*/
		public void set_AppID(String value) {
			this.setInput("AppID", value);
		}



		/** 
		Set the value of the Units input for this Choreo. 

		@param String - (optional, string) The unit of temperature in the response. Acceptable inputs: f for Fahrenheit or c for Celsius. Defaults to f. When c is specified, all units measurements returned are changed to metric.
		*/
		public void set_Units(String value) {
			this.setInput("Units", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetWeatherByAddress Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetWeatherByAddressResultSet extends ResultSet {
		public GetWeatherByAddressResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Yahoo Weather.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** 
		Retrieve the value for the "WOEID" output from this Choreo execution

		@return String - (integer) The unique Where On Earth ID of the location.
		*/
		public String get_WOEID() {
			return this.getResult("WOEID");
		}
	}
	
}
