package com.temboo.Library.Yelp;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
SearchForBusiness

Retrieves information for a given business id or name.
*/
public class SearchForBusiness extends Choreography {

	/**
	Create a new instance of the SearchForBusiness Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public SearchForBusiness(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Yelp/SearchForBusiness"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return SearchForBusinessInputSet
	*/
	public SearchForBusinessInputSet newInputSet() {
		return new SearchForBusinessInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public SearchForBusinessResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new SearchForBusinessResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the SearchForBusiness
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class SearchForBusinessInputSet extends InputSet {
		/** 
		Set the value of the BusinessId input for this Choreo. 

		@param String - (conditional, string) The business id to return results for. This can be found in the URL when you're on the business page on yelp.com (i.e. "yelp-san-francisco"). This is required unless using the BusinessName input.
		*/
		public void set_BusinessId(String value) {
			this.setInput("BusinessId", value);
		}



		/** 
		Set the value of the BusinessName input for this Choreo. 

		@param String - (conditional, string) A term to narrow the search, such as business name. This is required unless using the BusinessId input.
		*/
		public void set_BusinessName(String value) {
			this.setInput("BusinessName", value);
		}



		/** 
		Set the value of the City input for this Choreo. 

		@param String - (conditional, string) The name of the city in which to search for businesses. This is required unless providing the BusinessId.
		*/
		public void set_City(String value) {
			this.setInput("City", value);
		}



		/** 
		Set the value of the ConsumerKey input for this Choreo. 

		@param String - (required, string) The Consumer Key provided by Yelp.
		*/
		public void set_ConsumerKey(String value) {
			this.setInput("ConsumerKey", value);
		}



		/** 
		Set the value of the ConsumerSecret input for this Choreo. 

		@param String - (required, string) The Consumer Secret provided by Yelp.
		*/
		public void set_ConsumerSecret(String value) {
			this.setInput("ConsumerSecret", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, multiline) The format of the response from Yelp, either XML or JSON (the default).
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the TokenSecret input for this Choreo. 

		@param String - (required, string) The Token Secret provided by Yelp.
		*/
		public void set_TokenSecret(String value) {
			this.setInput("TokenSecret", value);
		}



		/** 
		Set the value of the Token input for this Choreo. 

		@param String - (required, string) The Token provided by Yelp.
		*/
		public void set_Token(String value) {
			this.setInput("Token", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the SearchForBusiness Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class SearchForBusinessResultSet extends ResultSet {
		public SearchForBusinessResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Yelp. Corresponds to the input value for ResponseFormat (defaults to JSON).
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
