package com.temboo.Library.Yelp;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
SearchForBusinessesWithDeals

Only returns information for businesses with deals.
*/
public class SearchForBusinessesWithDeals extends Choreography {

	/**
	Create a new instance of the SearchForBusinessesWithDeals Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public SearchForBusinessesWithDeals(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Yelp/SearchForBusinessesWithDeals"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return SearchForBusinessesWithDealsInputSet
	*/
	public SearchForBusinessesWithDealsInputSet newInputSet() {
		return new SearchForBusinessesWithDealsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public SearchForBusinessesWithDealsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new SearchForBusinessesWithDealsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the SearchForBusinessesWithDeals
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class SearchForBusinessesWithDealsInputSet extends InputSet {
		/** 
		Set the value of the Accuracy input for this Choreo. 

		@param Integer - (optional, integer) Narrow or widen the search range in relation to the coordinates, such as "2" for state or "8" for street address.
		*/
		public void set_Accuracy(Integer value) {
			this.setInput("Accuracy", value);
		}

		/** 
		Set the value of the Accuracy input for this Choreo as a String. 

		@param String - (optional, integer) Narrow or widen the search range in relation to the coordinates, such as "2" for state or "8" for street address.
		*/
		public void set_Accuracy(String value) {
			this.setInput("Accuracy", value);	
		}

		/** 
		Set the value of the BusinessType input for this Choreo. 

		@param String - (optional, string) A term to narrow the search, such as "comic books" or "restaurants". Leave blank to search for all business types.
		*/
		public void set_BusinessType(String value) {
			this.setInput("BusinessType", value);
		}



		/** 
		Set the value of the Category input for this Choreo. 

		@param String - (optional, string) Yelp categories to search in, separated by commas but no spaces, such as "hiking,climbing". See the Yelp API docimentation for a list of categories.
		*/
		public void set_Category(String value) {
			this.setInput("Category", value);
		}



		/** 
		Set the value of the ConsumerKey input for this Choreo. 

		@param String - (required, string) The Consumer Key provided by Yelp.
		*/
		public void set_ConsumerKey(String value) {
			this.setInput("ConsumerKey", value);
		}



		/** 
		Set the value of the ConsumerSecret input for this Choreo. 

		@param String - (required, string) The Consumer Secret provided by Yelp.
		*/
		public void set_ConsumerSecret(String value) {
			this.setInput("ConsumerSecret", value);
		}



		/** 
		Set the value of the Latitude input for this Choreo. 

		@param BigDecimal - (conditional, decimal) The latitude to search near, such as "37.788022". Searching with either Location or Coordinates is required.
		*/
		public void set_Latitude(BigDecimal value) {
			this.setInput("Latitude", value);
		}

		/** 
		Set the value of the Latitude input for this Choreo as a String. 

		@param String - (conditional, decimal) The latitude to search near, such as "37.788022". Searching with either Location or Coordinates is required.
		*/
		public void set_Latitude(String value) {
			this.setInput("Latitude", value);	
		}

		/** 
		Set the value of the Location input for this Choreo. 

		@param String - (conditional, string) An address, neighborhood, city, state, or ZIP code in which to search for the category. Searching with either Location or Coordinates is required.
		*/
		public void set_Location(String value) {
			this.setInput("Location", value);
		}



		/** 
		Set the value of the Longitude input for this Choreo. 

		@param BigDecimal - (conditional, decimal) The longitude to search near, such as "-122.399797". Searching with either Location or Coordinates is required.
		*/
		public void set_Longitude(BigDecimal value) {
			this.setInput("Longitude", value);
		}

		/** 
		Set the value of the Longitude input for this Choreo as a String. 

		@param String - (conditional, decimal) The longitude to search near, such as "-122.399797". Searching with either Location or Coordinates is required.
		*/
		public void set_Longitude(String value) {
			this.setInput("Longitude", value);	
		}

		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format of the response from Yelp, either XML or JSON (the default).
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the TokenSecret input for this Choreo. 

		@param String - (required, string) The Token Secret provided by Yelp.
		*/
		public void set_TokenSecret(String value) {
			this.setInput("TokenSecret", value);
		}



		/** 
		Set the value of the Token input for this Choreo. 

		@param String - (required, string) The Token provided by Yelp.
		*/
		public void set_Token(String value) {
			this.setInput("Token", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the SearchForBusinessesWithDeals Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class SearchForBusinessesWithDealsResultSet extends ResultSet {
		public SearchForBusinessesWithDealsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Yelp. Corresponds to the input value for ResponseFormat (defaults to JSON).
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
