package com.temboo.Library.YouTube.Activities;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;
import com.temboo.outputs.Google.Drive.GoogleFileList;

/** 
ListActivitiesByChannel

Returns a list of activities for a specified channel.
*/
public class ListActivitiesByChannel extends Choreography {

	/**
	Create a new instance of the ListActivitiesByChannel Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListActivitiesByChannel(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/YouTube/Activities/ListActivitiesByChannel"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListActivitiesByChannelInputSet
	*/
	public ListActivitiesByChannelInputSet newInputSet() {
		return new ListActivitiesByChannelInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListActivitiesByChannelResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListActivitiesByChannelResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListActivitiesByChannel
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListActivitiesByChannelInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (optional, string) The API Key provided by Google for simple API access when you do not need to access user data.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (optional, string) A valid access token retrieved during the OAuth process. This is required for OAuth authentication unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ChannelID input for this Choreo. 

		@param String - (required, string) The id of the channel to list activities for.
		*/
		public void set_ChannelID(String value) {
			this.setInput("ChannelID", value);
		}



		/** 
		Set the value of the ClientID input for this Choreo. 

		@param String - (conditional, string) The Client ID provided by Google. Required for OAuth authentication unless providing a valid AccessToken.
		*/
		public void set_ClientID(String value) {
			this.setInput("ClientID", value);
		}



		/** 
		Set the value of the ClientSecret input for this Choreo. 

		@param String - (conditional, string) The Client Secret provided by Google. Required for OAuth authentication unless providing a valid AccessToken.
		*/
		public void set_ClientSecret(String value) {
			this.setInput("ClientSecret", value);
		}



		/** 
		Set the value of the Fields input for this Choreo. 

		@param String - (optional, string) Allows you to specify a subset of fields to include in the response using an xpath-like syntax (i.e. items/snippet/title).
		*/
		public void set_Fields(String value) {
			this.setInput("Fields", value);
		}



		/** 
		Set the value of the MaxResults input for this Choreo. 

		@param Integer - (optional, integer) The maximum number of results to return.
		*/
		public void set_MaxResults(Integer value) {
			this.setInput("MaxResults", value);
		}

		/** 
		Set the value of the MaxResults input for this Choreo as a String. 

		@param String - (optional, integer) The maximum number of results to return.
		*/
		public void set_MaxResults(String value) {
			this.setInput("MaxResults", value);	
		}

		/** 
		Set the value of the PageToken input for this Choreo. 

		@param String - (optional, string) The "nextPageToken" found in the response which is used to page through results.
		*/
		public void set_PageToken(String value) {
			this.setInput("PageToken", value);
		}



		/** 
		Set the value of the Part input for this Choreo. 

		@param String - (optional, string) Specifies a comma-separated list of one or more activity resource properties that the API response will include. Part names that you can pass are id, snippet, and contentDetails.
		*/
		public void set_Part(String value) {
			this.setInput("Part", value);
		}



		/** 
		Set the value of the PublishedAfter input for this Choreo. 

		@param String - (optional, date) Returns only results created after the specified time (formatted as a RFC 3339 date-time i.e. 1970-01-01T00:00:00Z).
		*/
		public void set_PublishedAfter(String value) {
			this.setInput("PublishedAfter", value);
		}



		/** 
		Set the value of the PublishedBefore input for this Choreo. 

		@param String - (optional, date) Returns only results created before the specified time (formatted as a RFC 3339 date-time i.e. 1970-01-01T00:00:00Z).
		*/
		public void set_PublishedBefore(String value) {
			this.setInput("PublishedBefore", value);
		}



		/** 
		Set the value of the RefreshToken input for this Choreo. 

		@param String - (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required for OAuth authentication unless providing a valid AccessToken.
		*/
		public void set_RefreshToken(String value) {
			this.setInput("RefreshToken", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListActivitiesByChannel Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListActivitiesByChannelResultSet extends ResultSet {
		public ListActivitiesByChannelResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "NewAccessToken" output from this Choreo execution

		@return String - (string) Contains a new AccessToken when the RefreshToken is provided.
		*/
		public String get_NewAccessToken() {
			return this.getResult("NewAccessToken");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from YouTube.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** Get a list of files
		*/
		public GoogleFileList getFileList() {
		    return new GoogleFileList(((JSONObject)getJSONFromString(this.getResult("Response"))));
		}
	}
	
}
