package com.temboo.Library.YouTube.PlaylistItems;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;
import com.temboo.outputs.Google.Drive.GoogleFileList;

/** 
ListItemsByPlaylist

Returns a collection of playlist items within a specific playlist.
*/
public class ListItemsByPlaylist extends Choreography {

	/**
	Create a new instance of the ListItemsByPlaylist Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListItemsByPlaylist(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/YouTube/PlaylistItems/ListItemsByPlaylist"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListItemsByPlaylistInputSet
	*/
	public ListItemsByPlaylistInputSet newInputSet() {
		return new ListItemsByPlaylistInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListItemsByPlaylistResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListItemsByPlaylistResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListItemsByPlaylist
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListItemsByPlaylistInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (optional, string) The API Key provided by Google for simple API access when you do not need to access user data.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (optional, string) A valid access token retrieved during the OAuth process. This is required for OAuth authentication unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ClientID input for this Choreo. 

		@param String - (conditional, string) The Client ID provided by Google. Required for OAuth authentication unless providing a valid AccessToken.
		*/
		public void set_ClientID(String value) {
			this.setInput("ClientID", value);
		}



		/** 
		Set the value of the ClientSecret input for this Choreo. 

		@param String - (conditional, string) The Client Secret provided by Google. Required for OAuth authentication unless providing a valid AccessToken.
		*/
		public void set_ClientSecret(String value) {
			this.setInput("ClientSecret", value);
		}



		/** 
		Set the value of the Fields input for this Choreo. 

		@param String - (optional, string) Allows you to specify a subset of fields to include in the response using an xpath-like syntax (i.e. items/snippet/title).
		*/
		public void set_Fields(String value) {
			this.setInput("Fields", value);
		}



		/** 
		Set the value of the MaxResults input for this Choreo. 

		@param Integer - (optional, integer) The maximum number of results to return.
		*/
		public void set_MaxResults(Integer value) {
			this.setInput("MaxResults", value);
		}

		/** 
		Set the value of the MaxResults input for this Choreo as a String. 

		@param String - (optional, integer) The maximum number of results to return.
		*/
		public void set_MaxResults(String value) {
			this.setInput("MaxResults", value);	
		}

		/** 
		Set the value of the PageToken input for this Choreo. 

		@param String - (optional, string) The "nextPageToken" found in the response which is used to page through results.
		*/
		public void set_PageToken(String value) {
			this.setInput("PageToken", value);
		}



		/** 
		Set the value of the Part input for this Choreo. 

		@param String - (optional, string) Specifies a comma-separated list of playlistItem resource properties that the API response will include. Part names that you can pass are: id, snippet, and contentDetails.
		*/
		public void set_Part(String value) {
			this.setInput("Part", value);
		}



		/** 
		Set the value of the PlaylistID input for this Choreo. 

		@param String - (conditional, string) A unique ID of the playlist for which you want to retrieve playlist items.
		*/
		public void set_PlaylistID(String value) {
			this.setInput("PlaylistID", value);
		}



		/** 
		Set the value of the RefreshToken input for this Choreo. 

		@param String - (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required for OAuth authentication unless providing a valid AccessToken.
		*/
		public void set_RefreshToken(String value) {
			this.setInput("RefreshToken", value);
		}



		/** 
		Set the value of the VideoID input for this Choreo. 

		@param String - (optional, string) Indicates that only the playlist items that contain the specified video should be returned.
		*/
		public void set_VideoID(String value) {
			this.setInput("VideoID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListItemsByPlaylist Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListItemsByPlaylistResultSet extends ResultSet {
		public ListItemsByPlaylistResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "NewAccessToken" output from this Choreo execution

		@return String - (string) Contains a new AccessToken when the RefreshToken is provided.
		*/
		public String get_NewAccessToken() {
			return this.getResult("NewAccessToken");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from YouTube.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** Get a list of files
		*/
		public GoogleFileList getFileList() {
		    return new GoogleFileList(((JSONObject)getJSONFromString(this.getResult("Response"))));
		}
	}
	
}
