package com.temboo.Library.YouTube.Videos;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;
import com.temboo.outputs.Google.Drive.GoogleFileList;

/** 
UpdateVideo

Updates a video's metadata.
*/
public class UpdateVideo extends Choreography {

	/**
	Create a new instance of the UpdateVideo Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public UpdateVideo(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/YouTube/Videos/UpdateVideo"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return UpdateVideoInputSet
	*/
	public UpdateVideoInputSet newInputSet() {
		return new UpdateVideoInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public UpdateVideoResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new UpdateVideoResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the UpdateVideo
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class UpdateVideoInputSet extends InputSet {
		/** 
		Set the value of the VideoMetadata input for this Choreo. 

		@param String - (required, json) A JSON representation of the video resource containing fields to update. The id key for the video is requried for updates. See documentation for examples.
		*/
		public void set_VideoMetadata(String value) {
			this.setInput("VideoMetadata", value);
		}



		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (optional, string) A valid access token retrieved during the OAuth process. This is required for OAuth authentication unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ClientID input for this Choreo. 

		@param String - (conditional, string) The Client ID provided by Google. Required for OAuth authentication unless providing a valid AccessToken.
		*/
		public void set_ClientID(String value) {
			this.setInput("ClientID", value);
		}



		/** 
		Set the value of the ClientSecret input for this Choreo. 

		@param String - (conditional, string) The Client Secret provided by Google. Required for OAuth authentication unless providing a valid AccessToken.
		*/
		public void set_ClientSecret(String value) {
			this.setInput("ClientSecret", value);
		}



		/** 
		Set the value of the Fields input for this Choreo. 

		@param String - (optional, string) Allows you to specify a subset of fields to include in the response using an xpath-like syntax (i.e. items/snippet/title).
		*/
		public void set_Fields(String value) {
			this.setInput("Fields", value);
		}



		/** 
		Set the value of the Part input for this Choreo. 

		@param String - (optional, string) A comma-separated list of fields that are being set and that will be returned in the response (i.e. snippet,status).
		*/
		public void set_Part(String value) {
			this.setInput("Part", value);
		}



		/** 
		Set the value of the RefreshToken input for this Choreo. 

		@param String - (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required for OAuth authentication unless providing a valid AccessToken.
		*/
		public void set_RefreshToken(String value) {
			this.setInput("RefreshToken", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the UpdateVideo Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class UpdateVideoResultSet extends ResultSet {
		public UpdateVideoResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "NewAccessToken" output from this Choreo execution

		@return String - (string) Contains a new AccessToken when the RefreshToken is provided.
		*/
		public String get_NewAccessToken() {
			return this.getResult("NewAccessToken");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Google.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
		/** Get a list of files
		*/
		public GoogleFileList getFileList() {
		    return new GoogleFileList(((JSONObject)getJSONFromString(this.getResult("Response"))));
		}
	}
	
}
