package com.temboo.Library.Zendesk.Search;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
SearchAnonymous

Allows anonymous users to search public forums.
*/
public class SearchAnonymous extends Choreography {

	/**
	Create a new instance of the SearchAnonymous Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public SearchAnonymous(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Zendesk/Search/SearchAnonymous"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return SearchAnonymousInputSet
	*/
	public SearchAnonymousInputSet newInputSet() {
		return new SearchAnonymousInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public SearchAnonymousResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new SearchAnonymousResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the SearchAnonymous
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class SearchAnonymousInputSet extends InputSet {
		/** 
		Set the value of the Email input for this Choreo. 

		@param String - (required, string) The email to authenticate the Zendesk account.
		*/
		public void set_Email(String value) {
			this.setInput("Email", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The password matching the email to authenticate the Zendesk account.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Query input for this Choreo. 

		@param String - (required, string) Perform a search across usernames or email addresses.
		*/
		public void set_Query(String value) {
			this.setInput("Query", value);
		}



		/** 
		Set the value of the Server input for this Choreo. 

		@param String - (required, string) The server URL associated with your Zendesk account. In many cases this looks like: temboo.zendesk.com but may also be customized: support.temboo.com
		*/
		public void set_Server(String value) {
			this.setInput("Server", value);
		}



		/** 
		Set the value of the SortBy input for this Choreo. 

		@param String - (optional, string) Acceptable values: updated_at, created_at, priority, status, ticket_type.
		*/
		public void set_SortBy(String value) {
			this.setInput("SortBy", value);
		}



		/** 
		Set the value of the SortOrder input for this Choreo. 

		@param String - (optional, string) Indicate either: relevance, asc (for ascending), desc (for descending). Defaults to relevance.
		*/
		public void set_SortOrder(String value) {
			this.setInput("SortOrder", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the SearchAnonymous Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class SearchAnonymousResultSet extends ResultSet {
		public SearchAnonymousResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Zendesk.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
