package com.temboo.Library.Zendesk.Tickets;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ListTicketsByUser

*/
public class ListTicketsByUser extends Choreography {

	/**
	Create a new instance of the ListTicketsByUser Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListTicketsByUser(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Zendesk/Tickets/ListTicketsByUser"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListTicketsByUserInputSet
	*/
	public ListTicketsByUserInputSet newInputSet() {
		return new ListTicketsByUserInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListTicketsByUserResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListTicketsByUserResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListTicketsByUser
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListTicketsByUserInputSet extends InputSet {
		/** 
		Set the value of the Email input for this Choreo. 

		@param String - (required, string) The email to authenticate the Zendesk account.
		*/
		public void set_Email(String value) {
			this.setInput("Email", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The password matching the email to authenticate the Zendesk account.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Server input for this Choreo. 

		@param String - (required, string) The server URL associated with your Zendesk account. In many cases this looks like: temboo.zendesk.com but may also be customized: support.temboo.com
		*/
		public void set_Server(String value) {
			this.setInput("Server", value);
		}



		/** 
		Set the value of the UserID input for this Choreo. 

		@param Integer - (required, integer) The ID number of the user.
		*/
		public void set_UserID(Integer value) {
			this.setInput("UserID", value);
		}

		/** 
		Set the value of the UserID input for this Choreo as a String. 

		@param String - (required, integer) The ID number of the user.
		*/
		public void set_UserID(String value) {
			this.setInput("UserID", value);	
		}

		/** 
		Set the value of the UserType input for this Choreo. 

		@param String - (optional, string) Specify "requested" to find tickets that the given user requested and "ccd" to find tickets on which a given user was CC'd. Defaults to searching for tickets that the user requested.
		*/
		public void set_UserType(String value) {
			this.setInput("UserType", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListTicketsByUser Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListTicketsByUserResultSet extends ResultSet {
		public ListTicketsByUserResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Zendesk.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
