package com.temboo.Library.Zendesk.Users;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CreateManyUsers

Creates many new users at one time.
*/
public class CreateManyUsers extends Choreography {

	/**
	Create a new instance of the CreateManyUsers Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CreateManyUsers(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Zendesk/Users/CreateManyUsers"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CreateManyUsersInputSet
	*/
	public CreateManyUsersInputSet newInputSet() {
		return new CreateManyUsersInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CreateManyUsersResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CreateManyUsersResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CreateManyUsers
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CreateManyUsersInputSet extends InputSet {
		/** 
		Set the value of the Email input for this Choreo. 

		@param String - (required, string) The email address you use to login to your Zendesk account.
		*/
		public void set_Email(String value) {
			this.setInput("Email", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Zendesk password.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Server input for this Choreo. 

		@param String - (required, string) Your Zendesk domain and subdomain (i.e. support.temboo.com or temboo.zendesk.com).
		*/
		public void set_Server(String value) {
			this.setInput("Server", value);
		}



		/** 
		Set the value of the Users input for this Choreo. 

		@param String - (required, json) The JSON formatted list of new users. See documentation for required format.
		*/
		public void set_Users(String value) {
			this.setInput("Users", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CreateManyUsers Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CreateManyUsersResultSet extends ResultSet {
		public CreateManyUsersResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) 
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
