package com.temboo.Library.Zendesk.Users;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CreateUser

Creates a new user.
*/
public class CreateUser extends Choreography {

	/**
	Create a new instance of the CreateUser Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CreateUser(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Zendesk/Users/CreateUser"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CreateUserInputSet
	*/
	public CreateUserInputSet newInputSet() {
		return new CreateUserInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CreateUserResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CreateUserResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CreateUser
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CreateUserInputSet extends InputSet {
		/** 
		Set the value of the Email input for this Choreo. 

		@param String - (required, string) The email address you use to login to your Zendesk account.
		*/
		public void set_Email(String value) {
			this.setInput("Email", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Zendesk password.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Server input for this Choreo. 

		@param String - (required, string) Your Zendesk domain and subdomain (i.e. support.temboo.com or temboo.zendesk.com).
		*/
		public void set_Server(String value) {
			this.setInput("Server", value);
		}



		/** 
		Set the value of the UserData input for this Choreo. 

		@param String - (required, json) A JSON string containing the new user's information. See documentation for formatting details.
		*/
		public void set_UserData(String value) {
			this.setInput("UserData", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CreateUser Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CreateUserResultSet extends ResultSet {
		public CreateUserResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) 
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
