package com.temboo.Library.Zendesk.Users;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ListUsersByGroup

Retrieves a list of all users in a specified group.
*/
public class ListUsersByGroup extends Choreography {

	/**
	Create a new instance of the ListUsersByGroup Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListUsersByGroup(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Zendesk/Users/ListUsersByGroup"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListUsersByGroupInputSet
	*/
	public ListUsersByGroupInputSet newInputSet() {
		return new ListUsersByGroupInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListUsersByGroupResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListUsersByGroupResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListUsersByGroup
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListUsersByGroupInputSet extends InputSet {
		/** 
		Set the value of the Email input for this Choreo. 

		@param String - (required, string) The email to authenticate the Zendesk account.
		*/
		public void set_Email(String value) {
			this.setInput("Email", value);
		}



		/** 
		Set the value of the GroupID input for this Choreo. 

		@param Integer - (required, integer) The ID number of the group.
		*/
		public void set_GroupID(Integer value) {
			this.setInput("GroupID", value);
		}

		/** 
		Set the value of the GroupID input for this Choreo as a String. 

		@param String - (required, integer) The ID number of the group.
		*/
		public void set_GroupID(String value) {
			this.setInput("GroupID", value);	
		}

		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The password matching the email to authenticate the Zendesk account.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Server input for this Choreo. 

		@param String - (required, string) The server URL associated with your Zendesk account. In many cases this looks like: temboo.zendesk.com but may also be customized: support.temboo.com
		*/
		public void set_Server(String value) {
			this.setInput("Server", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListUsersByGroup Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListUsersByGroupResultSet extends ResultSet {
		public ListUsersByGroupResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Zendesk.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
