package com.temboo.Library.Zendesk.Users;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ShowCurrentUser

Returns information about the currently authenticated user.
*/
public class ShowCurrentUser extends Choreography {

	/**
	Create a new instance of the ShowCurrentUser Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ShowCurrentUser(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Zendesk/Users/ShowCurrentUser"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ShowCurrentUserInputSet
	*/
	public ShowCurrentUserInputSet newInputSet() {
		return new ShowCurrentUserInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ShowCurrentUserResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ShowCurrentUserResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ShowCurrentUser
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ShowCurrentUserInputSet extends InputSet {
		/** 
		Set the value of the Email input for this Choreo. 

		@param String - (required, string) The email to authenticate the Zendesk account.
		*/
		public void set_Email(String value) {
			this.setInput("Email", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The password matching the email to authenticate the Zendesk account.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Server input for this Choreo. 

		@param String - (required, string) The server URL associated with your Zendesk account. In many cases this looks like: temboo.zendesk.com but may also be customized: support.temboo.com
		*/
		public void set_Server(String value) {
			this.setInput("Server", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ShowCurrentUser Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ShowCurrentUserResultSet extends ResultSet {
		public ShowCurrentUserResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Zendesk.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
