package com.temboo.Library.Zillow;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetUpdatedPropertyDetails

Retrieve detailed property information that has been edited by the home's owner or agent.
*/
public class GetUpdatedPropertyDetails extends Choreography {

	/**
	Create a new instance of the GetUpdatedPropertyDetails Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetUpdatedPropertyDetails(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Zillow/GetUpdatedPropertyDetails"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetUpdatedPropertyDetailsInputSet
	*/
	public GetUpdatedPropertyDetailsInputSet newInputSet() {
		return new GetUpdatedPropertyDetailsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetUpdatedPropertyDetailsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetUpdatedPropertyDetailsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetUpdatedPropertyDetails
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetUpdatedPropertyDetailsInputSet extends InputSet {
		/** 
		Set the value of the ZPID input for this Choreo. 

		@param Integer - (required, integer) Enter a Zillow Property ID for the property being queried.
		*/
		public void set_ZPID(Integer value) {
			this.setInput("ZPID", value);
		}

		/** 
		Set the value of the ZPID input for this Choreo as a String. 

		@param String - (required, integer) Enter a Zillow Property ID for the property being queried.
		*/
		public void set_ZPID(String value) {
			this.setInput("ZPID", value);	
		}

		/** 
		Set the value of the ZWSID input for this Choreo. 

		@param String - (required, string) Enter a Zillow Web Service Identifier (ZWS ID).
		*/
		public void set_ZWSID(String value) {
			this.setInput("ZWSID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetUpdatedPropertyDetails Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetUpdatedPropertyDetailsResultSet extends ResultSet {
		public GetUpdatedPropertyDetailsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Zillow.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
