package com.temboo.Library.Zillow;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetZestimate

Retrieve estimate information for a specified property.
*/
public class GetZestimate extends Choreography {

	/**
	Create a new instance of the GetZestimate Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetZestimate(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Zillow/GetZestimate"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetZestimateInputSet
	*/
	public GetZestimateInputSet newInputSet() {
		return new GetZestimateInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetZestimateResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetZestimateResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetZestimate
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetZestimateInputSet extends InputSet {
		/** 
		Set the value of the RentEstimate input for this Choreo. 

		@param Boolean - (optional, boolean) Set to 1 (true) to enable. Defaults to 0 (false).
		*/
		public void set_RentEstimate(Boolean value) {
			this.setInput("RentEstimate", value);
		}

		/** 
		Set the value of the RentEstimate input for this Choreo as a String. 

		@param String - (optional, boolean) Set to 1 (true) to enable. Defaults to 0 (false).
		*/
		public void set_RentEstimate(String value) {
			this.setInput("RentEstimate", value);	
		}

		/** 
		Set the value of the ZPID input for this Choreo. 

		@param Integer - (required, integer) Enter a Zillow Property ID for the property being queried.
		*/
		public void set_ZPID(Integer value) {
			this.setInput("ZPID", value);
		}

		/** 
		Set the value of the ZPID input for this Choreo as a String. 

		@param String - (required, integer) Enter a Zillow Property ID for the property being queried.
		*/
		public void set_ZPID(String value) {
			this.setInput("ZPID", value);	
		}

		/** 
		Set the value of the ZWSID input for this Choreo. 

		@param String - (required, string) Enter a Zillow Web Service Identifier (ZWS ID).
		*/
		public void set_ZWSID(String value) {
			this.setInput("ZWSID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetZestimate Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetZestimateResultSet extends ResultSet {
		public GetZestimateResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Zillow.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
