package com.temboo.Library.Zoho.CRM;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetCVRecord

Retrieves data with respect to the Custom View in Zoho CRM.
*/
public class GetCVRecord extends Choreography {

	/**
	Create a new instance of the GetCVRecord Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetCVRecord(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Zoho/CRM/GetCVRecord"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetCVRecordInputSet
	*/
	public GetCVRecordInputSet newInputSet() {
		return new GetCVRecordInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetCVRecordResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetCVRecordResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetCVRecord
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetCVRecordInputSet extends InputSet {
		/** 
		Set the value of the AuthenticationToken input for this Choreo. 

		@param String - (required, string) A valid authentication token. Permanent authentication tokens can be generated by the GenerateAuthToken Choreo.
		*/
		public void set_AuthenticationToken(String value) {
			this.setInput("AuthenticationToken", value);
		}



		/** 
		Set the value of the CVName input for this Choreo. 

		@param String - (optional, string) Used to retrieve records from a specific customer view. Defaults to 'All Open Leads'.
		*/
		public void set_CVName(String value) {
			this.setInput("CVName", value);
		}



		/** 
		Set the value of the FromIndex input for this Choreo. 

		@param Integer - (optional, integer) The beginning index of the result set to return. Defaults to 1.
		*/
		public void set_FromIndex(Integer value) {
			this.setInput("FromIndex", value);
		}

		/** 
		Set the value of the FromIndex input for this Choreo as a String. 

		@param String - (optional, integer) The beginning index of the result set to return. Defaults to 1.
		*/
		public void set_FromIndex(String value) {
			this.setInput("FromIndex", value);	
		}

		/** 
		Set the value of the LastModifiedDate input for this Choreo. 

		@param String - (optional, date) Used to return records with a created or modified date that is after the specified time.  (i.e. 2010-04-21 11:09:23)
		*/
		public void set_LastModifiedDate(String value) {
			this.setInput("LastModifiedDate", value);
		}



		/** 
		Set the value of the Module input for this Choreo. 

		@param String - (optional, string) The Zoho module you want to access. Defaults to Leads.
		*/
		public void set_Module(String value) {
			this.setInput("Module", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid formats are: json and xml (the default).
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the ToIndex input for this Choreo. 

		@param Integer - (optional, integer) The ending index of the result set to return. Defaults to 20. Max is 200.
		*/
		public void set_ToIndex(Integer value) {
			this.setInput("ToIndex", value);
		}

		/** 
		Set the value of the ToIndex input for this Choreo as a String. 

		@param String - (optional, integer) The ending index of the result set to return. Defaults to 20. Max is 200.
		*/
		public void set_ToIndex(String value) {
			this.setInput("ToIndex", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetCVRecord Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetCVRecordResultSet extends ResultSet {
		public GetCVRecordResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Zoho. Format corresponds to the ResponseFormat input. Defaults to xml.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
