package com.temboo.Library.Zoho.Sheet;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
DownloadSpreadsheet

Downloads a specified spreadsheet in a user's Zoho Sheet Account.
*/
public class DownloadSpreadsheet extends Choreography {

	/**
	Create a new instance of the DownloadSpreadsheet Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DownloadSpreadsheet(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Zoho/Sheet/DownloadSpreadsheet"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DownloadSpreadsheetInputSet
	*/
	public DownloadSpreadsheetInputSet newInputSet() {
		return new DownloadSpreadsheetInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DownloadSpreadsheetResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DownloadSpreadsheetResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DownloadSpreadsheet
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DownloadSpreadsheetInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Zoho
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the BookId input for this Choreo. 

		@param Integer - (required, integer) Specifies the unique spreadsheet id to download.
		*/
		public void set_BookId(Integer value) {
			this.setInput("BookId", value);
		}

		/** 
		Set the value of the BookId input for this Choreo as a String. 

		@param String - (required, integer) Specifies the unique spreadsheet id to download.
		*/
		public void set_BookId(String value) {
			this.setInput("BookId", value);	
		}

		/** 
		Set the value of the DownloadFormat input for this Choreo. 

		@param String - (required, string) Specifies the file format in which the documents need to be downloaded. Possible values for documents: xls, xlsx, ods, sxc, pdf, html, csv, tsv.
		*/
		public void set_DownloadFormat(String value) {
			this.setInput("DownloadFormat", value);
		}



		/** 
		Set the value of the LoginID input for this Choreo. 

		@param String - (required, string) Your Zoho username (or login id)
		*/
		public void set_LoginID(String value) {
			this.setInput("LoginID", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Zoho password
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DownloadSpreadsheet Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DownloadSpreadsheetResultSet extends ResultSet {
		public DownloadSpreadsheetResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Zoho. Corresponds to the DownloadFormat input.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
