package com.temboo.Library.Zoho.Writer;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
DownloadDocument

Downloads a specified document in a user's Zoho Writer Account.
*/
public class DownloadDocument extends Choreography {

	/**
	Create a new instance of the DownloadDocument Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DownloadDocument(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Zoho/Writer/DownloadDocument"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DownloadDocumentInputSet
	*/
	public DownloadDocumentInputSet newInputSet() {
		return new DownloadDocumentInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DownloadDocumentResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DownloadDocumentResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DownloadDocument
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DownloadDocumentInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Zoho
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the DocumentId input for this Choreo. 

		@param Integer - (required, integer) Specifies the unique document id to download.
		*/
		public void set_DocumentId(Integer value) {
			this.setInput("DocumentId", value);
		}

		/** 
		Set the value of the DocumentId input for this Choreo as a String. 

		@param String - (required, integer) Specifies the unique document id to download.
		*/
		public void set_DocumentId(String value) {
			this.setInput("DocumentId", value);	
		}

		/** 
		Set the value of the DownloadFormat input for this Choreo. 

		@param String - (required, string) Specifies the file format in which the documents need to be downloaded. Possible values for documents: doc, docx, pdf, html, sxw, odt, rtf.
		*/
		public void set_DownloadFormat(String value) {
			this.setInput("DownloadFormat", value);
		}



		/** 
		Set the value of the LoginID input for this Choreo. 

		@param String - (required, string) Your Zoho username (or login id)
		*/
		public void set_LoginID(String value) {
			this.setInput("LoginID", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Zoho password
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DownloadDocument Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DownloadDocumentResultSet extends ResultSet {
		public DownloadDocumentResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Zoho. Corresponds to the DownloadFormat input.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
