package com.temboo.Library.Zoho.Writer;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ListSharedDocuments

Lists all the documents that have been "shared" to a user's Zoho Writer Account.
*/
public class ListSharedDocuments extends Choreography {

	/**
	Create a new instance of the ListSharedDocuments Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListSharedDocuments(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Zoho/Writer/ListSharedDocuments"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListSharedDocumentsInputSet
	*/
	public ListSharedDocumentsInputSet newInputSet() {
		return new ListSharedDocumentsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListSharedDocumentsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListSharedDocumentsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListSharedDocuments
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListSharedDocumentsInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Zoho
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}



		/** 
		Set the value of the Limit input for this Choreo. 

		@param Integer - (optional, integer) Sets the number of documents to be listed.
		*/
		public void set_Limit(Integer value) {
			this.setInput("Limit", value);
		}

		/** 
		Set the value of the Limit input for this Choreo as a String. 

		@param String - (optional, integer) Sets the number of documents to be listed.
		*/
		public void set_Limit(String value) {
			this.setInput("Limit", value);	
		}

		/** 
		Set the value of the LoginID input for this Choreo. 

		@param String - (required, string) Your Zoho username (or login id)
		*/
		public void set_LoginID(String value) {
			this.setInput("LoginID", value);
		}



		/** 
		Set the value of the OrderBy input for this Choreo. 

		@param String - (optional, string) Order documents by createdTime, lastModifiedTime or name.
		*/
		public void set_OrderBy(String value) {
			this.setInput("OrderBy", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Zoho password
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that response should be in. Can be set to xml or json. Defaults to xml.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the SortOrder input for this Choreo. 

		@param String - (optional, string) Sorting order: asc or desc. Default sort order is set to ascending.
		*/
		public void set_SortOrder(String value) {
			this.setInput("SortOrder", value);
		}



		/** 
		Set the value of the StartFrom input for this Choreo. 

		@param Integer - (optional, integer) Sets the initial document number from which the documents will be listed.
		*/
		public void set_StartFrom(Integer value) {
			this.setInput("StartFrom", value);
		}

		/** 
		Set the value of the StartFrom input for this Choreo as a String. 

		@param String - (optional, integer) Sets the initial document number from which the documents will be listed.
		*/
		public void set_StartFrom(String value) {
			this.setInput("StartFrom", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListSharedDocuments Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListSharedDocumentsResultSet extends ResultSet {
		public ListSharedDocumentsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Zoho. Corresponds to the ResponseFormat input. Defaults to XML.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
