package com.temboo.Library._23andMe;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
User

Retrieves the user id, and a list of profiles including their ids and whether or not they are genotyped.
*/
public class User extends Choreography {

	/**
	Create a new instance of the User Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public User(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/23andMe/User"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return UserInputSet
	*/
	public UserInputSet newInputSet() {
		return new UserInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public UserResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new UserResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the User
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class UserInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token retrieved after completing the OAuth2 process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the TestMode input for this Choreo. 

		@param Boolean - (optional, boolean) A boolean flag indicating that the request should be made to the "demo" 23andMe endpoint for testing. Set to 1 for test mode. Defaults to 0.
		*/
		public void set_TestMode(Boolean value) {
			this.setInput("TestMode", value);
		}

		/** 
		Set the value of the TestMode input for this Choreo as a String. 

		@param String - (optional, boolean) A boolean flag indicating that the request should be made to the "demo" 23andMe endpoint for testing. Set to 1 for test mode. Defaults to 0.
		*/
		public void set_TestMode(String value) {
			this.setInput("TestMode", value);	
		}

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the User Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class UserResultSet extends ResultSet {
		public UserResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from 23AndMe.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
