package com.temboo.Library._37Signals.Basecamp;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CompleteItem

Marks a single, specified item in a To-do list as complete.
*/
public class CompleteItem extends Choreography {

	/**
	Create a new instance of the CompleteItem Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CompleteItem(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/37Signals/Basecamp/CompleteItem"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CompleteItemInputSet
	*/
	public CompleteItemInputSet newInputSet() {
		return new CompleteItemInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CompleteItemResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CompleteItemResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CompleteItem
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CompleteItemInputSet extends InputSet {
		/** 
		Set the value of the AccountName input for this Choreo. 

		@param String - (required, string) A valid Basecamp account name. This is the first part of the account's URL.
		*/
		public void set_AccountName(String value) {
			this.setInput("AccountName", value);
		}



		/** 
		Set the value of the ItemID input for this Choreo. 

		@param Integer - (required, integer) The ID of the item to mark as complete.
		*/
		public void set_ItemID(Integer value) {
			this.setInput("ItemID", value);
		}

		/** 
		Set the value of the ItemID input for this Choreo as a String. 

		@param String - (required, integer) The ID of the item to mark as complete.
		*/
		public void set_ItemID(String value) {
			this.setInput("ItemID", value);	
		}

		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The Basecamp account password. Use the value 'X' when specifying an API Key for the Username input.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) A Basecamp account username or API Key.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CompleteItem Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CompleteItemResultSet extends ResultSet {
		public CompleteItemResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - There is no structrued response from complete item requests.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
