package com.temboo.Library._37Signals.Basecamp;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CreateMessage

Creates a new message under a specified project.
*/
public class CreateMessage extends Choreography {

	/**
	Create a new instance of the CreateMessage Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CreateMessage(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/37Signals/Basecamp/CreateMessage"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CreateMessageInputSet
	*/
	public CreateMessageInputSet newInputSet() {
		return new CreateMessageInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CreateMessageResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CreateMessageResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CreateMessage
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CreateMessageInputSet extends InputSet {
		/** 
		Set the value of the AccountName input for this Choreo. 

		@param String - (required, string) The Basecamp account name for you or your company. This is the first part of your account URL.
		*/
		public void set_AccountName(String value) {
			this.setInput("AccountName", value);
		}



		/** 
		Set the value of the Body input for this Choreo. 

		@param String - (required, string) The body of the message you're creating.
		*/
		public void set_Body(String value) {
			this.setInput("Body", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Basecamp password.  You can use the value 'X' when specifying an API Key for the Username input.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the ProjectId input for this Choreo. 

		@param Integer - (required, integer) The ID of the project that the message will be created under.
		*/
		public void set_ProjectId(Integer value) {
			this.setInput("ProjectId", value);
		}

		/** 
		Set the value of the ProjectId input for this Choreo as a String. 

		@param String - (required, integer) The ID of the project that the message will be created under.
		*/
		public void set_ProjectId(String value) {
			this.setInput("ProjectId", value);	
		}

		/** 
		Set the value of the Title input for this Choreo. 

		@param String - (required, string) The title of the message you'e creating.
		*/
		public void set_Title(String value) {
			this.setInput("Title", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) Your Basecamp username or API Key.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CreateMessage Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CreateMessageResultSet extends ResultSet {
		public CreateMessageResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Basecamp. Note that a successful request returns a null result in this output variable.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
