package com.temboo.Library._37Signals.Basecamp;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CreateProject

Creates a new Basecamp project.
*/
public class CreateProject extends Choreography {

	/**
	Create a new instance of the CreateProject Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CreateProject(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/37Signals/Basecamp/CreateProject"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CreateProjectInputSet
	*/
	public CreateProjectInputSet newInputSet() {
		return new CreateProjectInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CreateProjectResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CreateProjectResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CreateProject
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CreateProjectInputSet extends InputSet {
		/** 
		Set the value of the AccountName input for this Choreo. 

		@param String - (required, string) The Basecamp account name for you or your company. This is the first part of your account URL.
		*/
		public void set_AccountName(String value) {
			this.setInput("AccountName", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) Your Basecamp password. You can use the value 'X' when specifying an API Key for the Username input.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the ProjectName input for this Choreo. 

		@param String - (required, string) The name for the project you want to create.
		*/
		public void set_ProjectName(String value) {
			this.setInput("ProjectName", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) Your Basecamp username or API Key.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CreateProject Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CreateProjectResultSet extends ResultSet {
		public CreateProjectResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Basecamp. Note that a successful request returns a null result in this output variable.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
