package com.temboo.Library._37Signals.Basecamp;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetAllLists

Retrieves all To-do lists assigned to a specified user or company.
*/
public class GetAllLists extends Choreography {

	/**
	Create a new instance of the GetAllLists Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetAllLists(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/37Signals/Basecamp/GetAllLists"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetAllListsInputSet
	*/
	public GetAllListsInputSet newInputSet() {
		return new GetAllListsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetAllListsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetAllListsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetAllLists
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetAllListsInputSet extends InputSet {
		/** 
		Set the value of the AccountName input for this Choreo. 

		@param String - (required, string) A valid Basecamp account name. This is the first part of the account's URL.
		*/
		public void set_AccountName(String value) {
			this.setInput("AccountName", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The Basecamp account password. Use the value 'X' when specifying an API Key for the Username input.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the ResponsibleParty input for this Choreo. 

		@param Integer - (optional, integer) The user ID or company ID  (preceded by a “c”, as in "c1234") the To-Do lists are assigned to. Defaults to unassigned To-Dos If left blank.
		*/
		public void set_ResponsibleParty(Integer value) {
			this.setInput("ResponsibleParty", value);
		}

		/** 
		Set the value of the ResponsibleParty input for this Choreo as a String. 

		@param String - (optional, integer) The user ID or company ID  (preceded by a “c”, as in "c1234") the To-Do lists are assigned to. Defaults to unassigned To-Dos If left blank.
		*/
		public void set_ResponsibleParty(String value) {
			this.setInput("ResponsibleParty", value);	
		}

		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) A Basecamp account username or API Key.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetAllLists Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetAllListsResultSet extends ResultSet {
		public GetAllListsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response returned from Basecamp.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
