package com.temboo.Library._37Signals.Basecamp;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ReorderItems

Reorders the items in a specified To-do list.
*/
public class ReorderItems extends Choreography {

	/**
	Create a new instance of the ReorderItems Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ReorderItems(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/37Signals/Basecamp/ReorderItems"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ReorderItemsInputSet
	*/
	public ReorderItemsInputSet newInputSet() {
		return new ReorderItemsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ReorderItemsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ReorderItemsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ReorderItems
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ReorderItemsInputSet extends InputSet {
		/** 
		Set the value of the AccountName input for this Choreo. 

		@param String - (required, string) A valid Basecamp account name. This is the first part of the account's URL.
		*/
		public void set_AccountName(String value) {
			this.setInput("AccountName", value);
		}



		/** 
		Set the value of the FirstItemID input for this Choreo. 

		@param Integer - (required, integer) The ID number for the first item in the list.
		*/
		public void set_FirstItemID(Integer value) {
			this.setInput("FirstItemID", value);
		}

		/** 
		Set the value of the FirstItemID input for this Choreo as a String. 

		@param String - (required, integer) The ID number for the first item in the list.
		*/
		public void set_FirstItemID(String value) {
			this.setInput("FirstItemID", value);	
		}

		/** 
		Set the value of the ListID input for this Choreo. 

		@param Integer - (required, integer) The ID for the To-do list the items of which you're reordering.
		*/
		public void set_ListID(Integer value) {
			this.setInput("ListID", value);
		}

		/** 
		Set the value of the ListID input for this Choreo as a String. 

		@param String - (required, integer) The ID for the To-do list the items of which you're reordering.
		*/
		public void set_ListID(String value) {
			this.setInput("ListID", value);	
		}

		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The Basecamp account password. Use the value 'X' when specifying an API Key for the Username input.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the SecondItemID input for this Choreo. 

		@param Integer - (optional, integer) The ID number for the second item in the list.
		*/
		public void set_SecondItemID(Integer value) {
			this.setInput("SecondItemID", value);
		}

		/** 
		Set the value of the SecondItemID input for this Choreo as a String. 

		@param String - (optional, integer) The ID number for the second item in the list.
		*/
		public void set_SecondItemID(String value) {
			this.setInput("SecondItemID", value);	
		}

		/** 
		Set the value of the ThirdItemID input for this Choreo. 

		@param Integer - (optional, integer) The ID number for the third item in the list.
		*/
		public void set_ThirdItemID(Integer value) {
			this.setInput("ThirdItemID", value);
		}

		/** 
		Set the value of the ThirdItemID input for this Choreo as a String. 

		@param String - (optional, integer) The ID number for the third item in the list.
		*/
		public void set_ThirdItemID(String value) {
			this.setInput("ThirdItemID", value);	
		}

		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) A Basecamp account username or API Key.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ReorderItems Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ReorderItemsResultSet extends ResultSet {
		public ReorderItemsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - No response is returned from Basecamp for reorder items requests.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
