package com.temboo.Library._37Signals.Basecamp;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
UpdateList

Updates a specified To-do list record 
*/
public class UpdateList extends Choreography {

	/**
	Create a new instance of the UpdateList Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public UpdateList(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/37Signals/Basecamp/UpdateList"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return UpdateListInputSet
	*/
	public UpdateListInputSet newInputSet() {
		return new UpdateListInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public UpdateListResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new UpdateListResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the UpdateList
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class UpdateListInputSet extends InputSet {
		/** 
		Set the value of the AccountName input for this Choreo. 

		@param String - (required, string) A valid Basecamp account name. This is the first part of the account's URL.
		*/
		public void set_AccountName(String value) {
			this.setInput("AccountName", value);
		}



		/** 
		Set the value of the Description input for this Choreo. 

		@param String - (optional, string) The new description for the list.
		*/
		public void set_Description(String value) {
			this.setInput("Description", value);
		}



		/** 
		Set the value of the ListID input for this Choreo. 

		@param Integer - (required, integer) The ID for the list to update.
		*/
		public void set_ListID(Integer value) {
			this.setInput("ListID", value);
		}

		/** 
		Set the value of the ListID input for this Choreo as a String. 

		@param String - (required, integer) The ID for the list to update.
		*/
		public void set_ListID(String value) {
			this.setInput("ListID", value);	
		}

		/** 
		Set the value of the MilestoneID input for this Choreo. 

		@param Integer - (optional, integer) The ID of an existing milestone to add to the To-Do list.
		*/
		public void set_MilestoneID(Integer value) {
			this.setInput("MilestoneID", value);
		}

		/** 
		Set the value of the MilestoneID input for this Choreo as a String. 

		@param String - (optional, integer) The ID of an existing milestone to add to the To-Do list.
		*/
		public void set_MilestoneID(String value) {
			this.setInput("MilestoneID", value);	
		}

		/** 
		Set the value of the Name input for this Choreo. 

		@param String - (optional, string) The new name for the list.
		*/
		public void set_Name(String value) {
			this.setInput("Name", value);
		}



		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The Basecamp account password. Use the value 'X' when specifying an API Key for the Username input.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}



		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) A Basecamp account username or API Key.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the UpdateList Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class UpdateListResultSet extends ResultSet {
		public UpdateListResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - No response is returned from Basecamp for update requests.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
