package com.temboo.outputs.Dropbox;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Dropbox.DropboxQuotaInfo;

/**  Information about the user's account.

*/
public class DropboxAccountInfo {
    protected JSONObject base;
    
    public DropboxAccountInfo(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** The user's two-letter country code, if available.
    */
    public String getCountry() {
        return (String) base.opt("country");
    }

    /** The user's display name.
    */
    public String getDisplayName() {
        return (String) base.opt("display_name");
    }

    /** The user's e-mail address.
    */
    public String getEmail() {
        return (String) base.opt("email");
    }

    /** User's quota info for shared/unshared folders
    */
    public DropboxQuotaInfo getQuotaInfo() {
        return new DropboxQuotaInfo(base.opt("quota_info"));
    }

    /** The user's referral link.
    */
    public String getReferralLink() {
        return (String) base.opt("referral_link");
    }

    /** The user's unique Dropbox ID.
    */
    public Number getUid() {
        return (Number) base.opt("uid");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}