package com.temboo.outputs.Dropbox;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Dropbox.DropboxItemMetadata;

/**  A list of metdata for the folder's contents

*/
public class DropboxFolderContentsList {
    protected JSONObject base;
    
    public DropboxFolderContentsList(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** A human-readable description of the file size (translated by locale).
    */
    public Number getBytes() {
        return (Number) base.opt("bytes");
    }

    /** a list of metadata for the folder's contents
    */
    public DropboxItemMetadata[] getItemMetadata() {
        JSONArray list = (JSONArray) base.opt("contents");
        DropboxItemMetadata[] resultArray = new DropboxItemMetadata[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new DropboxItemMetadata(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** A folder's hash is useful for indicating changes to the folder's contents in later calls to /metadata. This is roughly the folder equivalent to a file's rev.
    */
    public String getHash() {
        return (String) base.opt("hash");
    }

    /** The name of the icon used to illustrate the file type in Dropbox's icon library.
    */
    public String getIcon() {
        return (String) base.opt("icon");
    }

    /** Whether the given entry is a folder or not.
    */
    public Boolean getIsDir() {
        return (Boolean) base.opt("is_dir");
    }

    /** Returns the canonical path to the file or directory.
    */
    public String getPath() {
        return (String) base.opt("path");
    }

    /** The root or top-level folder depending on your access level. All paths returned are relative to this root level. Permitted values are either dropbox or app_folder.
    */
    public String getRoot() {
        return (String) base.opt("root");
    }

    /** A human-readable description of the file size (translated by locale).
    */
    public String getSize() {
        return (String) base.opt("size");
    }

    /** True if the file is an image can be converted to a thumbnail via the /thumbnails call.
    */
    public Boolean getThumbExists() {
        return (Boolean) base.opt("thumb_exists");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}