package com.temboo.outputs.Dropbox;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;

/**  The metadata for the file or folder at the given <path>. If <path> represents a folder and the list parameter is true, the metadata will also include a listing of metadata for the folder's contents.

*/
public class DropboxItemMetadata {
    protected JSONObject base;
    
    public DropboxItemMetadata(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** The file size in bytes.
    */
    public Number getBytes() {
        return (Number) base.opt("bytes");
    }

    /** For files, this is the modification time set by the desktop client when the file was added to Dropbox, in the standard date format. Since this time is not verified (the Dropbox server stores whatever the desktop client sends up), this should only be used for display purposes (such as sorting) and not, for example, to determine if a file has changed or not.
    */
    public String getClientMtime() {
        return (String) base.opt("client_mtime");
    }

    /** The name of the icon used to illustrate the file type in Dropbox's icon library.
    */
    public String getIcon() {
        return (String) base.opt("icon");
    }

    /** Whether the given entry is deleted (only included if deleted files are being returned).
    */
    public Boolean getIsDeleted() {
        return (Boolean) base.opt("is_deleted");
    }

    /** Whether the given entry is a folder or not.
    */
    public Boolean getIsDir() {
        return (Boolean) base.opt("is_dir");
    }

    /** The mime type of the file.
    */
    public String getMimeType() {
        return (String) base.opt("mime_type");
    }

    /** The last time the file was modified on Dropbox, in the standard date format (not included for the root folder).
    */
    public String getModified() {
        return (String) base.opt("modified");
    }

    /** Returns the canonical path to the file or directory.
    */
    public String getPath() {
        return (String) base.opt("path");
    }

    /** A unique identifier for the current revision of a file. This field is the same rev as elsewhere in the API and can be used to detect changes and avoid conflicts.
    */
    public String getRev() {
        return (String) base.opt("rev");
    }

    /** A deprecated field that semi-uniquely identifies a file. Use rev instead.
    */
    public Number getRevision() {
        return (Number) base.opt("revision");
    }

    /** The root or top-level folder depending on your access level. All paths returned are relative to this root level. Permitted values are either dropbox or app_folder.
    */
    public String getRoot() {
        return (String) base.opt("root");
    }

    /** A human-readable description of the file size (translated by locale).
    */
    public String getSize() {
        return (String) base.opt("size");
    }

    /** True if the file is an image can be converted to a thumbnail via the /thumbnails call.
    */
    public Boolean getThumbExists() {
        return (Boolean) base.opt("thumb_exists");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}