package com.temboo.outputs.Facebook;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Facebook.FacebookApplication;
import com.temboo.outputs.Facebook.FacebookComment;
import com.temboo.outputs.Facebook.FacebookFrom;
import com.temboo.outputs.Facebook.FacebookLike;
import com.temboo.outputs.Facebook.FacebookPlace;

/**  A Checkin object represents a single visit to a location

*/
public class FacebookCheckin {
    protected JSONObject base;
    
    public FacebookCheckin(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** The application that created this checkin
    */
    public FacebookApplication getApplication() {
        return new FacebookApplication(base.opt("application"));
    }

    /** Get the comments for this checkin
    */
    public FacebookComment[] getComments() {
        JSONArray list = (JSONArray) getJSONObject(base, "comments").opt("data");
        FacebookComment[] resultArray = new FacebookComment[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FacebookComment(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** The date and time the checkin was created in ISO-8601 format
    */
    public String getCreatedTime() {
        return (String) base.opt("created_time");
    }

    /** Get the user that the checkin is from
    */
    public FacebookFrom getFrom() {
        return new FacebookFrom(base.opt("from"));
    }

    /** The id of the checkin
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** Get likes for this checkin
    */
    public FacebookLike[] getLikes() {
        JSONArray list = (JSONArray) getJSONObject(base, "likes").opt("data");
        FacebookLike[] resultArray = new FacebookLike[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FacebookLike(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** Get the place and location for this checkin
    */
    public FacebookPlace getPlace() {
        return new FacebookPlace(base.opt("place"));
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}