package com.temboo.outputs.Facebook;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Facebook.FacebookFrom;

/**  An object representing a comment on a graph object

*/
public class FacebookComment {
    protected JSONObject base;
    
    public FacebookComment(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** Whether or not the comment can be removed
    */
    public Boolean getCanRemove() {
        return (Boolean) base.opt("can_remove");
    }

    /** The date and time that the comment was created in ISO-8601 format
    */
    public String getCreatedTime() {
        return (String) base.opt("created_time");
    }

    /** Get the user that created the comment
    */
    public FacebookFrom getFrom() {
        return new FacebookFrom(base.opt("from"));
    }

    /** The id of the comment
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** The number of times this comment was liked
    */
    public Number getLikeCount() {
        return (Number) base.opt("like_count");
    }

    /** The comment text
    */
    public String getMessage() {
        return (String) base.opt("message");
    }

    /** Whether or not the authenticated user likes this comment
    */
    public Boolean getUserLikes() {
        return (Boolean) base.opt("user_likes");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}