package com.temboo.outputs.Facebook;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Facebook.FacebookAction;
import com.temboo.outputs.Facebook.FacebookApplication;
import com.temboo.outputs.Facebook.FacebookComment;
import com.temboo.outputs.Facebook.FacebookFrom;
import com.temboo.outputs.Facebook.FacebookLike;
import com.temboo.outputs.Facebook.FacebookPlace;
import com.temboo.outputs.Facebook.FacebookPrivacy;

/**  An item in a user's feed

*/
public class FacebookFeedItem {
    protected JSONObject base;
    
    public FacebookFeedItem(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** Get the action link and name for the feed item
    */
    public FacebookAction[] getActions() {
        JSONArray list = (JSONArray) base.opt("actions");
        FacebookAction[] resultArray = new FacebookAction[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FacebookAction(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** Get the application that created this post
    */
    public FacebookApplication getApplication() {
        return new FacebookApplication(base.opt("application"));
    }

    /** The feed item caption
    */
    public String getCaption() {
        return (String) base.opt("caption");
    }

    /** The comment for this feed item
    */
    public FacebookComment[] getComments() {
        JSONArray list = (JSONArray) getJSONObject(base, "comments").opt("data");
        FacebookComment[] resultArray = new FacebookComment[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FacebookComment(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** The date and time the feed item was created in ISO-8601 format
    */
    public String getCreatedTime() {
        return (String) base.opt("created_time");
    }

    /** Get the user that created this feed item
    */
    public FacebookFrom getFrom() {
        return new FacebookFrom(base.opt("from"));
    }

    /** The URL for the icon image
    */
    public String getIcon() {
        return (String) base.opt("icon");
    }

    /** The id of the feed item
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** The users that liked this feed item
    */
    public FacebookLike[] getLikes() {
        JSONArray list = (JSONArray) getJSONObject(base, "likes").opt("data");
        FacebookLike[] resultArray = new FacebookLike[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FacebookLike(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** Link to the page on Facebook
    */
    public String getLink() {
        return (String) base.opt("link");
    }

    /** The message text for the feed item
    */
    public String getMessage() {
        return (String) base.opt("message");
    }

    /** The Page's name
    */
    public String getName() {
        return (String) base.opt("name");
    }

    /** The source url for a picture in the feed
    */
    public String getPicture() {
        return (String) base.opt("picture");
    }

    /** A place associated with this feed item
    */
    public FacebookPlace getPlace() {
        return new FacebookPlace(base.opt("place"));
    }

    /** The privacy setting for this feed item
    */
    public FacebookPrivacy getPrivacy() {
        return new FacebookPrivacy(base.opt("privacy"));
    }

    /** The type of status
    */
    public String getStatusType() {
        return (String) base.opt("status_type");
    }

    /** The text of stories not intentionally generated by users
    */
    public String getStory() {
        return (String) base.opt("story");
    }

    /** The type of feed item
    */
    public String getType() {
        return (String) base.opt("type");
    }

    /** The last updated time for the feed
    */
    public String getUpdatedTime() {
        return (String) base.opt("updated_time");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}