package com.temboo.outputs.Facebook;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Facebook.FacebookComment;
import com.temboo.outputs.Facebook.FacebookFrom;
import com.temboo.outputs.Facebook.FacebookTo;

/**  An object containing information for an outbox message

*/
public class FacebookOutboxItem {
    protected JSONObject base;
    
    public FacebookOutboxItem(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** The comments for this outbox item
    */
    public FacebookComment[] getComments() {
        JSONArray list = (JSONArray) getJSONObject(base, "comments").opt("data");
        FacebookComment[] resultArray = new FacebookComment[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FacebookComment(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** Get the user that the outbox item has been sent from
    */
    public FacebookFrom getFrom() {
        return new FacebookFrom(base.opt("from"));
    }

    /** The id of the message
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** The message text
    */
    public String getMessage() {
        return (String) base.opt("message");
    }

    /** Get the user that the message has been sent to
    */
    public FacebookTo[] getTo() {
        JSONArray list = (JSONArray) getJSONObject(base, "to").opt("data");
        FacebookTo[] resultArray = new FacebookTo[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FacebookTo(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** Number of unread messages in the thread
    */
    public Number getUnread() {
        return (Number) base.opt("unread");
    }

    /** Whether or not the there are unseen messages
    */
    public Number getUnseen() {
        return (Number) base.opt("unseen");
    }

    /** Timestamp of when the thread was last updated
    */
    public String getUpdatedTime() {
        return (String) base.opt("updated_time");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}