package com.temboo.outputs.Facebook;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Facebook.FacebookFrom;

/**  An object containing information about a user's photo album

*/
public class FacebookPhotoAlbum {
    protected JSONObject base;
    
    public FacebookPhotoAlbum(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** Determines whether the UID can upload to the album and returns true if it allowed
    */
    public Boolean getCanUpload() {
        return (Boolean) base.opt("can_upload");
    }

    /** The number of photos in this album
    */
    public Number getCount() {
        return (Number) base.opt("count");
    }

    /** The album cover photo ID
    */
    public String getCoverPhoto() {
        return (String) base.opt("cover_photo");
    }

    /** The time the photo album was initially created
    */
    public String getCreatedTime() {
        return (String) base.opt("created_time");
    }

    /** Get the user that the photo is from
    */
    public FacebookFrom getFrom() {
        return new FacebookFrom(base.opt("from"));
    }

    /** The album ID
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** A link to this album on Facebook
    */
    public String getLink() {
        return (String) base.opt("link");
    }

    /** The title of the album
    */
    public String getName() {
        return (String) base.opt("name");
    }

    /** The privacy settings for the album
    */
    public String getPrivacy() {
        return (String) base.opt("privacy");
    }

    /** The type of the album: profile, mobile, wall, normal or album
    */
    public String getType() {
        return (String) base.opt("type");
    }

    /** The last time the photo album was updated
    */
    public String getUpdatedTime() {
        return (String) base.opt("updated_time");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}