package com.temboo.outputs.Facebook;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Facebook.FacebookComment;
import com.temboo.outputs.Facebook.FacebookFrom;
import com.temboo.outputs.Facebook.FacebookImage;
import com.temboo.outputs.Facebook.FacebookLike;
import com.temboo.outputs.Facebook.FacebookTag;

/**  A photo objects including tagged users and their positions in this photo

*/
public class FacebookPhotoTag {
    protected JSONObject base;
    
    public FacebookPhotoTag(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** Get comments for this photo object
    */
    public FacebookComment[] getComments() {
        JSONArray list = (JSONArray) getJSONObject(base, "comments").opt("data");
        FacebookComment[] resultArray = new FacebookComment[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FacebookComment(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** The time the photo was initially published in ISO-8601 format
    */
    public String getCreatedTime() {
        return (String) base.opt("created_time");
    }

    /** The profile (user or page) that posted this photo
    */
    public FacebookFrom getFrom() {
        return new FacebookFrom(base.opt("from"));
    }

    /** The height of the photo in pixels
    */
    public Number getHeight() {
        return (Number) base.opt("height");
    }

    /** The icon that Facebook displays when photos are published to the Feed
    */
    public String getIcon() {
        return (String) base.opt("icon");
    }

    /** The id of the photo
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** Get a representation fo this photo
    */
    public FacebookImage[] getImages() {
        JSONArray list = (JSONArray) base.opt("images");
        FacebookImage[] resultArray = new FacebookImage[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FacebookImage(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** The users that have liked this photo
    */
    public FacebookLike[] getLikes() {
        JSONArray list = (JSONArray) getJSONObject(base, "likes").opt("data");
        FacebookLike[] resultArray = new FacebookLike[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FacebookLike(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** A link to the photo
    */
    public String getLink() {
        return (String) base.opt("link");
    }

    /** The user provided caption given to this photo
    */
    public String getName() {
        return (String) base.opt("name");
    }

    /** The thumbnail-sized source of the photo
    */
    public String getPicture() {
        return (String) base.opt("picture");
    }

    /** The position of this photo in the album
    */
    public Number getPosition() {
        return (Number) base.opt("position");
    }

    /** The source image of the photo
    */
    public String getSource() {
        return (String) base.opt("source");
    }

    /** Get a tag in this photo
    */
    public FacebookTag[] getTags() {
        JSONArray list = (JSONArray) getJSONObject(base, "tags").opt("data");
        FacebookTag[] resultArray = new FacebookTag[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FacebookTag(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** The last time the photo or its caption was updated in ISO-8601 format
    */
    public String getUpdatedTime() {
        return (String) base.opt("updated_time");
    }

    /** The width of the photo in pixels
    */
    public Number getWidth() {
        return (Number) base.opt("width");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}