package com.temboo.outputs.Facebook;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Facebook.FacebookEducation;
import com.temboo.outputs.Facebook.FacebookSignificantOther;
import com.temboo.outputs.Facebook.FacebookUserLocation;

/**  A user object

*/
public class FacebookUser {
    protected JSONObject base;
    
    public FacebookUser(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** The user's date of birth
    */
    public String getBirthday() {
        return (String) base.opt("birthday");
    }

    /** Get the user's education information
    */
    public FacebookEducation[] getEducation() {
        JSONArray list = (JSONArray) base.opt("education");
        FacebookEducation[] resultArray = new FacebookEducation[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FacebookEducation(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** The user's email address
    */
    public String getEmail() {
        return (String) base.opt("email");
    }

    /** the user's first name
    */
    public String getFirstName() {
        return (String) base.opt("first_name");
    }

    /** The user's gender
    */
    public String getGender() {
        return (String) base.opt("gender");
    }

    /** The id of the user
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** The last name of the user
    */
    public String getLastName() {
        return (String) base.opt("last_name");
    }

    /** The link the the user's profile page
    */
    public String getLink() {
        return (String) base.opt("link");
    }

    /** The user's locale
    */
    public String getLocale() {
        return (String) base.opt("locale");
    }

    /** Get the location information
    */
    public FacebookUserLocation getUserLocation() {
        return new FacebookUserLocation(base.opt("location"));
    }

    /** The name of the user
    */
    public String getName() {
        return (String) base.opt("name");
    }

    /** The relationship status of the user
    */
    public String getRelationshipStatus() {
        return (String) base.opt("relationship_status");
    }

    /** Get the id and name of the user's significant other
    */
    public FacebookSignificantOther getSignificantOther() {
        return new FacebookSignificantOther(base.opt("significant_other"));
    }

    /** The user's timezone offset from UTC
    */
    public Number getTimezone() {
        return (Number) base.opt("timezone");
    }

    /** The last time the user's profile was updated;
    */
    public String getUpdatedTime() {
        return (String) base.opt("updated_time");
    }

    /** The user's Facebook username
    */
    public String getUsername() {
        return (String) base.opt("username");
    }

    /** The user's account verification status, either true or false
    */
    public Boolean getVerified() {
        return (Boolean) base.opt("verified");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}