package com.temboo.outputs.Facebook;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Facebook.FacebookFormat;
import com.temboo.outputs.Facebook.FacebookFrom;
import com.temboo.outputs.Facebook.FacebookVideoTag;

/**  An object containing video tags and video metadata 

*/
public class FacebookVideoMetadata {
    protected JSONObject base;
    
    public FacebookVideoMetadata(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** The time that the video was created in ISO-8601 format
    */
    public String getCreatedTime() {
        return (String) base.opt("created_time");
    }

    /** The description of the video
    */
    public String getDescription() {
        return (String) base.opt("description");
    }

    /** The html element that may be embedded in an Web page to play the video
    */
    public String getEmbedHtml() {
        return (String) base.opt("embed_html");
    }

    /** Get the formats for this video
    */
    public FacebookFormat[] getFormat() {
        JSONArray list = (JSONArray) base.opt("format");
        FacebookFormat[] resultArray = new FacebookFormat[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FacebookFormat(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** The profile (user or page) that created the video
    */
    public FacebookFrom getFrom() {
        return new FacebookFrom(base.opt("from"));
    }

    /** The icon that Facebook displays when video are published to the Feed
    */
    public String getIcon() {
        return (String) base.opt("icon");
    }

    /** The id of the video
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** The name of the video
    */
    public String getName() {
        return (String) base.opt("name");
    }

    /** The URL for the thumbnail picture for the video
    */
    public String getPicture() {
        return (String) base.opt("picture");
    }

    /** The source url for the video
    */
    public String getSource() {
        return (String) base.opt("source");
    }

    /** Get the tags for this video
    */
    public FacebookVideoTag[] getVideoTags() {
        JSONArray list = (JSONArray) getJSONObject(base, "tags").opt("data");
        FacebookVideoTag[] resultArray = new FacebookVideoTag[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FacebookVideoTag(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** The last time the video or video caption was updated in ISO-8601 format
    */
    public String getUpdatedTime() {
        return (String) base.opt("updated_time");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}