package com.temboo.outputs.Foursquare;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;

/**   Contains information about the categories that have been applied to this foursquare object

*/
public class FoursquareCategory {
    protected JSONObject base;
    
    public FoursquareCategory(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** The icon for this category
    */
    public String getIcon() {
        return (String) base.opt("icon");
    }

    /** The id of the category
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** The name of the category
    */
    public String getName() {
        return (String) base.opt("name");
    }

    /** 
    */
    public String[] getParents() {
        JSONArray list = (JSONArray) base.opt("parents");
        String[] resultArray = new String[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = (String) list.get(i);
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** The plural name for the category
    */
    public String getPluralName() {
        return (String) base.opt("pluralName");
    }

    /** Whether or not this category is tagged as the primary category
    */
    public Boolean getPrimary() {
        return (Boolean) base.opt("primary");
    }

    /** The short name for the category
    */
    public String getShortName() {
        return (String) base.opt("shortName");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}