package com.temboo.outputs.Foursquare;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Foursquare.FoursquareBadge;
import com.temboo.outputs.Foursquare.FoursquareComment;
import com.temboo.outputs.Foursquare.FoursquareLikes;
import com.temboo.outputs.Foursquare.FoursquareOverlap;
import com.temboo.outputs.Foursquare.FoursquarePhoto;
import com.temboo.outputs.Foursquare.FoursquarePost;
import com.temboo.outputs.Foursquare.FoursquareScore;
import com.temboo.outputs.Foursquare.FoursquareSource;
import com.temboo.outputs.Foursquare.FoursquareUser;
import com.temboo.outputs.Foursquare.FoursquareVenue;

/**  A checkin object

*/
public class FoursquareCheckin {
    protected JSONObject base;
    
    public FoursquareCheckin(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    public FoursquareBadge[] getBadges() {
        JSONArray list = (JSONArray) getJSONObject(base, "badges").opt("items");
        FoursquareBadge[] resultArray = new FoursquareBadge[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FoursquareBadge(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    public FoursquareComment[] getComments() {
        JSONArray list = (JSONArray) getJSONObject(base, "comments").opt("items");
        FoursquareComment[] resultArray = new FoursquareComment[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FoursquareComment(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** The epoch timestamp for when the checkin was created
    */
    public Number getCreatedAt() {
        return (Number) base.opt("createdAt");
    }

    /** The id the checkin
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** Whether or not the checkin has been liked
    */
    public Boolean getLike() {
        return (Boolean) base.opt("like");
    }

    /** Get likes for this checkin
    */
    public FoursquareLikes getLikes() {
        return new FoursquareLikes(base.opt("likes"));
    }

    /** Get information about overlapping checkins
    */
    public FoursquareOverlap[] getOverlaps() {
        JSONArray list = (JSONArray) getJSONObject(base, "overlaps").opt("items");
        FoursquareOverlap[] resultArray = new FoursquareOverlap[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FoursquareOverlap(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** Get photos for this checkin
    */
    public FoursquarePhoto[] getPhotos() {
        JSONArray list = (JSONArray) getJSONObject(base, "photos").opt("items");
        FoursquarePhoto[] resultArray = new FoursquarePhoto[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FoursquarePhoto(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** Get the posts for this checkin. May not be present.
    */
    public FoursquarePost[] getPosts() {
        JSONArray list = (JSONArray) getJSONObject(base, "posts").opt("items");
        FoursquarePost[] resultArray = new FoursquarePost[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FoursquarePost(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** Get scores for this checkin
    */
    public FoursquareScore[] getScores() {
        JSONArray list = (JSONArray) getJSONObject(base, "score").opt("scores");
        FoursquareScore[] resultArray = new FoursquareScore[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FoursquareScore(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** The message from check-in
    */
    public String getShout() {
        return (String) base.opt("shout");
    }

    /** Get the source information for the app that created the checkin
    */
    public FoursquareSource getSource() {
        return new FoursquareSource(base.opt("source"));
    }

    /** The timezone associated with this checkin
    */
    public String getTimeZone() {
        return (String) base.opt("timeZone");
    }

    /** A string representation of the time zone where this check-in occurred
    */
    public Number getTimeZoneOffset() {
        return (Number) base.opt("timeZoneOffset");
    }

    /** The type of foursquare object. One of checkin, shout, or venueless.
    */
    public String getType() {
        return (String) base.opt("type");
    }

    /** Get the user associated with this checkin
    */
    public FoursquareUser getUser() {
        return new FoursquareUser(base.opt("user"));
    }

    /** Get the venue for this checkin
    */
    public FoursquareVenue getVenue() {
        return new FoursquareVenue(base.opt("venue"));
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}