package com.temboo.outputs.Foursquare;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Foursquare.FoursquareCategory;
import com.temboo.outputs.Foursquare.FoursquareForeignIds;
import com.temboo.outputs.Foursquare.FoursquareHereNow;
import com.temboo.outputs.Foursquare.FoursquareStats;

/**  Contains details about venue events
  
*/
public class FoursquareEvent {
    protected JSONObject base;
    
    public FoursquareEvent(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** Whether or not this is an all day event
    */
    public Boolean getAllDay() {
        return (Boolean) base.opt("allDay");
    }

    /** Get categories for this event
    */
    public FoursquareCategory[] getCategories() {
        JSONArray list = (JSONArray) base.opt("categories");
        FoursquareCategory[] resultArray = new FoursquareCategory[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FoursquareCategory(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** The date of the even as an epoch timestamp
    */
    public Number getDate() {
        return (Number) base.opt("date");
    }

    /** Get foreign ids
    */
    public FoursquareForeignIds[] getForeignIds() {
        JSONArray list = (JSONArray) getJSONObject(base, "foreignIds").opt("items");
        FoursquareForeignIds[] resultArray = new FoursquareForeignIds[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FoursquareForeignIds(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** Get the people at this event now
    */
    public FoursquareHereNow getHereNow() {
        return new FoursquareHereNow(base.opt("hereNow"));
    }

    /** The event id
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** The name of the event
    */
    public String getName() {
        return (String) base.opt("name");
    }

    /** Get stats for the event
    */
    public FoursquareStats getStats() {
        return new FoursquareStats(base.opt("stats"));
    }

    /** The event timezone
    */
    public String getTimeZone() {
        return (String) base.opt("timeZone");
    }

    /** The url for the event
    */
    public String getUrl() {
        return (String) base.opt("url");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}