package com.temboo.outputs.Foursquare;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Foursquare.FoursquareTimeframe;

/**  Contains the hours during the week that the venue is open along with any named hours segments in a human-readable format
  
*/
public class FoursquareHours {
    protected JSONObject base;
    
    public FoursquareHours(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** Whether or not the venue is open
    */
    public Boolean getIsOpen() {
        return (Boolean) base.opt("isOpen");
    }

    /** The venue status
    */
    public String getStatus() {
        return (String) base.opt("status");
    }

    /** Get the timeframe information for the venue including days of operation
    */
    public FoursquareTimeframe[] getTimeframes() {
        JSONArray list = (JSONArray) base.opt("timeframes");
        FoursquareTimeframe[] resultArray = new FoursquareTimeframe[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FoursquareTimeframe(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}