package com.temboo.outputs.Foursquare;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Foursquare.FoursquareListed;
import com.temboo.outputs.Foursquare.FoursquareTip;
import com.temboo.outputs.Foursquare.FoursquareVenue;

/**  A list item object

*/
public class FoursquareItem {
    protected JSONObject base;
    
    public FoursquareItem(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** Whether or not this item has been done
    */
    public Boolean getDone() {
        return (Boolean) base.opt("done");
    }

    /** The id of the item
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** Get lists for the authenticated user
    */
    public FoursquareListed getListed() {
        return new FoursquareListed(base.opt("listed"));
    }

    /** Get the tip for this item
    */
    public FoursquareTip getTip() {
        return new FoursquareTip(base.opt("tip"));
    }

    /** Whether or not this item is a todo
    */
    public Boolean getTodo() {
        return (Boolean) base.opt("todo");
    }

    /** Get the venue that this item is for
    */
    public FoursquareVenue getVenue() {
        return new FoursquareVenue(base.opt("venue"));
    }

    /** How many times the venue is has been visited
    */
    public Number getVisitedCount() {
        return (Number) base.opt("visitedCount");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}