package com.temboo.outputs.Foursquare;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Foursquare.FoursquareCategory;
import com.temboo.outputs.Foursquare.FoursquareCollaborator;
import com.temboo.outputs.Foursquare.FoursquareFollowers;
import com.temboo.outputs.Foursquare.FoursquareItem;
import com.temboo.outputs.Foursquare.FoursquareUser;

/**  A list object

*/
public class FoursquareList {
    protected JSONObject base;
    
    public FoursquareList(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** The canonical URL for the list
    */
    public String getCanonicalUrl() {
        return (String) base.opt("canonicalUrl");
    }

    /** Get categories for the list
    */
    public FoursquareCategory[] getCategories() {
        JSONArray list = (JSONArray) getJSONObject(base, "categories").opt("item");
        FoursquareCategory[] resultArray = new FoursquareCategory[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FoursquareCategory(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** Whether or not the list has collaborators
    */
    public Boolean getCollaborative() {
        return (Boolean) base.opt("collaborative");
    }

    /** Get collaborators for this list
    */
    public FoursquareCollaborator[] getCollaborators() {
        JSONArray list = (JSONArray) getJSONObject(base, "collaborators").opt("items");
        FoursquareCollaborator[] resultArray = new FoursquareCollaborator[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FoursquareCollaborator(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** The description of the list
    */
    public String getDescription() {
        return (String) base.opt("description");
    }

    /** The count of items that are done
    */
    public Number getDoneCount() {
        return (Number) base.opt("doneCount");
    }

    /** Whether or not the list is editable
    */
    public Boolean getEditable() {
        return (Boolean) base.opt("editable");
    }

    /** Get the count of followers
    */
    public FoursquareFollowers getFollowers() {
        return new FoursquareFollowers(base.opt("followers"));
    }

    /** Whether or not there are followers of the list
    */
    public Boolean getFollowing() {
        return (Boolean) base.opt("following");
    }

    /** The id of the list
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** Get the list items
    */
    public FoursquareItem[] getItems() {
        JSONArray list = (JSONArray) getJSONObject(base, "listItems").opt("items");
        FoursquareItem[] resultArray = new FoursquareItem[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FoursquareItem(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** The name of the list
    */
    public String getName() {
        return (String) base.opt("name");
    }

    /** Whether not the list is editable by others
    */
    public Boolean getPublic() {
        return (Boolean) base.opt("public");
    }

    /** The type of list
    */
    public String getType() {
        return (String) base.opt("type");
    }

    /** The list url
    */
    public String getUrl() {
        return (String) base.opt("url");
    }

    /** Get the user who created this list
    */
    public FoursquareUser getUser() {
        return new FoursquareUser(base.opt("user"));
    }

    /** The venue count for this list
    */
    public Number getVenueCount() {
        return (Number) base.opt("venueCount");
    }

    /** The count of visits
    */
    public Number getVisitedCount() {
        return (Number) base.opt("visitedCount");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}