package com.temboo.outputs.Foursquare;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Foursquare.FoursquareFollowers;
import com.temboo.outputs.Foursquare.FoursquareItem;
import com.temboo.outputs.Foursquare.FoursquareUser;

/**  Contains list objects for the authenitcated user
  
*/
public class FoursquareListedItems {
    protected JSONObject base;
    
    public FoursquareListedItems(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** The canonical url for the list
    */
    public String getCanonicalUrl() {
        return (String) base.opt("canonicalUrl");
    }

    /** Whether or not this list is editable by the owner's friends
    */
    public Boolean getCollaborative() {
        return (Boolean) base.opt("collaborative");
    }

    /** The epoch timestamp for when this list was created
    */
    public Number getCreatedAt() {
        return (Number) base.opt("createdAt");
    }

    /** The description of the list
    */
    public String getDescription() {
        return (String) base.opt("description");
    }

    /** Whether or not this item is editable
    */
    public Boolean getEditable() {
        return (Boolean) base.opt("editable");
    }

    /** Get the follower count for this list item
    */
    public FoursquareFollowers getFollowers() {
        return new FoursquareFollowers(base.opt("followers"));
    }

    /** The id of this item
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** Get the list items
    */
    public FoursquareItem[] getItems() {
        JSONArray list = (JSONArray) getJSONObject(base, "listItems").opt("items");
        FoursquareItem[] resultArray = new FoursquareItem[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FoursquareItem(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** The name of the list
    */
    public String getName() {
        return (String) base.opt("name");
    }

    /** Whether or not the list is public
    */
    public Boolean getPublic() {
        return (Boolean) base.opt("public");
    }

    /** An epoch timestamp representing the last update time for the list
    */
    public Number getUpdatedAt() {
        return (Number) base.opt("updatedAt");
    }

    /** The url for the list
    */
    public String getUrl() {
        return (String) base.opt("url");
    }

    /** Get the user who created the list
    */
    public FoursquareUser getUser() {
        return new FoursquareUser(base.opt("user"));
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}