package com.temboo.outputs.Foursquare;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;

/**  Contains location information for the venue

*/
public class FoursquareLocation {
    protected JSONObject base;
    
    public FoursquareLocation(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** The venue address
    */
    public String getAddress() {
        return (String) base.opt("address");
    }

    /** The country abbreviation field for the venue address
    */
    public String getCc() {
        return (String) base.opt("cc");
    }

    /** The city that the venue is in
    */
    public String getCity() {
        return (String) base.opt("city");
    }

    /** The country field for the venue address
    */
    public String getCountry() {
        return (String) base.opt("country");
    }

    /** The cross street of the venue
    */
    public String getCrossStreet() {
        return (String) base.opt("crossStreet");
    }

    /** The latitude coordinate for the venue
    */
    public Number getLat() {
        return (Number) base.opt("lat");
    }

    /** The longitude coordinate for the venue
    */
    public Number getLng() {
        return (Number) base.opt("lng");
    }

    /** The postal code of the venue
    */
    public String getPostalCode() {
        return (String) base.opt("postalCode");
    }

    /** The state that the venue is in
    */
    public String getState() {
        return (String) base.opt("state");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}