package com.temboo.outputs.Foursquare;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Foursquare.FoursquareInsight;
import com.temboo.outputs.Foursquare.FoursquareLeaderboard;
import com.temboo.outputs.Foursquare.FoursquareScore;
import com.temboo.outputs.Foursquare.FoursquareUser;

/**  Contains
  
*/
public class FoursquareNotificationItem {
    protected JSONObject base;
    
    public FoursquareNotificationItem(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** The number of checkins
    */
    public Number getCheckins() {
        return (Number) base.opt("checkins");
    }

    /** The url for the user image
    */
    public String getImage() {
        return (String) base.opt("image");
    }

    /** Get insights
    */
    public FoursquareInsight[] getInsights() {
        JSONArray list = (JSONArray) getJSONObject(base, "insights").opt("items");
        FoursquareInsight[] resultArray = new FoursquareInsight[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FoursquareInsight(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** Get the scores for this checkin
    */
    public FoursquareScore[] getScores() {
        JSONArray list = (JSONArray) getJSONObject(base, "item").opt("scores");
        FoursquareScore[] resultArray = new FoursquareScore[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FoursquareScore(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** Get the leadboard object for the authenticated user
    */
    public FoursquareLeaderboard[] getLeaderboard() {
        JSONArray list = (JSONArray) base.opt("leaderboard");
        FoursquareLeaderboard[] resultArray = new FoursquareLeaderboard[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FoursquareLeaderboard(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** The notification message
    */
    public String getMessage() {
        return (String) base.opt("message");
    }

    /** The total number of items
    */
    public Number getTotal() {
        return (Number) base.opt("total");
    }

    /** The type of notification item
    */
    public String getType() {
        return (String) base.opt("type");
    }

    /** The number of unread notifications
    */
    public Number getUnreadCount() {
        return (Number) base.opt("unreadCount");
    }

    /** Get the user information for this notification item
    */
    public FoursquareUser getUser() {
        return new FoursquareUser(base.opt("user"));
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}