package com.temboo.outputs.Foursquare;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Foursquare.FoursquareSize;
import com.temboo.outputs.Foursquare.FoursquareSource;
import com.temboo.outputs.Foursquare.FoursquareTip;
import com.temboo.outputs.Foursquare.FoursquareUser;
import com.temboo.outputs.Foursquare.FoursquareVenue;

/**  Contains a photo object

*/
public class FoursquarePhoto {
    protected JSONObject base;
    
    public FoursquarePhoto(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** 
    */
    public Number getCreatedAt() {
        return (Number) base.opt("createdAt");
    }

    /** The height of the photo in pixels
    */
    public String getHeight() {
        return (String) base.opt("height");
    }

    /** 
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** The start of the URL for this photo
    */
    public String getPrefix() {
        return (String) base.opt("prefix");
    }

    public FoursquareSize[] getSizes() {
        JSONArray list = (JSONArray) getJSONObject(base, "sizes").opt("items");
        FoursquareSize[] resultArray = new FoursquareSize[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FoursquareSize(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** Get the source information for this photo
    */
    public FoursquareSource getSource() {
        return new FoursquareSource(base.opt("source"));
    }

    /** The end of the URL for this photo
    */
    public String getSuffix() {
        return (String) base.opt("suffix");
    }

    /** Get the tip for this photo
    */
    public FoursquareTip getTip() {
        return new FoursquareTip(base.opt("tip"));
    }

    /** 
    */
    public String getUrl() {
        return (String) base.opt("url");
    }

    /** Get the user that took this photo
    */
    public FoursquareUser getUser() {
        return new FoursquareUser(base.opt("user"));
    }

    /** Get the venue associated with this photo
    */
    public FoursquareVenue getVenue() {
        return new FoursquareVenue(base.opt("venue"));
    }

    /** 
    */
    public String getVisibility() {
        return (String) base.opt("visibility");
    }

    /** The width of this photo in pixels
    */
    public String getWidth() {
        return (String) base.opt("width");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}