package com.temboo.outputs.Foursquare;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Foursquare.FoursquarePhoto;
import com.temboo.outputs.Foursquare.FoursquareSource;
import com.temboo.outputs.Foursquare.FoursquareUser;
import com.temboo.outputs.Foursquare.FoursquareVenue;

/**  Contains recent checkins for the authenticated user
  
*/
public class FoursquareRecent {
    protected JSONObject base;
    
    public FoursquareRecent(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** The epoch timestamp for when the checkin created
    */
    public Number getCreatedAt() {
        return (Number) base.opt("createdAt");
    }

    /** The checkin id
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** Get photos for recent checkins
    */
    public FoursquarePhoto[] getPhotos() {
        JSONArray list = (JSONArray) getJSONObject(base, "photos").opt("items");
        FoursquarePhoto[] resultArray = new FoursquarePhoto[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FoursquarePhoto(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** Get the source information for this checkin
    */
    public FoursquareSource getSource() {
        return new FoursquareSource(base.opt("source"));
    }

    /** The timezone associated with this checkin
    */
    public String getTimeZone() {
        return (String) base.opt("timeZone");
    }

    /** String representation of the time zone where this check-in occurred
    */
    public Number getTimeZoneOffset() {
        return (Number) base.opt("timeZoneOffset");
    }

    /** The type of checkin. One of checkin, shout, or venueless.
    */
    public String getType() {
        return (String) base.opt("type");
    }

    /** Get the user for this checkin
    */
    public FoursquareUser getUser() {
        return new FoursquareUser(base.opt("user"));
    }

    /** Get the venue that was checked into
    */
    public FoursquareVenue getVenue() {
        return new FoursquareVenue(base.opt("venue"));
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}