package com.temboo.outputs.Foursquare;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Foursquare.FoursquareKeywords;
import com.temboo.outputs.Foursquare.FoursquareRecommendationGroup;
import com.temboo.outputs.Foursquare.FoursquareWarning;

/** 
*/
public class FoursquareRecommendations {
    protected JSONObject base;
    
    public FoursquareRecommendations(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    public FoursquareRecommendationGroup[] getRecommendationGroups() {
        JSONArray list = (JSONArray) base.opt("groups");
        FoursquareRecommendationGroup[] resultArray = new FoursquareRecommendationGroup[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FoursquareRecommendationGroup(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** A full text name for the location the user searched
    */
    public String getHeaderFullLocation() {
        return (String) base.opt("headerFullLocation");
    }

    /** A text name for the location the user searched
    */
    public String getHeaderLocation() {
        return (String) base.opt("headerLocation");
    }

    /** More granular location information
    */
    public String getHeaderLocationGranularity() {
        return (String) base.opt("headerLocationGranularity");
    }

    /** A message to the user based on their current context
    */
    public String getHeaderMessage() {
        return (String) base.opt("headerMessage");
    }

    /** Get keyword suggestions
    */
    public FoursquareKeywords getKeywords() {
        return new FoursquareKeywords(getJSONObject(base, "keywords").opt("items"));
    }

    /** When no radius is specified, this represents the radius that was used for the query (based upon the density of venues in the query area)
    */
    public Number getSuggestedRadius() {
        return (Number) base.opt("suggestedRadius");
    }

    /** Get warnings about the request
    */
    public FoursquareWarning getWarning() {
        return new FoursquareWarning(base.opt("warning"));
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}