package com.temboo.outputs.Foursquare;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Foursquare.FoursquareOpen;
import com.temboo.outputs.Foursquare.FoursquareSegment;

/**  An object containing the days
    
*/
public class FoursquareTimeframe {
    protected JSONObject base;
    
    public FoursquareTimeframe(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** Days represented as integers with Monday = 1,..., Sunday = 7 on which these hours apply
    */
    public String getDays() {
        return (String) base.opt("days");
    }

    /** Indicates if this timeframe includes today
    */
    public Boolean getIncludesToday() {
        return (Boolean) base.opt("includesToday");
    }

    /** Get the start, end, and rendered time for the venue
    */
    public FoursquareOpen[] getOpen() {
        JSONArray list = (JSONArray) base.opt("open");
        FoursquareOpen[] resultArray = new FoursquareOpen[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FoursquareOpen(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** Get segment information for the venue
    */
    public FoursquareSegment[] getSegments() {
        JSONArray list = (JSONArray) base.opt("segments");
        FoursquareSegment[] resultArray = new FoursquareSegment[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FoursquareSegment(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}