package com.temboo.outputs.Foursquare;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Foursquare.FoursquareDone;
import com.temboo.outputs.Foursquare.FoursquareLikes;
import com.temboo.outputs.Foursquare.FoursquarePhoto;
import com.temboo.outputs.Foursquare.FoursquareTodo;
import com.temboo.outputs.Foursquare.FoursquareUser;

/**  Contains information about tips associated with a venue

*/
public class FoursquareTip {
    protected JSONObject base;
    
    public FoursquareTip(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** The url for the tip
    */
    public String getCanonicalUrl() {
        return (String) base.opt("canonicalUrl");
    }

    /** The date that this tip was created in epoch format
    */
    public Number getCreatedAt() {
        return (Number) base.opt("createdAt");
    }

    /** Get the count of tips that have been done
    */
    public FoursquareDone getDone() {
        return new FoursquareDone(base.opt("done"));
    }

    /** The id of the tip
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** Get the photos for this tip
    */
    public FoursquarePhoto getPhoto() {
        return new FoursquarePhoto(getJSONObject(base, "items").opt("photo"));
    }

    /** Get the likes for this tip
    */
    public FoursquareLikes getLikes() {
        return new FoursquareLikes(base.opt("likes"));
    }

    /** The url to the photo
    */
    public String getPhotourl() {
        return (String) base.opt("photourl");
    }

    /** The text of the tip
    */
    public String getText() {
        return (String) base.opt("text");
    }

    /** Get to count of todos for this tip
    */
    public FoursquareTodo getTodo() {
        return new FoursquareTodo(base.opt("todo"));
    }

    /** The tip url
    */
    public String getUrl() {
        return (String) base.opt("url");
    }

    /** Get the user that created this tip
    */
    public FoursquareUser getUser() {
        return new FoursquareUser(base.opt("user"));
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}