package com.temboo.outputs.Foursquare;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Foursquare.FoursquareDone;
import com.temboo.outputs.Foursquare.FoursquareLikes;
import com.temboo.outputs.Foursquare.FoursquareListed;
import com.temboo.outputs.Foursquare.FoursquareTodo;
import com.temboo.outputs.Foursquare.FoursquareUser;
import com.temboo.outputs.Foursquare.FoursquareVenue;

/**  Contains tip details including users that have marked a tip done and users that have marked a tip as a todo

*/
public class FoursquareTipDetails {
    protected JSONObject base;
    
    public FoursquareTipDetails(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** The url for the tip
    */
    public String getCanonicalUrl() {
        return (String) base.opt("canonicalUrl");
    }

    /** An epoch timestamp when the tip was created
    */
    public Number getCreatedAt() {
        return (Number) base.opt("createdAt");
    }

    /** Get the info for user who have marked this tip done
    */
    public FoursquareDone getDone() {
        return new FoursquareDone(base.opt("done"));
    }

    /** The id of this tip
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** Whether or not the tip has been liked
    */
    public Boolean getLike() {
        return (Boolean) base.opt("like");
    }

    /** Get the likes for this tip
    */
    public FoursquareLikes getLikes() {
        return new FoursquareLikes(base.opt("likes"));
    }

    /** Get the the count of tip
    */
    public FoursquareListed getListed() {
        return new FoursquareListed(base.opt("listed"));
    }

    /** The actual tip
    */
    public String getText() {
        return (String) base.opt("text");
    }

    /** Get information about people that have indicated this tip as a todo
    */
    public FoursquareTodo getTodo() {
        return new FoursquareTodo(base.opt("todo"));
    }

    /** Get the user that created this tip
    */
    public FoursquareUser getUser() {
        return new FoursquareUser(base.opt("user"));
    }

    /** Get the venue associated with this tip
    */
    public FoursquareVenue getVenue() {
        return new FoursquareVenue(base.opt("venue"));
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}