package com.temboo.outputs.Foursquare;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Foursquare.FoursquareCollaborator;
import com.temboo.outputs.Foursquare.FoursquareFollowers;
import com.temboo.outputs.Foursquare.FoursquareTodoCategory;
import com.temboo.outputs.Foursquare.FoursquareUser;

/**  Contains information about a todo list for the venue
  
*/
public class FoursquareTodos {
    protected JSONObject base;
    
    public FoursquareTodos(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** The canonical url for the todo
    */
    public String getCanonicalUrl() {
        return (String) base.opt("canonicalUrl");
    }

    public FoursquareTodoCategory[] getTodoCategories() {
        JSONArray list = (JSONArray) getJSONObject(getJSONObject(base, "categories"), "items").opt("category");
        FoursquareTodoCategory[] resultArray = new FoursquareTodoCategory[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FoursquareTodoCategory(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** Whether or not other users have edited this todo
    */
    public Boolean getCollaborative() {
        return (Boolean) base.opt("collaborative");
    }

    /** Get collaborators for the todo item
    */
    public FoursquareCollaborator[] getCollaborators() {
        JSONArray list = (JSONArray) getJSONObject(base, "collaborators").opt("items");
        FoursquareCollaborator[] resultArray = new FoursquareCollaborator[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FoursquareCollaborator(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** A description of the todo
    */
    public String getDescription() {
        return (String) base.opt("description");
    }

    /** The count of todos marked done
    */
    public Number getDoneCount() {
        return (Number) base.opt("doneCount");
    }

    /** Whether or not this todo is editable
    */
    public Boolean getEditable() {
        return (Boolean) base.opt("editable");
    }

    /** Get the number of followers for this to do
    */
    public FoursquareFollowers getFollowers() {
        return new FoursquareFollowers(base.opt("followers"));
    }

    /** Whether or not the acting user is following the list
    */
    public Boolean getFollowing() {
        return (Boolean) base.opt("following");
    }

    /** 
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** The name of the todo item
    */
    public String getName() {
        return (String) base.opt("name");
    }

    /** Whether or not this todo is public
    */
    public Boolean getPublic() {
        return (Boolean) base.opt("public");
    }

    /** The type of todo
    */
    public String getType() {
        return (String) base.opt("type");
    }

    /** The url of the todo
    */
    public String getUrl() {
        return (String) base.opt("url");
    }

    /** The user that created the todo for this venue
    */
    public FoursquareUser getUser() {
        return new FoursquareUser(base.opt("user"));
    }

    /** The venue count for the todo
    */
    public Number getVenueCount() {
        return (Number) base.opt("venueCount");
    }

    /** The count of visits
    */
    public Number getVisitedCount() {
        return (Number) base.opt("visitedCount");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}