package com.temboo.outputs.Foursquare;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Foursquare.FoursquareContact;
import com.temboo.outputs.Foursquare.FoursquareListGroup;
import com.temboo.outputs.Foursquare.FoursquareTipsCount;

/**  A user object

*/
public class FoursquareUser {
    protected JSONObject base;
    
    public FoursquareUser(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** The bio of the user
    */
    public String getBio() {
        return (String) base.opt("bio");
    }

    /** An object containing twitter, phone, and formattedPhone of the user
    */
    public FoursquareContact getContact() {
        return new FoursquareContact(base.opt("contact"));
    }

    /** 
    */
    public String getFirstName() {
        return (String) base.opt("firstName");
    }

    /** 
    */
    public String getGender() {
        return (String) base.opt("gender");
    }

    /** 
    */
    public String getHomeCity() {
        return (String) base.opt("homeCity");
    }

    /** 
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** 
    */
    public String getLastName() {
        return (String) base.opt("lastName");
    }

    public FoursquareListGroup[] getListGroup() {
        JSONArray list = (JSONArray) getJSONObject(base, "lists").opt("groups");
        FoursquareListGroup[] resultArray = new FoursquareListGroup[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FoursquareListGroup(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** 
    */
    public String getPhoto() {
        return (String) base.opt("photo");
    }

    /** Contains the total count of tips and groups with friends and others
    */
    public FoursquareTipsCount getTipsCount() {
        return new FoursquareTipsCount(base.opt("tips"));
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}