package com.temboo.outputs.Foursquare;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Foursquare.FoursquareBeenHere;
import com.temboo.outputs.Foursquare.FoursquareCategory;
import com.temboo.outputs.Foursquare.FoursquareContact;
import com.temboo.outputs.Foursquare.FoursquareHereNow;
import com.temboo.outputs.Foursquare.FoursquareHours;
import com.temboo.outputs.Foursquare.FoursquareLikes;
import com.temboo.outputs.Foursquare.FoursquareListed;
import com.temboo.outputs.Foursquare.FoursquareLocation;
import com.temboo.outputs.Foursquare.FoursquareMayor;
import com.temboo.outputs.Foursquare.FoursquareMenu;
import com.temboo.outputs.Foursquare.FoursquarePageUpdates;
import com.temboo.outputs.Foursquare.FoursquarePhotoGroup;
import com.temboo.outputs.Foursquare.FoursquarePrice;
import com.temboo.outputs.Foursquare.FoursquareSpecial;
import com.temboo.outputs.Foursquare.FoursquareStats;
import com.temboo.outputs.Foursquare.FoursquareTipGroup;
import com.temboo.outputs.Foursquare.FoursquareTodos;

/**  An containing information about foursquare venue

*/
public class FoursquareVenue {
    protected JSONObject base;
    
    public FoursquareVenue(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** Contains count of the number of times the acting user has been here. Absent if there is no acting user
    */
    public FoursquareBeenHere getBeenHere() {
        return new FoursquareBeenHere(base.opt("beenHere"));
    }

    /** 
    */
    public String getCanonicalUrl() {
        return (String) base.opt("canonicalUrl");
    }

    /** Categories that have been applied to this venue
    */
    public FoursquareCategory[] getCategories() {
        JSONArray list = (JSONArray) base.opt("categories");
        FoursquareCategory[] resultArray = new FoursquareCategory[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FoursquareCategory(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** An object containing twitter, phone, and formattedPhone of the user or venue contact. All can be present, and all can be absent from the response.
    */
    public FoursquareContact getContact() {
        return new FoursquareContact(base.opt("contact"));
    }

    /** The date the venue was created in epoch format
    */
    public Number getCreatedAt() {
        return (Number) base.opt("createdAt");
    }

    /** Whether or not a menu is available for this venue
    */
    public Boolean getHasMenu() {
        return (Boolean) base.opt("hasMenu");
    }

    /** Contains information about who is here now
    */
    public FoursquareHereNow getHereNow() {
        return new FoursquareHereNow(base.opt("hereNow"));
    }

    /** Get the hours that the venue is open
    */
    public FoursquareHours getHours() {
        return new FoursquareHours(base.opt("hours"));
    }

    /** The id of the venue
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** The count of users who have liked this object, and groups containing any friends and others who have liked it
    */
    public FoursquareLikes getLikes() {
        return new FoursquareLikes(base.opt("likes"));
    }

    /** A grouped response of lists that contain this venue
    */
    public FoursquareListed getListed() {
        return new FoursquareListed(base.opt("listed"));
    }

    /** An object containing the location information for the venue
    */
    public FoursquareLocation getLocation() {
        return new FoursquareLocation(base.opt("location"));
    }

    /** An object containing information about the mayor of the venue
    */
    public FoursquareMayor getMayor() {
        return new FoursquareMayor(base.opt("mayor"));
    }

    /** An object containing url and mobileUrl that display the menu information for this venue
    */
    public FoursquareMenu getMenu() {
        return new FoursquareMenu(base.opt("menu"));
    }

    /** The name of the venue
    */
    public String getName() {
        return (String) base.opt("name");
    }

    /** Get the count of page updates
    */
    public FoursquarePageUpdates getPageUpdates() {
        return new FoursquarePageUpdates(base.opt("pageUpdates"));
    }

    /** Contain information about photos for this venue
    */
    public FoursquarePhotoGroup[] getPhotoGroups() {
        JSONArray list = (JSONArray) getJSONObject(base, "photos").opt("groups");
        FoursquarePhotoGroup[] resultArray = new FoursquarePhotoGroup[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FoursquarePhotoGroup(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** Get price information for this venue
    */
    public FoursquarePrice getPrice() {
        return new FoursquarePrice(base.opt("price"));
    }

    /** The venue rating
    */
    public Number getRating() {
        return (Number) base.opt("rating");
    }

    /** The short url for the venue
    */
    public String getShortUrl() {
        return (String) base.opt("shortUrl");
    }

    /** Contains information about specials offered by the venue
    */
    public FoursquareSpecial[] getSpecials() {
        JSONArray list = (JSONArray) base.opt("specials");
        FoursquareSpecial[] resultArray = new FoursquareSpecial[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FoursquareSpecial(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** Contains statistics for the venue including checkinsCount, tipCount, and userCount
    */
    public FoursquareStats getStats() {
        return new FoursquareStats(base.opt("stats"));
    }

    /** Contains tags for this venue
    */
    public String[] getTags() {
        JSONArray list = (JSONArray) base.opt("tags");
        String[] resultArray = new String[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = (String) list.get(i);
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** The timezone for this venue
    */
    public String getTimeZone() {
        return (String) base.opt("timeZone");
    }

    /** Get tips from others and friends
    */
    public FoursquareTipGroup[] getTipGroups() {
        JSONArray list = (JSONArray) getJSONObject(base, "tips").opt("groups");
        FoursquareTipGroup[] resultArray = new FoursquareTipGroup[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new FoursquareTipGroup(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    public FoursquareTodos getTodos() {
        return new FoursquareTodos(base.opt("todos"));
    }

    /** The url for this venue
    */
    public String getUrl() {
        return (String) base.opt("url");
    }

    /** Whether or not the venue has been verified
    */
    public Boolean getVerified() {
        return (Boolean) base.opt("verified");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}