package com.temboo.outputs.Google.Calendar;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;

/**  Represents a Google Calendar
  
*/
public class GoogleCalendar {
    protected JSONObject base;
    
    public GoogleCalendar(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** Description of the calendar.
    */
    public String getDescription() {
        return (String) base.opt("description");
    }

    /** ETag of the resource.
    */
    public String getEtag() {
        return (String) base.opt("etag");
    }

    /** Identifier of the calendar.
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** Type of the resource ("calendar#calendar").
    */
    public String getKind() {
        return (String) base.opt("kind");
    }

    /** Geographic location of the calendar as free-form text
    */
    public String getLocation() {
        return (String) base.opt("location");
    }

    /** Title of the calendar.
    */
    public String getSummary() {
        return (String) base.opt("summary");
    }

    /** The time zone of the calendar.
    */
    public String getTimeZone() {
        return (String) base.opt("timeZone");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}