package com.temboo.outputs.Google.Calendar;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Google.Calendar.GoogleDefaultReminders;
import com.temboo.outputs.Google.Calendar.GoogleCalendar;

/**  Represents a Google Calendar List Entry
  
*/
public class GoogleCalendarListEntry extends GoogleCalendar {
    
    public GoogleCalendarListEntry(Object base) {
        super(base);
    }

    /** The effective access role that the authenticated user has on the calendar: "freeBusyReader" - Provides read access to free/busy information, "reader" - Provides read access to the calendar. Private events will appear to users with reader access, but event details will be hidden, "writer" - Provides read and write access to the calendar. Private events will appear to users with writer access, and event details will be visible, "owner" - Provides ownership of the calendar. This role has all of the permissions of the writer role with the additional ability to see and manipulate ACLs.
    */
    public String getAccessRole() {
        return (String) base.opt("accessRole");
    }

    /** The main color of the calendar in the format '#0088aa'. This property supersedes the index-based colorId property
    */
    public String getBackgroundColor() {
        return (String) base.opt("backgroundColor");
    }

    /** The color of the calendar. This is an ID referring to an entry in the "calendar" section of the colors definition (see the "colors" endpoint).
    */
    public String getColorId() {
        return (String) base.opt("colorId");
    }

    /** The default reminders that the authenticated user has for this calendar.
    */
    public GoogleDefaultReminders[] getDefaultReminders() {
        JSONArray list = (JSONArray) base.opt("defaultReminders");
        GoogleDefaultReminders[] resultArray = new GoogleDefaultReminders[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new GoogleDefaultReminders(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** The foreground color of the calendar in the format '#ffffff'. This property supersedes the index-based colorId property.
    */
    public String getForegroundColor() {
        return (String) base.opt("foregroundColor");
    }

    /** Type of the resource ("calendar#calendarListEntry").
    */
    public String getKind() {
        return (String) base.opt("kind");
    }

    /** Whether the calendar content shows up in the calendar UI.
    */
    public Boolean getSelected() {
        return (Boolean) base.opt("selected");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}