package com.temboo.outputs.Google.Calendar;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Google.Calendar.GoogleAttendees;
import com.temboo.outputs.Google.Calendar.GoogleCreator;
import com.temboo.outputs.Google.Calendar.GoogleEnd;
import com.temboo.outputs.Google.Calendar.GoogleOrganizer;
import com.temboo.outputs.Google.Calendar.GoogleReminders;
import com.temboo.outputs.Google.Calendar.GoogleStart;

/**  A single event on a calendar containing information such as the title of event, start and end times, and attendees.
  
*/
public class GoogleEvent {
    protected JSONObject base;
    
    public GoogleEvent(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** The attendees of the event.
    */
    public GoogleAttendees[] getAttendees() {
        JSONArray list = (JSONArray) base.opt("attendees");
        GoogleAttendees[] resultArray = new GoogleAttendees[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new GoogleAttendees(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** Creation time of the event (as a RFC 3339 timestamp).
    */
    public String getCreated() {
        return (String) base.opt("created");
    }

    /** The creator of the event.
    */
    public GoogleCreator getCreator() {
        return new GoogleCreator(base.opt("creator"));
    }

    /** Description of the event.
    */
    public String getDescription() {
        return (String) base.opt("description");
    }

    /** The (exclusive) end time of the event. For a recurring event, this is the end time of the first instance.
    */
    public GoogleEnd getEnd() {
        return new GoogleEnd(base.opt("end"));
    }

    /** ETag of the resource.
    */
    public String getEtag() {
        return (String) base.opt("etag");
    }

    /** An absolute link to this event in the Google Calendar Web UI.
    */
    public String getHtmlLink() {
        return (String) base.opt("htmlLink");
    }

    /** Event ID in the iCalendar format.
    */
    public String getICalUID() {
        return (String) base.opt("iCalUID");
    }

    /** Identifier of the event.
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** Type of the resource ("calendar#event").
    */
    public String getKind() {
        return (String) base.opt("kind");
    }

    /** Geographic location of the event as free-form text.
    */
    public String getLocation() {
        return (String) base.opt("location");
    }

    /** Whether the organizer corresponds to the calendar on which this copy of the event appears
    */
    public GoogleOrganizer getOrganizer() {
        return new GoogleOrganizer(base.opt("organizer"));
    }

    /** List of RRULE, EXRULE, RDATE and EXDATE lines for a recurring event. This field is omitted for single events or instances of recurring events.
    */
    public String[] getRecurrence() {
        JSONArray list = (JSONArray) base.opt("recurrence");
        String[] resultArray = new String[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = (String) list.get(i);
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** If the event doesn't use the default reminders, this lists the reminders specific to the event, or, if not set, indicates that no reminders are set for this event.
    */
    public GoogleReminders getReminders() {
        return new GoogleReminders(base.opt("reminders"));
    }

    /** Sequence number as per iCalendar.
    */
    public Number getSequence() {
        return (Number) base.opt("sequence");
    }

    /** The (inclusive) start time of the event. For a recurring event, this is the start time of the first instance.
    */
    public GoogleStart getStart() {
        return new GoogleStart(base.opt("start"));
    }

    /** Status of the event: "confirmed" - The event is confirmed. This is the default status, "tentative" - The event is tentatively confirmed, "cancelled" - The event is cancelled.
    */
    public String getStatus() {
        return (String) base.opt("status");
    }

    /** Title of the event.
    */
    public String getSummary() {
        return (String) base.opt("summary");
    }

    /** Last modification time of the event (as a RFC 3339 timestamp).
    */
    public String getUpdated() {
        return (String) base.opt("updated");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}