package com.temboo.outputs.Google.Calendar;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Google.Calendar.GoogleDefaultReminders;
import com.temboo.outputs.Google.Calendar.GoogleEvent;

/**  A listing of Google Calendar Events

*/
public class GoogleEventList {
    protected JSONObject base;
    
    public GoogleEventList(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** The user's access role for this calendar: "none" - The user has no access, "freeBusyReader" - The user has read access to free/busy information, "reader" - The user has read access to the calendar. Private events will appear to users with reader access, but event details will be hidden, "writer" - The user has read and write access to the calendar. Private events will appear to users with writer access, and event details will be visible, "owner" - The user has ownership of the calendar. This role has all of the permissions of the writer role with the additional ability to see and manipulate ACLs.
    */
    public String getAccessRole() {
        return (String) base.opt("accessRole");
    }

    /** 
    */
    public GoogleDefaultReminders[] getDefaultReminders() {
        JSONArray list = (JSONArray) base.opt("defaultReminders");
        GoogleDefaultReminders[] resultArray = new GoogleDefaultReminders[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new GoogleDefaultReminders(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** Description of the calendar.
    */
    public String getDescription() {
        return (String) base.opt("description");
    }

    /** ETag of the collection.
    */
    public String getEtag() {
        return (String) base.opt("etag");
    }

    /** A list of Google Calendar Events.
    */
    public GoogleEvent[] getEvents() {
        JSONArray list = (JSONArray) base.opt("items");
        GoogleEvent[] resultArray = new GoogleEvent[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new GoogleEvent(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** Type of the collection ("calendar#events").
    */
    public String getKind() {
        return (String) base.opt("kind");
    }

    /** Title of the calendar
    */
    public String getSummary() {
        return (String) base.opt("summary");
    }

    /** The time zone of the calendar.
    */
    public String getTimeZone() {
        return (String) base.opt("timeZone");
    }

    /** Last modification time of the calendar (as a RFC 3339 timestamp)
    */
    public String getUpdated() {
        return (String) base.opt("updated");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}