package com.temboo.outputs.Google.Drive;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;

/**  An object representing a change for a Google Drive resource

*/
public class GoogleChange {
    protected JSONObject base;
    
    public GoogleChange(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** Whether the file has been deleted
    */
    public Boolean getDeleted() {
        return (Boolean) base.opt("deleted");
    }

    /** The ID of the file associated with this change
    */
    public String getFileId() {
        return (String) base.opt("fileId");
    }

    /** The ID of the change
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** This is always drive#change
    */
    public String getKind() {
        return (String) base.opt("kind");
    }

    /** A link back to this change
    */
    public String getSelfLink() {
        return (String) base.opt("selfLink");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}