package com.temboo.outputs.Google.Drive;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Google.Drive.GoogleAuthor;
import com.temboo.outputs.Google.Drive.GoogleReply;

/**  An object representing a comment on a file

*/
public class GoogleComment {
    protected JSONObject base;
    
    public GoogleComment(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** Get the user who wronte this comment
    */
    public GoogleAuthor getAuthor() {
        return new GoogleAuthor(base.opt("author"));
    }

    /** The ID of the comment
    */
    public String getCommentId() {
        return (String) base.opt("commentId");
    }

    /** The plain text content used to create this comment
    */
    public String getContent() {
        return (String) base.opt("content");
    }

    /** The date when this comment was first created (formatted RFC 3339 timestamp)
    */
    public String getCreatedDate() {
        return (String) base.opt("createdDate");
    }

    /** Whether this comment has been deleted
    */
    public Boolean getDeleted() {
        return (Boolean) base.opt("deleted");
    }

    /** The file which this comment is addressing
    */
    public String getFileId() {
        return (String) base.opt("fileId");
    }

    /** The title of the file which this comment is addressing
    */
    public String getFileTitle() {
        return (String) base.opt("fileTitle");
    }

    /** HTML formatted content for this comment
    */
    public String getHtmlContent() {
        return (String) base.opt("htmlContent");
    }

    /** This is always drive#comment
    */
    public String getKind() {
        return (String) base.opt("kind");
    }

    /** The date when this comment or any of its replies were last modified (formatted RFC 3339 timestamp)
    */
    public String getModifiedDate() {
        return (String) base.opt("modifiedDate");
    }

    /** Get replies for this comment
    */
    public GoogleReply[] getReplies() {
        JSONArray list = (JSONArray) base.opt("replies");
        GoogleReply[] resultArray = new GoogleReply[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new GoogleReply(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** The status of this comment (open or resolved)
    */
    public String getStatus() {
        return (String) base.opt("status");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}