package com.temboo.outputs.Google.Drive;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;

/**  Links for exporting Google Docs to specific formats

*/
public class GoogleExportLinks {
    protected JSONObject base;
    
    public GoogleExportLinks(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** A link to the file in pdf format
    */
    public String getPdfLink() {
        return (String) base.opt("application/pdf");
    }

    /** A link to the file in rtf format
    */
    public String getRtfLink() {
        return (String) base.opt("application/rtf");
    }

    /** A link to the file in odt format
    */
    public String getOdtLink() {
        return (String) base.opt("application/vnd.oasis.opendocument.text");
    }

    /** A link to the file in xlsx format
    */
    public String getXlsxLink() {
        return (String) base.opt("application/vnd.openxmlformats-officedocument.spreadsheetml.sheet");
    }

    /** A link to the file in docx format
    */
    public String getDocxLink() {
        return (String) base.opt("application/vnd.openxmlformats-officedocument.wordprocessingml.document");
    }

    /** A link to the file in ods format
    */
    public String getOdsLink() {
        return (String) base.opt("application/x-vnd.oasis.opendocument.spreadsheet");
    }

    /** A link to the file in html format
    */
    public String getHtmlLink() {
        return (String) base.opt("text/html");
    }

    /** A link to the file in txt format
    */
    public String getTxtLink() {
        return (String) base.opt("text/plain");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}