package com.temboo.outputs.Google.Drive;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Google.Drive.GoogleExportLinks;
import com.temboo.outputs.Google.Drive.GoogleLabels;
import com.temboo.outputs.Google.Drive.GoogleParent;
import com.temboo.outputs.Google.Drive.GoogleUserPermission;

/**  A complete Google Drive file resource

*/
public class GoogleFile {
    protected JSONObject base;
    
    public GoogleFile(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** A link for opening the file in using a relevant Google editor or viewer
    */
    public String getAlternateLink() {
        return (String) base.opt("alternateLink");
    }

    /** Create time for this file (formatted ISO8601 timestamp)
    */
    public String getCreatedDate() {
        return (String) base.opt("createdDate");
    }

    /** Whether the file can be edited by the current user
    */
    public Boolean getEditable() {
        return (Boolean) base.opt("editable");
    }

    /** A link for embedding the file
    */
    public String getEmbedLink() {
        return (String) base.opt("embedLink");
    }

    /** ETag of the file
    */
    public String getEtag() {
        return (String) base.opt("etag");
    }

    /** A Link for exporting Google Docs to specific formats
    */
    public GoogleExportLinks getExportLinks() {
        return new GoogleExportLinks(base.opt("exportLinks"));
    }

    /** A link to the file's icon
    */
    public String getIconLink() {
        return (String) base.opt("iconLink");
    }

    /** The ID of the file
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** The type of file (this is always drive#file)
    */
    public String getKind() {
        return (String) base.opt("kind");
    }

    public GoogleLabels getLabels() {
        return new GoogleLabels(base.opt("labels"));
    }

    /** Name of the last user to modify this file. This will only be populated if a user has edited this file
    */
    public String getLastModifyingUserName() {
        return (String) base.opt("lastModifyingUserName");
    }

    /** Last time this file was viewed by the user (formatted RFC 3339 timestamp)
    */
    public String getLastViewedByMeDate() {
        return (String) base.opt("lastViewedByMeDate");
    }

    /** The mimetype of the file
    */
    public String getMimeType() {
        return (String) base.opt("mimeType");
    }

    /** Last time this file was modified by the user (formatted RFC 3339 timestamp)
    */
    public String getModifiedByMeDate() {
        return (String) base.opt("modifiedByMeDate");
    }

    /** Last time this file was modified by anyone (formatted RFC 3339 timestamp)
    */
    public String getModifiedDate() {
        return (String) base.opt("modifiedDate");
    }

    /** Name(s) of the owner(s) of this file
    */
    public String[] getOwnerNames() {
        JSONArray list = (JSONArray) base.opt("ownerNames");
        String[] resultArray = new String[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = (String) list.get(i);
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** A parent folder which contain this file
    */
    public GoogleParent[] getParents() {
        JSONArray list = (JSONArray) base.opt("parents");
        GoogleParent[] resultArray = new GoogleParent[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new GoogleParent(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** The number of quota bytes used by this file
    */
    public String getQuotaBytesUsed() {
        return (String) base.opt("quotaBytesUsed");
    }

    /** A link back to this file
    */
    public String getSelfLink() {
        return (String) base.opt("selfLink");
    }

    /** Whether or not this file is shared
    */
    public Boolean getShared() {
        return (Boolean) base.opt("shared");
    }

    /** Time at which this file was shared with the user (formatted RFC 3339 timestamp)
    */
    public String getSharedWithMeDate() {
        return (String) base.opt("sharedWithMeDate");
    }

    /** A link to the file's thumbnail
    */
    public String getThumbnailLink() {
        return (String) base.opt("thumbnailLink");
    }

    /** The title of the this file
    */
    public String getTitle() {
        return (String) base.opt("title");
    }

    /** The permissions for the authenticated user on this file.
    */
    public GoogleUserPermission getUserPermission() {
        return new GoogleUserPermission(base.opt("userPermission"));
    }

    /** Whether writers can share the document with other users
    */
    public Boolean getWritersCanShare() {
        return (Boolean) base.opt("writersCanShare");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}