package com.temboo.outputs.Google.Drive;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Google.Drive.GooglePermission;

/**  A list of permission for a file

*/
public class GooglePermissionList {
    protected JSONObject base;
    
    public GooglePermissionList(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** The ETag of the list
    */
    public String getEtag() {
        return (String) base.opt("etag");
    }

    /** A Google Drive permission resource
    */
    public GooglePermission[] getPermissions() {
        JSONArray list = (JSONArray) base.opt("items");
        GooglePermission[] resultArray = new GooglePermission[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new GooglePermission(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** This is always drive#permissionList
    */
    public String getKind() {
        return (String) base.opt("kind");
    }

    /** A link back to this list
    */
    public String getSelfLink() {
        return (String) base.opt("selfLink");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}