package com.temboo.outputs.Google.Drive;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Google.Drive.GoogleAuthor;

/**  An object representing a reply to a comment

*/
public class GoogleReply {
    protected JSONObject base;
    
    public GoogleReply(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** Get the user who wronte this comment
    */
    public GoogleAuthor getAuthor() {
        return new GoogleAuthor(base.opt("author"));
    }

    /** The plain text content used to create this reply
    */
    public String getContent() {
        return (String) base.opt("content");
    }

    /** The date when this reply was first created (formatted RFC 3339 timestamp)
    */
    public String getCreatedDate() {
        return (String) base.opt("createdDate");
    }

    /** Whether this reply has been deleted
    */
    public Boolean getDeleted() {
        return (Boolean) base.opt("deleted");
    }

    /** HTML formatted content for this reply
    */
    public String getHtmlContent() {
        return (String) base.opt("htmlContent");
    }

    /** This is always drive#commentReply
    */
    public String getKind() {
        return (String) base.opt("kind");
    }

    /** The date when this reply was last modified (formatted RFC 3339 timestamp)
    */
    public String getModifiedDate() {
        return (String) base.opt("modifiedDate");
    }

    /** The ID of the reply
    */
    public String getReplyId() {
        return (String) base.opt("replyId");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}