package com.temboo.outputs.Google.Drive;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Google.Drive.GoogleReply;

/**  A list of replies to a specified comment on a file

*/
public class GoogleReplyList {
    protected JSONObject base;
    
    public GoogleReplyList(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** Get a reply to a Google Drive comment
    */
    public GoogleReply[] getReplies() {
        JSONArray list = (JSONArray) base.opt("items");
        GoogleReply[] resultArray = new GoogleReply[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new GoogleReply(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** This is always drive#commentReplyList
    */
    public String getKind() {
        return (String) base.opt("kind");
    }

    /** A link to the next page of replies
    */
    public String getNextLink() {
        return (String) base.opt("nextLink");
    }

    /** The page token for the next page of replies
    */
    public String getNextPageToken() {
        return (String) base.opt("nextPageToken");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}