package com.temboo.outputs.Google.Drive;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Google.Drive.GoogleExportLinks;

/**  An object representing a revision of a file

*/
public class GoogleRevision {
    protected JSONObject base;
    
    public GoogleRevision(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** The ETag of the revision
    */
    public String getEtag() {
        return (String) base.opt("etag");
    }

    /** Get links for exporting Google Docs to specific formats
    */
    public GoogleExportLinks getExportLinks() {
        return new GoogleExportLinks(base.opt("exportLinks"));
    }

    /** The ID of the revision
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** This is always drive#revision
    */
    public String getKind() {
        return (String) base.opt("kind");
    }

    /** Name of the last user to modify this revision
    */
    public String getLastModifyingUserName() {
        return (String) base.opt("lastModifyingUserName");
    }

    /** The MIME type of the revision
    */
    public String getMimeType() {
        return (String) base.opt("mimeType");
    }

    /** Last time this revision was modified (formatted RFC 3339 timestamp)
    */
    public String getModifiedDate() {
        return (String) base.opt("modifiedDate");
    }

    /** Whether this revision is published
    */
    public Boolean getPublished() {
        return (Boolean) base.opt("published");
    }

    /** A link back to this revision
    */
    public String getSelfLink() {
        return (String) base.opt("selfLink");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}