package com.temboo.outputs.Google.Drive;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;

/**  An object containing a permission resource

*/
public class GoogleUserPermission {
    protected JSONObject base;
    
    public GoogleUserPermission(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** The ETag of the permission
    */
    public String getEtag() {
        return (String) base.opt("etag");
    }

    /** The ID of the permission
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** The type of resource (this is always drive#permission)
    */
    public String getKind() {
        return (String) base.opt("kind");
    }

    /** The primary role for this user. Allowed values are: owner, reader, writer
    */
    public String getRole() {
        return (String) base.opt("role");
    }

    /** A link back to this permission
    */
    public String getSelfLink() {
        return (String) base.opt("selfLink");
    }

    /** The account type. Allowed values are: user, group, domain, anyone
    */
    public String getType() {
        return (String) base.opt("type");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}