package com.temboo.outputs.Stripe;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;

/**  This is an object representing your Stripe account. You can retrieve it to see properties on the account like its current e-mail address or if the account is enabled yet to make live charges.

*/
public class StripeAccountDetails {
    protected JSONObject base;
    
    public StripeAccountDetails(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** Whether or not the account can create live charges
    */
    public Boolean getChargeEnabled() {
        return (Boolean) base.opt("charge_enabled");
    }

    /** The currencies this account can submit when creating charges
    */
    public String[] getCurrenciesSupported() {
        JSONArray list = (JSONArray) base.opt("currencies_supported");
        String[] resultArray = new String[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = (String) list.get(i);
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** Whether or not account details have been submitted yet
    */
    public Boolean getDetailsSubmitted() {
        return (Boolean) base.opt("details_submitted");
    }

    /** The primary user's email address
    */
    public String getEmail() {
        return (String) base.opt("email");
    }

    /** A unique identifier for the account
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** Value is "account"
    */
    public String getObject() {
        return (String) base.opt("object");
    }

    /** The text that will appear on credit card statements
    */
    public String getStatementDescriptor() {
        return (String) base.opt("statement_descriptor");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}