package com.temboo.outputs.Stripe;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;

/**  Object describing the card used to make the charge

*/
public class StripeCard {
    protected JSONObject base;
    
    public StripeCard(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** billing address city, if provided when creating card
    */
    public String getAddressCity() {
        return (String) base.opt("address_city");
    }

    /** Billing address country, if provided when creating card
    */
    public String getAddressCountry() {
        return (String) base.opt("address_country");
    }

    /** line 1 of the address
    */
    public String getAddressLine1() {
        return (String) base.opt("address_line1");
    }

    /** If address_line1 was provided, results of the check: pass, fail, or unchecked.
    */
    public String getAddressLine1Check() {
        return (String) base.opt("address_line1_check");
    }

    /** line 2 of the address
    */
    public String getAddressLine2() {
        return (String) base.opt("address_line2");
    }

    /** 
    */
    public String getAddressState() {
        return (String) base.opt("address_state");
    }

    /** zip code
    */
    public String getAddressZip() {
        return (String) base.opt("address_zip");
    }

    /** If address_zip was provided, results of the check: pass, fail, or unchecked.
    */
    public String getAddressZipCheck() {
        return (String) base.opt("address_zip_check");
    }

    /** Two-letter ISO code representing the country of the card (as accurately as we can determine it). You could use this attribute to get a sense of the international breakdown of cards you've collected.
    */
    public String getCountry() {
        return (String) base.opt("country");
    }

    /** Card's expiration month.
    */
    public Number getExpMonth() {
        return (Number) base.opt("exp_month");
    }

    /** Card's expiration year. (yyyy).
    */
    public Number getExpYear() {
        return (Number) base.opt("exp_year");
    }

    /** Uniquely identifies this particular card number. You can use this attribute to check whether two customers who've signed up with you are using the same card number, for example.
    */
    public String getFingerprint() {
        return (String) base.opt("fingerprint");
    }

    /** Last 4 digits of the card's number.
    */
    public String getLast4() {
        return (String) base.opt("last4");
    }

    /** Cardholder name
    */
    public String getName() {
        return (String) base.opt("name");
    }

    /** Value is always "card"
    */
    public String getObject() {
        return (String) base.opt("object");
    }

    /** Credit card type (visa/mastercard)
    */
    public String getType() {
        return (String) base.opt("type");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}