package com.temboo.outputs.Stripe;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Stripe.StripeCard;
import com.temboo.outputs.Stripe.StripeDispute;
import com.temboo.outputs.Stripe.StripeFeeDetails;

/**  To charge a credit or a debit card, you create a new charge object. You can retrieve and refund individual charges as well as list all charges. Charges are identified by a unique random ID.

*/
public class StripeCharge {
    protected JSONObject base;
    
    public StripeCharge(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** Amount (in the currency specified)
    */
    public Number getAmount() {
        return (Number) base.opt("amount");
    }

    /** If the charge was created without capturing, this boolean represents whether or not it is still uncaptured or has since been captured.
    */
    public Boolean getCaptured() {
        return (Boolean) base.opt("captured");
    }

    /** Object describing the card used to make the charge
    */
    public StripeCard getCard() {
        return new StripeCard(base.opt("card"));
    }

    /** timestamp
    */
    public Number getCreated() {
        return (Number) base.opt("created");
    }

    /** (3-letter ISO currency code)
    */
    public String getCurrency() {
        return (String) base.opt("currency");
    }

    /** ID of the customer this charge is for if one exists
    */
    public String getCustomer() {
        return (String) base.opt("customer");
    }

    /** description of the Charge
    */
    public String getDescription() {
        return (String) base.opt("description");
    }

    /** Details about the dispute if the charge has been disputed
    */
    public StripeDispute getDispute() {
        return new StripeDispute(base.opt("dispute"));
    }

    /** Disputed amount. Usually the amount of the charge, but can differ (usually because of currency fluctuation or because only part of the order is disputed).
    */
    public Boolean getDisputed() {
        return (Boolean) base.opt("disputed");
    }

    /** Message to user further explaining reason for charge failure if available
    */
    public String getFailureMessage() {
        return (String) base.opt("failure_message");
    }

    /** The fee (in cents) paid for this charge
    */
    public Number getFee() {
        return (Number) base.opt("fee");
    }

    /** The fee details for this charge
    */
    public StripeFeeDetails[] getFeeDetails() {
        JSONArray list = (JSONArray) base.opt("fee_details");
        StripeFeeDetails[] resultArray = new StripeFeeDetails[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new StripeFeeDetails(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** The unique ID of the charge
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** ID of the invoice this charge is for if one exists
    */
    public String getInvoice() {
        return (String) base.opt("invoice");
    }

    /** In livemode, credit card transactions are actually processed.  In testmode, transactions don't go through the credit card network.
    */
    public Boolean getLivemode() {
        return (Boolean) base.opt("livemode");
    }

    /** value is always "charge"
    */
    public String getObject() {
        return (String) base.opt("object");
    }

    /** Whether or not payment was successfully collected for this invoice. An invoice can be paid (most commonly) with a charge or with credit from the customer's account balance.
    */
    public Boolean getPaid() {
        return (Boolean) base.opt("paid");
    }

    /** Whether or not the charge has been fully refunded. If the charge is only partially refunded, this attribute will still be false.
    */
    public Boolean getRefunded() {
        return (Boolean) base.opt("refunded");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}