package com.temboo.outputs.Stripe;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Stripe.StripeCharge;

/**  Returns a list of charges you've previously created. The charges are returned in sorted order, with the most recent charges appearing first.

*/
public class StripeChargeList {
    protected JSONObject base;
    
    public StripeChargeList(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** A limit on the number of objects to be returned. Count can range between 1 and 100 items.
    */
    public Number getCount() {
        return (Number) base.opt("count");
    }

    /** The Stripe Charge object
    */
    public StripeCharge[] getCharges() {
        JSONArray list = (JSONArray) base.opt("data");
        StripeCharge[] resultArray = new StripeCharge[(list != null) ? list.length() : 0];
        if(list != null) {
        	for(int i=0; i<list.length(); i++) {
        	    try {
        	        resultArray[i] = new StripeCharge(list.get(i));
        	    } catch (JSONException e) {}
        	}
        }
        return resultArray;

    }

    /** Value is always "list"
    */
    public String getObject() {
        return (String) base.opt("object");
    }

    /** URL to the REST API call
    */
    public String getUrl() {
        return (String) base.opt("url");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}