package com.temboo.outputs.Stripe;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;

/**  class Coupon coupon /_ // A coupon contains information about a percent-off discount you might want to apply to a customer. Coupons only apply to invoices created for recurring subscriptions and invoice items; they do not apply to one-off charges.


*/
public class StripeCoupon {
    protected JSONObject base;
    
    public StripeCoupon(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** Amount (in the currency specified)
    */
    public Number getAmountOff() {
        return (Number) base.opt("amount_off");
    }

    /** (3-letter ISO currency code) If amount_off has been set, the currency of the amount to take off.
    */
    public String getCurrency() {
        return (String) base.opt("currency");
    }

    /** One of forever, once, and repeating. Describes how long a customer who applies this coupon will get the discount.
    */
    public String getDuration() {
        return (String) base.opt("duration");
    }

    /** If duration is repeating, the number of months the coupon applies. Null if coupon duration is forever or once.
    */
    public Number getDurationInMonths() {
        return (Number) base.opt("duration_in_months");
    }

    /** the ID of coupon
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** In livemode, credit card transactions are actually processed.  In testmode, transactions don't go through the credit card network.
    */
    public Boolean getLivemode() {
        return (Boolean) base.opt("livemode");
    }

    /** Maximum number of times this coupon can be redeemed by a customer before it is no longer valid.
    */
    public Number getMaxRedemptions() {
        return (Number) base.opt("max_redemptions");
    }

    /** Value is always "coupon"
    */
    public String getObject() {
        return (String) base.opt("object");
    }

    /** Percent that will be taken off the subtotal of any invoices for this customer for the duration of the coupon. For example, a coupon with percent_off of 50 will make a $100 invoice $50 instead.
    */
    public Number getPercentOff() {
        return (Number) base.opt("percent_off");
    }

    /** Date after which the coupon can no longer be redeemed
    */
    public Number getRedeemBy() {
        return (Number) base.opt("redeem_by");
    }

    /** Number of times this coupon has been applied to a customer.
    */
    public Number getTimesRedeemed() {
        return (Number) base.opt("times_redeemed");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}