package com.temboo.outputs.Stripe;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Stripe.StripeCard;
import com.temboo.outputs.Stripe.StripeNextRecurringCharge;
import com.temboo.outputs.Stripe.StripeSubscription;

/** 

*/
public class StripeCustomer {
    protected JSONObject base;
    
    public StripeCustomer(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** Current balance, if any, being stored on the customer's account. If negative, the customer has credit to apply to the next invoice. If positive, the customer has an amount owed that will be added to the next invoice. The balance does not refer to any unpaid invoices; it solely takes into account amounts that have yet to be successfully applied to any invoice. This balance is only taken into account for recurring charges.
    */
    public Number getAccountBalance() {
        return (Number) base.opt("account_balance");
    }

    /** Object describing the current card on the customer, if there is one.
    */
    public StripeCard getActiveCard() {
        return new StripeCard(base.opt("active_card"));
    }

    /** timestamp of when Customer was created
    */
    public Number getCreated() {
        return (Number) base.opt("created");
    }

    /** description of the Customer
    */
    public String getDescription() {
        return (String) base.opt("description");
    }

    /** e-mail address of the Customer
    */
    public String getEmail() {
        return (String) base.opt("email");
    }

    /** ID of the Customer
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** In livemode, credit card transactions are actually processed.  In testmode, transactions don't go through the credit card network.
    */
    public Boolean getLivemode() {
        return (Boolean) base.opt("livemode");
    }

    /** 
    */
    public StripeNextRecurringCharge getNextRecurringCharge() {
        return new StripeNextRecurringCharge(base.opt("next_recurring_charge"));
    }

    /** Value is always "customer"
    */
    public String getObject() {
        return (String) base.opt("object");
    }

    /** Object describing the Subscription type
    */
    public StripeSubscription getSubscription() {
        return new StripeSubscription(base.opt("subscription"));
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}