package com.temboo.outputs.Stripe;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;

/**  A dispute occurs when a customer questions your charge with their bank or credit card company. When a customer disputes your charge, you're given the opportunity to respond to the dispute with evidence that shows the charge is legitimate. You can find more information about the dispute process in our

*/
public class StripeDispute {
    protected JSONObject base;
    
    public StripeDispute(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** Disputed amount. Usually the amount of the charge, but can differ (usually because of currency fluctuation or because only part of the order is disputed).
    */
    public Number getAmount() {
        return (Number) base.opt("amount");
    }

    /** ID of the charge that was disputed
    */
    public String getCharge() {
        return (String) base.opt("charge");
    }

    /** Date dispute was opened
    */
    public Number getCreated() {
        return (Number) base.opt("created");
    }

    /** (3-letter ISO currency code)
    */
    public String getCurrency() {
        return (String) base.opt("currency");
    }

    /** Evidence that you have submitted to demonstrate the charge is legitimate (proof of delivery, IP addresses of logins, text of invoices, etc.). 1000 characters maximum.
    */
    public String getEvidence() {
        return (String) base.opt("evidence");
    }

    /** Date by which evidence must be submitted in order to successfully challenge dispute.
    */
    public Number getEvidenceDueBy() {
        return (Number) base.opt("evidence_due_by");
    }

    /** In livemode, credit card transactions are actually processed.  In testmode, transactions don't go through the credit card network.
    */
    public Boolean getLivemode() {
        return (Boolean) base.opt("livemode");
    }

    /** always "dispute"
    */
    public String getObject() {
        return (String) base.opt("object");
    }

    /** Reason given by cardholder for dispute. Possible values are duplicate, fraudulent, subscription_canceled, product_unacceptable, product_not_received, unrecognized, credit_not_processed, general.
    */
    public String getReason() {
        return (String) base.opt("reason");
    }

    /** Current status of dispute. Possible values are won, lost, needs_response, under_review.
    */
    public String getStatus() {
        return (String) base.opt("status");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}