package com.temboo.outputs.Stripe;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;

/**  Detailed breakdown of fees (in cents) paid for this charge  
*/
public class StripeFeeDetails {
    protected JSONObject base;
    
    public StripeFeeDetails(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** Amount (in the currency specified)
    */
    public Number getAmount() {
        return (Number) base.opt("amount");
    }

    /** Amount in cents refunded (can be less than the amount attribute on the charge if a partial refund was issued)
    */
    public Number getAmountRefunded() {
        return (Number) base.opt("amount_refunded");
    }

    /** 
    */
    public String getApplication() {
        return (String) base.opt("application");
    }

    /** (3-letter ISO currency code)
    */
    public String getCurrency() {
        return (String) base.opt("currency");
    }

    /** description of the fee
    */
    public String getDescription() {
        return (String) base.opt("description");
    }

    /** value always "stripe_fee"
    */
    public String getType() {
        return (String) base.opt("type");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}