package com.temboo.outputs.Stripe;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Stripe.StripePeriod;
import com.temboo.outputs.Stripe.StripePlan;

/**  An Invoice Line Item

*/
public class StripeInvoiceItem {
    protected JSONObject base;
    
    public StripeInvoiceItem(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** Amount (in the currency specified)
    */
    public Number getAmount() {
        return (Number) base.opt("amount");
    }

    /** (3-letter ISO currency code)
    */
    public String getCurrency() {
        return (String) base.opt("currency");
    }

    /** ID of the Customer
    */
    public String getCustomer() {
        return (String) base.opt("customer");
    }

    /** timestamp
    */
    public Number getDate() {
        return (Number) base.opt("date");
    }

    /** A text description of the line item
    */
    public String getDescription() {
        return (String) base.opt("description");
    }

    /** The ID of the source of this line item, either an invoice item or a subscription
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** ID of the invoice
    */
    public String getInvoice() {
        return (String) base.opt("invoice");
    }

    /** In livemode, credit card transactions are actually processed.  In testmode, transactions don't go through the credit card network.
    */
    public Boolean getLivemode() {
        return (Boolean) base.opt("livemode");
    }

    /** value is always "invoiceitem"
    */
    public String getObject() {
        return (String) base.opt("object");
    }

    /** The period this InvoiceItme covers
    */
    public StripePeriod getPeriod() {
        return new StripePeriod(base.opt("period"));
    }

    /** The plan of the subscription, if the line item is a subscription
    */
    public StripePlan getPlan() {
        return new StripePlan(base.opt("plan"));
    }

    /** Whether or not this is a proration
    */
    public Boolean getProration() {
        return (Boolean) base.opt("proration");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}