package com.temboo.outputs.Stripe;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;

/**  class Plan plan /_ // A subscription plan contains the pricing information for different products and feature levels on your site. For example, you might have a $10/month plan for basic features and a different $20/month plan for premium features.


*/
public class StripePlan {
    protected JSONObject base;
    
    public StripePlan(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** The amount in cents to be charged on the interval specified
    */
    public Number getAmount() {
        return (Number) base.opt("amount");
    }

    /** (3-letter ISO currency code) Currency in which subscription will be charged
    */
    public String getCurrency() {
        return (String) base.opt("currency");
    }

    /** the ID of the Plan
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** One of month or year. The frequency with which a subscription should be billed.
    */
    public String getInterval() {
        return (String) base.opt("interval");
    }

    /** The number of the unit specified in the interval parameter. For example, you could specify an interval_count of 3 and an interval of 'month' for quarterly billing (every 3 months).
    */
    public Number getIntervalCount() {
        return (Number) base.opt("interval_count");
    }

    /** In livemode, credit card transactions are actually processed.  In testmode, transactions don't go through the credit card network.
    */
    public Boolean getLivemode() {
        return (Boolean) base.opt("livemode");
    }

    /** Display name of the plan
    */
    public String getName() {
        return (String) base.opt("name");
    }

    /** Value is always "plan"
    */
    public String getObject() {
        return (String) base.opt("object");
    }

    /** Number of trial period days granted when subscribing a customer to this plan. Null if the plan has no trial period
    */
    public Number getTrialPeriodDays() {
        return (Number) base.opt("trial_period_days");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}