package com.temboo.outputs.Stripe;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Stripe.StripePeriod;
import com.temboo.outputs.Stripe.StripePlan;

/**  Subscriptions allow you to charge a customer's card on a recurring basis. A subscription ties a customer to a particular plan you've created.

*/
public class StripeSubscription {
    protected JSONObject base;
    
    public StripeSubscription(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** Amount (in the currency specified)
    */
    public Number getAmount() {
        return (Number) base.opt("amount");
    }

    /** If the subscription has been canceled with the at_period_end flag set to true, cancel_at_period_end on the subscription will be true. You can use this attribute to determine whether a subscription that has a status of active is scheduled to be canceled at the end of the current period.
    */
    public Boolean getCancelAtPeriodEnd() {
        return (Boolean) base.opt("cancel_at_period_end");
    }

    /** If the subscription has been canceled, the date of that cancellation. If the subscription was canceled with cancel_at_period_end, canceled_at will still reflect the date of the initial cancellation request, not the end of the subscription period when the subscription is automatically moved to a canceled state.
    */
    public Number getCanceledAt() {
        return (Number) base.opt("canceled_at");
    }

    /** (3-letter ISO currency code)
    */
    public String getCurrency() {
        return (String) base.opt("currency");
    }

    /** End of the current period that the subscription has been invoiced for. At the end of this period, a new invoice will be created.
    */
    public Number getCurrentPeriodEnd() {
        return (Number) base.opt("current_period_end");
    }

    /** Start of the current period that the subscription has been invoiced for
    */
    public Number getCurrentPeriodStart() {
        return (Number) base.opt("current_period_start");
    }

    /** Object describing the customer
    */
    public String getCustomer() {
        return (String) base.opt("customer");
    }

    /** description of the Subscription
    */
    public String getDescription() {
        return (String) base.opt("description");
    }

    /** If the subscription has ended (either because it was canceled or because the customer was switched to a subscription to a new plan), the date the subscription ended
    */
    public Number getEndedAt() {
        return (Number) base.opt("ended_at");
    }

    /** ID of the subscription
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** Value always "subscription"
    */
    public String getObject() {
        return (String) base.opt("object");
    }

    /** The period this subscription covers
    */
    public StripePeriod getPeriod() {
        return new StripePeriod(base.opt("period"));
    }

    /** Object describing the plan the customer is subscribed to
    */
    public StripePlan getPlan() {
        return new StripePlan(base.opt("plan"));
    }

    /** Whether or not this is a proration
    */
    public Boolean getProration() {
        return (Boolean) base.opt("proration");
    }

    /** number of subscriptions
    */
    public Number getQuantity() {
        return (Number) base.opt("quantity");
    }

    /** timestamp.  Date the subscription started
    */
    public Number getStart() {
        return (Number) base.opt("start");
    }

    /** Possible values are trialing, active, past_due, canceled, or unpaid. A subscription still in its trial period is trialing and moves to active when the trial period is over. When payment to renew the subscription fails, the subscription becomes past_due. After Stripe has exhausted all payment retry attempts, the subscription ends up with a status of either canceled or unpaid depending on your retry settings. Note that when a subscription has a status of unpaid, any future invoices will not be attempted until the customer's card details are updated.
    */
    public String getStatus() {
        return (String) base.opt("status");
    }

    /** If the subscription has a trial, the end of that trial.
    */
    public Number getTrialEnd() {
        return (Number) base.opt("trial_end");
    }

    /** If the subscription has a trial, the beginning of that trial.
    */
    public Number getTrialStart() {
        return (Number) base.opt("trial_start");
    }

    /** the Type of the object
    */
    public String getType() {
        return (String) base.opt("type");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}