package com.temboo.outputs.Stripe;

import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.temboo.outputs.Stripe.StripeCard;

/**   Often you want to be able to charge credit cards without having to hold sensitive card information on your own servers. Stripe.js makes this easy in the browser, but you can use the same technique in other environments with our card token API. Card tokens can be created with your publishable API key, which can safely be embedded in downloadable applications like iPhone and Android apps. You can then use a token anywhere in our API that a card is accepted. Note that tokens are not meant to be stored or used more than once -- to store payment details for use later, you should create a Customer object.

*/
public class StripeToken {
    protected JSONObject base;
    
    public StripeToken(Object base) {
    	if (base instanceof JSONObject) {
            this.base = (JSONObject) base;
        } else if (base instanceof JSONArray) {
            if (((JSONArray)base).length()==0) {
                this.base=new JSONObject();
            } else {
                throw new ClassCastException("Expecting JSONObject but got non-empty JSONArray");
            }
        }
    }

    /** Amount (in the currency specified)
    */
    public Number getAmount() {
        return (Number) base.opt("amount");
    }

    /** Object describing the card used to make the charge
    */
    public StripeCard getCard() {
        return new StripeCard(base.opt("card"));
    }

    /** Object describing the card used to make the charge
    */
    public Number getCreated() {
        return (Number) base.opt("created");
    }

    /** (3-letter ISO currency code)
    */
    public String getCurrency() {
        return (String) base.opt("currency");
    }

    /** ID of the Token
    */
    public String getId() {
        return (String) base.opt("id");
    }

    /** In livemode, credit card transactions are actually processed.  In testmode, transactions don't go through the credit card network.
    */
    public Boolean getLivemode() {
        return (Boolean) base.opt("livemode");
    }

    /** Value is always "token"
    */
    public String getObject() {
        return (String) base.opt("object");
    }

    /** Whether or not this token has already been used (tokens can be used only once)
    */
    public Boolean getUsed() {
        return (Boolean) base.opt("used");
    }
    
    /* Internal utility method; retrieve the base JSON object for this element of the response data.
    */
    public JSONObject getBase() {
        return base;
    }
	/* Internal utility method; retrieve a sub-object from a JSON object/array; returns an empty object if key is not present
	*/
	protected JSONObject getJSONObject(Object json, String key) {
		JSONObject toReturn = null;

		try {
			if(json != null && (json instanceof JSONObject))
				toReturn = ((JSONObject) json).optJSONObject(key);					
		} catch(Exception e) {
		}
		if(toReturn == null)
			toReturn = new JSONObject();
		
		return toReturn;
	}
}