package com.temboo.Library.EnviroFacts.Toxins;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
FacilitiesSearchByZip

Retrieves a list of EPA-regulated facilities in the Toxins Release Inventory (TRI) database within a given area code.
*/
public class FacilitiesSearchByZip extends Choreography {

	/**
	Create a new instance of the FacilitiesSearchByZip Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public FacilitiesSearchByZip(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/EnviroFacts/Toxins/FacilitiesSearchByZip"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return FacilitiesSearchByZipInputSet
	*/
	public FacilitiesSearchByZipInputSet newInputSet() {
		return new FacilitiesSearchByZipInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public FacilitiesSearchByZipResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new FacilitiesSearchByZipResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the FacilitiesSearchByZip
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class FacilitiesSearchByZipInputSet extends InputSet {
		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) Specify the desired response format. Valid formats are: xml (the default) and csv.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the RowEnd input for this Choreo. 

		@param Integer - (optional, integer) Number 1 or greater indicates the ending row number of the results displayed. Default is 4999 when RowStart is 0. Up to 5000 entries are returned in the output.
		*/
		public void set_RowEnd(Integer value) {
			this.setInput("RowEnd", value);
		}

		/** 
		Set the value of the RowEnd input for this Choreo as a String. 

		@param String - (optional, integer) Number 1 or greater indicates the ending row number of the results displayed. Default is 4999 when RowStart is 0. Up to 5000 entries are returned in the output.
		*/
		public void set_RowEnd(String value) {
			this.setInput("RowEnd", value);	
		}

		/** 
		Set the value of the RowStart input for this Choreo. 

		@param Integer - (optional, integer) Indicates the starting row number of the results displayed. Default is 0.
		*/
		public void set_RowStart(Integer value) {
			this.setInput("RowStart", value);
		}

		/** 
		Set the value of the RowStart input for this Choreo as a String. 

		@param String - (optional, integer) Indicates the starting row number of the results displayed. Default is 0.
		*/
		public void set_RowStart(String value) {
			this.setInput("RowStart", value);	
		}

		/** 
		Set the value of the Zip input for this Choreo. 

		@param String - (required, string) Zip code to be searched.
		*/
		public void set_Zip(String value) {
			this.setInput("Zip", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the FacilitiesSearchByZip Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class FacilitiesSearchByZipResultSet extends ResultSet {
		public FacilitiesSearchByZipResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from EnviroFacts.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
